@@ -1,5 +1,5 @@
-# Copyright (c) 2022 PaddlePaddle Authors. All Rights Reserved.
-# Copyright 2022 The HuggingFace Team. All rights reserved.
+# Copyright (c) 2023 PaddlePaddle Authors. All Rights Reserved.
+# Copyright 2023 The HuggingFace Team. All rights reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,8 +16,8 @@
 import platform
 from argparse import ArgumentParser
 
-from .. import __version__ as version
 from ..utils import is_paddle_available, is_paddlenlp_available
+from ..version import VERSION as version
 from . import BasePPDiffusersCLICommand
 
 
@@ -57,7 +57,9 @@ class EnvironmentCommand(BasePPDiffusersCLICommand):
             "Using distributed or parallel set-up in script?": "<fill in>",
         }
 
-        print("\nCopy-and-paste the text below in your GitHub issue and FILL OUT the two last points.\n")
+        print(
+            "\nCopy-and-paste the text below in your GitHub issue and FILL OUT the two last points.\n"
+        )
         print(self.format_dict(info))
 
         return info
