@@ -36,7 +36,12 @@ class Upsample1D(nn.Layer):
             out_channels:
     """
 
-    def __init__(self, channels, use_conv=False, use_conv_transpose=False, out_channels=None, name="conv"):
+    def __init__(self,
+                 channels,
+                 use_conv=False,
+                 use_conv_transpose=False,
+                 out_channels=None,
+                 name="conv"):
         super().__init__()
         self.channels = channels
         self.out_channels = out_channels or channels
@@ -48,7 +53,8 @@ class Upsample1D(nn.Layer):
         if use_conv_transpose:
             self.conv = nn.Conv1DTranspose(channels, self.out_channels, 4, 2, 1)
         elif use_conv:
-            self.conv = nn.Conv1D(self.channels, self.out_channels, 3, padding=1)
+            self.conv = nn.Conv1D(
+                self.channels, self.out_channels, 3, padding=1)
 
     def forward(self, x):
         assert x.shape[1] == self.channels
@@ -74,7 +80,12 @@ class Downsample1D(nn.Layer):
         padding:
     """
 
-    def __init__(self, channels, use_conv=False, out_channels=None, padding=1, name="conv"):
+    def __init__(self,
+                 channels,
+                 use_conv=False,
+                 out_channels=None,
+                 padding=1,
+                 name="conv"):
         super().__init__()
         self.channels = channels
         self.out_channels = out_channels or channels
@@ -84,7 +95,12 @@ class Downsample1D(nn.Layer):
         self.name = name
 
         if use_conv:
-            self.conv = nn.Conv1D(self.channels, self.out_channels, 3, stride=stride, padding=padding)
+            self.conv = nn.Conv1D(
+                self.channels,
+                self.out_channels,
+                3,
+                stride=stride,
+                padding=padding)
         else:
             assert self.channels == self.out_channels
             self.conv = nn.AvgPool1D(kernel_size=stride, stride=stride)
@@ -105,7 +121,12 @@ class Upsample2D(nn.Layer):
         out_channels:
     """
 
-    def __init__(self, channels, use_conv=False, use_conv_transpose=False, out_channels=None, name="conv"):
+    def __init__(self,
+                 channels,
+                 use_conv=False,
+                 use_conv_transpose=False,
+                 out_channels=None,
+                 name="conv"):
         super().__init__()
         self.channels = channels
         self.out_channels = out_channels or channels
@@ -141,9 +162,11 @@ class Upsample2D(nn.Layer):
         # if `output_size` is passed we force the interpolation output
         # size and do not make use of `scale_factor=2`
         if output_size is None:
-            hidden_states = F.interpolate(hidden_states, scale_factor=2.0, mode="nearest")
+            hidden_states = F.interpolate(
+                hidden_states, scale_factor=2.0, mode="nearest")
         else:
-            hidden_states = F.interpolate(hidden_states, size=output_size, mode="nearest")
+            hidden_states = F.interpolate(
+                hidden_states, size=output_size, mode="nearest")
 
         # If the input is bfloat16, we cast back to bfloat16
         if dtype == paddle.bfloat16:
@@ -170,7 +193,12 @@ class Downsample2D(nn.Layer):
         padding:
     """
 
-    def __init__(self, channels, use_conv=False, out_channels=None, padding=1, name="conv"):
+    def __init__(self,
+                 channels,
+                 use_conv=False,
+                 out_channels=None,
+                 padding=1,
+                 name="conv"):
         super().__init__()
         self.channels = channels
         self.out_channels = out_channels or channels
@@ -180,7 +208,12 @@ class Downsample2D(nn.Layer):
         self.name = name
 
         if use_conv:
-            conv = nn.Conv2D(self.channels, self.out_channels, 3, stride=stride, padding=padding)
+            conv = nn.Conv2D(
+                self.channels,
+                self.out_channels,
+                3,
+                stride=stride,
+                padding=padding)
         else:
             assert self.channels == self.out_channels
             conv = nn.AvgPool2D(kernel_size=stride, stride=stride)
@@ -207,16 +240,26 @@ class Downsample2D(nn.Layer):
 
 
 class FirUpsample2D(nn.Layer):
-    def __init__(self, channels=None, out_channels=None, use_conv=False, fir_kernel=(1, 3, 3, 1)):
+    def __init__(self,
+                 channels=None,
+                 out_channels=None,
+                 use_conv=False,
+                 fir_kernel=(1, 3, 3, 1)):
         super().__init__()
         out_channels = out_channels if out_channels else channels
         if use_conv:
-            self.Conv2d_0 = nn.Conv2D(channels, out_channels, kernel_size=3, stride=1, padding=1)
+            self.Conv2d_0 = nn.Conv2D(
+                channels, out_channels, kernel_size=3, stride=1, padding=1)
         self.use_conv = use_conv
         self.fir_kernel = fir_kernel
         self.out_channels = out_channels
 
-    def _upsample_2d(self, hidden_states, weight=None, kernel=None, factor=2, gain=1):
+    def _upsample_2d(self,
+                     hidden_states,
+                     weight=None,
+                     kernel=None,
+                     factor=2,
+                     gain=1):
         """Fused `upsample_2d()` followed by `Conv2d()`.
 
         Padding is performed only once at the beginning, not between the operations. The fused op is considerably more
@@ -262,12 +305,12 @@ class FirUpsample2D(nn.Layer):
             # Determine data dimensions.
             output_shape = (
                 (hidden_states.shape[2] - 1) * factor + convH,
-                (hidden_states.shape[3] - 1) * factor + convW,
-            )
+                (hidden_states.shape[3] - 1) * factor + convW, )
             output_padding = (
-                output_shape[0] - (hidden_states.shape[2] - 1) * stride[0] - convH,
-                output_shape[1] - (hidden_states.shape[3] - 1) * stride[1] - convW,
-            )
+                output_shape[0] -
+                (hidden_states.shape[2] - 1) * stride[0] - convH,
+                output_shape[1] -
+                (hidden_states.shape[3] - 1) * stride[1] - convW, )
             assert output_padding[0] >= 0 and output_padding[1] >= 0
             num_groups = hidden_states.shape[1] // inC
 
@@ -277,46 +320,59 @@ class FirUpsample2D(nn.Layer):
             weight = weight.reshape([num_groups * inC, -1, convH, convW])
 
             inverse_conv = F.conv2d_transpose(
-                hidden_states, weight, stride=stride, output_padding=output_padding, padding=0
-            )
+                hidden_states,
+                weight,
+                stride=stride,
+                output_padding=output_padding,
+                padding=0)
 
             output = upfirdn2d_native(
                 inverse_conv,
                 paddle.to_tensor(kernel),
-                pad=((pad_value + 1) // 2 + factor - 1, pad_value // 2 + 1),
-            )
+                pad=((pad_value + 1) // 2 + factor - 1, pad_value // 2 + 1), )
         else:
             pad_value = kernel.shape[0] - factor
             output = upfirdn2d_native(
                 hidden_states,
                 paddle.to_tensor(kernel),
                 up=factor,
-                pad=((pad_value + 1) // 2 + factor - 1, pad_value // 2),
-            )
+                pad=((pad_value + 1) // 2 + factor - 1, pad_value // 2), )
 
         return output
 
     def forward(self, hidden_states):
         if self.use_conv:
-            height = self._upsample_2d(hidden_states, self.Conv2d_0.weight, kernel=self.fir_kernel)
+            height = self._upsample_2d(
+                hidden_states, self.Conv2d_0.weight, kernel=self.fir_kernel)
             height = height + self.Conv2d_0.bias.reshape([1, -1, 1, 1])
         else:
-            height = self._upsample_2d(hidden_states, kernel=self.fir_kernel, factor=2)
+            height = self._upsample_2d(
+                hidden_states, kernel=self.fir_kernel, factor=2)
 
         return height
 
 
 class FirDownsample2D(nn.Layer):
-    def __init__(self, channels=None, out_channels=None, use_conv=False, fir_kernel=(1, 3, 3, 1)):
+    def __init__(self,
+                 channels=None,
+                 out_channels=None,
+                 use_conv=False,
+                 fir_kernel=(1, 3, 3, 1)):
         super().__init__()
         out_channels = out_channels if out_channels else channels
         if use_conv:
-            self.Conv2d_0 = nn.Conv2D(channels, out_channels, kernel_size=3, stride=1, padding=1)
+            self.Conv2d_0 = nn.Conv2D(
+                channels, out_channels, kernel_size=3, stride=1, padding=1)
         self.fir_kernel = fir_kernel
         self.use_conv = use_conv
         self.out_channels = out_channels
 
-    def _downsample_2d(self, hidden_states, weight=None, kernel=None, factor=2, gain=1):
+    def _downsample_2d(self,
+                       hidden_states,
+                       weight=None,
+                       kernel=None,
+                       factor=2,
+                       gain=1):
         """Fused `Conv2d()` followed by `downsample_2d()`.
         Padding is performed only once at the beginning, not between the operations. The fused op is considerably more
         efficient than performing the same calculation using standard TensorFlow ops. It supports gradients of
@@ -356,26 +412,30 @@ class FirDownsample2D(nn.Layer):
             upfirdn_input = upfirdn2d_native(
                 hidden_states,
                 paddle.to_tensor(kernel),
-                pad=((pad_value + 1) // 2, pad_value // 2),
-            )
-            output = F.conv2d(upfirdn_input, weight, stride=stride_value, padding=0)
+                pad=((pad_value + 1) // 2, pad_value // 2), )
+            output = F.conv2d(
+                upfirdn_input, weight, stride=stride_value, padding=0)
         else:
             pad_value = kernel.shape[0] - factor
             output = upfirdn2d_native(
                 hidden_states,
                 paddle.to_tensor(kernel),
                 down=factor,
-                pad=((pad_value + 1) // 2, pad_value // 2),
-            )
+                pad=((pad_value + 1) // 2, pad_value // 2), )
 
         return output
 
     def forward(self, hidden_states):
         if self.use_conv:
-            downsample_input = self._downsample_2d(hidden_states, weight=self.Conv2d_0.weight, kernel=self.fir_kernel)
-            hidden_states = downsample_input + self.Conv2d_0.bias.reshape([1, -1, 1, 1])
+            downsample_input = self._downsample_2d(
+                hidden_states,
+                weight=self.Conv2d_0.weight,
+                kernel=self.fir_kernel)
+            hidden_states = downsample_input + self.Conv2d_0.bias.reshape(
+                [1, -1, 1, 1])
         else:
-            hidden_states = self._downsample_2d(hidden_states, kernel=self.fir_kernel, factor=2)
+            hidden_states = self._downsample_2d(
+                hidden_states, kernel=self.fir_kernel, factor=2)
 
         return hidden_states
 
@@ -387,11 +447,20 @@ class KDownsample2D(nn.Layer):
         self.pad_mode = pad_mode
         kernel_1d = paddle.to_tensor([[1 / 8, 3 / 8, 3 / 8, 1 / 8]])
         self.pad = kernel_1d.shape[1] // 2 - 1
-        self.register_buffer("kernel", paddle.matmul(kernel_1d, kernel_1d, transpose_x=True), persistable=False)
+        self.register_buffer(
+            "kernel",
+            paddle.matmul(
+                kernel_1d, kernel_1d, transpose_x=True),
+            persistable=False)
 
     def forward(self, x):
-        x = F.pad(x, (self.pad,) * 4, self.pad_mode)
-        weight = paddle.zeros([x.shape[1], x.shape[1], self.kernel.shape[0], self.kernel.shape[1]], dtype=x.dtype)
+        x = F.pad(x, (self.pad, ) * 4, self.pad_mode)
+        weight = paddle.zeros(
+            [
+                x.shape[1], x.shape[1], self.kernel.shape[0],
+                self.kernel.shape[1]
+            ],
+            dtype=x.dtype)
         indices = paddle.arange(x.shape[1])
         # TODO verify this method
         weight[indices, indices] = self.kernel.cast(weight.dtype)
@@ -404,11 +473,20 @@ class KUpsample2D(nn.Layer):
         self.pad_mode = pad_mode
         kernel_1d = paddle.to_tensor([[1 / 8, 3 / 8, 3 / 8, 1 / 8]]) * 2
         self.pad = kernel_1d.shape[1] // 2 - 1
-        self.register_buffer("kernel", paddle.matmul(kernel_1d, kernel_1d, transpose_x=True), persistable=False)
+        self.register_buffer(
+            "kernel",
+            paddle.matmul(
+                kernel_1d, kernel_1d, transpose_x=True),
+            persistable=False)
 
     def forward(self, x):
-        x = F.pad(x, ((self.pad + 1) // 2,) * 4, self.pad_mode)
-        weight = paddle.zeros([x.shape[1], x.shape[1], self.kernel.shape[0], self.kernel.shape[1]], dtype=x.dtype)
+        x = F.pad(x, ((self.pad + 1) // 2, ) * 4, self.pad_mode)
+        weight = paddle.zeros(
+            [
+                x.shape[1], x.shape[1], self.kernel.shape[0],
+                self.kernel.shape[1]
+            ],
+            dtype=x.dtype)
         indices = paddle.arange(x.shape[1])
         # TODO verify this method
         weight[indices, indices] = self.kernel.cast(weight.dtype)
@@ -447,28 +525,28 @@ class ResnetBlock2D(nn.Layer):
     """
 
     def __init__(
-        self,
-        *,
-        in_channels,
-        out_channels=None,
-        conv_shortcut=False,
-        dropout=0.0,
-        temb_channels=512,
-        groups=32,
-        groups_out=None,
-        pre_norm=True,
-        eps=1e-6,
-        non_linearity="swish",
-        skip_time_act: bool = False,  # skip_time_act is the same as pre_temb_non_linearity
-        time_embedding_norm="default",  # default, scale_shift, ada_group
-        kernel=None,
-        output_scale_factor=1.0,
-        use_in_shortcut=None,
-        up=False,
-        down=False,
-        conv_shortcut_bias: bool = True,
-        conv_2d_out_channels: Optional[int] = None,
-        pre_temb_non_linearity: bool = False,  # skip_time_act is the same as pre_temb_non_linearity
+            self,
+            *,
+            in_channels,
+            out_channels=None,
+            conv_shortcut=False,
+            dropout=0.0,
+            temb_channels=512,
+            groups=32,
+            groups_out=None,
+            pre_norm=True,
+            eps=1e-6,
+            non_linearity="swish",
+            skip_time_act: bool=False,  # skip_time_act is the same as pre_temb_non_linearity
+            time_embedding_norm="default",  # default, scale_shift, ada_group
+            kernel=None,
+            output_scale_factor=1.0,
+            use_in_shortcut=None,
+            up=False,
+            down=False,
+            conv_shortcut_bias: bool=True,
+            conv_2d_out_channels: Optional[int]=None,
+            pre_temb_non_linearity: bool=False,  # skip_time_act is the same as pre_temb_non_linearity
     ):
         super().__init__()
         self.pre_temb_non_linearity = pre_temb_non_linearity
@@ -488,11 +566,14 @@ class ResnetBlock2D(nn.Layer):
             groups_out = groups
 
         if self.time_embedding_norm == "ada_group":
-            self.norm1 = AdaGroupNorm(temb_channels, in_channels, groups, eps=eps)
+            self.norm1 = AdaGroupNorm(
+                temb_channels, in_channels, groups, eps=eps)
         else:
-            self.norm1 = nn.GroupNorm(num_groups=groups, num_channels=in_channels, epsilon=eps)
+            self.norm1 = nn.GroupNorm(
+                num_groups=groups, num_channels=in_channels, epsilon=eps)
 
-        self.conv1 = nn.Conv2D(in_channels, out_channels, kernel_size=3, stride=1, padding=1)
+        self.conv1 = nn.Conv2D(
+            in_channels, out_channels, kernel_size=3, stride=1, padding=1)
 
         if temb_channels is not None:
             if self.time_embedding_norm == "default":
@@ -502,18 +583,26 @@ class ResnetBlock2D(nn.Layer):
             elif self.time_embedding_norm == "ada_group":
                 self.time_emb_proj = None
             else:
-                raise ValueError(f"unknown time_embedding_norm : {self.time_embedding_norm} ")
+                raise ValueError(
+                    f"unknown time_embedding_norm : {self.time_embedding_norm} ")
         else:
             self.time_emb_proj = None
 
         if self.time_embedding_norm == "ada_group":
-            self.norm2 = AdaGroupNorm(temb_channels, out_channels, groups_out, eps=eps)
+            self.norm2 = AdaGroupNorm(
+                temb_channels, out_channels, groups_out, eps=eps)
         else:
-            self.norm2 = nn.GroupNorm(num_groups=groups_out, num_channels=out_channels, epsilon=eps)
+            self.norm2 = nn.GroupNorm(
+                num_groups=groups_out, num_channels=out_channels, epsilon=eps)
 
         self.dropout = nn.Dropout(dropout)
         conv_2d_out_channels = conv_2d_out_channels or out_channels
-        self.conv2 = nn.Conv2D(out_channels, conv_2d_out_channels, kernel_size=3, stride=1, padding=1)
+        self.conv2 = nn.Conv2D(
+            out_channels,
+            conv_2d_out_channels,
+            kernel_size=3,
+            stride=1,
+            padding=1)
 
         if non_linearity == "swish":
             self.nonlinearity = lambda x: F.silu(x)
@@ -530,7 +619,8 @@ class ResnetBlock2D(nn.Layer):
                 fir_kernel = (1, 3, 3, 1)
                 self.upsample = lambda x: upsample_2d(x, kernel=fir_kernel)
             elif kernel == "sde_vp":
-                self.upsample = partial(F.interpolate, scale_factor=2.0, mode="nearest")
+                self.upsample = partial(
+                    F.interpolate, scale_factor=2.0, mode="nearest")
             else:
                 self.upsample = Upsample2D(in_channels, use_conv=False)
         elif self.down:
@@ -540,15 +630,20 @@ class ResnetBlock2D(nn.Layer):
             elif kernel == "sde_vp":
                 self.downsample = partial(F.avg_pool2d, kernel_size=2, stride=2)
             else:
-                self.downsample = Downsample2D(in_channels, use_conv=False, padding=1, name="op")
+                self.downsample = Downsample2D(
+                    in_channels, use_conv=False, padding=1, name="op")
 
         self.use_in_shortcut = self.in_channels != conv_2d_out_channels if use_in_shortcut is None else use_in_shortcut
 
         self.conv_shortcut = None
         if self.use_in_shortcut:
             self.conv_shortcut = nn.Conv2D(
-                in_channels, conv_2d_out_channels, kernel_size=1, stride=1, padding=0, bias_attr=conv_shortcut_bias
-            )
+                in_channels,
+                conv_2d_out_channels,
+                kernel_size=1,
+                stride=1,
+                padding=0,
+                bias_attr=conv_shortcut_bias)
 
     def forward(self, input_tensor, temb):
         hidden_states = input_tensor
@@ -595,7 +690,8 @@ class ResnetBlock2D(nn.Layer):
             input_tensor = self.conv_shortcut(input_tensor)
 
         # TODO this maybe result -inf, input_tensor's min value -57644  hidden_states's min value -10000
-        output_tensor = (input_tensor + hidden_states) / self.output_scale_factor
+        output_tensor = (
+            input_tensor + hidden_states) / self.output_scale_factor
 
         return output_tensor
 
@@ -625,7 +721,8 @@ class Conv1dBlock(nn.Layer):
     def __init__(self, inp_channels, out_channels, kernel_size, n_groups=8):
         super().__init__()
 
-        self.conv1d = nn.Conv1D(inp_channels, out_channels, kernel_size, padding=kernel_size // 2)
+        self.conv1d = nn.Conv1D(
+            inp_channels, out_channels, kernel_size, padding=kernel_size // 2)
         self.group_norm = nn.GroupNorm(n_groups, out_channels)
         self.mish = nn.Mish()
 
@@ -648,9 +745,8 @@ class ResidualTemporalBlock1D(nn.Layer):
         self.time_emb_act = nn.Mish()
         self.time_emb = nn.Linear(embed_dim, out_channels)
 
-        self.residual_conv = (
-            nn.Conv1D(inp_channels, out_channels, 1) if inp_channels != out_channels else nn.Identity()
-        )
+        self.residual_conv = (nn.Conv1D(inp_channels, out_channels, 1) if
+                              inp_channels != out_channels else nn.Identity())
 
     def forward(self, x, t):
         """
@@ -700,8 +796,7 @@ def upsample_2d(hidden_states, kernel=None, factor=2, gain=1):
         hidden_states,
         kernel,
         up=factor,
-        pad=((pad_value + 1) // 2 + factor - 1, pad_value // 2),
-    )
+        pad=((pad_value + 1) // 2 + factor - 1, pad_value // 2), )
     return output
 
 
@@ -734,7 +829,11 @@ def downsample_2d(hidden_states, kernel=None, factor=2, gain=1):
 
     kernel = kernel * gain
     pad_value = kernel.shape[0] - factor
-    output = upfirdn2d_native(hidden_states, kernel, down=factor, pad=((pad_value + 1) // 2, pad_value // 2))
+    output = upfirdn2d_native(
+        hidden_states,
+        kernel,
+        down=factor,
+        pad=((pad_value + 1) // 2, pad_value // 2))
     return output
 
 
@@ -744,23 +843,25 @@ def dummy_pad(tensor, up_x=0, up_y=0):
             [
                 tensor,
                 paddle.zeros(
-                    [tensor.shape[0], tensor.shape[1], tensor.shape[2], tensor.shape[3], up_x, tensor.shape[5]],
-                    dtype=tensor.dtype,
-                ),
+                    [
+                        tensor.shape[0], tensor.shape[1], tensor.shape[2],
+                        tensor.shape[3], up_x, tensor.shape[5]
+                    ],
+                    dtype=tensor.dtype, ),
             ],
-            axis=4,
-        )
+            axis=4, )
     if up_y > 0:
         tensor = paddle.concat(
             [
                 tensor,
                 paddle.zeros(
-                    [tensor.shape[0], tensor.shape[1], up_y, tensor.shape[3], tensor.shape[4], tensor.shape[5]],
-                    dtype=tensor.dtype,
-                ),
+                    [
+                        tensor.shape[0], tensor.shape[1], up_y, tensor.shape[3],
+                        tensor.shape[4], tensor.shape[5]
+                    ],
+                    dtype=tensor.dtype, ),
             ],
-            axis=2,
-        )
+            axis=2, )
     return tensor
 
 
@@ -785,23 +886,24 @@ def upfirdn2d_native(tensor, kernel, up=1, down=1, pad=(0, 0)):
     # (TODO, junnyu F.pad bug)
     # out = F.pad(out, [0, 0, max(pad_x0, 0), max(pad_x1, 0), max(pad_y0, 0), max(pad_y1, 0)])
     out = out.unsqueeze(0)
-    out = F.pad(out, [max(pad_x0, 0), max(pad_x1, 0), max(pad_y0, 0), max(pad_y1, 0), 0, 0], data_format="NDHWC")
+    out = F.pad(
+        out,
+        [max(pad_x0, 0), max(pad_x1, 0), max(pad_y0, 0), max(pad_y1, 0), 0, 0],
+        data_format="NDHWC")
     out = out.squeeze(0)
 
-    out = out[
-        :,
-        max(-pad_y0, 0) : out.shape[1] - max(-pad_y1, 0),
-        max(-pad_x0, 0) : out.shape[2] - max(-pad_x1, 0),
-        :,
-    ]
+    out = out[:, max(-pad_y0, 0):out.shape[1] - max(-pad_y1, 0), max(
+        -pad_x0, 0):out.shape[2] - max(-pad_x1, 0), :, ]
 
     out = out.transpose([0, 3, 1, 2])
-    out = out.reshape([-1, 1, in_h * up_y + pad_y0 + pad_y1, in_w * up_x + pad_x0 + pad_x1])
+    out = out.reshape(
+        [-1, 1, in_h * up_y + pad_y0 + pad_y1, in_w * up_x + pad_x0 + pad_x1])
     w = paddle.flip(kernel, [0, 1]).reshape([1, 1, kernel_h, kernel_w])
     out = F.conv2d(out, w)
-    out = out.reshape(
-        [-1, minor, in_h * up_y + pad_y0 + pad_y1 - kernel_h + 1, in_w * up_x + pad_x0 + pad_x1 - kernel_w + 1]
-    )
+    out = out.reshape([
+        -1, minor, in_h * up_y + pad_y0 + pad_y1 - kernel_h + 1,
+        in_w * up_x + pad_x0 + pad_x1 - kernel_w + 1
+    ])
     out = out.transpose([0, 2, 3, 1])
     out = out[:, ::down_y, ::down_x, :]
 
@@ -823,28 +925,44 @@ class TemporalConvLayer(nn.Layer):
         self.in_dim = in_dim
         self.out_dim = out_dim
         self.conv1 = nn.Sequential(
-            nn.GroupNorm(num_groups=32, num_channels=in_dim),
+            nn.GroupNorm(
+                num_groups=32, num_channels=in_dim),
             nn.Silu(),
-            nn.Conv3D(in_channels=in_dim, out_channels=out_dim, kernel_size=(3, 1, 1), padding=(1, 0, 0)),
-        )
+            nn.Conv3D(
+                in_channels=in_dim,
+                out_channels=out_dim,
+                kernel_size=(3, 1, 1),
+                padding=(1, 0, 0)), )
         self.conv2 = nn.Sequential(
-            nn.GroupNorm(num_groups=32, num_channels=out_dim),
+            nn.GroupNorm(
+                num_groups=32, num_channels=out_dim),
             nn.Silu(),
             nn.Dropout(p=dropout),
-            nn.Conv3D(in_channels=out_dim, out_channels=in_dim, kernel_size=(3, 1, 1), padding=(1, 0, 0)),
-        )
+            nn.Conv3D(
+                in_channels=out_dim,
+                out_channels=in_dim,
+                kernel_size=(3, 1, 1),
+                padding=(1, 0, 0)), )
         self.conv3 = nn.Sequential(
-            nn.GroupNorm(num_groups=32, num_channels=out_dim),
+            nn.GroupNorm(
+                num_groups=32, num_channels=out_dim),
             nn.Silu(),
             nn.Dropout(p=dropout),
-            nn.Conv3D(in_channels=out_dim, out_channels=in_dim, kernel_size=(3, 1, 1), padding=(1, 0, 0)),
-        )
+            nn.Conv3D(
+                in_channels=out_dim,
+                out_channels=in_dim,
+                kernel_size=(3, 1, 1),
+                padding=(1, 0, 0)), )
         self.conv4 = nn.Sequential(
-            nn.GroupNorm(num_groups=32, num_channels=out_dim),
+            nn.GroupNorm(
+                num_groups=32, num_channels=out_dim),
             nn.Silu(),
             nn.Dropout(p=dropout),
-            nn.Conv3D(in_channels=out_dim, out_channels=in_dim, kernel_size=(3, 1, 1), padding=(1, 0, 0)),
-        )
+            nn.Conv3D(
+                in_channels=out_dim,
+                out_channels=in_dim,
+                kernel_size=(3, 1, 1),
+                padding=(1, 0, 0)), )
         zeros_(self.conv4[-1].weight)
         zeros_(self.conv4[-1].bias)
 
@@ -852,15 +970,14 @@ class TemporalConvLayer(nn.Layer):
         hidden_states = (
             hidden_states[None, :]
             .reshape((-1, num_frames) + tuple(hidden_states.shape[1:]))
-            .transpose(perm=[0, 2, 1, 3, 4])
-        )
+            .transpose(perm=[0, 2, 1, 3, 4]))
         identity = hidden_states
         hidden_states = self.conv1(hidden_states)
         hidden_states = self.conv2(hidden_states)
         hidden_states = self.conv3(hidden_states)
         hidden_states = self.conv4(hidden_states)
         hidden_states = identity + hidden_states
-        hidden_states = hidden_states.transpose(perm=[0, 2, 1, 3, 4]).reshape(
-            (hidden_states.shape[0] * hidden_states.shape[2], -1) + tuple(hidden_states.shape[3:])
-        )
+        hidden_states = hidden_states.transpose(perm=[0, 2, 1, 3, 4]).reshape((
+            hidden_states.shape[0] * hidden_states.shape[2], -1) + tuple(
+                hidden_states.shape[3:]))
         return hidden_states
