@@ -25,19 +25,18 @@ from .resnet import Downsample1D, ResidualTemporalBlock1D, Upsample1D, rearrange
 
 class DownResnetBlock1D(nn.Layer):
     def __init__(
-        self,
-        in_channels,
-        out_channels=None,
-        num_layers=1,
-        conv_shortcut=False,
-        temb_channels=32,
-        groups=32,
-        groups_out=None,
-        non_linearity=None,
-        time_embedding_norm="default",
-        output_scale_factor=1.0,
-        add_downsample=True,
-    ):
+            self,
+            in_channels,
+            out_channels=None,
+            num_layers=1,
+            conv_shortcut=False,
+            temb_channels=32,
+            groups=32,
+            groups_out=None,
+            non_linearity=None,
+            time_embedding_norm="default",
+            output_scale_factor=1.0,
+            add_downsample=True, ):
         super().__init__()
         self.in_channels = in_channels
         out_channels = in_channels if out_channels is None else out_channels
@@ -51,10 +50,15 @@ class DownResnetBlock1D(nn.Layer):
             groups_out = groups
 
         # there will always be at least one resnet
-        resnets = [ResidualTemporalBlock1D(in_channels, out_channels, embed_dim=temb_channels)]
+        resnets = [
+            ResidualTemporalBlock1D(
+                in_channels, out_channels, embed_dim=temb_channels)
+        ]
 
         for _ in range(num_layers):
-            resnets.append(ResidualTemporalBlock1D(out_channels, out_channels, embed_dim=temb_channels))
+            resnets.append(
+                ResidualTemporalBlock1D(
+                    out_channels, out_channels, embed_dim=temb_channels))
 
         self.resnets = nn.LayerList(resnets)
 
@@ -69,7 +73,8 @@ class DownResnetBlock1D(nn.Layer):
 
         self.downsample = None
         if add_downsample:
-            self.downsample = Downsample1D(out_channels, use_conv=True, padding=1)
+            self.downsample = Downsample1D(
+                out_channels, use_conv=True, padding=1)
 
     def forward(self, hidden_states, temb=None):
         output_states = ()
@@ -78,7 +83,7 @@ class DownResnetBlock1D(nn.Layer):
         for resnet in self.resnets[1:]:
             hidden_states = resnet(hidden_states, temb)
 
-        output_states += (hidden_states,)
+        output_states += (hidden_states, )
 
         if self.nonlinearity is not None:
             hidden_states = self.nonlinearity(hidden_states)
@@ -91,18 +96,17 @@ class DownResnetBlock1D(nn.Layer):
 
 class UpResnetBlock1D(nn.Layer):
     def __init__(
-        self,
-        in_channels,
-        out_channels=None,
-        num_layers=1,
-        temb_channels=32,
-        groups=32,
-        groups_out=None,
-        non_linearity=None,
-        time_embedding_norm="default",
-        output_scale_factor=1.0,
-        add_upsample=True,
-    ):
+            self,
+            in_channels,
+            out_channels=None,
+            num_layers=1,
+            temb_channels=32,
+            groups=32,
+            groups_out=None,
+            non_linearity=None,
+            time_embedding_norm="default",
+            output_scale_factor=1.0,
+            add_upsample=True, ):
         super().__init__()
         self.in_channels = in_channels
         out_channels = in_channels if out_channels is None else out_channels
@@ -115,10 +119,15 @@ class UpResnetBlock1D(nn.Layer):
             groups_out = groups
 
         # there will always be at least one resnet
-        resnets = [ResidualTemporalBlock1D(2 * in_channels, out_channels, embed_dim=temb_channels)]
+        resnets = [
+            ResidualTemporalBlock1D(
+                2 * in_channels, out_channels, embed_dim=temb_channels)
+        ]
 
         for _ in range(num_layers):
-            resnets.append(ResidualTemporalBlock1D(out_channels, out_channels, embed_dim=temb_channels))
+            resnets.append(
+                ResidualTemporalBlock1D(
+                    out_channels, out_channels, embed_dim=temb_channels))
 
         self.resnets = nn.LayerList(resnets)
 
@@ -138,7 +147,8 @@ class UpResnetBlock1D(nn.Layer):
     def forward(self, hidden_states, res_hidden_states_tuple=None, temb=None):
         if res_hidden_states_tuple is not None:
             res_hidden_states = res_hidden_states_tuple[-1]
-            hidden_states = paddle.concat((hidden_states, res_hidden_states), axis=1)
+            hidden_states = paddle.concat(
+                (hidden_states, res_hidden_states), axis=1)
 
         hidden_states = self.resnets[0](hidden_states, temb)
         for resnet in self.resnets[1:]:
@@ -160,9 +170,11 @@ class ValueFunctionMidBlock1D(nn.Layer):
         self.out_channels = out_channels
         self.embed_dim = embed_dim
 
-        self.res1 = ResidualTemporalBlock1D(in_channels, in_channels // 2, embed_dim=embed_dim)
+        self.res1 = ResidualTemporalBlock1D(
+            in_channels, in_channels // 2, embed_dim=embed_dim)
         self.down1 = Downsample1D(out_channels // 2, use_conv=True)
-        self.res2 = ResidualTemporalBlock1D(in_channels // 2, in_channels // 4, embed_dim=embed_dim)
+        self.res2 = ResidualTemporalBlock1D(
+            in_channels // 2, in_channels // 4, embed_dim=embed_dim)
         self.down2 = Downsample1D(out_channels // 4, use_conv=True)
 
     def forward(self, x, temb=None):
@@ -175,25 +187,29 @@ class ValueFunctionMidBlock1D(nn.Layer):
 
 class MidResTemporalBlock1D(nn.Layer):
     def __init__(
-        self,
-        in_channels,
-        out_channels,
-        embed_dim,
-        num_layers: int = 1,
-        add_downsample: bool = False,
-        add_upsample: bool = False,
-        non_linearity=None,
-    ):
+            self,
+            in_channels,
+            out_channels,
+            embed_dim,
+            num_layers: int=1,
+            add_downsample: bool=False,
+            add_upsample: bool=False,
+            non_linearity=None, ):
         super().__init__()
         self.in_channels = in_channels
         self.out_channels = out_channels
         self.add_downsample = add_downsample
 
         # there will always be at least one resnet
-        resnets = [ResidualTemporalBlock1D(in_channels, out_channels, embed_dim=embed_dim)]
+        resnets = [
+            ResidualTemporalBlock1D(
+                in_channels, out_channels, embed_dim=embed_dim)
+        ]
 
         for _ in range(num_layers):
-            resnets.append(ResidualTemporalBlock1D(out_channels, out_channels, embed_dim=embed_dim))
+            resnets.append(
+                ResidualTemporalBlock1D(
+                    out_channels, out_channels, embed_dim=embed_dim))
 
         self.resnets = nn.LayerList(resnets)
 
@@ -254,13 +270,11 @@ class OutConv1DBlock(nn.Layer):
 class OutValueFunctionBlock(nn.Layer):
     def __init__(self, fc_dim, embed_dim):
         super().__init__()
-        self.final_block = nn.LayerList(
-            [
-                nn.Linear(fc_dim + embed_dim, fc_dim // 2),
-                nn.Mish(),
-                nn.Linear(fc_dim // 2, 1),
-            ]
-        )
+        self.final_block = nn.LayerList([
+            nn.Linear(fc_dim + embed_dim, fc_dim // 2),
+            nn.Mish(),
+            nn.Linear(fc_dim // 2, 1),
+        ])
 
     def forward(self, hidden_states, temb):
         hidden_states = hidden_states.reshape([hidden_states.shape[0], -1])
@@ -273,7 +287,10 @@ class OutValueFunctionBlock(nn.Layer):
 
 _kernels = {
     "linear": [1 / 8, 3 / 8, 3 / 8, 1 / 8],
-    "cubic": [-0.01171875, -0.03515625, 0.11328125, 0.43359375, 0.43359375, 0.11328125, -0.03515625, -0.01171875],
+    "cubic": [
+        -0.01171875, -0.03515625, 0.11328125, 0.43359375, 0.43359375,
+        0.11328125, -0.03515625, -0.01171875
+    ],
     "lanczos3": [
         0.003689131001010537,
         0.015056144446134567,
@@ -300,10 +317,15 @@ class Downsample1d(nn.Layer):
         self.register_buffer("kernel", kernel_1d)
 
     def forward(self, hidden_states):
-        hidden_states = F.pad(hidden_states, (self.pad,) * 2, self.pad_mode, data_format="NCL")
+        hidden_states = F.pad(hidden_states, (self.pad, ) * 2,
+                              self.pad_mode,
+                              data_format="NCL")
         weight = paddle.zeros(
-            [hidden_states.shape[1], hidden_states.shape[1], self.kernel.shape[0]], dtype=hidden_states.dtype
-        )
+            [
+                hidden_states.shape[1], hidden_states.shape[1],
+                self.kernel.shape[0]
+            ],
+            dtype=hidden_states.dtype)
         indices = paddle.arange(hidden_states.shape[1])
         weight[indices, indices] = self.kernel.cast(weight.dtype)
         return F.conv1d(hidden_states, weight, stride=2)
@@ -318,13 +340,19 @@ class Upsample1d(nn.Layer):
         self.register_buffer("kernel", kernel_1d)
 
     def forward(self, hidden_states, temb=None):
-        hidden_states = F.pad(hidden_states, ((self.pad + 1) // 2,) * 2, self.pad_mode, data_format="NCL")
+        hidden_states = F.pad(hidden_states, ((self.pad + 1) // 2, ) * 2,
+                              self.pad_mode,
+                              data_format="NCL")
         weight = paddle.zeros(
-            [hidden_states.shape[1], hidden_states.shape[1], self.kernel.shape[0]], dtype=hidden_states.dtype
-        )
+            [
+                hidden_states.shape[1], hidden_states.shape[1],
+                self.kernel.shape[0]
+            ],
+            dtype=hidden_states.dtype)
         indices = paddle.arange(hidden_states.shape[1])
         weight[indices, indices] = self.kernel.cast(weight.dtype)
-        return F.conv1d_transpose(hidden_states, weight, stride=2, padding=self.pad * 2 + 1)
+        return F.conv1d_transpose(
+            hidden_states, weight, stride=2, padding=self.pad * 2 + 1)
 
 
 class SelfAttention1d(nn.Layer):
@@ -360,10 +388,12 @@ class SelfAttention1d(nn.Layer):
         return tensor
 
     def set_use_memory_efficient_attention_xformers(
-        self, use_memory_efficient_attention_xformers: bool, attention_op: Optional[str] = None
-    ):
-        if self.head_size > 128 and attention_op == "flash":
-            attention_op = "cutlass"
+            self,
+            use_memory_efficient_attention_xformers: bool,
+            attention_op: Optional[str]=None):
+        # remove this PR: https://github.com/PaddlePaddle/Paddle/pull/56045
+        # if self.head_size > 128 and attention_op == "flash":
+        #     attention_op = "cutlass"
         if use_memory_efficient_attention_xformers:
             if not is_ppxformers_available():
                 raise NotImplementedError(
@@ -372,11 +402,13 @@ class SelfAttention1d(nn.Layer):
             else:
                 try:
                     _ = F.scaled_dot_product_attention_(
-                        paddle.randn((1, 1, 2, 40), dtype=paddle.float16),
-                        paddle.randn((1, 1, 2, 40), dtype=paddle.float16),
-                        paddle.randn((1, 1, 2, 40), dtype=paddle.float16),
-                        attention_op=attention_op,
-                    )
+                        paddle.randn(
+                            (1, 1, 2, 40), dtype=paddle.float16),
+                        paddle.randn(
+                            (1, 1, 2, 40), dtype=paddle.float16),
+                        paddle.randn(
+                            (1, 1, 2, 40), dtype=paddle.float16),
+                        attention_op=attention_op, )
                 except Exception as e:
                     raise e
 
@@ -394,14 +426,14 @@ class SelfAttention1d(nn.Layer):
         value_proj = self.value(hidden_states)
 
         query_proj = self.reshape_heads_to_batch_dim(
-            query_proj, transpose=not self._use_memory_efficient_attention_xformers
-        )
+            query_proj,
+            transpose=not self._use_memory_efficient_attention_xformers)
         key_proj = self.reshape_heads_to_batch_dim(
-            key_proj, transpose=not self._use_memory_efficient_attention_xformers
-        )
+            key_proj,
+            transpose=not self._use_memory_efficient_attention_xformers)
         value_proj = self.reshape_heads_to_batch_dim(
-            value_proj, transpose=not self._use_memory_efficient_attention_xformers
-        )
+            value_proj,
+            transpose=not self._use_memory_efficient_attention_xformers)
 
         if self._use_memory_efficient_attention_xformers:
             hidden_states = F.scaled_dot_product_attention_(
@@ -412,17 +444,19 @@ class SelfAttention1d(nn.Layer):
                 scale=self.scale,
                 dropout_p=0.0,
                 training=self.training,
-                attention_op=self._attention_op,
-            )
+                attention_op=self._attention_op, )
         else:
-            attention_scores = paddle.matmul(query_proj, key_proj, transpose_y=True) * self.scale
-            attention_probs = F.softmax(attention_scores.cast("float32"), axis=-1).cast(attention_scores.dtype)
+            attention_scores = paddle.matmul(
+                query_proj, key_proj, transpose_y=True) * self.scale
+            attention_probs = F.softmax(
+                attention_scores.cast("float32"),
+                axis=-1).cast(attention_scores.dtype)
             hidden_states = paddle.matmul(attention_probs, value_proj)
 
         # reshape hidden_states
         hidden_states = self.reshape_batch_dim_to_heads(
-            hidden_states, transpose=not self._use_memory_efficient_attention_xformers
-        )
+            hidden_states,
+            transpose=not self._use_memory_efficient_attention_xformers)
 
         # compute next hidden_states
         hidden_states = self.proj_attn(hidden_states)
@@ -441,7 +475,8 @@ class ResConvBlock(nn.Layer):
         self.has_conv_skip = in_channels != out_channels
 
         if self.has_conv_skip:
-            self.conv_skip = nn.Conv1D(in_channels, out_channels, 1, bias_attr=False)
+            self.conv_skip = nn.Conv1D(
+                in_channels, out_channels, 1, bias_attr=False)
 
         self.conv_1 = nn.Conv1D(in_channels, mid_channels, 5, padding=2)
         self.group_norm_1 = nn.GroupNorm(1, mid_channels)
@@ -453,7 +488,8 @@ class ResConvBlock(nn.Layer):
             self.gelu_2 = nn.GELU()
 
     def forward(self, hidden_states):
-        residual = self.conv_skip(hidden_states) if self.has_conv_skip else hidden_states
+        residual = self.conv_skip(
+            hidden_states) if self.has_conv_skip else hidden_states
 
         hidden_states = self.conv_1(hidden_states)
         hidden_states = self.group_norm_1(hidden_states)
@@ -535,7 +571,7 @@ class AttnDownBlock1D(nn.Layer):
             hidden_states = resnet(hidden_states)
             hidden_states = attn(hidden_states)
 
-        return hidden_states, (hidden_states,)
+        return hidden_states, (hidden_states, )
 
 
 class DownBlock1D(nn.Layer):
@@ -558,7 +594,7 @@ class DownBlock1D(nn.Layer):
         for resnet in self.resnets:
             hidden_states = resnet(hidden_states)
 
-        return hidden_states, (hidden_states,)
+        return hidden_states, (hidden_states, )
 
 
 class DownBlock1DNoSkip(nn.Layer):
@@ -579,7 +615,7 @@ class DownBlock1DNoSkip(nn.Layer):
         for resnet in self.resnets:
             hidden_states = resnet(hidden_states)
 
-        return hidden_states, (hidden_states,)
+        return hidden_states, (hidden_states, )
 
 
 class AttnUpBlock1D(nn.Layer):
@@ -604,7 +640,8 @@ class AttnUpBlock1D(nn.Layer):
 
     def forward(self, hidden_states, res_hidden_states_tuple, temb=None):
         res_hidden_states = res_hidden_states_tuple[-1]
-        hidden_states = paddle.concat([hidden_states, res_hidden_states], axis=1)
+        hidden_states = paddle.concat(
+            [hidden_states, res_hidden_states], axis=1)
 
         for resnet, attn in zip(self.resnets, self.attentions):
             hidden_states = resnet(hidden_states)
@@ -631,7 +668,8 @@ class UpBlock1D(nn.Layer):
 
     def forward(self, hidden_states, res_hidden_states_tuple, temb=None):
         res_hidden_states = res_hidden_states_tuple[-1]
-        hidden_states = paddle.concat([hidden_states, res_hidden_states], axis=1)
+        hidden_states = paddle.concat(
+            [hidden_states, res_hidden_states], axis=1)
 
         for resnet in self.resnets:
             hidden_states = resnet(hidden_states)
@@ -649,14 +687,16 @@ class UpBlock1DNoSkip(nn.Layer):
         resnets = [
             ResConvBlock(2 * in_channels, mid_channels, mid_channels),
             ResConvBlock(mid_channels, mid_channels, mid_channels),
-            ResConvBlock(mid_channels, mid_channels, out_channels, is_last=True),
+            ResConvBlock(
+                mid_channels, mid_channels, out_channels, is_last=True),
         ]
 
         self.resnets = nn.LayerList(resnets)
 
     def forward(self, hidden_states, res_hidden_states_tuple, temb=None):
         res_hidden_states = res_hidden_states_tuple[-1]
-        hidden_states = paddle.concat([hidden_states, res_hidden_states], axis=1)
+        hidden_states = paddle.concat(
+            [hidden_states, res_hidden_states], axis=1)
 
         for resnet in self.resnets:
             hidden_states = resnet(hidden_states)
@@ -664,59 +704,69 @@ class UpBlock1DNoSkip(nn.Layer):
         return hidden_states
 
 
-def get_down_block(down_block_type, num_layers, in_channels, out_channels, temb_channels, add_downsample):
+def get_down_block(down_block_type, num_layers, in_channels, out_channels,
+                   temb_channels, add_downsample):
     if down_block_type == "DownResnetBlock1D":
         return DownResnetBlock1D(
             in_channels=in_channels,
             num_layers=num_layers,
             out_channels=out_channels,
             temb_channels=temb_channels,
-            add_downsample=add_downsample,
-        )
+            add_downsample=add_downsample, )
     elif down_block_type == "DownBlock1D":
         return DownBlock1D(out_channels=out_channels, in_channels=in_channels)
     elif down_block_type == "AttnDownBlock1D":
-        return AttnDownBlock1D(out_channels=out_channels, in_channels=in_channels)
+        return AttnDownBlock1D(
+            out_channels=out_channels, in_channels=in_channels)
     elif down_block_type == "DownBlock1DNoSkip":
-        return DownBlock1DNoSkip(out_channels=out_channels, in_channels=in_channels)
+        return DownBlock1DNoSkip(
+            out_channels=out_channels, in_channels=in_channels)
     raise ValueError(f"{down_block_type} does not exist.")
 
 
-def get_up_block(up_block_type, num_layers, in_channels, out_channels, temb_channels, add_upsample):
+def get_up_block(up_block_type, num_layers, in_channels, out_channels,
+                 temb_channels, add_upsample):
     if up_block_type == "UpResnetBlock1D":
         return UpResnetBlock1D(
             in_channels=in_channels,
             num_layers=num_layers,
             out_channels=out_channels,
             temb_channels=temb_channels,
-            add_upsample=add_upsample,
-        )
+            add_upsample=add_upsample, )
     elif up_block_type == "UpBlock1D":
         return UpBlock1D(in_channels=in_channels, out_channels=out_channels)
     elif up_block_type == "AttnUpBlock1D":
         return AttnUpBlock1D(in_channels=in_channels, out_channels=out_channels)
     elif up_block_type == "UpBlock1DNoSkip":
-        return UpBlock1DNoSkip(in_channels=in_channels, out_channels=out_channels)
+        return UpBlock1DNoSkip(
+            in_channels=in_channels, out_channels=out_channels)
     raise ValueError(f"{up_block_type} does not exist.")
 
 
-def get_mid_block(mid_block_type, num_layers, in_channels, mid_channels, out_channels, embed_dim, add_downsample):
+def get_mid_block(mid_block_type, num_layers, in_channels, mid_channels,
+                  out_channels, embed_dim, add_downsample):
     if mid_block_type == "MidResTemporalBlock1D":
         return MidResTemporalBlock1D(
             num_layers=num_layers,
             in_channels=in_channels,
             out_channels=out_channels,
             embed_dim=embed_dim,
-            add_downsample=add_downsample,
-        )
+            add_downsample=add_downsample, )
     elif mid_block_type == "ValueFunctionMidBlock1D":
-        return ValueFunctionMidBlock1D(in_channels=in_channels, out_channels=out_channels, embed_dim=embed_dim)
+        return ValueFunctionMidBlock1D(
+            in_channels=in_channels,
+            out_channels=out_channels,
+            embed_dim=embed_dim)
     elif mid_block_type == "UNetMidBlock1D":
-        return UNetMidBlock1D(in_channels=in_channels, mid_channels=mid_channels, out_channels=out_channels)
+        return UNetMidBlock1D(
+            in_channels=in_channels,
+            mid_channels=mid_channels,
+            out_channels=out_channels)
     raise ValueError(f"{mid_block_type} does not exist.")
 
 
-def get_out_block(*, out_block_type, num_groups_out, embed_dim, out_channels, act_fn, fc_dim):
+def get_out_block(*, out_block_type, num_groups_out, embed_dim, out_channels,
+                  act_fn, fc_dim):
     if out_block_type == "OutConv1DBlock":
         return OutConv1DBlock(num_groups_out, out_channels, embed_dim, act_fn)
     elif out_block_type == "ValueFunction":
