@@ -18,7 +18,4 @@
 # It only exists so that temporarely `from diffusers.pipelines import DiffusionPipeline` works
 
 from .pipelines import (  # noqa: F401
-    DiffusionPipeline,
-    ImagePipelineOutput,
-    TextPipelineOutput,
-)
+    DiffusionPipeline, ImagePipelineOutput, TextPipelineOutput, )
