@@ -21,8 +21,7 @@ from ..utils import (
     is_librosa_available,
     is_note_seq_available,
     is_paddle_available,
-    is_paddlenlp_available,
-)
+    is_paddlenlp_available, )
 
 try:
     if not is_paddle_available():
@@ -40,8 +39,7 @@ else:
         AudioPipelineOutput,
         DiffusionPipeline,
         ImagePipelineOutput,
-        TextPipelineOutput,
-    )
+        TextPipelineOutput, )
     from .pndm import PNDMPipeline
     from .repaint import RePaintPipeline
     from .score_sde_ve import ScoreSdeVePipeline
@@ -69,9 +67,9 @@ else:
         IFInpaintingPipeline,
         IFInpaintingSuperResolutionPipeline,
         IFPipeline,
-        IFSuperResolutionPipeline,
-    )
+        IFSuperResolutionPipeline, )
     from .latent_diffusion import LDMTextToImagePipeline
+    from .lvdm import LVDMUncondPipeline, LVDMTextToVideoPipeline
     from .paint_by_example import PaintByExamplePipeline
     from .semantic_stable_diffusion import SemanticStableDiffusionPipeline
     from .stable_diffusion import (
@@ -95,8 +93,7 @@ else:
         StableDiffusionSAGPipeline,
         StableDiffusionUpscalePipeline,
         StableUnCLIPImg2ImgPipeline,
-        StableUnCLIPPipeline,
-    )
+        StableUnCLIPPipeline, )
     from .stable_diffusion_safe import StableDiffusionPipelineSafe
     from .text_to_video_synthesis import TextToVideoSDPipeline, TextToVideoZeroPipeline
     from .unclip import UnCLIPImageVariationPipeline, UnCLIPPipeline
@@ -104,8 +101,7 @@ else:
         VersatileDiffusionDualGuidedPipeline,
         VersatileDiffusionImageVariationPipeline,
         VersatileDiffusionPipeline,
-        VersatileDiffusionTextToImagePipeline,
-    )
+        VersatileDiffusionTextToImagePipeline, )
     from .vq_diffusion import VQDiffusionPipeline
 
 try:
@@ -116,11 +112,11 @@ except OptionalDependencyNotAvailable:
 else:
     from .fastdeploy_utils import (
         FastDeployDiffusionPipelineMixin,
-        FastDeployRuntimeModel,
-    )
+        FastDeployRuntimeModel, )
 
 try:
-    if not (is_paddle_available() and is_paddlenlp_available() and is_fastdeploy_available()):
+    if not (is_paddle_available() and is_paddlenlp_available() and
+            is_fastdeploy_available()):
         raise OptionalDependencyNotAvailable()
 except OptionalDependencyNotAvailable:
     from ..utils.dummy_paddle_and_paddlenlp_and_fastdeploy_objects import *  # noqa F403
@@ -128,25 +124,26 @@ else:
     from .stable_diffusion import (
         FastDeployCycleDiffusionPipeline,
         FastDeployStableDiffusionControlNetPipeline,
+        FastDeployStableDiffusionImageVariationPipeline,
         FastDeployStableDiffusionImg2ImgPipeline,
         FastDeployStableDiffusionInpaintPipeline,
         FastDeployStableDiffusionInpaintPipelineLegacy,
         FastDeployStableDiffusionMegaPipeline,
         FastDeployStableDiffusionPipeline,
-        FastDeployStableDiffusionUpscalePipeline,
-    )
+        FastDeployStableDiffusionUpscalePipeline, )
 
 try:
-    if not (is_paddle_available() and is_paddlenlp_available() and is_k_diffusion_available()):
+    if not (is_paddle_available() and is_paddlenlp_available() and
+            is_k_diffusion_available()):
         raise OptionalDependencyNotAvailable()
 except OptionalDependencyNotAvailable:
     from ..utils.dummy_paddle_and_paddlenlp_and_k_diffusion_objects import *  # noqa F403
 else:
     from .stable_diffusion import StableDiffusionKDiffusionPipeline
 
-
 try:
-    if not (is_paddle_available() and is_paddlenlp_available() and is_einops_available()):
+    if not (is_paddle_available() and is_paddlenlp_available() and
+            is_einops_available()):
         raise OptionalDependencyNotAvailable()
 except OptionalDependencyNotAvailable:
     from ..utils.dummy_paddle_and_paddlenlp_and_einops_objects import *  # noqa F403
@@ -154,7 +151,8 @@ else:
     from .unidiffuser import UniDiffuserPipeline
 
 try:
-    if not (is_paddle_available() and is_paddlenlp_available() and is_note_seq_available()):
+    if not (is_paddle_available() and is_paddlenlp_available() and
+            is_note_seq_available()):
         raise OptionalDependencyNotAvailable()
 except OptionalDependencyNotAvailable:
     from ..utils.dummy_paddle_and_paddlenlp_and_note_seq_objects import *  # noqa F403
