@@ -25,7 +25,9 @@ from paddlenlp.transformers import RobertaPretrainedModel
 from paddlenlp.transformers.model_outputs import ModelOutput
 
 
-def create_position_ids_from_input_ids(input_ids, padding_idx, past_key_values_length=0):
+def create_position_ids_from_input_ids(input_ids,
+                                       padding_idx,
+                                       past_key_values_length=0):
     """
     Replace non-padding symbols with their position numbers. Position numbers begin at padding_idx+1. Padding symbols
     are ignored. This is modified from fairseq's `utils.make_positions`.
@@ -37,7 +39,8 @@ def create_position_ids_from_input_ids(input_ids, padding_idx, past_key_values_l
     """
     # The series of casts and type-conversions here are carefully balanced to both work with ONNX export and XLA.
     mask = (input_ids != padding_idx).cast("int64")
-    incremental_indices = (paddle.cumsum(mask, axis=1) + past_key_values_length) * mask
+    incremental_indices = (paddle.cumsum(
+        mask, axis=1) + past_key_values_length) * mask
     return incremental_indices + padding_idx
 
 
@@ -74,18 +77,21 @@ class RobertaSeriesConfig(XLMRobertaConfig):
     model_type = "roberta"
 
     def __init__(
-        self,
-        pad_token_id=1,
-        bos_token_id=0,
-        eos_token_id=2,
-        project_dim=512,
-        pooler_fn="cls",
-        learn_encoder=False,
-        use_attention_mask=True,
-        **kwargs,
-    ):
+            self,
+            pad_token_id=1,
+            bos_token_id=0,
+            eos_token_id=2,
+            project_dim=512,
+            pooler_fn="cls",
+            learn_encoder=False,
+            use_attention_mask=True,
+            **kwargs, ):
         kwargs["return_dict"] = kwargs.pop("return_dict", True)
-        super().__init__(pad_token_id=pad_token_id, bos_token_id=bos_token_id, eos_token_id=eos_token_id, **kwargs)
+        super().__init__(
+            pad_token_id=pad_token_id,
+            bos_token_id=bos_token_id,
+            eos_token_id=eos_token_id,
+            **kwargs)
         self.project_dim = project_dim
         self.pooler_fn = pooler_fn
         self.learn_encoder = learn_encoder
@@ -94,7 +100,9 @@ class RobertaSeriesConfig(XLMRobertaConfig):
 
 class RobertaSeriesModelWithTransformation(RobertaPretrainedModel):
     _keys_to_ignore_on_load_unexpected = [r"pooler", r"logit_scale"]
-    _keys_to_ignore_on_load_missing = [r"position_ids", r"predictions.decoder.bias"]
+    _keys_to_ignore_on_load_missing = [
+        r"position_ids", r"predictions.decoder.bias"
+    ]
     base_model_prefix = "roberta"
     config_class = RobertaSeriesConfig
 
@@ -104,35 +112,38 @@ class RobertaSeriesModelWithTransformation(RobertaPretrainedModel):
         # must reset _padding_idx
         self.roberta.embeddings.word_embeddings._padding_idx = None
         self.transformation = nn.Linear(config.hidden_size, config.project_dim)
-        self.has_pre_transformation = getattr(config, "has_pre_transformation", False)
+        self.has_pre_transformation = getattr(config, "has_pre_transformation",
+                                              False)
         if self.has_pre_transformation:
-            self.transformation_pre = nn.Linear(config.hidden_size, config.project_dim)
-            self.pre_LN = nn.LayerNorm(config.hidden_size, eps=config.layer_norm_eps)
+            self.transformation_pre = nn.Linear(config.hidden_size,
+                                                config.project_dim)
+            self.pre_LN = nn.LayerNorm(
+                config.hidden_size, eps=config.layer_norm_eps)
         self.init_weights()
 
     def forward(
-        self,
-        input_ids: Optional[paddle.Tensor] = None,
-        attention_mask: Optional[paddle.Tensor] = None,
-        token_type_ids: Optional[paddle.Tensor] = None,
-        position_ids: Optional[paddle.Tensor] = None,
-        output_attentions: Optional[bool] = None,
-        return_dict: Optional[bool] = None,
-        output_hidden_states: Optional[bool] = None,
-    ):
+            self,
+            input_ids: Optional[paddle.Tensor]=None,
+            attention_mask: Optional[paddle.Tensor]=None,
+            token_type_ids: Optional[paddle.Tensor]=None,
+            position_ids: Optional[paddle.Tensor]=None,
+            output_attentions: Optional[bool]=None,
+            return_dict: Optional[bool]=None,
+            output_hidden_states: Optional[bool]=None, ):
         return_dict = return_dict if return_dict is not None else self.config.use_return_dict
 
         if position_ids is None:
-            position_ids = create_position_ids_from_input_ids(input_ids, self.config.pad_token_id)
+            position_ids = create_position_ids_from_input_ids(
+                input_ids, self.config.pad_token_id)
         outputs = self.base_model(
             input_ids=input_ids,
             attention_mask=attention_mask,
             token_type_ids=token_type_ids,
             position_ids=position_ids,
             output_attentions=output_attentions,
-            output_hidden_states=True if self.has_pre_transformation else output_hidden_states,
-            return_dict=return_dict,
-        )
+            output_hidden_states=True
+            if self.has_pre_transformation else output_hidden_states,
+            return_dict=return_dict, )
 
         if self.has_pre_transformation:
             sequence_output2 = outputs["hidden_states"][-2]
@@ -143,13 +154,11 @@ class RobertaSeriesModelWithTransformation(RobertaPretrainedModel):
                 projection_state=projection_state2,
                 last_hidden_state=outputs.last_hidden_state,
                 hidden_states=outputs.hidden_states,
-                attentions=outputs.attentions,
-            )
+                attentions=outputs.attentions, )
         else:
             projection_state = self.transformation(outputs.last_hidden_state)
             return TransformationModelOutput(
                 projection_state=projection_state,
                 last_hidden_state=outputs.last_hidden_state,
                 hidden_states=outputs.hidden_states,
-                attentions=outputs.attentions,
-            )
+                attentions=outputs.attentions, )
