@@ -38,13 +38,13 @@ class DDPMPipeline(DiffusionPipeline):
 
     @paddle.no_grad()
     def __call__(
-        self,
-        batch_size: int = 1,
-        generator: Optional[Union[paddle.Generator, List[paddle.Generator]]] = None,
-        num_inference_steps: int = 1000,
-        output_type: Optional[str] = "pil",
-        return_dict: bool = True,
-    ) -> Union[ImagePipelineOutput, Tuple]:
+            self,
+            batch_size: int=1,
+            generator: Optional[Union[paddle.Generator, List[
+                paddle.Generator]]]=None,
+            num_inference_steps: int=1000,
+            output_type: Optional[str]="pil",
+            return_dict: bool=True, ) -> Union[ImagePipelineOutput, Tuple]:
         """
         Args:
             batch_size (`int`, *optional*, defaults to 1):
@@ -70,10 +70,10 @@ class DDPMPipeline(DiffusionPipeline):
                 batch_size,
                 self.unet.config.in_channels,
                 self.unet.config.sample_size,
-                self.unet.config.sample_size,
-            )
+                self.unet.config.sample_size, )
         else:
-            image_shape = (batch_size, self.unet.config.in_channels, *self.unet.config.sample_size)
+            image_shape = (batch_size, self.unet.config.in_channels,
+                           *self.unet.config.sample_size)
         image = randn_tensor(image_shape, generator=generator)
         # set step values
         self.scheduler.set_timesteps(num_inference_steps)
@@ -82,11 +82,12 @@ class DDPMPipeline(DiffusionPipeline):
             model_output = self.unet(image, t).sample
 
             # 2. compute previous image: x_t -> x_t-1
-            image = self.scheduler.step(model_output, t, image, generator=generator).prev_sample
+            image = self.scheduler.step(
+                model_output, t, image, generator=generator).prev_sample
         image = (image / 2 + 0.5).clip(min=0, max=1)
         image = image.cpu().transpose(perm=[0, 2, 3, 1]).numpy()
         if output_type == "pil":
             image = self.numpy_to_pil(image)
         if not return_dict:
-            return (image,)
+            return (image, )
         return ImagePipelineOutput(images=image)
