@@ -33,8 +33,7 @@ from ...utils import (
     is_ftfy_available,
     logging,
     randn_tensor,
-    replace_example_docstring,
-)
+    replace_example_docstring, )
 from ..pipeline_utils import DiffusionPipeline
 from . import IFPipelineOutput
 from .safety_checker import IFSafetyChecker
@@ -61,7 +60,8 @@ def resize(images: PIL.Image.Image, img_size: int) -> PIL.Image.Image:
     else:
         h = int(round(img_size / 8 / coef) * 8)
 
-    images = images.resize((w, h), resample=PIL_INTERPOLATION["bicubic"], reducing_gap=None)
+    images = images.resize(
+        (w, h), resample=PIL_INTERPOLATION["bicubic"], reducing_gap=None)
 
     return images
 
@@ -132,22 +132,24 @@ class IFImg2ImgPipeline(DiffusionPipeline):
     watermarker: Optional[IFWatermarker]
 
     bad_punct_regex = re.compile(
-        r"[" + "#®•©™&@·º½¾¿¡§~" + "\)" + "\(" + "\]" + "\[" + "\}" + "\{" + "\|" + "\\" + "\/" + "\*" + r"]{1,}"
-    )  # noqa
+        r"[" + "#®•©™&@·º½¾¿¡§~" + "\)" + "\(" + "\]" + "\[" + "\}" + "\{" +
+        "\|" + "\\" + "\/" + "\*" + r"]{1,}")  # noqa
 
-    _optional_components = ["tokenizer", "text_encoder", "safety_checker", "feature_extractor", "watermarker"]
+    _optional_components = [
+        "tokenizer", "text_encoder", "safety_checker", "feature_extractor",
+        "watermarker"
+    ]
 
     def __init__(
-        self,
-        tokenizer: T5Tokenizer,
-        text_encoder: T5EncoderModel,
-        unet: UNet2DConditionModel,
-        scheduler: DDPMScheduler,
-        safety_checker: Optional[IFSafetyChecker],
-        feature_extractor: Optional[CLIPImageProcessor],
-        watermarker: Optional[IFWatermarker],
-        requires_safety_checker: bool = True,
-    ):
+            self,
+            tokenizer: T5Tokenizer,
+            text_encoder: T5EncoderModel,
+            unet: UNet2DConditionModel,
+            scheduler: DDPMScheduler,
+            safety_checker: Optional[IFSafetyChecker],
+            feature_extractor: Optional[CLIPImageProcessor],
+            watermarker: Optional[IFWatermarker],
+            requires_safety_checker: bool=True, ):
         super().__init__()
 
         if safety_checker is None and requires_safety_checker:
@@ -173,22 +175,20 @@ class IFImg2ImgPipeline(DiffusionPipeline):
             scheduler=scheduler,
             safety_checker=safety_checker,
             feature_extractor=feature_extractor,
-            watermarker=watermarker,
-        )
+            watermarker=watermarker, )
         self.register_to_config(requires_safety_checker=requires_safety_checker)
 
     @paddle.no_grad()
     # Copied from ppdiffusers.pipelines.deepfloyd_if.pipeline_if.IFPipeline.encode_prompt
     def encode_prompt(
-        self,
-        prompt,
-        do_classifier_free_guidance=True,
-        num_images_per_prompt=1,
-        negative_prompt=None,
-        prompt_embeds: Optional[paddle.Tensor] = None,
-        negative_prompt_embeds: Optional[paddle.Tensor] = None,
-        clean_caption: bool = False,
-    ):
+            self,
+            prompt,
+            do_classifier_free_guidance=True,
+            num_images_per_prompt=1,
+            negative_prompt=None,
+            prompt_embeds: Optional[paddle.Tensor]=None,
+            negative_prompt_embeds: Optional[paddle.Tensor]=None,
+            clean_caption: bool=False, ):
         r"""
         Encodes the prompt into text encoder hidden states.
 
@@ -215,8 +215,7 @@ class IFImg2ImgPipeline(DiffusionPipeline):
             if type(prompt) is not type(negative_prompt):
                 raise TypeError(
                     f"`negative_prompt` should be the same type to `prompt`, but got {type(negative_prompt)} !="
-                    f" {type(prompt)}."
-                )
+                    f" {type(prompt)}.")
 
         if prompt is not None and isinstance(prompt, str):
             batch_size = 1
@@ -229,31 +228,31 @@ class IFImg2ImgPipeline(DiffusionPipeline):
         max_length = 77
 
         if prompt_embeds is None:
-            prompt = self._text_preprocessing(prompt, clean_caption=clean_caption)
+            prompt = self._text_preprocessing(
+                prompt, clean_caption=clean_caption)
             text_inputs = self.tokenizer(
                 prompt,
                 padding="max_length",
                 max_length=max_length,
                 truncation=True,
                 add_special_tokens=True,
-                return_tensors="pd",
-            )
+                return_tensors="pd", )
             text_input_ids = text_inputs.input_ids
-            untruncated_ids = self.tokenizer(prompt, padding="longest", return_tensors="pd").input_ids
+            untruncated_ids = self.tokenizer(
+                prompt, padding="longest", return_tensors="pd").input_ids
 
-            if untruncated_ids.shape[-1] >= text_input_ids.shape[-1] and not paddle.equal_all(
-                text_input_ids, untruncated_ids
-            ):
-                removed_text = self.tokenizer.batch_decode(untruncated_ids[:, max_length - 1 : -1])
+            if untruncated_ids.shape[-1] >= text_input_ids.shape[
+                    -1] and not paddle.equal_all(text_input_ids,
+                                                 untruncated_ids):
+                removed_text = self.tokenizer.batch_decode(
+                    untruncated_ids[:, max_length - 1:-1])
                 logger.warning(
                     "The following part of your input was truncated because CLIP can only handle sequences up to"
-                    f" {max_length} tokens: {removed_text}"
-                )
+                    f" {max_length} tokens: {removed_text}")
             attention_mask = text_inputs.attention_mask
             prompt_embeds = self.text_encoder(
                 text_input_ids,
-                attention_mask=attention_mask,
-            )
+                attention_mask=attention_mask, )
             prompt_embeds = prompt_embeds[0]
 
         if self.text_encoder is not None:
@@ -268,7 +267,8 @@ class IFImg2ImgPipeline(DiffusionPipeline):
         bs_embed, seq_len, _ = prompt_embeds.shape
         # duplicate text embeddings for each generation per prompt, using mps friendly method
         prompt_embeds = prompt_embeds.tile([1, num_images_per_prompt, 1])
-        prompt_embeds = prompt_embeds.reshape([bs_embed * num_images_per_prompt, seq_len, -1])
+        prompt_embeds = prompt_embeds.reshape(
+            [bs_embed * num_images_per_prompt, seq_len, -1])
 
         # get unconditional embeddings for classifier free guidance
         if do_classifier_free_guidance and negative_prompt_embeds is None:
@@ -281,12 +281,12 @@ class IFImg2ImgPipeline(DiffusionPipeline):
                 raise ValueError(
                     f"`negative_prompt`: {negative_prompt} has batch size {len(negative_prompt)}, but `prompt`:"
                     f" {prompt} has batch size {batch_size}. Please make sure that passed `negative_prompt` matches"
-                    " the batch size of `prompt`."
-                )
+                    " the batch size of `prompt`.")
             else:
                 uncond_tokens = negative_prompt
 
-            uncond_tokens = self._text_preprocessing(uncond_tokens, clean_caption=clean_caption)
+            uncond_tokens = self._text_preprocessing(
+                uncond_tokens, clean_caption=clean_caption)
             max_length = prompt_embeds.shape[1]
             uncond_input = self.tokenizer(
                 uncond_tokens,
@@ -295,14 +295,12 @@ class IFImg2ImgPipeline(DiffusionPipeline):
                 truncation=True,
                 return_attention_mask=True,
                 add_special_tokens=True,
-                return_tensors="pd",
-            )
+                return_tensors="pd", )
             attention_mask = uncond_input.attention_mask
 
             negative_prompt_embeds = self.text_encoder(
                 uncond_input.input_ids,
-                attention_mask=attention_mask,
-            )
+                attention_mask=attention_mask, )
             negative_prompt_embeds = negative_prompt_embeds[0]
 
         if do_classifier_free_guidance:
@@ -312,8 +310,10 @@ class IFImg2ImgPipeline(DiffusionPipeline):
             if dtype is not None:
                 negative_prompt_embeds = negative_prompt_embeds.cast(dtype)
 
-            negative_prompt_embeds = negative_prompt_embeds.tile([1, num_images_per_prompt, 1])
-            negative_prompt_embeds = negative_prompt_embeds.reshape([batch_size * num_images_per_prompt, seq_len, -1])
+            negative_prompt_embeds = negative_prompt_embeds.tile(
+                [1, num_images_per_prompt, 1])
+            negative_prompt_embeds = negative_prompt_embeds.reshape(
+                [batch_size * num_images_per_prompt, seq_len, -1])
 
             # For classifier free guidance, we need to do two forward passes.
             # Here we concatenate the unconditional and text embeddings into a single batch
@@ -326,11 +326,11 @@ class IFImg2ImgPipeline(DiffusionPipeline):
     # Copied from ppdiffusers.pipelines.deepfloyd_if.pipeline_if.IFPipeline.run_safety_checker
     def run_safety_checker(self, image, dtype):
         if self.safety_checker is not None:
-            safety_checker_input = self.feature_extractor(self.numpy_to_pil(image), return_tensors="pd")
+            safety_checker_input = self.feature_extractor(
+                self.numpy_to_pil(image), return_tensors="pd")
             image, nsfw_detected, watermark_detected = self.safety_checker(
                 images=image,
-                clip_input=safety_checker_input.pixel_values.cast(dtype),
-            )
+                clip_input=safety_checker_input.pixel_values.cast(dtype), )
         else:
             nsfw_detected = None
             watermark_detected = None
@@ -344,46 +344,48 @@ class IFImg2ImgPipeline(DiffusionPipeline):
         # eta corresponds to η in DDIM paper: https://arxiv.org/abs/2010.02502
         # and should be between [0, 1]
 
-        accepts_eta = "eta" in set(inspect.signature(self.scheduler.step).parameters.keys())
+        accepts_eta = "eta" in set(
+            inspect.signature(self.scheduler.step).parameters.keys())
         extra_step_kwargs = {}
         if accepts_eta:
             extra_step_kwargs["eta"] = eta
 
         # check if the scheduler accepts generator
-        accepts_generator = "generator" in set(inspect.signature(self.scheduler.step).parameters.keys())
+        accepts_generator = "generator" in set(
+            inspect.signature(self.scheduler.step).parameters.keys())
         if accepts_generator:
             extra_step_kwargs["generator"] = generator
         return extra_step_kwargs
 
     def check_inputs(
-        self,
-        prompt,
-        image,
-        batch_size,
-        callback_steps,
-        negative_prompt=None,
-        prompt_embeds=None,
-        negative_prompt_embeds=None,
-    ):
+            self,
+            prompt,
+            image,
+            batch_size,
+            callback_steps,
+            negative_prompt=None,
+            prompt_embeds=None,
+            negative_prompt_embeds=None, ):
         if (callback_steps is None) or (
-            callback_steps is not None and (not isinstance(callback_steps, int) or callback_steps <= 0)
-        ):
+                callback_steps is not None and
+            (not isinstance(callback_steps, int) or callback_steps <= 0)):
             raise ValueError(
                 f"`callback_steps` has to be a positive integer but is {callback_steps} of type"
-                f" {type(callback_steps)}."
-            )
+                f" {type(callback_steps)}.")
 
         if prompt is not None and prompt_embeds is not None:
             raise ValueError(
                 f"Cannot forward both `prompt`: {prompt} and `prompt_embeds`: {prompt_embeds}. Please make sure to"
-                " only forward one of the two."
-            )
+                " only forward one of the two.")
         elif prompt is None and prompt_embeds is None:
             raise ValueError(
                 "Provide either `prompt` or `prompt_embeds`. Cannot leave both `prompt` and `prompt_embeds` undefined."
             )
-        elif prompt is not None and (not isinstance(prompt, str) and not isinstance(prompt, list)):
-            raise ValueError(f"`prompt` has to be of type `str` or `list` but is {type(prompt)}")
+        elif prompt is not None and (not isinstance(prompt, str) and
+                                     not isinstance(prompt, list)):
+            raise ValueError(
+                f"`prompt` has to be of type `str` or `list` but is {type(prompt)}"
+            )
 
         if negative_prompt is not None and negative_prompt_embeds is not None:
             raise ValueError(
@@ -396,23 +398,19 @@ class IFImg2ImgPipeline(DiffusionPipeline):
                 raise ValueError(
                     "`prompt_embeds` and `negative_prompt_embeds` must have the same shape when passed directly, but"
                     f" got: `prompt_embeds` {prompt_embeds.shape} != `negative_prompt_embeds`"
-                    f" {negative_prompt_embeds.shape}."
-                )
+                    f" {negative_prompt_embeds.shape}.")
 
         if isinstance(image, list):
             check_image_type = image[0]
         else:
             check_image_type = image
 
-        if (
-            not isinstance(check_image_type, paddle.Tensor)
-            and not isinstance(check_image_type, PIL.Image.Image)
-            and not isinstance(check_image_type, np.ndarray)
-        ):
+        if (not isinstance(check_image_type, paddle.Tensor) and
+                not isinstance(check_image_type, PIL.Image.Image) and
+                not isinstance(check_image_type, np.ndarray)):
             raise ValueError(
                 "`image` has to be of type `paddle.Tensor`, `PIL.Image.Image`, `np.ndarray`, or List[...] but is"
-                f" {type(check_image_type)}"
-            )
+                f" {type(check_image_type)}")
 
         if isinstance(image, list):
             image_batch_size = len(image)
@@ -426,17 +424,21 @@ class IFImg2ImgPipeline(DiffusionPipeline):
             assert False
 
         if batch_size != image_batch_size:
-            raise ValueError(f"image batch size: {image_batch_size} must be same as prompt batch size {batch_size}")
+            raise ValueError(
+                f"image batch size: {image_batch_size} must be same as prompt batch size {batch_size}"
+            )
 
     # Copied from ppdiffusers.pipelines.deepfloyd_if.pipeline_if.IFPipeline._text_preprocessing
     def _text_preprocessing(self, text, clean_caption=False):
         if clean_caption and not is_bs4_available():
-            logger.warn(BACKENDS_MAPPING["bs4"][-1].format("Setting `clean_caption=True`"))
+            logger.warn(BACKENDS_MAPPING["bs4"][-1].format(
+                "Setting `clean_caption=True`"))
             logger.warn("Setting `clean_caption` to False...")
             clean_caption = False
 
         if clean_caption and not is_ftfy_available():
-            logger.warn(BACKENDS_MAPPING["ftfy"][-1].format("Setting `clean_caption=True`"))
+            logger.warn(BACKENDS_MAPPING["ftfy"][-1].format(
+                "Setting `clean_caption=True`"))
             logger.warn("Setting `clean_caption` to False...")
             clean_caption = False
 
@@ -463,13 +465,11 @@ class IFImg2ImgPipeline(DiffusionPipeline):
         caption = re.sub(
             r"\b((?:https?:(?:\/{1,3}|[a-zA-Z0-9%])|[a-zA-Z0-9.\-]+[.](?:com|co|ru|net|org|edu|gov|it)[\w/-]*\b\/?(?!@)))",  # noqa
             "",
-            caption,
-        )  # regex for urls
+            caption, )  # regex for urls
         caption = re.sub(
             r"\b((?:www:(?:\/{1,3}|[a-zA-Z0-9%])|[a-zA-Z0-9.\-]+[.](?:com|co|ru|net|org|edu|gov|it)[\w/-]*\b\/?(?!@)))",  # noqa
             "",
-            caption,
-        )  # regex for urls
+            caption, )  # regex for urls
         # html:
         caption = BeautifulSoup(caption, features="html.parser").text
 
@@ -496,8 +496,7 @@ class IFImg2ImgPipeline(DiffusionPipeline):
         caption = re.sub(
             r"[\u002D\u058A\u05BE\u1400\u1806\u2010-\u2015\u2E17\u2E1A\u2E3A\u2E3B\u2E40\u301C\u3030\u30A0\uFE31\uFE32\uFE58\uFE63\uFF0D]+",  # noqa
             "-",
-            caption,
-        )
+            caption, )
 
         # кавычки к одному стандарту
         caption = re.sub(r"[`´«»“”¨]", '"', caption)
@@ -524,13 +523,15 @@ class IFImg2ImgPipeline(DiffusionPipeline):
         # "123456.."
         caption = re.sub(r"\b\d{6,}\b", "", caption)
         # filenames:
-        caption = re.sub(r"[\S]+\.(?:png|jpg|jpeg|bmp|webp|eps|pdf|apk|mp4)", "", caption)
+        caption = re.sub(r"[\S]+\.(?:png|jpg|jpeg|bmp|webp|eps|pdf|apk|mp4)",
+                         "", caption)
 
         #
         caption = re.sub(r"[\"\']{2,}", r'"', caption)  # """AUSVERKAUFT"""
         caption = re.sub(r"[\.]{2,}", r" ", caption)  # """AUSVERKAUFT"""
 
-        caption = re.sub(self.bad_punct_regex, r" ", caption)  # ***AUSVERKAUFT***, #AUSVERKAUFT
+        caption = re.sub(self.bad_punct_regex, r" ",
+                         caption)  # ***AUSVERKAUFT***, #AUSVERKAUFT
         caption = re.sub(r"\s+\.\s+", r" ", caption)  # " . "
 
         # this-is-my-cute-cat / this_is_my_cute_cat
@@ -548,10 +549,13 @@ class IFImg2ImgPipeline(DiffusionPipeline):
         caption = re.sub(r"(worldwide\s+)?(free\s+)?shipping", "", caption)
         caption = re.sub(r"(free\s)?download(\sfree)?", "", caption)
         caption = re.sub(r"\bclick\b\s(?:for|on)\s\w+", "", caption)
-        caption = re.sub(r"\b(?:png|jpg|jpeg|bmp|webp|eps|pdf|apk|mp4)(\simage[s]?)?", "", caption)
+        caption = re.sub(
+            r"\b(?:png|jpg|jpeg|bmp|webp|eps|pdf|apk|mp4)(\simage[s]?)?", "",
+            caption)
         caption = re.sub(r"\bpage\s+\d+\b", "", caption)
 
-        caption = re.sub(r"\b\d*[a-zA-Z]+\d+[a-zA-Z]+\d+[a-zA-Z\d]*\b", r" ", caption)  # j2d1a2a...
+        caption = re.sub(r"\b\d*[a-zA-Z]+\d+[a-zA-Z]+\d+[a-zA-Z\d]*\b", r" ",
+                         caption)  # j2d1a2a...
 
         caption = re.sub(r"\b\d+\.?\d*[xх×]\d+\.?\d*\b", "", caption)
 
@@ -596,24 +600,35 @@ class IFImg2ImgPipeline(DiffusionPipeline):
             image = numpy_to_pd(image)  # to pd
 
         elif isinstance(image[0], np.ndarray):
-            image = np.concatenate(image, axis=0) if image[0].ndim == 4 else np.stack(image, axis=0)
+            image = np.concatenate(
+                image, axis=0) if image[0].ndim == 4 else np.stack(
+                    image, axis=0)
             image = numpy_to_pd(image)
 
         elif isinstance(image[0], paddle.Tensor):
-            image = paddle.concat(image, axis=0) if image[0].ndim == 4 else paddle.stack(image, axis=0)
+            image = paddle.concat(
+                image, axis=0) if image[0].ndim == 4 else paddle.stack(
+                    image, axis=0)
 
         return image
 
     def get_timesteps(self, num_inference_steps, strength):
         # get the original timestep using init_timestep
-        init_timestep = min(int(num_inference_steps * strength), num_inference_steps)
+        init_timestep = min(
+            int(num_inference_steps * strength), num_inference_steps)
 
         t_start = max(num_inference_steps - init_timestep, 0)
         timesteps = self.scheduler.timesteps[t_start:]
 
         return timesteps, num_inference_steps - t_start
 
-    def prepare_intermediate_images(self, image, timestep, batch_size, num_images_per_prompt, dtype, generator=None):
+    def prepare_intermediate_images(self,
+                                    image,
+                                    timestep,
+                                    batch_size,
+                                    num_images_per_prompt,
+                                    dtype,
+                                    generator=None):
         _, channels, height, width = image.shape
 
         batch_size = batch_size * num_images_per_prompt
@@ -636,28 +651,27 @@ class IFImg2ImgPipeline(DiffusionPipeline):
     @paddle.no_grad()
     @replace_example_docstring(EXAMPLE_DOC_STRING)
     def __call__(
-        self,
-        prompt: Union[str, List[str]] = None,
-        image: Union[
-            PIL.Image.Image, paddle.Tensor, np.ndarray, List[PIL.Image.Image], List[paddle.Tensor], List[np.ndarray]
-        ] = None,
-        strength: float = 0.7,
-        num_inference_steps: int = 80,
-        timesteps: List[int] = None,
-        guidance_scale: float = 10.0,
-        negative_prompt: Optional[Union[str, List[str]]] = None,
-        num_images_per_prompt: Optional[int] = 1,
-        eta: float = 0.0,
-        generator: Optional[Union[paddle.Generator, List[paddle.Generator]]] = None,
-        prompt_embeds: Optional[paddle.Tensor] = None,
-        negative_prompt_embeds: Optional[paddle.Tensor] = None,
-        output_type: Optional[str] = "pil",
-        return_dict: bool = True,
-        callback: Optional[Callable[[int, int, paddle.Tensor], None]] = None,
-        callback_steps: int = 1,
-        clean_caption: bool = True,
-        cross_attention_kwargs: Optional[Dict[str, Any]] = None,
-    ):
+            self,
+            prompt: Union[str, List[str]]=None,
+            image: Union[PIL.Image.Image, paddle.Tensor, np.ndarray, List[
+                PIL.Image.Image], List[paddle.Tensor], List[np.ndarray]]=None,
+            strength: float=0.7,
+            num_inference_steps: int=80,
+            timesteps: List[int]=None,
+            guidance_scale: float=10.0,
+            negative_prompt: Optional[Union[str, List[str]]]=None,
+            num_images_per_prompt: Optional[int]=1,
+            eta: float=0.0,
+            generator: Optional[Union[paddle.Generator, List[
+                paddle.Generator]]]=None,
+            prompt_embeds: Optional[paddle.Tensor]=None,
+            negative_prompt_embeds: Optional[paddle.Tensor]=None,
+            output_type: Optional[str]="pil",
+            return_dict: bool=True,
+            callback: Optional[Callable[[int, int, paddle.Tensor], None]]=None,
+            callback_steps: int=1,
+            clean_caption: bool=True,
+            cross_attention_kwargs: Optional[Dict[str, Any]]=None, ):
         """
         Function invoked when calling the pipeline for generation.
 
@@ -741,9 +755,9 @@ class IFImg2ImgPipeline(DiffusionPipeline):
         else:
             batch_size = prompt_embeds.shape[0]
 
-        self.check_inputs(
-            prompt, image, batch_size, callback_steps, negative_prompt, prompt_embeds, negative_prompt_embeds
-        )
+        self.check_inputs(prompt, image, batch_size, callback_steps,
+                          negative_prompt, prompt_embeds,
+                          negative_prompt_embeds)
 
         # here `guidance_scale` is defined analog to the guidance weight `w` of equation (2)
         # of the Imagen paper: https://arxiv.org/pdf/2205.11487.pdf . `guidance_scale = 1`
@@ -758,11 +772,11 @@ class IFImg2ImgPipeline(DiffusionPipeline):
             negative_prompt=negative_prompt,
             prompt_embeds=prompt_embeds,
             negative_prompt_embeds=negative_prompt_embeds,
-            clean_caption=clean_caption,
-        )
+            clean_caption=clean_caption, )
 
         if do_classifier_free_guidance:
-            prompt_embeds = paddle.concat([negative_prompt_embeds, prompt_embeds])
+            prompt_embeds = paddle.concat(
+                [negative_prompt_embeds, prompt_embeds])
 
         dtype = prompt_embeds.dtype
 
@@ -775,29 +789,32 @@ class IFImg2ImgPipeline(DiffusionPipeline):
             self.scheduler.set_timesteps(num_inference_steps)
             timesteps = self.scheduler.timesteps
 
-        timesteps, num_inference_steps = self.get_timesteps(num_inference_steps, strength)
+        timesteps, num_inference_steps = self.get_timesteps(num_inference_steps,
+                                                            strength)
 
         # 5. Prepare intermediate images
         image = self.preprocess_image(image)
         image = image.cast(dtype)
 
         noise_timestep = timesteps[0:1]
-        noise_timestep = noise_timestep.tile((batch_size * num_images_per_prompt,))
+        noise_timestep = noise_timestep.tile(
+            (batch_size * num_images_per_prompt, ))
 
         intermediate_images = self.prepare_intermediate_images(
-            image, noise_timestep, batch_size, num_images_per_prompt, dtype, generator
-        )
+            image, noise_timestep, batch_size, num_images_per_prompt, dtype,
+            generator)
 
         # 6. Prepare extra step kwargs. TODO: Logic should ideally just be moved out of the pipeline
         extra_step_kwargs = self.prepare_extra_step_kwargs(generator, eta)
 
         # 7. Denoising loop
-        num_warmup_steps = len(timesteps) - num_inference_steps * self.scheduler.order
+        num_warmup_steps = len(
+            timesteps) - num_inference_steps * self.scheduler.order
         with self.progress_bar(total=num_inference_steps) as progress_bar:
             for i, t in enumerate(timesteps):
-                model_input = (
-                    paddle.concat([intermediate_images] * 2) if do_classifier_free_guidance else intermediate_images
-                )
+                model_input = (paddle.concat([intermediate_images] * 2)
+                               if do_classifier_free_guidance else
+                               intermediate_images)
                 model_input = self.scheduler.scale_model_input(model_input, t)
 
                 # predict the noise residual
@@ -805,28 +822,37 @@ class IFImg2ImgPipeline(DiffusionPipeline):
                     model_input,
                     t,
                     encoder_hidden_states=prompt_embeds,
-                    cross_attention_kwargs=cross_attention_kwargs,
-                ).sample
+                    cross_attention_kwargs=cross_attention_kwargs, ).sample
 
                 # perform guidance
                 if do_classifier_free_guidance:
                     noise_pred_uncond, noise_pred_text = noise_pred.chunk(2)
                     noise_pred_uncond, _ = noise_pred_uncond.split(
-                        [model_input.shape[1], noise_pred_uncond.shape[1] - model_input.shape[1]], axis=1
-                    )
+                        [
+                            model_input.shape[1],
+                            noise_pred_uncond.shape[1] - model_input.shape[1]
+                        ],
+                        axis=1)
                     noise_pred_text, predicted_variance = noise_pred_text.split(
-                        [model_input.shape[1], noise_pred_text.shape[1] - model_input.shape[1]], axis=1
-                    )
-                    noise_pred = noise_pred_uncond + guidance_scale * (noise_pred_text - noise_pred_uncond)
-                    noise_pred = paddle.concat([noise_pred, predicted_variance], axis=1)
+                        [
+                            model_input.shape[1],
+                            noise_pred_text.shape[1] - model_input.shape[1]
+                        ],
+                        axis=1)
+                    noise_pred = noise_pred_uncond + guidance_scale * (
+                        noise_pred_text - noise_pred_uncond)
+                    noise_pred = paddle.concat(
+                        [noise_pred, predicted_variance], axis=1)
 
                 # compute the previous noisy sample x_t -> x_t-1
                 intermediate_images = self.scheduler.step(
-                    noise_pred, t, intermediate_images, **extra_step_kwargs
-                ).prev_sample
+                    noise_pred, t, intermediate_images,
+                    **extra_step_kwargs).prev_sample
 
                 # call the callback, if provided
-                if i == len(timesteps) - 1 or ((i + 1) > num_warmup_steps and (i + 1) % self.scheduler.order == 0):
+                if i == len(timesteps) - 1 or (
+                    (i + 1) > num_warmup_steps and
+                    (i + 1) % self.scheduler.order == 0):
                     progress_bar.update()
                     if callback is not None and i % callback_steps == 0:
                         callback(i, t, intermediate_images)
@@ -839,14 +865,16 @@ class IFImg2ImgPipeline(DiffusionPipeline):
             image = image.cpu().transpose([0, 2, 3, 1]).cast("float32").numpy()
 
             # 9. Run safety checker
-            image, nsfw_detected, watermark_detected = self.run_safety_checker(image, prompt_embeds.dtype)
+            image, nsfw_detected, watermark_detected = self.run_safety_checker(
+                image, prompt_embeds.dtype)
 
             # 10. Convert to PIL
             image = self.numpy_to_pil(image)
 
             # 11. Apply watermark
             if self.watermarker is not None:
-                self.watermarker.apply_watermark(image, self.unet.config.sample_size)
+                self.watermarker.apply_watermark(image,
+                                                 self.unet.config.sample_size)
         elif output_type == "pd":
             nsfw_detected = None
             watermark_detected = None
@@ -857,9 +885,13 @@ class IFImg2ImgPipeline(DiffusionPipeline):
             image = image.cpu().transpose([0, 2, 3, 1]).cast("float32").numpy()
 
             # 9. Run safety checker
-            image, nsfw_detected, watermark_detected = self.run_safety_checker(image, prompt_embeds.dtype)
+            image, nsfw_detected, watermark_detected = self.run_safety_checker(
+                image, prompt_embeds.dtype)
 
         if not return_dict:
             return (image, nsfw_detected, watermark_detected)
 
-        return IFPipelineOutput(images=image, nsfw_detected=nsfw_detected, watermark_detected=watermark_detected)
+        return IFPipelineOutput(
+            images=image,
+            nsfw_detected=nsfw_detected,
+            watermark_detected=watermark_detected)
