@@ -1,5 +1,5 @@
-# Copyright (c) 2022 PaddlePaddle Authors. All Rights Reserved.
-# Copyright 2022 The HuggingFace Team. All rights reserved.
+# Copyright (c) 2023 PaddlePaddle Authors. All Rights Reserved.
+# Copyright 2023 The HuggingFace Team. All rights reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,4 +18,7 @@ from ...utils import is_paddlenlp_available
 from .pipeline_latent_diffusion_superresolution import LDMSuperResolutionPipeline
 
 if is_paddlenlp_available():
-    from .pipeline_latent_diffusion import LDMBertModel, LDMTextToImagePipeline
+    from .pipeline_latent_diffusion import (
+        LDMBertConfig,
+        LDMBertModel,
+        LDMTextToImagePipeline, )
