@@ -13,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-
 from typing import List, Optional, Tuple, Union
 
 import numpy as np
@@ -39,7 +38,11 @@ def _preprocess_image(image: Union[List, PIL.Image.Image, paddle.Tensor]):
         w, h = image[0].size
         w, h = (x - x % 8 for x in (w, h))  # resize to integer multiple of 8
 
-        image = [np.array(i.resize((w, h), resample=PIL_INTERPOLATION["lanczos"]))[None, :] for i in image]
+        image = [
+            np.array(i.resize(
+                (w, h), resample=PIL_INTERPOLATION["lanczos"]))[None, :]
+            for i in image
+        ]
         image = np.concatenate(image, axis=0)
         image = np.array(image).astype(np.float32) / 255.0
         image = image.transpose(0, 3, 1, 2)
@@ -59,7 +62,12 @@ def _preprocess_mask(mask: Union[List, PIL.Image.Image, paddle.Tensor]):
     if isinstance(mask[0], PIL.Image.Image):
         w, h = mask[0].size
         w, h = (x - x % 32 for x in (w, h))  # resize to integer multiple of 32
-        mask = [np.array(m.convert("L").resize((w, h), resample=PIL_INTERPOLATION["nearest"]))[None, :] for m in mask]
+        mask = [
+            np.array(
+                m.convert("L").resize(
+                    (w, h), resample=PIL_INTERPOLATION["nearest"]))[None, :]
+            for m in mask
+        ]
         mask = np.concatenate(mask, axis=0)
         mask = mask.astype(np.float32) / 255.0
         mask[mask < 0.5] = 0
@@ -80,17 +88,17 @@ class RePaintPipeline(DiffusionPipeline):
 
     @paddle.no_grad()
     def __call__(
-        self,
-        image: Union[paddle.Tensor, PIL.Image.Image],
-        mask_image: Union[paddle.Tensor, PIL.Image.Image],
-        num_inference_steps: int = 250,
-        eta: float = 0.0,
-        jump_length: int = 10,
-        jump_n_sample: int = 10,
-        generator: Optional[Union[paddle.Generator, List[paddle.Generator]]] = None,
-        output_type: Optional[str] = "pil",
-        return_dict: bool = True,
-    ) -> Union[ImagePipelineOutput, Tuple]:
+            self,
+            image: Union[paddle.Tensor, PIL.Image.Image],
+            mask_image: Union[paddle.Tensor, PIL.Image.Image],
+            num_inference_steps: int=250,
+            eta: float=0.0,
+            jump_length: int=10,
+            jump_n_sample: int=10,
+            generator: Optional[Union[paddle.Generator, List[
+                paddle.Generator]]]=None,
+            output_type: Optional[str]="pil",
+            return_dict: bool=True, ) -> Union[ImagePipelineOutput, Tuple]:
         r"""
         Args:
             image (`paddle.Tensor` or `PIL.Image.Image`):
@@ -138,10 +146,12 @@ class RePaintPipeline(DiffusionPipeline):
             )
 
         image_shape = original_image.shape
-        image = randn_tensor(image_shape, generator=generator, dtype=self.unet.dtype)
+        image = randn_tensor(
+            image_shape, generator=generator, dtype=self.unet.dtype)
 
         # set step values
-        self.scheduler.set_timesteps(num_inference_steps, jump_length, jump_n_sample)
+        self.scheduler.set_timesteps(num_inference_steps, jump_length,
+                                     jump_n_sample)
         self.scheduler.eta = eta
 
         t_last = self.scheduler.timesteps[0] + 1
@@ -151,7 +161,9 @@ class RePaintPipeline(DiffusionPipeline):
                 # predict the noise residual
                 model_output = self.unet(image, t).sample
                 # compute previous image: x_t -> x_t-1
-                image = self.scheduler.step(model_output, t, image, original_image, mask_image, generator).prev_sample
+                image = self.scheduler.step(model_output, t, image,
+                                            original_image, mask_image,
+                                            generator).prev_sample
 
             else:
                 # compute the reverse: x_t-1 -> x_t
@@ -164,6 +176,6 @@ class RePaintPipeline(DiffusionPipeline):
             image = self.numpy_to_pil(image)
 
         if not return_dict:
-            return (image,)
+            return (image, )
 
         return ImagePipelineOutput(images=image)
