@@ -65,11 +65,14 @@ def prepare_mask_and_masked_image(image, mask):
     """
     if isinstance(image, paddle.Tensor):
         if not isinstance(mask, paddle.Tensor):
-            raise TypeError(f"`image` is a paddle.Tensor but `mask` (type: {type(mask)} is not")
+            raise TypeError(
+                f"`image` is a paddle.Tensor but `mask` (type: {type(mask)} is not"
+            )
 
         # Batch single image
         if image.ndim == 3:
-            assert image.shape[0] == 3, "Image outside a batch should be of shape (3, H, W)"
+            assert image.shape[
+                0] == 3, "Image outside a batch should be of shape (3, H, W)"
             image = image.unsqueeze(0)
 
         # Batch and add channel dim for single mask
@@ -87,8 +90,10 @@ def prepare_mask_and_masked_image(image, mask):
                 mask = mask.unsqueeze(1)
 
         assert image.ndim == 4 and mask.ndim == 4, "Image and Mask must have 4 dimensions"
-        assert image.shape[-2:] == mask.shape[-2:], "Image and Mask must have the same spatial dimensions"
-        assert image.shape[0] == mask.shape[0], "Image and Mask must have the same batch size"
+        assert image.shape[-2:] == mask.shape[
+            -2:], "Image and Mask must have the same spatial dimensions"
+        assert image.shape[0] == mask.shape[
+            0], "Image and Mask must have the same batch size"
 
         # Check image is in [-1, 1]
         if image.min() < -1 or image.max() > 1:
@@ -104,7 +109,8 @@ def prepare_mask_and_masked_image(image, mask):
         # Image as float32
         image = image.cast(paddle.float32)
     elif isinstance(mask, paddle.Tensor):
-        raise TypeError(f"`mask` is a paddle.Tensor but `image` (type: {type(image)} is not")
+        raise TypeError(
+            f"`mask` is a paddle.Tensor but `image` (type: {type(image)} is not")
     else:
         # preprocess image
         if isinstance(image, (PIL.Image.Image, np.ndarray)):
@@ -124,7 +130,8 @@ def prepare_mask_and_masked_image(image, mask):
             mask = [mask]
 
         if isinstance(mask, list) and isinstance(mask[0], PIL.Image.Image):
-            mask = np.concatenate([np.array(m.convert("L"))[None, None, :] for m in mask], axis=0)
+            mask = np.concatenate(
+                [np.array(m.convert("L"))[None, None, :] for m in mask], axis=0)
             mask = mask.astype(np.float32) / 255.0
         elif isinstance(mask, list) and isinstance(mask[0], np.ndarray):
             mask = np.concatenate([m[None, None, :] for m in mask], axis=0)
@@ -168,42 +175,50 @@ class StableDiffusionInpaintPipeline(DiffusionPipeline):
     _optional_components = ["safety_checker", "feature_extractor"]
 
     def __init__(
-        self,
-        vae: AutoencoderKL,
-        text_encoder: CLIPTextModel,
-        tokenizer: CLIPTokenizer,
-        unet: UNet2DConditionModel,
-        scheduler: KarrasDiffusionSchedulers,
-        safety_checker: StableDiffusionSafetyChecker,
-        feature_extractor: CLIPFeatureExtractor,
-        requires_safety_checker: bool = True,
-    ):
+            self,
+            vae: AutoencoderKL,
+            text_encoder: CLIPTextModel,
+            tokenizer: CLIPTokenizer,
+            unet: UNet2DConditionModel,
+            scheduler: KarrasDiffusionSchedulers,
+            safety_checker: StableDiffusionSafetyChecker,
+            feature_extractor: CLIPFeatureExtractor,
+            requires_safety_checker: bool=True, ):
         super().__init__()
 
-        if hasattr(scheduler.config, "steps_offset") and scheduler.config.steps_offset != 1:
+        if hasattr(scheduler.config,
+                   "steps_offset") and scheduler.config.steps_offset != 1:
             deprecation_message = (
                 f"The configuration file of this scheduler: {scheduler} is outdated. `steps_offset`"
                 f" should be set to 1 instead of {scheduler.config.steps_offset}. Please make sure "
                 "to update the config accordingly as leaving `steps_offset` might led to incorrect results"
                 " in future versions. If you have downloaded this checkpoint from the Hugging Face Hub,"
                 " it would be very nice if you could open a Pull request for the `scheduler/scheduler_config.json`"
-                " file"
-            )
-            deprecate("steps_offset!=1", "1.0.0", deprecation_message, standard_warn=False)
+                " file")
+            deprecate(
+                "steps_offset!=1",
+                "1.0.0",
+                deprecation_message,
+                standard_warn=False)
             new_config = dict(scheduler.config)
             new_config["steps_offset"] = 1
             scheduler._internal_dict = FrozenDict(new_config)
 
-        if hasattr(scheduler.config, "skip_prk_steps") and scheduler.config.skip_prk_steps is False:
+        if hasattr(
+                scheduler.config,
+                "skip_prk_steps") and scheduler.config.skip_prk_steps is False:
             deprecation_message = (
                 f"The configuration file of this scheduler: {scheduler} has not set the configuration"
                 " `skip_prk_steps`. `skip_prk_steps` should be set to True in the configuration file. Please make"
                 " sure to update the config accordingly as not setting `skip_prk_steps` in the config might lead to"
                 " incorrect results in future versions. If you have downloaded this checkpoint from the Hugging Face"
                 " Hub, it would be very nice if you could open a Pull request for the"
-                " `scheduler/scheduler_config.json` file"
-            )
-            deprecate("skip_prk_steps not set", "1.0.0", deprecation_message, standard_warn=False)
+                " `scheduler/scheduler_config.json` file")
+            deprecate(
+                "skip_prk_steps not set",
+                "1.0.0",
+                deprecation_message,
+                standard_warn=False)
             new_config = dict(scheduler.config)
             new_config["skip_prk_steps"] = True
             scheduler._internal_dict = FrozenDict(new_config)
@@ -224,10 +239,12 @@ class StableDiffusionInpaintPipeline(DiffusionPipeline):
                 " checker. If you do not want to use the safety checker, you can pass `'safety_checker=None'` instead."
             )
 
-        is_unet_version_less_0_9_0 = hasattr(unet.config, "_ppdiffusers_version") and version.parse(
-            version.parse(unet.config._ppdiffusers_version).base_version
-        ) < version.parse("0.9.0.dev0")
-        is_unet_sample_size_less_64 = hasattr(unet.config, "sample_size") and unet.config.sample_size < 64
+        is_unet_version_less_0_9_0 = hasattr(
+            unet.config, "_ppdiffusers_version") and version.parse(
+                version.parse(unet.config._ppdiffusers_version)
+                .base_version) < version.parse("0.9.0.dev0")
+        is_unet_sample_size_less_64 = hasattr(
+            unet.config, "sample_size") and unet.config.sample_size < 64
         if is_unet_version_less_0_9_0 and is_unet_sample_size_less_64:
             deprecation_message = (
                 "The configuration file of the unet has set the default `sample_size` to smaller than"
@@ -238,9 +255,12 @@ class StableDiffusionInpaintPipeline(DiffusionPipeline):
                 " configuration file. Please make sure to update the config accordingly as leaving `sample_size=32`"
                 " in the config might lead to incorrect results in future versions. If you have downloaded this"
                 " checkpoint from the Hugging Face Hub, it would be very nice if you could open a Pull request for"
-                " the `unet/config.json` file"
-            )
-            deprecate("sample_size<64", "1.0.0", deprecation_message, standard_warn=False)
+                " the `unet/config.json` file")
+            deprecate(
+                "sample_size<64",
+                "1.0.0",
+                deprecation_message,
+                standard_warn=False)
             new_config = dict(unet.config)
             new_config["sample_size"] = 64
             unet._internal_dict = FrozenDict(new_config)
@@ -252,21 +272,19 @@ class StableDiffusionInpaintPipeline(DiffusionPipeline):
             unet=unet,
             scheduler=scheduler,
             safety_checker=safety_checker,
-            feature_extractor=feature_extractor,
-        )
-        self.vae_scale_factor = 2 ** (len(self.vae.config.block_out_channels) - 1)
+            feature_extractor=feature_extractor, )
+        self.vae_scale_factor = 2**(len(self.vae.config.block_out_channels) - 1)
         self.register_to_config(requires_safety_checker=requires_safety_checker)
 
     # Copied from ppdiffusers.pipelines.stable_diffusion.pipeline_stable_diffusion.StableDiffusionPipeline._encode_prompt
     def _encode_prompt(
-        self,
-        prompt,
-        num_images_per_prompt,
-        do_classifier_free_guidance,
-        negative_prompt=None,
-        prompt_embeds: Optional[paddle.Tensor] = None,
-        negative_prompt_embeds: Optional[paddle.Tensor] = None,
-    ):
+            self,
+            prompt,
+            num_images_per_prompt,
+            do_classifier_free_guidance,
+            negative_prompt=None,
+            prompt_embeds: Optional[paddle.Tensor]=None,
+            negative_prompt_embeds: Optional[paddle.Tensor]=None, ):
         r"""
         Encodes the prompt into text encoder hidden states.
 
@@ -302,31 +320,29 @@ class StableDiffusionInpaintPipeline(DiffusionPipeline):
                 padding="max_length",
                 max_length=self.tokenizer.model_max_length,
                 truncation=True,
-                return_tensors="pd",
-            )
+                return_tensors="pd", )
             text_input_ids = text_inputs.input_ids
-            untruncated_ids = self.tokenizer(prompt, padding="longest", return_tensors="pd").input_ids
+            untruncated_ids = self.tokenizer(
+                prompt, padding="longest", return_tensors="pd").input_ids
 
-            if untruncated_ids.shape[-1] >= text_input_ids.shape[-1] and not paddle.equal_all(
-                text_input_ids, untruncated_ids
-            ):
+            if untruncated_ids.shape[-1] >= text_input_ids.shape[
+                    -1] and not paddle.equal_all(text_input_ids,
+                                                 untruncated_ids):
                 removed_text = self.tokenizer.batch_decode(
-                    untruncated_ids[:, self.tokenizer.model_max_length - 1 : -1]
-                )
+                    untruncated_ids[:, self.tokenizer.model_max_length - 1:-1])
                 logger.warning(
                     "The following part of your input was truncated because CLIP can only handle sequences up to"
-                    f" {self.tokenizer.model_max_length} tokens: {removed_text}"
-                )
+                    f" {self.tokenizer.model_max_length} tokens: {removed_text}")
 
-            if hasattr(self.text_encoder.config, "use_attention_mask") and self.text_encoder.config.use_attention_mask:
+            if hasattr(self.text_encoder.config, "use_attention_mask"
+                       ) and self.text_encoder.config.use_attention_mask:
                 attention_mask = text_inputs.attention_mask
             else:
                 attention_mask = None
 
             prompt_embeds = self.text_encoder(
                 text_input_ids,
-                attention_mask=attention_mask,
-            )
+                attention_mask=attention_mask, )
             prompt_embeds = prompt_embeds[0]
 
         prompt_embeds = prompt_embeds.cast(self.text_encoder.dtype)
@@ -334,7 +350,8 @@ class StableDiffusionInpaintPipeline(DiffusionPipeline):
         bs_embed, seq_len, _ = prompt_embeds.shape
         # duplicate text embeddings for each generation per prompt, using mps friendly method
         prompt_embeds = prompt_embeds.tile([1, num_images_per_prompt, 1])
-        prompt_embeds = prompt_embeds.reshape([bs_embed * num_images_per_prompt, seq_len, -1])
+        prompt_embeds = prompt_embeds.reshape(
+            [bs_embed * num_images_per_prompt, seq_len, -1])
 
         # get unconditional embeddings for classifier free guidance
         if do_classifier_free_guidance and negative_prompt_embeds is None:
@@ -344,16 +361,14 @@ class StableDiffusionInpaintPipeline(DiffusionPipeline):
             elif type(prompt) is not type(negative_prompt):
                 raise TypeError(
                     f"`negative_prompt` should be the same type to `prompt`, but got {type(negative_prompt)} !="
-                    f" {type(prompt)}."
-                )
+                    f" {type(prompt)}.")
             elif isinstance(negative_prompt, str):
                 uncond_tokens = [negative_prompt]
             elif batch_size != len(negative_prompt):
                 raise ValueError(
                     f"`negative_prompt`: {negative_prompt} has batch size {len(negative_prompt)}, but `prompt`:"
                     f" {prompt} has batch size {batch_size}. Please make sure that passed `negative_prompt` matches"
-                    " the batch size of `prompt`."
-                )
+                    " the batch size of `prompt`.")
             else:
                 uncond_tokens = negative_prompt
 
@@ -363,43 +378,47 @@ class StableDiffusionInpaintPipeline(DiffusionPipeline):
                 padding="max_length",
                 max_length=max_length,
                 truncation=True,
-                return_tensors="pd",
-            )
+                return_tensors="pd", )
 
-            if hasattr(self.text_encoder.config, "use_attention_mask") and self.text_encoder.config.use_attention_mask:
+            if hasattr(self.text_encoder.config, "use_attention_mask"
+                       ) and self.text_encoder.config.use_attention_mask:
                 attention_mask = uncond_input.attention_mask
             else:
                 attention_mask = None
 
             negative_prompt_embeds = self.text_encoder(
                 uncond_input.input_ids,
-                attention_mask=attention_mask,
-            )
+                attention_mask=attention_mask, )
             negative_prompt_embeds = negative_prompt_embeds[0]
 
         if do_classifier_free_guidance:
             # duplicate unconditional embeddings for each generation per prompt, using mps friendly method
             seq_len = negative_prompt_embeds.shape[1]
 
-            negative_prompt_embeds = negative_prompt_embeds.cast(self.text_encoder.dtype)
+            negative_prompt_embeds = negative_prompt_embeds.cast(
+                self.text_encoder.dtype)
 
-            negative_prompt_embeds = negative_prompt_embeds.tile([1, num_images_per_prompt, 1])
-            negative_prompt_embeds = negative_prompt_embeds.reshape([batch_size * num_images_per_prompt, seq_len, -1])
+            negative_prompt_embeds = negative_prompt_embeds.tile(
+                [1, num_images_per_prompt, 1])
+            negative_prompt_embeds = negative_prompt_embeds.reshape(
+                [batch_size * num_images_per_prompt, seq_len, -1])
 
             # For classifier free guidance, we need to do two forward passes.
             # Here we concatenate the unconditional and text embeddings into a single batch
             # to avoid doing two forward passes
-            prompt_embeds = paddle.concat([negative_prompt_embeds, prompt_embeds])
+            prompt_embeds = paddle.concat(
+                [negative_prompt_embeds, prompt_embeds])
 
         return prompt_embeds
 
     # Copied from ppdiffusers.pipelines.stable_diffusion.pipeline_stable_diffusion.StableDiffusionPipeline.run_safety_checker
     def run_safety_checker(self, image, dtype):
         if self.safety_checker is not None:
-            safety_checker_input = self.feature_extractor(self.numpy_to_pil(image), return_tensors="pd")
+            safety_checker_input = self.feature_extractor(
+                self.numpy_to_pil(image), return_tensors="pd")
             image, has_nsfw_concept = self.safety_checker(
-                images=image, clip_input=safety_checker_input.pixel_values.cast(dtype)
-            )
+                images=image,
+                clip_input=safety_checker_input.pixel_values.cast(dtype))
         else:
             has_nsfw_concept = None
         return image, has_nsfw_concept
@@ -411,13 +430,15 @@ class StableDiffusionInpaintPipeline(DiffusionPipeline):
         # eta corresponds to η in DDIM paper: https://arxiv.org/abs/2010.02502
         # and should be between [0, 1]
 
-        accepts_eta = "eta" in set(inspect.signature(self.scheduler.step).parameters.keys())
+        accepts_eta = "eta" in set(
+            inspect.signature(self.scheduler.step).parameters.keys())
         extra_step_kwargs = {}
         if accepts_eta:
             extra_step_kwargs["eta"] = eta
 
         # check if the scheduler accepts generator
-        accepts_generator = "generator" in set(inspect.signature(self.scheduler.step).parameters.keys())
+        accepts_generator = "generator" in set(
+            inspect.signature(self.scheduler.step).parameters.keys())
         if accepts_generator:
             extra_step_kwargs["generator"] = generator
         return extra_step_kwargs
@@ -433,37 +454,39 @@ class StableDiffusionInpaintPipeline(DiffusionPipeline):
 
     # Copied from ppdiffusers.pipelines.stable_diffusion.pipeline_stable_diffusion.StableDiffusionPipeline.check_inputs
     def check_inputs(
-        self,
-        prompt,
-        height,
-        width,
-        callback_steps,
-        negative_prompt=None,
-        prompt_embeds=None,
-        negative_prompt_embeds=None,
-    ):
+            self,
+            prompt,
+            height,
+            width,
+            callback_steps,
+            negative_prompt=None,
+            prompt_embeds=None,
+            negative_prompt_embeds=None, ):
         if height % 8 != 0 or width % 8 != 0:
-            raise ValueError(f"`height` and `width` have to be divisible by 8 but are {height} and {width}.")
+            raise ValueError(
+                f"`height` and `width` have to be divisible by 8 but are {height} and {width}."
+            )
 
         if (callback_steps is None) or (
-            callback_steps is not None and (not isinstance(callback_steps, int) or callback_steps <= 0)
-        ):
+                callback_steps is not None and
+            (not isinstance(callback_steps, int) or callback_steps <= 0)):
             raise ValueError(
                 f"`callback_steps` has to be a positive integer but is {callback_steps} of type"
-                f" {type(callback_steps)}."
-            )
+                f" {type(callback_steps)}.")
 
         if prompt is not None and prompt_embeds is not None:
             raise ValueError(
                 f"Cannot forward both `prompt`: {prompt} and `prompt_embeds`: {prompt_embeds}. Please make sure to"
-                " only forward one of the two."
-            )
+                " only forward one of the two.")
         elif prompt is None and prompt_embeds is None:
             raise ValueError(
                 "Provide either `prompt` or `prompt_embeds`. Cannot leave both `prompt` and `prompt_embeds` undefined."
             )
-        elif prompt is not None and (not isinstance(prompt, str) and not isinstance(prompt, list)):
-            raise ValueError(f"`prompt` has to be of type `str` or `list` but is {type(prompt)}")
+        elif prompt is not None and (not isinstance(prompt, str) and
+                                     not isinstance(prompt, list)):
+            raise ValueError(
+                f"`prompt` has to be of type `str` or `list` but is {type(prompt)}"
+            )
 
         if negative_prompt is not None and negative_prompt_embeds is not None:
             raise ValueError(
@@ -476,12 +499,21 @@ class StableDiffusionInpaintPipeline(DiffusionPipeline):
                 raise ValueError(
                     "`prompt_embeds` and `negative_prompt_embeds` must have the same shape when passed directly, but"
                     f" got: `prompt_embeds` {prompt_embeds.shape} != `negative_prompt_embeds`"
-                    f" {negative_prompt_embeds.shape}."
-                )
+                    f" {negative_prompt_embeds.shape}.")
 
     # Copied from ppdiffusers.pipelines.stable_diffusion.pipeline_stable_diffusion.StableDiffusionPipeline.prepare_latents
-    def prepare_latents(self, batch_size, num_channels_latents, height, width, dtype, generator, latents=None):
-        shape = [batch_size, num_channels_latents, height // self.vae_scale_factor, width // self.vae_scale_factor]
+    def prepare_latents(self,
+                        batch_size,
+                        num_channels_latents,
+                        height,
+                        width,
+                        dtype,
+                        generator,
+                        latents=None):
+        shape = [
+            batch_size, num_channels_latents, height // self.vae_scale_factor,
+            width // self.vae_scale_factor
+        ]
         if isinstance(generator, list) and len(generator) != batch_size:
             raise ValueError(
                 f"You have passed a list of generators of length {len(generator)}, but requested an effective batch"
@@ -495,13 +527,16 @@ class StableDiffusionInpaintPipeline(DiffusionPipeline):
         latents = latents * self.scheduler.init_noise_sigma
         return latents
 
-    def prepare_mask_latents(
-        self, mask, masked_image, batch_size, height, width, dtype, generator, do_classifier_free_guidance
-    ):
+    def prepare_mask_latents(self, mask, masked_image, batch_size, height,
+                             width, dtype, generator,
+                             do_classifier_free_guidance):
         # resize the mask to latents shape as we concatenate the mask to the latents
         # we do that before converting to dtype to avoid breaking in case we're using cpu_offload
         # and half precision
-        mask = F.interpolate(mask, size=(height // self.vae_scale_factor, width // self.vae_scale_factor))
+        mask = F.interpolate(
+            mask,
+            size=(height // self.vae_scale_factor,
+                  width // self.vae_scale_factor))
         mask = mask.cast(dtype)
 
         masked_image = masked_image.cast(dtype)
@@ -509,12 +544,13 @@ class StableDiffusionInpaintPipeline(DiffusionPipeline):
         # encode the mask image into latents space so we can concatenate it to the latents
         if isinstance(generator, list):
             masked_image_latents = [
-                self.vae.encode(masked_image[i : i + 1]).latent_dist.sample(generator=generator[i])
-                for i in range(batch_size)
+                self.vae.encode(masked_image[i:i + 1]).latent_dist.sample(
+                    generator=generator[i]) for i in range(batch_size)
             ]
             masked_image_latents = paddle.concat(masked_image_latents, axis=0)
         else:
-            masked_image_latents = self.vae.encode(masked_image).latent_dist.sample(generator=generator)
+            masked_image_latents = self.vae.encode(
+                masked_image).latent_dist.sample(generator=generator)
         masked_image_latents = self.vae.config.scaling_factor * masked_image_latents
 
         # duplicate mask and masked_image_latents for each generation per prompt, using mps friendly method
@@ -533,12 +569,14 @@ class StableDiffusionInpaintPipeline(DiffusionPipeline):
                     f" to a total batch size of {batch_size}, but {masked_image_latents.shape[0]} images were passed."
                     " Make sure the number of images that you pass is divisible by the total requested batch size."
                 )
-            masked_image_latents = masked_image_latents.tile([batch_size // masked_image_latents.shape[0], 1, 1, 1])
+            masked_image_latents = masked_image_latents.tile(
+                [batch_size // masked_image_latents.shape[0], 1, 1, 1])
 
-        mask = paddle.concat([mask] * 2) if do_classifier_free_guidance else mask
-        masked_image_latents = (
-            paddle.concat([masked_image_latents] * 2) if do_classifier_free_guidance else masked_image_latents
-        )
+        mask = paddle.concat([mask] *
+                             2) if do_classifier_free_guidance else mask
+        masked_image_latents = (paddle.concat([masked_image_latents] * 2)
+                                if do_classifier_free_guidance else
+                                masked_image_latents)
 
         # aligning device to prevent device errors when concating it with the latent model input
         masked_image_latents = masked_image_latents.cast(dtype)
@@ -546,26 +584,26 @@ class StableDiffusionInpaintPipeline(DiffusionPipeline):
 
     @paddle.no_grad()
     def __call__(
-        self,
-        prompt: Union[str, List[str]] = None,
-        image: Union[paddle.Tensor, PIL.Image.Image] = None,
-        mask_image: Union[paddle.Tensor, PIL.Image.Image] = None,
-        height: Optional[int] = None,
-        width: Optional[int] = None,
-        num_inference_steps: int = 50,
-        guidance_scale: float = 7.5,
-        negative_prompt: Optional[Union[str, List[str]]] = None,
-        num_images_per_prompt: Optional[int] = 1,
-        eta: float = 0.0,
-        generator: Optional[Union[paddle.Generator, List[paddle.Generator]]] = None,
-        latents: Optional[paddle.Tensor] = None,
-        prompt_embeds: Optional[paddle.Tensor] = None,
-        negative_prompt_embeds: Optional[paddle.Tensor] = None,
-        output_type: Optional[str] = "pil",
-        return_dict: bool = True,
-        callback: Optional[Callable[[int, int, paddle.Tensor], None]] = None,
-        callback_steps: Optional[int] = 1,
-    ):
+            self,
+            prompt: Union[str, List[str]]=None,
+            image: Union[paddle.Tensor, PIL.Image.Image]=None,
+            mask_image: Union[paddle.Tensor, PIL.Image.Image]=None,
+            height: Optional[int]=None,
+            width: Optional[int]=None,
+            num_inference_steps: int=50,
+            guidance_scale: float=7.5,
+            negative_prompt: Optional[Union[str, List[str]]]=None,
+            num_images_per_prompt: Optional[int]=1,
+            eta: float=0.0,
+            generator: Optional[Union[paddle.Generator, List[
+                paddle.Generator]]]=None,
+            latents: Optional[paddle.Tensor]=None,
+            prompt_embeds: Optional[paddle.Tensor]=None,
+            negative_prompt_embeds: Optional[paddle.Tensor]=None,
+            output_type: Optional[str]="pil",
+            return_dict: bool=True,
+            callback: Optional[Callable[[int, int, paddle.Tensor], None]]=None,
+            callback_steps: Optional[int]=1, ):
         r"""
         Function invoked when calling the pipeline for generation.
 
@@ -678,8 +716,7 @@ class StableDiffusionInpaintPipeline(DiffusionPipeline):
             callback_steps,
             negative_prompt,
             prompt_embeds,
-            negative_prompt_embeds,
-        )
+            negative_prompt_embeds, )
 
         if image is None:
             raise ValueError("`image` input cannot be undefined.")
@@ -707,8 +744,7 @@ class StableDiffusionInpaintPipeline(DiffusionPipeline):
             do_classifier_free_guidance,
             negative_prompt,
             prompt_embeds=prompt_embeds,
-            negative_prompt_embeds=negative_prompt_embeds,
-        )
+            negative_prompt_embeds=negative_prompt_embeds, )
 
         # 4. Preprocess mask and image
         mask, masked_image = prepare_mask_and_masked_image(image, mask_image)
@@ -726,8 +762,7 @@ class StableDiffusionInpaintPipeline(DiffusionPipeline):
             width,
             prompt_embeds.dtype,
             generator,
-            latents,
-        )
+            latents, )
 
         # 7. Prepare mask latent variables
         mask, masked_image_latents = self.prepare_mask_latents(
@@ -738,8 +773,7 @@ class StableDiffusionInpaintPipeline(DiffusionPipeline):
             width,
             prompt_embeds.dtype,
             generator,
-            do_classifier_free_guidance,
-        )
+            do_classifier_free_guidance, )
 
         # 8. Check that sizes of mask, masked image and latents match
         num_channels_mask = mask.shape[1]
@@ -750,39 +784,48 @@ class StableDiffusionInpaintPipeline(DiffusionPipeline):
                 f" {self.unet.config.in_channels} but received `num_channels_latents`: {num_channels_latents} +"
                 f" `num_channels_mask`: {num_channels_mask} + `num_channels_masked_image`: {num_channels_masked_image}"
                 f" = {num_channels_latents+num_channels_masked_image+num_channels_mask}. Please verify the config of"
-                " `pipeline.unet` or your `mask_image` or `image` input."
-            )
+                " `pipeline.unet` or your `mask_image` or `image` input.")
 
         # 9. Prepare extra step kwargs. TODO: Logic should ideally just be moved out of the pipeline
         extra_step_kwargs = self.prepare_extra_step_kwargs(generator, eta)
 
         # 10. Denoising loop
-        num_warmup_steps = len(timesteps) - num_inference_steps * self.scheduler.order
+        num_warmup_steps = len(
+            timesteps) - num_inference_steps * self.scheduler.order
         with self.progress_bar(total=num_inference_steps) as progress_bar:
             for i, t in enumerate(timesteps):
                 # expand the latents if we are doing classifier free guidance
-                latent_model_input = paddle.concat([latents] * 2) if do_classifier_free_guidance else latents
+                latent_model_input = paddle.concat(
+                    [latents] * 2) if do_classifier_free_guidance else latents
 
                 # concat latents, mask, masked_image_latents in the channel dimension
-                latent_model_input = self.scheduler.scale_model_input(latent_model_input, t)
-                latent_model_input = paddle.concat([latent_model_input, mask, masked_image_latents], axis=1)
+                latent_model_input = self.scheduler.scale_model_input(
+                    latent_model_input, t)
+                latent_model_input = paddle.concat(
+                    [latent_model_input, mask, masked_image_latents], axis=1)
 
                 # predict the noise residual
-                noise_pred = self.unet(latent_model_input, t, encoder_hidden_states=prompt_embeds).sample
+                noise_pred = self.unet(
+                    latent_model_input, t,
+                    encoder_hidden_states=prompt_embeds).sample
 
                 # perform guidance
                 if do_classifier_free_guidance:
                     noise_pred_uncond, noise_pred_text = noise_pred.chunk(2)
-                    noise_pred = noise_pred_uncond + guidance_scale * (noise_pred_text - noise_pred_uncond)
+                    noise_pred = noise_pred_uncond + guidance_scale * (
+                        noise_pred_text - noise_pred_uncond)
 
                 # compute the previous noisy sample x_t -> x_t-1
-                latents = self.scheduler.step(noise_pred, t, latents, **extra_step_kwargs).prev_sample
+                latents = self.scheduler.step(noise_pred, t, latents,
+                                              **extra_step_kwargs).prev_sample
 
                 # must cast dtype, paddle.concat has bug....
                 latents = latents.cast(prompt_embeds.dtype)
 
                 # call the callback, if provided
-                if i == len(timesteps) - 1 or ((i + 1) > num_warmup_steps and (i + 1) % self.scheduler.order == 0):
+                if i == len(timesteps) - 1 or (
+                    (i + 1) > num_warmup_steps and
+                    (i + 1) % self.scheduler.order == 0):
                     progress_bar.update()
                     if callback is not None and i % callback_steps == 0:
                         callback(i, t, latents)
@@ -791,7 +834,8 @@ class StableDiffusionInpaintPipeline(DiffusionPipeline):
         image = self.decode_latents(latents)
 
         # 12. Run safety checker
-        image, has_nsfw_concept = self.run_safety_checker(image, prompt_embeds.dtype)
+        image, has_nsfw_concept = self.run_safety_checker(image,
+                                                          prompt_embeds.dtype)
 
         # 13. Convert to PIL
         if output_type == "pil":
@@ -800,4 +844,5 @@ class StableDiffusionInpaintPipeline(DiffusionPipeline):
         if not return_dict:
             return (image, has_nsfw_concept)
 
-        return StableDiffusionPipelineOutput(images=image, nsfw_content_detected=has_nsfw_concept)
+        return StableDiffusionPipelineOutput(
+            images=image, nsfw_content_detected=has_nsfw_concept)
