@@ -21,8 +21,7 @@ import paddle
 from paddlenlp.transformers import (
     CLIPTextModel,
     CLIPTextModelWithProjection,
-    CLIPTokenizer,
-)
+    CLIPTokenizer, )
 from paddlenlp.transformers.clip.modeling import CLIPTextModelOutput
 
 from ...loaders import TextualInversionLoaderMixin
@@ -108,23 +107,22 @@ class StableUnCLIPPipeline(DiffusionPipeline, TextualInversionLoaderMixin):
     vae: AutoencoderKL
 
     def __init__(
-        self,
-        # prior components
-        prior_tokenizer: CLIPTokenizer,
-        prior_text_encoder: CLIPTextModelWithProjection,
-        prior: PriorTransformer,
-        prior_scheduler: KarrasDiffusionSchedulers,
-        # image noising components
-        image_normalizer: StableUnCLIPImageNormalizer,
-        image_noising_scheduler: KarrasDiffusionSchedulers,
-        # regular denoising components
-        tokenizer: CLIPTokenizer,
-        text_encoder: CLIPTextModelWithProjection,
-        unet: UNet2DConditionModel,
-        scheduler: KarrasDiffusionSchedulers,
-        # vae
-        vae: AutoencoderKL,
-    ):
+            self,
+            # prior components
+            prior_tokenizer: CLIPTokenizer,
+            prior_text_encoder: CLIPTextModelWithProjection,
+            prior: PriorTransformer,
+            prior_scheduler: KarrasDiffusionSchedulers,
+            # image noising components
+            image_normalizer: StableUnCLIPImageNormalizer,
+            image_noising_scheduler: KarrasDiffusionSchedulers,
+            # regular denoising components
+            tokenizer: CLIPTokenizer,
+            text_encoder: CLIPTextModelWithProjection,
+            unet: UNet2DConditionModel,
+            scheduler: KarrasDiffusionSchedulers,
+            # vae
+            vae: AutoencoderKL, ):
         super().__init__()
 
         self.register_modules(
@@ -138,20 +136,18 @@ class StableUnCLIPPipeline(DiffusionPipeline, TextualInversionLoaderMixin):
             text_encoder=text_encoder,
             unet=unet,
             scheduler=scheduler,
-            vae=vae,
-        )
+            vae=vae, )
 
-        self.vae_scale_factor = 2 ** (len(self.vae.config.block_out_channels) - 1)
+        self.vae_scale_factor = 2**(len(self.vae.config.block_out_channels) - 1)
 
     # Copied from ppdiffusers.pipelines.unclip.pipeline_unclip.UnCLIPPipeline._encode_prompt with _encode_prompt->_encode_prior_prompt, tokenizer->prior_tokenizer, text_encoder->prior_text_encoder
     def _encode_prior_prompt(
-        self,
-        prompt,
-        num_images_per_prompt,
-        do_classifier_free_guidance,
-        text_model_output: Optional[Union[CLIPTextModelOutput, Tuple]] = None,
-        text_attention_mask: Optional[paddle.Tensor] = None,
-    ):
+            self,
+            prompt,
+            num_images_per_prompt,
+            do_classifier_free_guidance,
+            text_model_output: Optional[Union[CLIPTextModelOutput, Tuple]]=None,
+            text_attention_mask: Optional[paddle.Tensor]=None, ):
         if text_model_output is None:
             batch_size = len(prompt) if isinstance(prompt, list) else 1
             # get prompt text embeddings
@@ -161,24 +157,25 @@ class StableUnCLIPPipeline(DiffusionPipeline, TextualInversionLoaderMixin):
                 max_length=self.prior_tokenizer.model_max_length,
                 return_attention_mask=True,
                 truncation=True,
-                return_tensors="pd",
-            )
+                return_tensors="pd", )
             text_input_ids = text_inputs.input_ids
             text_mask = text_inputs.attention_mask
 
-            untruncated_ids = self.prior_tokenizer(prompt, padding="longest", return_tensors="pd").input_ids
+            untruncated_ids = self.prior_tokenizer(
+                prompt, padding="longest", return_tensors="pd").input_ids
 
-            if untruncated_ids.shape[-1] >= text_input_ids.shape[-1] and not paddle.equal_all(
-                text_input_ids, untruncated_ids
-            ):
+            if untruncated_ids.shape[-1] >= text_input_ids.shape[
+                    -1] and not paddle.equal_all(text_input_ids,
+                                                 untruncated_ids):
                 removed_text = self.prior_tokenizer.batch_decode(
-                    untruncated_ids[:, self.prior_tokenizer.model_max_length - 1 : -1]
-                )
+                    untruncated_ids[:, self.prior_tokenizer.model_max_length -
+                                    1:-1])
                 logger.warning(
                     "The following part of your input was truncated because CLIP can only handle sequences up to"
                     f" {self.prior_tokenizer.model_max_length} tokens: {removed_text}"
                 )
-                text_input_ids = text_input_ids[:, : self.prior_tokenizer.model_max_length]
+                text_input_ids = text_input_ids[:, :self.prior_tokenizer.
+                                                model_max_length]
 
             prior_text_encoder_output = self.prior_text_encoder(text_input_ids)
 
@@ -187,13 +184,14 @@ class StableUnCLIPPipeline(DiffusionPipeline, TextualInversionLoaderMixin):
 
         else:
             batch_size = text_model_output[0].shape[0]
-            prompt_embeds, prior_text_encoder_hidden_states = text_model_output[0], text_model_output[1]
+            prompt_embeds, prior_text_encoder_hidden_states = text_model_output[
+                0], text_model_output[1]
             text_mask = text_attention_mask
 
-        prompt_embeds = prompt_embeds.repeat_interleave(num_images_per_prompt, axis=0)
+        prompt_embeds = prompt_embeds.repeat_interleave(
+            num_images_per_prompt, axis=0)
         prior_text_encoder_hidden_states = prior_text_encoder_hidden_states.repeat_interleave(
-            num_images_per_prompt, axis=0
-        )
+            num_images_per_prompt, axis=0)
 
         text_mask = text_mask.repeat_interleave(num_images_per_prompt, axis=0)
 
@@ -206,40 +204,43 @@ class StableUnCLIPPipeline(DiffusionPipeline, TextualInversionLoaderMixin):
                 max_length=self.prior_tokenizer.model_max_length,
                 return_attention_mask=True,
                 truncation=True,
-                return_tensors="pd",
-            )
+                return_tensors="pd", )
             uncond_text_mask = uncond_input.attention_mask
-            negative_prompt_embeds_prior_text_encoder_output = self.prior_text_encoder(uncond_input.input_ids)
+            negative_prompt_embeds_prior_text_encoder_output = self.prior_text_encoder(
+                uncond_input.input_ids)
 
             negative_prompt_embeds = negative_prompt_embeds_prior_text_encoder_output.text_embeds
             uncond_prior_text_encoder_hidden_states = (
-                negative_prompt_embeds_prior_text_encoder_output.last_hidden_state
-            )
+                negative_prompt_embeds_prior_text_encoder_output.
+                last_hidden_state)
 
             # duplicate unconditional embeddings for each generation per prompt, using mps friendly method
 
             seq_len = negative_prompt_embeds.shape[1]
-            negative_prompt_embeds = negative_prompt_embeds.tile([1, num_images_per_prompt])
-            negative_prompt_embeds = negative_prompt_embeds.reshape([batch_size * num_images_per_prompt, seq_len])
+            negative_prompt_embeds = negative_prompt_embeds.tile(
+                [1, num_images_per_prompt])
+            negative_prompt_embeds = negative_prompt_embeds.reshape(
+                [batch_size * num_images_per_prompt, seq_len])
 
             seq_len = uncond_prior_text_encoder_hidden_states.shape[1]
             uncond_prior_text_encoder_hidden_states = uncond_prior_text_encoder_hidden_states.tile(
-                [1, num_images_per_prompt, 1]
-            )
+                [1, num_images_per_prompt, 1])
             uncond_prior_text_encoder_hidden_states = uncond_prior_text_encoder_hidden_states.reshape(
-                [batch_size * num_images_per_prompt, seq_len, -1]
-            )
-            uncond_text_mask = uncond_text_mask.repeat_interleave(num_images_per_prompt, axis=0)
+                [batch_size * num_images_per_prompt, seq_len, -1])
+            uncond_text_mask = uncond_text_mask.repeat_interleave(
+                num_images_per_prompt, axis=0)
 
             # done duplicates
 
             # For classifier free guidance, we need to do two forward passes.
             # Here we concatenate the unconditional and text embeddings into a single batch
             # to avoid doing two forward passes
-            prompt_embeds = paddle.concat([negative_prompt_embeds, prompt_embeds])
-            prior_text_encoder_hidden_states = paddle.concat(
-                [uncond_prior_text_encoder_hidden_states, prior_text_encoder_hidden_states]
-            )
+            prompt_embeds = paddle.concat(
+                [negative_prompt_embeds, prompt_embeds])
+            prior_text_encoder_hidden_states = paddle.concat([
+                uncond_prior_text_encoder_hidden_states,
+                prior_text_encoder_hidden_states
+            ])
 
             text_mask = paddle.concat([uncond_text_mask, text_mask])
 
@@ -247,14 +248,13 @@ class StableUnCLIPPipeline(DiffusionPipeline, TextualInversionLoaderMixin):
 
     # Copied from ppdiffusers.pipelines.stable_diffusion.pipeline_stable_diffusion.StableDiffusionPipeline._encode_prompt
     def _encode_prompt(
-        self,
-        prompt,
-        num_images_per_prompt,
-        do_classifier_free_guidance,
-        negative_prompt=None,
-        prompt_embeds: Optional[paddle.Tensor] = None,
-        negative_prompt_embeds: Optional[paddle.Tensor] = None,
-    ):
+            self,
+            prompt,
+            num_images_per_prompt,
+            do_classifier_free_guidance,
+            negative_prompt=None,
+            prompt_embeds: Optional[paddle.Tensor]=None,
+            negative_prompt_embeds: Optional[paddle.Tensor]=None, ):
         r"""
         Encodes the prompt into text encoder hidden states.
 
@@ -294,31 +294,29 @@ class StableUnCLIPPipeline(DiffusionPipeline, TextualInversionLoaderMixin):
                 padding="max_length",
                 max_length=self.tokenizer.model_max_length,
                 truncation=True,
-                return_tensors="pd",
-            )
+                return_tensors="pd", )
             text_input_ids = text_inputs.input_ids
-            untruncated_ids = self.tokenizer(prompt, padding="longest", return_tensors="pd").input_ids
+            untruncated_ids = self.tokenizer(
+                prompt, padding="longest", return_tensors="pd").input_ids
 
-            if untruncated_ids.shape[-1] >= text_input_ids.shape[-1] and not paddle.equal_all(
-                text_input_ids, untruncated_ids
-            ):
+            if untruncated_ids.shape[-1] >= text_input_ids.shape[
+                    -1] and not paddle.equal_all(text_input_ids,
+                                                 untruncated_ids):
                 removed_text = self.tokenizer.batch_decode(
-                    untruncated_ids[:, self.tokenizer.model_max_length - 1 : -1]
-                )
+                    untruncated_ids[:, self.tokenizer.model_max_length - 1:-1])
                 logger.warning(
                     "The following part of your input was truncated because CLIP can only handle sequences up to"
-                    f" {self.tokenizer.model_max_length} tokens: {removed_text}"
-                )
+                    f" {self.tokenizer.model_max_length} tokens: {removed_text}")
 
-            if hasattr(self.text_encoder.config, "use_attention_mask") and self.text_encoder.config.use_attention_mask:
+            if hasattr(self.text_encoder.config, "use_attention_mask"
+                       ) and self.text_encoder.config.use_attention_mask:
                 attention_mask = text_inputs.attention_mask
             else:
                 attention_mask = None
 
             prompt_embeds = self.text_encoder(
                 text_input_ids,
-                attention_mask=attention_mask,
-            )
+                attention_mask=attention_mask, )
             prompt_embeds = prompt_embeds[0]
 
         prompt_embeds = prompt_embeds.cast(self.text_encoder.dtype)
@@ -326,7 +324,8 @@ class StableUnCLIPPipeline(DiffusionPipeline, TextualInversionLoaderMixin):
         bs_embed, seq_len, _ = prompt_embeds.shape
         # duplicate text embeddings for each generation per prompt, using mps friendly method
         prompt_embeds = prompt_embeds.tile([1, num_images_per_prompt, 1])
-        prompt_embeds = prompt_embeds.reshape([bs_embed * num_images_per_prompt, seq_len, -1])
+        prompt_embeds = prompt_embeds.reshape(
+            [bs_embed * num_images_per_prompt, seq_len, -1])
 
         # get unconditional embeddings for classifier free guidance
         if do_classifier_free_guidance and negative_prompt_embeds is None:
@@ -336,22 +335,21 @@ class StableUnCLIPPipeline(DiffusionPipeline, TextualInversionLoaderMixin):
             elif type(prompt) is not type(negative_prompt):
                 raise TypeError(
                     f"`negative_prompt` should be the same type to `prompt`, but got {type(negative_prompt)} !="
-                    f" {type(prompt)}."
-                )
+                    f" {type(prompt)}.")
             elif isinstance(negative_prompt, str):
                 uncond_tokens = [negative_prompt]
             elif batch_size != len(negative_prompt):
                 raise ValueError(
                     f"`negative_prompt`: {negative_prompt} has batch size {len(negative_prompt)}, but `prompt`:"
                     f" {prompt} has batch size {batch_size}. Please make sure that passed `negative_prompt` matches"
-                    " the batch size of `prompt`."
-                )
+                    " the batch size of `prompt`.")
             else:
                 uncond_tokens = negative_prompt
 
             # textual inversion: procecss multi-vector tokens if necessary
             if isinstance(self, TextualInversionLoaderMixin):
-                uncond_tokens = self.maybe_convert_prompt(uncond_tokens, self.tokenizer)
+                uncond_tokens = self.maybe_convert_prompt(uncond_tokens,
+                                                          self.tokenizer)
 
             max_length = prompt_embeds.shape[1]
             uncond_input = self.tokenizer(
@@ -359,33 +357,36 @@ class StableUnCLIPPipeline(DiffusionPipeline, TextualInversionLoaderMixin):
                 padding="max_length",
                 max_length=max_length,
                 truncation=True,
-                return_tensors="pd",
-            )
+                return_tensors="pd", )
 
-            if hasattr(self.text_encoder.config, "use_attention_mask") and self.text_encoder.config.use_attention_mask:
+            if hasattr(self.text_encoder.config, "use_attention_mask"
+                       ) and self.text_encoder.config.use_attention_mask:
                 attention_mask = uncond_input.attention_mask
             else:
                 attention_mask = None
 
             negative_prompt_embeds = self.text_encoder(
                 uncond_input.input_ids,
-                attention_mask=attention_mask,
-            )
+                attention_mask=attention_mask, )
             negative_prompt_embeds = negative_prompt_embeds[0]
 
         if do_classifier_free_guidance:
             # duplicate unconditional embeddings for each generation per prompt, using mps friendly method
             seq_len = negative_prompt_embeds.shape[1]
 
-            negative_prompt_embeds = negative_prompt_embeds.cast(self.text_encoder.dtype)
+            negative_prompt_embeds = negative_prompt_embeds.cast(
+                self.text_encoder.dtype)
 
-            negative_prompt_embeds = negative_prompt_embeds.tile([1, num_images_per_prompt, 1])
-            negative_prompt_embeds = negative_prompt_embeds.reshape([batch_size * num_images_per_prompt, seq_len, -1])
+            negative_prompt_embeds = negative_prompt_embeds.tile(
+                [1, num_images_per_prompt, 1])
+            negative_prompt_embeds = negative_prompt_embeds.reshape(
+                [batch_size * num_images_per_prompt, seq_len, -1])
 
             # For classifier free guidance, we need to do two forward passes.
             # Here we concatenate the unconditional and text embeddings into a single batch
             # to avoid doing two forward passes
-            prompt_embeds = paddle.concat([negative_prompt_embeds, prompt_embeds])
+            prompt_embeds = paddle.concat(
+                [negative_prompt_embeds, prompt_embeds])
 
         return prompt_embeds
 
@@ -405,13 +406,15 @@ class StableUnCLIPPipeline(DiffusionPipeline, TextualInversionLoaderMixin):
         # eta corresponds to η in DDIM paper: https://arxiv.org/abs/2010.02502
         # and should be between [0, 1]
 
-        accepts_eta = "eta" in set(inspect.signature(self.prior_scheduler.step).parameters.keys())
+        accepts_eta = "eta" in set(
+            inspect.signature(self.prior_scheduler.step).parameters.keys())
         extra_step_kwargs = {}
         if accepts_eta:
             extra_step_kwargs["eta"] = eta
 
         # check if the prior_scheduler accepts generator
-        accepts_generator = "generator" in set(inspect.signature(self.prior_scheduler.step).parameters.keys())
+        accepts_generator = "generator" in set(
+            inspect.signature(self.prior_scheduler.step).parameters.keys())
         if accepts_generator:
             extra_step_kwargs["generator"] = generator
         return extra_step_kwargs
@@ -423,38 +426,40 @@ class StableUnCLIPPipeline(DiffusionPipeline, TextualInversionLoaderMixin):
         # eta corresponds to η in DDIM paper: https://arxiv.org/abs/2010.02502
         # and should be between [0, 1]
 
-        accepts_eta = "eta" in set(inspect.signature(self.scheduler.step).parameters.keys())
+        accepts_eta = "eta" in set(
+            inspect.signature(self.scheduler.step).parameters.keys())
         extra_step_kwargs = {}
         if accepts_eta:
             extra_step_kwargs["eta"] = eta
 
         # check if the scheduler accepts generator
-        accepts_generator = "generator" in set(inspect.signature(self.scheduler.step).parameters.keys())
+        accepts_generator = "generator" in set(
+            inspect.signature(self.scheduler.step).parameters.keys())
         if accepts_generator:
             extra_step_kwargs["generator"] = generator
         return extra_step_kwargs
 
     def check_inputs(
-        self,
-        prompt,
-        height,
-        width,
-        callback_steps,
-        noise_level,
-        negative_prompt=None,
-        prompt_embeds=None,
-        negative_prompt_embeds=None,
-    ):
+            self,
+            prompt,
+            height,
+            width,
+            callback_steps,
+            noise_level,
+            negative_prompt=None,
+            prompt_embeds=None,
+            negative_prompt_embeds=None, ):
         if height % 8 != 0 or width % 8 != 0:
-            raise ValueError(f"`height` and `width` have to be divisible by 8 but are {height} and {width}.")
+            raise ValueError(
+                f"`height` and `width` have to be divisible by 8 but are {height} and {width}."
+            )
 
         if (callback_steps is None) or (
-            callback_steps is not None and (not isinstance(callback_steps, int) or callback_steps <= 0)
-        ):
+                callback_steps is not None and
+            (not isinstance(callback_steps, int) or callback_steps <= 0)):
             raise ValueError(
                 f"`callback_steps` has to be a positive integer but is {callback_steps} of type"
-                f" {type(callback_steps)}."
-            )
+                f" {type(callback_steps)}.")
 
         if prompt is not None and prompt_embeds is not None:
             raise ValueError(
@@ -466,8 +471,11 @@ class StableUnCLIPPipeline(DiffusionPipeline, TextualInversionLoaderMixin):
                 "Provide either `prompt` or `prompt_embeds`. Cannot leave both `prompt` and `prompt_embeds` undefined."
             )
 
-        if prompt is not None and (not isinstance(prompt, str) and not isinstance(prompt, list)):
-            raise ValueError(f"`prompt` has to be of type `str` or `list` but is {type(prompt)}")
+        if prompt is not None and (not isinstance(prompt, str) and
+                                   not isinstance(prompt, list)):
+            raise ValueError(
+                f"`prompt` has to be of type `str` or `list` but is {type(prompt)}"
+            )
 
         if negative_prompt is not None and negative_prompt_embeds is not None:
             raise ValueError(
@@ -478,16 +486,14 @@ class StableUnCLIPPipeline(DiffusionPipeline, TextualInversionLoaderMixin):
             if type(prompt) is not type(negative_prompt):
                 raise TypeError(
                     f"`negative_prompt` should be the same type to `prompt`, but got {type(negative_prompt)} !="
-                    f" {type(prompt)}."
-                )
+                    f" {type(prompt)}.")
 
         if prompt_embeds is not None and negative_prompt_embeds is not None:
             if prompt_embeds.shape != negative_prompt_embeds.shape:
                 raise ValueError(
                     "`prompt_embeds` and `negative_prompt_embeds` must have the same shape when passed directly, but"
                     f" got: `prompt_embeds` {prompt_embeds.shape} != `negative_prompt_embeds`"
-                    f" {negative_prompt_embeds.shape}."
-                )
+                    f" {negative_prompt_embeds.shape}.")
 
         if noise_level < 0 or noise_level >= self.image_noising_scheduler.config.num_train_timesteps:
             raise ValueError(
@@ -500,19 +506,20 @@ class StableUnCLIPPipeline(DiffusionPipeline, TextualInversionLoaderMixin):
             latents = randn_tensor(shape, generator=generator, dtype=dtype)
         else:
             if latents.shape != list(shape):
-                raise ValueError(f"Unexpected latents shape, got {latents.shape}, expected {shape}")
+                raise ValueError(
+                    f"Unexpected latents shape, got {latents.shape}, expected {shape}"
+                )
             latents = latents
 
         latents = latents * scheduler.init_noise_sigma
         return latents
 
     def noise_image_embeddings(
-        self,
-        image_embeds: paddle.Tensor,
-        noise_level: int,
-        noise: Optional[paddle.Tensor] = None,
-        generator: Optional[paddle.Generator] = None,
-    ):
+            self,
+            image_embeds: paddle.Tensor,
+            noise_level: int,
+            noise: Optional[paddle.Tensor]=None,
+            generator: Optional[paddle.Generator]=None, ):
         """
         Add noise to the image embeddings. The amount of noise is controlled by a `noise_level` input. A higher
         `noise_level` increases the variance in the final un-noised images.
@@ -526,19 +533,25 @@ class StableUnCLIPPipeline(DiffusionPipeline, TextualInversionLoaderMixin):
         The embeddings are normalized before the noise is applied and un-normalized after the noise is applied.
         """
         if noise is None:
-            noise = randn_tensor(image_embeds.shape, generator=generator, dtype=image_embeds.dtype)
+            noise = randn_tensor(
+                image_embeds.shape,
+                generator=generator,
+                dtype=image_embeds.dtype)
 
         noise_level = paddle.to_tensor([noise_level] * image_embeds.shape[0])
 
         image_embeds = self.image_normalizer.scale(image_embeds)
 
-        image_embeds = self.image_noising_scheduler.add_noise(image_embeds, timesteps=noise_level, noise=noise)
+        image_embeds = self.image_noising_scheduler.add_noise(
+            image_embeds, timesteps=noise_level, noise=noise)
 
         image_embeds = self.image_normalizer.unscale(image_embeds)
 
         noise_level = get_timestep_embedding(
-            timesteps=noise_level, embedding_dim=image_embeds.shape[-1], flip_sin_to_cos=True, downscale_freq_shift=0
-        )
+            timesteps=noise_level,
+            embedding_dim=image_embeds.shape[-1],
+            flip_sin_to_cos=True,
+            downscale_freq_shift=0)
 
         # `get_timestep_embeddings` does not contain any weights and will always return f32 tensors,
         # but we might actually be running in fp16. so we need to cast here.
@@ -552,31 +565,30 @@ class StableUnCLIPPipeline(DiffusionPipeline, TextualInversionLoaderMixin):
     @paddle.no_grad()
     @replace_example_docstring(EXAMPLE_DOC_STRING)
     def __call__(
-        self,
-        # regular denoising process args
-        prompt: Optional[Union[str, List[str]]] = None,
-        height: Optional[int] = None,
-        width: Optional[int] = None,
-        num_inference_steps: int = 20,
-        guidance_scale: float = 10.0,
-        negative_prompt: Optional[Union[str, List[str]]] = None,
-        num_images_per_prompt: Optional[int] = 1,
-        eta: float = 0.0,
-        generator: Optional[paddle.Generator] = None,
-        latents: Optional[paddle.Tensor] = None,
-        prompt_embeds: Optional[paddle.Tensor] = None,
-        negative_prompt_embeds: Optional[paddle.Tensor] = None,
-        output_type: Optional[str] = "pil",
-        return_dict: bool = True,
-        callback: Optional[Callable[[int, int, paddle.Tensor], None]] = None,
-        callback_steps: Optional[int] = 1,
-        cross_attention_kwargs: Optional[Dict[str, Any]] = None,
-        noise_level: int = 0,
-        # prior args
-        prior_num_inference_steps: int = 25,
-        prior_guidance_scale: float = 4.0,
-        prior_latents: Optional[paddle.Tensor] = None,
-    ):
+            self,
+            # regular denoising process args
+            prompt: Optional[Union[str, List[str]]]=None,
+            height: Optional[int]=None,
+            width: Optional[int]=None,
+            num_inference_steps: int=20,
+            guidance_scale: float=10.0,
+            negative_prompt: Optional[Union[str, List[str]]]=None,
+            num_images_per_prompt: Optional[int]=1,
+            eta: float=0.0,
+            generator: Optional[paddle.Generator]=None,
+            latents: Optional[paddle.Tensor]=None,
+            prompt_embeds: Optional[paddle.Tensor]=None,
+            negative_prompt_embeds: Optional[paddle.Tensor]=None,
+            output_type: Optional[str]="pil",
+            return_dict: bool=True,
+            callback: Optional[Callable[[int, int, paddle.Tensor], None]]=None,
+            callback_steps: Optional[int]=1,
+            cross_attention_kwargs: Optional[Dict[str, Any]]=None,
+            noise_level: int=0,
+            # prior args
+            prior_num_inference_steps: int=25,
+            prior_guidance_scale: float=4.0,
+            prior_latents: Optional[paddle.Tensor]=None, ):
         """
         Function invoked when calling the pipeline for generation.
 
@@ -634,7 +646,7 @@ class StableUnCLIPPipeline(DiffusionPipeline, TextualInversionLoaderMixin):
             cross_attention_kwargs (`dict`, *optional*):
                 A kwargs dictionary that if specified is passed along to the `AttentionProcessor` as defined under
                 `self.processor` in
-                [ppdiffusers.cross_attention](https://github.com/PaddlePaddle/PaddleNLP/blob/develop/ppdiffusers/ppdiffusers/models/cross_attention.py).
+                [ppdiffusers.cross_attention](https://github.com/PaddlePaddle/PaddleMIX/blob/develop/ppdiffusers/ppdiffusers/models/cross_attention.py).
             noise_level (`int`, *optional*, defaults to `0`):
                 The amount of noise to add to the image embeddings. A higher `noise_level` increases the variance in
                 the final un-noised images. See `StableUnCLIPPipeline.noise_image_embeddings` for details.
@@ -672,8 +684,7 @@ class StableUnCLIPPipeline(DiffusionPipeline, TextualInversionLoaderMixin):
             noise_level=noise_level,
             negative_prompt=negative_prompt,
             prompt_embeds=prompt_embeds,
-            negative_prompt_embeds=negative_prompt_embeds,
-        )
+            negative_prompt_embeds=negative_prompt_embeds, )
 
         # 2. Define call parameters
         if prompt is not None and isinstance(prompt, str):
@@ -694,8 +705,7 @@ class StableUnCLIPPipeline(DiffusionPipeline, TextualInversionLoaderMixin):
         prior_prompt_embeds, prior_text_encoder_hidden_states, prior_text_mask = self._encode_prior_prompt(
             prompt=prompt,
             num_images_per_prompt=num_images_per_prompt,
-            do_classifier_free_guidance=prior_do_classifier_free_guidance,
-        )
+            do_classifier_free_guidance=prior_do_classifier_free_guidance, )
 
         # 4. Prepare prior timesteps
         self.prior_scheduler.set_timesteps(prior_num_inference_steps)
@@ -708,40 +718,40 @@ class StableUnCLIPPipeline(DiffusionPipeline, TextualInversionLoaderMixin):
             prior_prompt_embeds.dtype,
             generator,
             prior_latents,
-            self.prior_scheduler,
-        )
+            self.prior_scheduler, )
 
         # 6. Prepare extra step kwargs. TODO: Logic should ideally just be moved out of the pipeline
-        prior_extra_step_kwargs = self.prepare_prior_extra_step_kwargs(generator, eta)
+        prior_extra_step_kwargs = self.prepare_prior_extra_step_kwargs(
+            generator, eta)
 
         # 7. Prior denoising loop
         for i, t in enumerate(self.progress_bar(prior_timesteps_tensor)):
             # expand the latents if we are doing classifier free guidance
-            latent_model_input = (
-                paddle.concat([prior_latents] * 2) if prior_do_classifier_free_guidance else prior_latents
-            )
-            latent_model_input = self.prior_scheduler.scale_model_input(latent_model_input, t)
+            latent_model_input = (paddle.concat([prior_latents] * 2)
+                                  if prior_do_classifier_free_guidance else
+                                  prior_latents)
+            latent_model_input = self.prior_scheduler.scale_model_input(
+                latent_model_input, t)
 
             predicted_image_embedding = self.prior(
                 latent_model_input,
                 timestep=t,
                 proj_embedding=prior_prompt_embeds,
                 encoder_hidden_states=prior_text_encoder_hidden_states,
-                attention_mask=prior_text_mask,
-            ).predicted_image_embedding
+                attention_mask=prior_text_mask, ).predicted_image_embedding
 
             if prior_do_classifier_free_guidance:
-                predicted_image_embedding_uncond, predicted_image_embedding_text = predicted_image_embedding.chunk(2)
+                predicted_image_embedding_uncond, predicted_image_embedding_text = predicted_image_embedding.chunk(
+                    2)
                 predicted_image_embedding = predicted_image_embedding_uncond + prior_guidance_scale * (
-                    predicted_image_embedding_text - predicted_image_embedding_uncond
-                )
+                    predicted_image_embedding_text -
+                    predicted_image_embedding_uncond)
 
             prior_latents = self.prior_scheduler.step(
                 predicted_image_embedding,
                 timestep=t,
                 sample=prior_latents,
-                **prior_extra_step_kwargs,
-            ).prev_sample
+                **prior_extra_step_kwargs, ).prev_sample
 
             if callback is not None and i % callback_steps == 0:
                 callback(i, t, prior_latents)
@@ -764,15 +774,13 @@ class StableUnCLIPPipeline(DiffusionPipeline, TextualInversionLoaderMixin):
             do_classifier_free_guidance=do_classifier_free_guidance,
             negative_prompt=negative_prompt,
             prompt_embeds=prompt_embeds,
-            negative_prompt_embeds=negative_prompt_embeds,
-        )
+            negative_prompt_embeds=negative_prompt_embeds, )
 
         # 9. Prepare image embeddings
         image_embeds = self.noise_image_embeddings(
             image_embeds=image_embeds,
             noise_level=noise_level,
-            generator=generator,
-        )
+            generator=generator, )
 
         if do_classifier_free_guidance:
             negative_prompt_embeds = paddle.zeros_like(image_embeds)
@@ -788,22 +796,24 @@ class StableUnCLIPPipeline(DiffusionPipeline, TextualInversionLoaderMixin):
 
         # 11. Prepare latent variables
         num_channels_latents = self.unet.config.in_channels
-        shape = (batch_size, num_channels_latents, height // self.vae_scale_factor, width // self.vae_scale_factor)
+        shape = (batch_size, num_channels_latents, height //
+                 self.vae_scale_factor, width // self.vae_scale_factor)
         latents = self.prepare_latents(
             shape=shape,
             dtype=prompt_embeds.dtype,
             generator=generator,
             latents=latents,
-            scheduler=self.scheduler,
-        )
+            scheduler=self.scheduler, )
 
         # 12. Prepare extra step kwargs. TODO: Logic should ideally just be moved out of the pipeline
         extra_step_kwargs = self.prepare_extra_step_kwargs(generator, eta)
 
         # 13. Denoising loop
         for i, t in enumerate(self.progress_bar(timesteps)):
-            latent_model_input = paddle.concat([latents] * 2) if do_classifier_free_guidance else latents
-            latent_model_input = self.scheduler.scale_model_input(latent_model_input, t)
+            latent_model_input = paddle.concat(
+                [latents] * 2) if do_classifier_free_guidance else latents
+            latent_model_input = self.scheduler.scale_model_input(
+                latent_model_input, t)
 
             # predict the noise residual
             noise_pred = self.unet(
@@ -811,16 +821,17 @@ class StableUnCLIPPipeline(DiffusionPipeline, TextualInversionLoaderMixin):
                 t,
                 encoder_hidden_states=prompt_embeds,
                 class_labels=image_embeds,
-                cross_attention_kwargs=cross_attention_kwargs,
-            ).sample
+                cross_attention_kwargs=cross_attention_kwargs, ).sample
 
             # perform guidance
             if do_classifier_free_guidance:
                 noise_pred_uncond, noise_pred_text = noise_pred.chunk(2)
-                noise_pred = noise_pred_uncond + guidance_scale * (noise_pred_text - noise_pred_uncond)
+                noise_pred = noise_pred_uncond + guidance_scale * (
+                    noise_pred_text - noise_pred_uncond)
 
             # compute the previous noisy sample x_t -> x_t-1
-            latents = self.scheduler.step(noise_pred, t, latents, **extra_step_kwargs).prev_sample
+            latents = self.scheduler.step(noise_pred, t, latents,
+                                          **extra_step_kwargs).prev_sample
 
             if callback is not None and i % callback_steps == 0:
                 callback(i, t, latents)
@@ -833,6 +844,6 @@ class StableUnCLIPPipeline(DiffusionPipeline, TextualInversionLoaderMixin):
             image = self.numpy_to_pil(image)
 
         if not return_dict:
-            return (image,)
+            return (image, )
 
         return ImagePipelineOutput(images=image)
