@@ -67,38 +67,41 @@ class StableDiffusionPipelineSafe(DiffusionPipeline):
     _optional_components = ["safety_checker", "feature_extractor"]
 
     def __init__(
-        self,
-        vae: AutoencoderKL,
-        text_encoder: CLIPTextModel,
-        tokenizer: CLIPTokenizer,
-        unet: UNet2DConditionModel,
-        scheduler: KarrasDiffusionSchedulers,
-        safety_checker: SafeStableDiffusionSafetyChecker,
-        feature_extractor: CLIPImageProcessor,
-        requires_safety_checker: bool = True,
-    ):
+            self,
+            vae: AutoencoderKL,
+            text_encoder: CLIPTextModel,
+            tokenizer: CLIPTokenizer,
+            unet: UNet2DConditionModel,
+            scheduler: KarrasDiffusionSchedulers,
+            safety_checker: SafeStableDiffusionSafetyChecker,
+            feature_extractor: CLIPImageProcessor,
+            requires_safety_checker: bool=True, ):
         super().__init__()
         safety_concept: Optional[str] = (
             "an image showing hate, harassment, violence, suffering, humiliation, harm, suicide, sexual, nudity,"
             " bodily fluids, blood, obscene gestures, illegal activity, drug use, theft, vandalism, weapons, child"
-            " abuse, brutality, cruelty"
-        )
+            " abuse, brutality, cruelty")
 
-        if hasattr(scheduler.config, "steps_offset") and scheduler.config.steps_offset != 1:
+        if hasattr(scheduler.config,
+                   "steps_offset") and scheduler.config.steps_offset != 1:
             deprecation_message = (
                 f"The configuration file of this scheduler: {scheduler} is outdated. `steps_offset`"
                 f" should be set to 1 instead of {scheduler.config.steps_offset}. Please make sure "
                 "to update the config accordingly as leaving `steps_offset` might led to incorrect results"
                 " in future versions. If you have downloaded this checkpoint from the Hugging Face Hub,"
                 " it would be very nice if you could open a Pull request for the `scheduler/scheduler_config.json`"
-                " file"
-            )
-            deprecate("steps_offset!=1", "1.0.0", deprecation_message, standard_warn=False)
+                " file")
+            deprecate(
+                "steps_offset!=1",
+                "1.0.0",
+                deprecation_message,
+                standard_warn=False)
             new_config = dict(scheduler.config)
             new_config["steps_offset"] = 1
             scheduler._internal_dict = FrozenDict(new_config)
 
-        if hasattr(scheduler.config, "clip_sample") and scheduler.config.clip_sample is True:
+        if hasattr(scheduler.config,
+                   "clip_sample") and scheduler.config.clip_sample is True:
             deprecation_message = (
                 f"The configuration file of this scheduler: {scheduler} has not set the configuration `clip_sample`."
                 " `clip_sample` should be set to False in the configuration file. Please make sure to update the"
@@ -106,7 +109,11 @@ class StableDiffusionPipelineSafe(DiffusionPipeline):
                 " future versions. If you have downloaded this checkpoint from the Hugging Face Hub, it would be very"
                 " nice if you could open a Pull request for the `scheduler/scheduler_config.json` file"
             )
-            deprecate("clip_sample not set", "1.0.0", deprecation_message, standard_warn=False)
+            deprecate(
+                "clip_sample not set",
+                "1.0.0",
+                deprecation_message,
+                standard_warn=False)
             new_config = dict(scheduler.config)
             new_config["clip_sample"] = False
             scheduler._internal_dict = FrozenDict(new_config)
@@ -127,10 +134,12 @@ class StableDiffusionPipelineSafe(DiffusionPipeline):
                 " checker. If you do not want to use the safety checker, you can pass `'safety_checker=None'` instead."
             )
 
-        is_unet_version_less_0_9_0 = hasattr(unet.config, "_ppdiffusers_version") and version.parse(
-            version.parse(unet.config._ppdiffusers_version).base_version
-        ) < version.parse("0.9.0.dev0")
-        is_unet_sample_size_less_64 = hasattr(unet.config, "sample_size") and unet.config.sample_size < 64
+        is_unet_version_less_0_9_0 = hasattr(
+            unet.config, "_ppdiffusers_version") and version.parse(
+                version.parse(unet.config._ppdiffusers_version)
+                .base_version) < version.parse("0.9.0.dev0")
+        is_unet_sample_size_less_64 = hasattr(
+            unet.config, "sample_size") and unet.config.sample_size < 64
         if is_unet_version_less_0_9_0 and is_unet_sample_size_less_64:
             deprecation_message = (
                 "The configuration file of the unet has set the default `sample_size` to smaller than"
@@ -141,9 +150,12 @@ class StableDiffusionPipelineSafe(DiffusionPipeline):
                 " configuration file. Please make sure to update the config accordingly as leaving `sample_size=32`"
                 " in the config might lead to incorrect results in future versions. If you have downloaded this"
                 " checkpoint from the Hugging Face Hub, it would be very nice if you could open a Pull request for"
-                " the `unet/config.json` file"
-            )
-            deprecate("sample_size<64", "1.0.0", deprecation_message, standard_warn=False)
+                " the `unet/config.json` file")
+            deprecate(
+                "sample_size<64",
+                "1.0.0",
+                deprecation_message,
+                standard_warn=False)
             new_config = dict(unet.config)
             new_config["sample_size"] = 64
             unet._internal_dict = FrozenDict(new_config)
@@ -155,10 +167,9 @@ class StableDiffusionPipelineSafe(DiffusionPipeline):
             unet=unet,
             scheduler=scheduler,
             safety_checker=safety_checker,
-            feature_extractor=feature_extractor,
-        )
+            feature_extractor=feature_extractor, )
         self._safety_text_concept = safety_concept
-        self.vae_scale_factor = 2 ** (len(self.vae.config.block_out_channels) - 1)
+        self.vae_scale_factor = 2**(len(self.vae.config.block_out_channels) - 1)
         self.register_to_config(requires_safety_checker=requires_safety_checker)
 
     @property
@@ -183,13 +194,12 @@ class StableDiffusionPipelineSafe(DiffusionPipeline):
         self._safety_text_concept = concept
 
     def _encode_prompt(
-        self,
-        prompt,
-        num_images_per_prompt,
-        do_classifier_free_guidance,
-        negative_prompt,
-        enable_safety_guidance,
-    ):
+            self,
+            prompt,
+            num_images_per_prompt,
+            do_classifier_free_guidance,
+            negative_prompt,
+            enable_safety_guidance, ):
         r"""
         Encodes the prompt into text encoder hidden states.
 
@@ -211,35 +221,35 @@ class StableDiffusionPipelineSafe(DiffusionPipeline):
             padding="max_length",
             max_length=self.tokenizer.model_max_length,
             truncation=True,
-            return_tensors="pd",
-        )
+            return_tensors="pd", )
         text_input_ids = text_inputs.input_ids
-        untruncated_ids = self.tokenizer(prompt, padding="longest", return_tensors="pd").input_ids
+        untruncated_ids = self.tokenizer(
+            prompt, padding="longest", return_tensors="pd").input_ids
 
-        if untruncated_ids.shape[-1] >= text_input_ids.shape[-1] and not paddle.equal_all(
-            text_input_ids, untruncated_ids
-        ):
-            removed_text = self.tokenizer.batch_decode(untruncated_ids[:, self.tokenizer.model_max_length - 1 : -1])
+        if untruncated_ids.shape[-1] >= text_input_ids.shape[
+                -1] and not paddle.equal_all(text_input_ids, untruncated_ids):
+            removed_text = self.tokenizer.batch_decode(
+                untruncated_ids[:, self.tokenizer.model_max_length - 1:-1])
             logger.warning(
                 "The following part of your input was truncated because CLIP can only handle sequences up to"
-                f" {self.tokenizer.model_max_length} tokens: {removed_text}"
-            )
+                f" {self.tokenizer.model_max_length} tokens: {removed_text}")
 
-        if hasattr(self.text_encoder.config, "use_attention_mask") and self.text_encoder.config.use_attention_mask:
+        if hasattr(self.text_encoder.config, "use_attention_mask"
+                   ) and self.text_encoder.config.use_attention_mask:
             attention_mask = text_inputs.attention_mask
         else:
             attention_mask = None
 
         prompt_embeds = self.text_encoder(
             text_input_ids,
-            attention_mask=attention_mask,
-        )
+            attention_mask=attention_mask, )
         prompt_embeds = prompt_embeds[0]
 
         # duplicate text embeddings for each generation per prompt, using mps friendly method
         bs_embed, seq_len, _ = prompt_embeds.shape
         prompt_embeds = prompt_embeds.tile([1, num_images_per_prompt, 1])
-        prompt_embeds = prompt_embeds.reshape([bs_embed * num_images_per_prompt, seq_len, -1])
+        prompt_embeds = prompt_embeds.reshape(
+            [bs_embed * num_images_per_prompt, seq_len, -1])
 
         # get unconditional embeddings for classifier free guidance
         if do_classifier_free_guidance:
@@ -249,16 +259,14 @@ class StableDiffusionPipelineSafe(DiffusionPipeline):
             elif type(prompt) is not type(negative_prompt):
                 raise TypeError(
                     f"`negative_prompt` should be the same type to `prompt`, but got {type(negative_prompt)} !="
-                    f" {type(prompt)}."
-                )
+                    f" {type(prompt)}.")
             elif isinstance(negative_prompt, str):
                 uncond_tokens = [negative_prompt]
             elif batch_size != len(negative_prompt):
                 raise ValueError(
                     f"`negative_prompt`: {negative_prompt} has batch size {len(negative_prompt)}, but `prompt`:"
                     f" {prompt} has batch size {batch_size}. Please make sure that passed `negative_prompt` matches"
-                    " the batch size of `prompt`."
-                )
+                    " the batch size of `prompt`.")
             else:
                 uncond_tokens = negative_prompt
 
@@ -268,24 +276,25 @@ class StableDiffusionPipelineSafe(DiffusionPipeline):
                 padding="max_length",
                 max_length=max_length,
                 truncation=True,
-                return_tensors="pd",
-            )
+                return_tensors="pd", )
 
-            if hasattr(self.text_encoder.config, "use_attention_mask") and self.text_encoder.config.use_attention_mask:
+            if hasattr(self.text_encoder.config, "use_attention_mask"
+                       ) and self.text_encoder.config.use_attention_mask:
                 attention_mask = uncond_input.attention_mask
             else:
                 attention_mask = None
 
             negative_prompt_embeds = self.text_encoder(
                 uncond_input.input_ids,
-                attention_mask=attention_mask,
-            )
+                attention_mask=attention_mask, )
             negative_prompt_embeds = negative_prompt_embeds[0]
 
             # duplicate unconditional embeddings for each generation per prompt, using mps friendly method
             seq_len = negative_prompt_embeds.shape[1]
-            negative_prompt_embeds = negative_prompt_embeds.tile([1, num_images_per_prompt, 1])
-            negative_prompt_embeds = negative_prompt_embeds.reshape([batch_size * num_images_per_prompt, seq_len, -1])
+            negative_prompt_embeds = negative_prompt_embeds.tile(
+                [1, num_images_per_prompt, 1])
+            negative_prompt_embeds = negative_prompt_embeds.reshape(
+                [batch_size * num_images_per_prompt, seq_len, -1])
 
             # Encode the safety concept text
             if enable_safety_guidance:
@@ -294,35 +303,40 @@ class StableDiffusionPipelineSafe(DiffusionPipeline):
                     padding="max_length",
                     max_length=max_length,
                     truncation=True,
-                    return_tensors="pd",
-                )
-                safety_embeddings = self.text_encoder(safety_concept_input.input_ids)[0]
+                    return_tensors="pd", )
+                safety_embeddings = self.text_encoder(
+                    safety_concept_input.input_ids)[0]
 
                 # duplicate safety embeddings for each generation per prompt, using mps friendly method
                 seq_len = safety_embeddings.shape[1]
-                safety_embeddings = safety_embeddings.tile([batch_size, num_images_per_prompt, 1])
-                safety_embeddings = safety_embeddings.reshape([batch_size * num_images_per_prompt, seq_len, -1])
+                safety_embeddings = safety_embeddings.tile(
+                    [batch_size, num_images_per_prompt, 1])
+                safety_embeddings = safety_embeddings.reshape(
+                    [batch_size * num_images_per_prompt, seq_len, -1])
 
                 # For classifier free guidance + sld, we need to do three forward passes.
                 # Here we concatenate the unconditional and text embeddings into a single batch
                 # to avoid doing three forward passes
-                prompt_embeds = paddle.concat([negative_prompt_embeds, prompt_embeds, safety_embeddings])
+                prompt_embeds = paddle.concat(
+                    [negative_prompt_embeds, prompt_embeds, safety_embeddings])
 
             else:
                 # For classifier free guidance, we need to do two forward passes.
                 # Here we concatenate the unconditional and text embeddings into a single batch
                 # to avoid doing two forward passes
-                prompt_embeds = paddle.concat([negative_prompt_embeds, prompt_embeds])
+                prompt_embeds = paddle.concat(
+                    [negative_prompt_embeds, prompt_embeds])
 
         return prompt_embeds
 
     def run_safety_checker(self, image, dtype, enable_safety_guidance):
         if self.safety_checker is not None:
             images = image.copy()
-            safety_checker_input = self.feature_extractor(self.numpy_to_pil(image), return_tensors="pd")
+            safety_checker_input = self.feature_extractor(
+                self.numpy_to_pil(image), return_tensors="pd")
             image, has_nsfw_concept = self.safety_checker(
-                images=image, clip_input=safety_checker_input.pixel_values.cast(dtype)
-            )
+                images=image,
+                clip_input=safety_checker_input.pixel_values.cast(dtype))
             flagged_images = np.zeros((2, *image.shape[1:]))
             if any(has_nsfw_concept):
                 logger.warning(
@@ -355,50 +369,54 @@ class StableDiffusionPipelineSafe(DiffusionPipeline):
         # eta corresponds to η in DDIM paper: https://arxiv.org/abs/2010.02502
         # and should be between [0, 1]
 
-        accepts_eta = "eta" in set(inspect.signature(self.scheduler.step).parameters.keys())
+        accepts_eta = "eta" in set(
+            inspect.signature(self.scheduler.step).parameters.keys())
         extra_step_kwargs = {}
         if accepts_eta:
             extra_step_kwargs["eta"] = eta
 
         # check if the scheduler accepts generator
-        accepts_generator = "generator" in set(inspect.signature(self.scheduler.step).parameters.keys())
+        accepts_generator = "generator" in set(
+            inspect.signature(self.scheduler.step).parameters.keys())
         if accepts_generator:
             extra_step_kwargs["generator"] = generator
         return extra_step_kwargs
 
     # Copied from ppdiffusers.pipelines.stable_diffusion.pipeline_stable_diffusion.StableDiffusionPipeline.check_inputs
     def check_inputs(
-        self,
-        prompt,
-        height,
-        width,
-        callback_steps,
-        negative_prompt=None,
-        prompt_embeds=None,
-        negative_prompt_embeds=None,
-    ):
+            self,
+            prompt,
+            height,
+            width,
+            callback_steps,
+            negative_prompt=None,
+            prompt_embeds=None,
+            negative_prompt_embeds=None, ):
         if height % 8 != 0 or width % 8 != 0:
-            raise ValueError(f"`height` and `width` have to be divisible by 8 but are {height} and {width}.")
+            raise ValueError(
+                f"`height` and `width` have to be divisible by 8 but are {height} and {width}."
+            )
 
         if (callback_steps is None) or (
-            callback_steps is not None and (not isinstance(callback_steps, int) or callback_steps <= 0)
-        ):
+                callback_steps is not None and
+            (not isinstance(callback_steps, int) or callback_steps <= 0)):
             raise ValueError(
                 f"`callback_steps` has to be a positive integer but is {callback_steps} of type"
-                f" {type(callback_steps)}."
-            )
+                f" {type(callback_steps)}.")
 
         if prompt is not None and prompt_embeds is not None:
             raise ValueError(
                 f"Cannot forward both `prompt`: {prompt} and `prompt_embeds`: {prompt_embeds}. Please make sure to"
-                " only forward one of the two."
-            )
+                " only forward one of the two.")
         elif prompt is None and prompt_embeds is None:
             raise ValueError(
                 "Provide either `prompt` or `prompt_embeds`. Cannot leave both `prompt` and `prompt_embeds` undefined."
             )
-        elif prompt is not None and (not isinstance(prompt, str) and not isinstance(prompt, list)):
-            raise ValueError(f"`prompt` has to be of type `str` or `list` but is {type(prompt)}")
+        elif prompt is not None and (not isinstance(prompt, str) and
+                                     not isinstance(prompt, list)):
+            raise ValueError(
+                f"`prompt` has to be of type `str` or `list` but is {type(prompt)}"
+            )
 
         if negative_prompt is not None and negative_prompt_embeds is not None:
             raise ValueError(
@@ -411,12 +429,19 @@ class StableDiffusionPipelineSafe(DiffusionPipeline):
                 raise ValueError(
                     "`prompt_embeds` and `negative_prompt_embeds` must have the same shape when passed directly, but"
                     f" got: `prompt_embeds` {prompt_embeds.shape} != `negative_prompt_embeds`"
-                    f" {negative_prompt_embeds.shape}."
-                )
+                    f" {negative_prompt_embeds.shape}.")
 
     # Copied from ppdiffusers.pipelines.stable_diffusion.pipeline_stable_diffusion.StableDiffusionPipeline.prepare_latents
-    def prepare_latents(self, batch_size, num_channels_latents, height, width, dtype, generator, latents=None):
-        shape = (batch_size, num_channels_latents, height // self.vae_scale_factor, width // self.vae_scale_factor)
+    def prepare_latents(self,
+                        batch_size,
+                        num_channels_latents,
+                        height,
+                        width,
+                        dtype,
+                        generator,
+                        latents=None):
+        shape = (batch_size, num_channels_latents, height //
+                 self.vae_scale_factor, width // self.vae_scale_factor)
         if isinstance(generator, list) and len(generator) != batch_size:
             raise ValueError(
                 f"You have passed a list of generators of length {len(generator)}, but requested an effective batch"
@@ -431,45 +456,47 @@ class StableDiffusionPipelineSafe(DiffusionPipeline):
         return latents
 
     def perform_safety_guidance(
-        self,
-        enable_safety_guidance,
-        safety_momentum,
-        noise_guidance,
-        noise_pred_out,
-        i,
-        sld_guidance_scale,
-        sld_warmup_steps,
-        sld_threshold,
-        sld_momentum_scale,
-        sld_mom_beta,
-    ):
+            self,
+            enable_safety_guidance,
+            safety_momentum,
+            noise_guidance,
+            noise_pred_out,
+            i,
+            sld_guidance_scale,
+            sld_warmup_steps,
+            sld_threshold,
+            sld_momentum_scale,
+            sld_mom_beta, ):
         # Perform SLD guidance
         if enable_safety_guidance:
             if safety_momentum is None:
                 safety_momentum = paddle.zeros_like(noise_guidance)
-            noise_pred_text, noise_pred_uncond = noise_pred_out[0], noise_pred_out[1]
+            noise_pred_text, noise_pred_uncond = noise_pred_out[
+                0], noise_pred_out[1]
             noise_pred_safety_concept = noise_pred_out[2]
 
             # Equation 6
             scale = paddle.clip(
-                paddle.abs((noise_pred_text - noise_pred_safety_concept)) * sld_guidance_scale, max=1.0
-            )
+                paddle.abs((noise_pred_text - noise_pred_safety_concept)) *
+                sld_guidance_scale,
+                max=1.0)
 
             # Equation 6
             safety_concept_scale = paddle.where(
-                (noise_pred_text - noise_pred_safety_concept) >= sld_threshold, paddle.zeros_like(scale), scale
-            )
+                (noise_pred_text - noise_pred_safety_concept) >= sld_threshold,
+                paddle.zeros_like(scale), scale)
 
             # Equation 4
             noise_guidance_safety = paddle.multiply(
-                (noise_pred_safety_concept - noise_pred_uncond), safety_concept_scale
-            )
+                (noise_pred_safety_concept - noise_pred_uncond),
+                safety_concept_scale)
 
             # Equation 7
             noise_guidance_safety = noise_guidance_safety + sld_momentum_scale * safety_momentum
 
             # Equation 8
-            safety_momentum = sld_mom_beta * safety_momentum + (1 - sld_mom_beta) * noise_guidance_safety
+            safety_momentum = sld_mom_beta * safety_momentum + (
+                1 - sld_mom_beta) * noise_guidance_safety
 
             if i >= sld_warmup_steps:  # Warmup
                 # Equation 3
@@ -478,27 +505,27 @@ class StableDiffusionPipelineSafe(DiffusionPipeline):
 
     @paddle.no_grad()
     def __call__(
-        self,
-        prompt: Union[str, List[str]],
-        height: Optional[int] = None,
-        width: Optional[int] = None,
-        num_inference_steps: int = 50,
-        guidance_scale: float = 7.5,
-        negative_prompt: Optional[Union[str, List[str]]] = None,
-        num_images_per_prompt: Optional[int] = 1,
-        eta: float = 0.0,
-        generator: Optional[Union[paddle.Generator, List[paddle.Generator]]] = None,
-        latents: Optional[paddle.Tensor] = None,
-        output_type: Optional[str] = "pil",
-        return_dict: bool = True,
-        callback: Optional[Callable[[int, int, paddle.Tensor], None]] = None,
-        callback_steps: Optional[int] = 1,
-        sld_guidance_scale: Optional[float] = 1000,
-        sld_warmup_steps: Optional[int] = 10,
-        sld_threshold: Optional[float] = 0.01,
-        sld_momentum_scale: Optional[float] = 0.3,
-        sld_mom_beta: Optional[float] = 0.4,
-    ):
+            self,
+            prompt: Union[str, List[str]],
+            height: Optional[int]=None,
+            width: Optional[int]=None,
+            num_inference_steps: int=50,
+            guidance_scale: float=7.5,
+            negative_prompt: Optional[Union[str, List[str]]]=None,
+            num_images_per_prompt: Optional[int]=1,
+            eta: float=0.0,
+            generator: Optional[Union[paddle.Generator, List[
+                paddle.Generator]]]=None,
+            latents: Optional[paddle.Tensor]=None,
+            output_type: Optional[str]="pil",
+            return_dict: bool=True,
+            callback: Optional[Callable[[int, int, paddle.Tensor], None]]=None,
+            callback_steps: Optional[int]=1,
+            sld_guidance_scale: Optional[float]=1000,
+            sld_warmup_steps: Optional[int]=10,
+            sld_threshold: Optional[float]=0.01,
+            sld_momentum_scale: Optional[float]=0.3,
+            sld_mom_beta: Optional[float]=0.4, ):
         r"""
         Function invoked when calling the pipeline for generation.
 
@@ -593,8 +620,8 @@ class StableDiffusionPipelineSafe(DiffusionPipeline):
 
         # 3. Encode input prompt
         prompt_embeds = self._encode_prompt(
-            prompt, num_images_per_prompt, do_classifier_free_guidance, negative_prompt, enable_safety_guidance
-        )
+            prompt, num_images_per_prompt, do_classifier_free_guidance,
+            negative_prompt, enable_safety_guidance)
 
         # 4. Prepare timesteps
         self.scheduler.set_timesteps(num_inference_steps)
@@ -609,32 +636,35 @@ class StableDiffusionPipelineSafe(DiffusionPipeline):
             width,
             prompt_embeds.dtype,
             generator,
-            latents,
-        )
+            latents, )
 
         # 6. Prepare extra step kwargs.
         extra_step_kwargs = self.prepare_extra_step_kwargs(generator, eta)
 
         safety_momentum = None
 
-        num_warmup_steps = len(timesteps) - num_inference_steps * self.scheduler.order
+        num_warmup_steps = len(
+            timesteps) - num_inference_steps * self.scheduler.order
         with self.progress_bar(total=num_inference_steps) as progress_bar:
             for i, t in enumerate(timesteps):
                 # expand the latents if we are doing classifier free guidance
-                latent_model_input = (
-                    paddle.concat([latents] * (3 if enable_safety_guidance else 2))
-                    if do_classifier_free_guidance
-                    else latents
-                )
-                latent_model_input = self.scheduler.scale_model_input(latent_model_input, t)
+                latent_model_input = (paddle.concat(
+                    [latents] * (3 if enable_safety_guidance else 2)) if
+                                      do_classifier_free_guidance else latents)
+                latent_model_input = self.scheduler.scale_model_input(
+                    latent_model_input, t)
 
                 # predict the noise residual
-                noise_pred = self.unet(latent_model_input, t, encoder_hidden_states=prompt_embeds).sample
+                noise_pred = self.unet(
+                    latent_model_input, t,
+                    encoder_hidden_states=prompt_embeds).sample
 
                 # perform guidance
                 if do_classifier_free_guidance:
-                    noise_pred_out = noise_pred.chunk((3 if enable_safety_guidance else 2))
-                    noise_pred_uncond, noise_pred_text = noise_pred_out[0], noise_pred_out[1]
+                    noise_pred_out = noise_pred.chunk(
+                        (3 if enable_safety_guidance else 2))
+                    noise_pred_uncond, noise_pred_text = noise_pred_out[
+                        0], noise_pred_out[1]
 
                     # default classifier free guidance
                     noise_guidance = noise_pred_text - noise_pred_uncond
@@ -647,26 +677,29 @@ class StableDiffusionPipelineSafe(DiffusionPipeline):
 
                         # Equation 6
                         scale = paddle.clip(
-                            paddle.abs((noise_pred_text - noise_pred_safety_concept)) * sld_guidance_scale, max=1.0
-                        )
+                            paddle.abs(
+                                (noise_pred_text - noise_pred_safety_concept)) *
+                            sld_guidance_scale,
+                            max=1.0)
 
                         # Equation 6
                         safety_concept_scale = paddle.where(
-                            (noise_pred_text - noise_pred_safety_concept) >= sld_threshold,
+                            (noise_pred_text - noise_pred_safety_concept) >=
+                            sld_threshold,
                             paddle.zeros_like(scale),
-                            scale,
-                        )
+                            scale, )
 
                         # Equation 4
                         noise_guidance_safety = paddle.multiply(
-                            (noise_pred_safety_concept - noise_pred_uncond), safety_concept_scale
-                        )
+                            (noise_pred_safety_concept - noise_pred_uncond),
+                            safety_concept_scale)
 
                         # Equation 7
                         noise_guidance_safety = noise_guidance_safety + sld_momentum_scale * safety_momentum
 
                         # Equation 8
-                        safety_momentum = sld_mom_beta * safety_momentum + (1 - sld_mom_beta) * noise_guidance_safety
+                        safety_momentum = sld_mom_beta * safety_momentum + (
+                            1 - sld_mom_beta) * noise_guidance_safety
 
                         if i >= sld_warmup_steps:  # Warmup
                             # Equation 3
@@ -675,10 +708,13 @@ class StableDiffusionPipelineSafe(DiffusionPipeline):
                     noise_pred = noise_pred_uncond + guidance_scale * noise_guidance
 
                     # compute the previous noisy sample x_t -> x_t-1
-                latents = self.scheduler.step(noise_pred, t, latents, **extra_step_kwargs).prev_sample
+                latents = self.scheduler.step(noise_pred, t, latents,
+                                              **extra_step_kwargs).prev_sample
 
                 # call the callback, if provided
-                if i == len(timesteps) - 1 or ((i + 1) > num_warmup_steps and (i + 1) % self.scheduler.order == 0):
+                if i == len(timesteps) - 1 or (
+                    (i + 1) > num_warmup_steps and
+                    (i + 1) % self.scheduler.order == 0):
                     progress_bar.update()
                     if callback is not None and i % callback_steps == 0:
                         callback(i, t, latents)
@@ -688,8 +724,7 @@ class StableDiffusionPipelineSafe(DiffusionPipeline):
 
         # 9. Run safety checker
         image, has_nsfw_concept, flagged_images = self.run_safety_checker(
-            image, prompt_embeds.dtype, enable_safety_guidance
-        )
+            image, prompt_embeds.dtype, enable_safety_guidance)
 
         # 10. Convert to PIL
         if output_type == "pil":
@@ -702,12 +737,11 @@ class StableDiffusionPipelineSafe(DiffusionPipeline):
                 image,
                 has_nsfw_concept,
                 self._safety_text_concept if enable_safety_guidance else None,
-                flagged_images,
-            )
+                flagged_images, )
 
         return StableDiffusionSafePipelineOutput(
             images=image,
             nsfw_content_detected=has_nsfw_concept,
-            applied_safety_concept=self._safety_text_concept if enable_safety_guidance else None,
-            unsafe_images=flagged_images,
-        )
+            applied_safety_concept=self._safety_text_concept
+            if enable_safety_guidance else None,
+            unsafe_images=flagged_images, )
