@@ -12,12 +12,10 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-
 from ...utils import (
     OptionalDependencyNotAvailable,
     is_paddle_available,
-    is_paddlenlp_available,
-)
+    is_paddlenlp_available, )
 
 try:
     if not (is_paddlenlp_available() and is_paddle_available()):
@@ -25,8 +23,7 @@ try:
 except OptionalDependencyNotAvailable:
     from ...utils.dummy_paddle_and_paddlenlp_objects import (
         UnCLIPImageVariationPipeline,
-        UnCLIPPipeline,
-    )
+        UnCLIPPipeline, )
 else:
     from .pipeline_unclip import UnCLIPPipeline
     from .pipeline_unclip_image_variation import UnCLIPImageVariationPipeline
