@@ -23,8 +23,7 @@ from paddlenlp.transformers import (
     CLIPImageProcessor,
     CLIPTextModelWithProjection,
     CLIPTokenizer,
-    CLIPVisionModelWithProjection,
-)
+    CLIPVisionModelWithProjection, )
 
 from ...models import UNet2DConditionModel, UNet2DModel
 from ...pipelines import DiffusionPipeline, ImagePipelineOutput
@@ -82,18 +81,17 @@ class UnCLIPImageVariationPipeline(DiffusionPipeline):
     super_res_scheduler: UnCLIPScheduler
 
     def __init__(
-        self,
-        decoder: UNet2DConditionModel,
-        text_encoder: CLIPTextModelWithProjection,
-        tokenizer: CLIPTokenizer,
-        text_proj: UnCLIPTextProjModel,
-        feature_extractor: CLIPImageProcessor,
-        image_encoder: CLIPVisionModelWithProjection,
-        super_res_first: UNet2DModel,
-        super_res_last: UNet2DModel,
-        decoder_scheduler: UnCLIPScheduler,
-        super_res_scheduler: UnCLIPScheduler,
-    ):
+            self,
+            decoder: UNet2DConditionModel,
+            text_encoder: CLIPTextModelWithProjection,
+            tokenizer: CLIPTokenizer,
+            text_proj: UnCLIPTextProjModel,
+            feature_extractor: CLIPImageProcessor,
+            image_encoder: CLIPVisionModelWithProjection,
+            super_res_first: UNet2DModel,
+            super_res_last: UNet2DModel,
+            decoder_scheduler: UnCLIPScheduler,
+            super_res_scheduler: UnCLIPScheduler, ):
         super().__init__()
 
         self.register_modules(
@@ -106,8 +104,7 @@ class UnCLIPImageVariationPipeline(DiffusionPipeline):
             super_res_first=super_res_first,
             super_res_last=super_res_last,
             decoder_scheduler=decoder_scheduler,
-            super_res_scheduler=super_res_scheduler,
-        )
+            super_res_scheduler=super_res_scheduler, )
 
     # Copied from ppdiffusers.pipelines.unclip.pipeline_unclip.UnCLIPPipeline.prepare_latents
     def prepare_latents(self, shape, dtype, generator, latents, scheduler):
@@ -115,12 +112,15 @@ class UnCLIPImageVariationPipeline(DiffusionPipeline):
             latents = randn_tensor(shape, generator=generator, dtype=dtype)
         else:
             if latents.shape != list(shape):
-                raise ValueError(f"Unexpected latents shape, got {latents.shape}, expected {shape}")
+                raise ValueError(
+                    f"Unexpected latents shape, got {latents.shape}, expected {shape}"
+                )
 
         latents = latents * scheduler.init_noise_sigma
         return latents
 
-    def _encode_prompt(self, prompt, num_images_per_prompt, do_classifier_free_guidance):
+    def _encode_prompt(self, prompt, num_images_per_prompt,
+                       do_classifier_free_guidance):
         batch_size = len(prompt) if isinstance(prompt, list) else 1
 
         # get prompt text embeddings
@@ -129,8 +129,7 @@ class UnCLIPImageVariationPipeline(DiffusionPipeline):
             padding="max_length",
             max_length=self.tokenizer.model_max_length,
             return_attention_mask=True,
-            return_tensors="pd",
-        )
+            return_tensors="pd", )
         text_input_ids = text_inputs.input_ids
         text_mask = text_inputs.attention_mask
         text_encoder_output = self.text_encoder(text_input_ids)
@@ -141,19 +140,21 @@ class UnCLIPImageVariationPipeline(DiffusionPipeline):
         # duplicate text embeddings for each generation per prompt
         seq_len = prompt_embeds.shape[1]
         prompt_embeds = prompt_embeds.tile([1, num_images_per_prompt])
-        prompt_embeds = prompt_embeds.reshape([batch_size * num_images_per_prompt, seq_len])
+        prompt_embeds = prompt_embeds.reshape(
+            [batch_size * num_images_per_prompt, seq_len])
 
         # duplicate text_encoder_hidden_states for each generation per prompt
         seq_len = text_encoder_hidden_states.shape[1]
-        text_encoder_hidden_states = text_encoder_hidden_states.tile([1, num_images_per_prompt, 1])
+        text_encoder_hidden_states = text_encoder_hidden_states.tile(
+            [1, num_images_per_prompt, 1])
         text_encoder_hidden_states = text_encoder_hidden_states.reshape(
-            [batch_size * num_images_per_prompt, seq_len, -1]
-        )
+            [batch_size * num_images_per_prompt, seq_len, -1])
 
         # duplicate text_mask for each generation per prompt
         seq_len = text_mask.shape[1]
         text_mask = text_mask.tile([1, num_images_per_prompt])
-        text_mask = text_mask.reshape([batch_size * num_images_per_prompt, seq_len])
+        text_mask = text_mask.reshape(
+            [batch_size * num_images_per_prompt, seq_len])
 
         # prompt_embeds = prompt_embeds.repeat_interleave(num_images_per_prompt, axis=0)
         # text_encoder_hidden_states = text_encoder_hidden_states.repeat_interleave(num_images_per_prompt, axis=0)
@@ -169,10 +170,10 @@ class UnCLIPImageVariationPipeline(DiffusionPipeline):
                 max_length=max_length,
                 return_attention_mask=True,
                 truncation=True,
-                return_tensors="pd",
-            )
+                return_tensors="pd", )
             uncond_text_mask = uncond_input.attention_mask
-            negative_prompt_embeds_text_encoder_output = self.text_encoder(uncond_input.input_ids)
+            negative_prompt_embeds_text_encoder_output = self.text_encoder(
+                uncond_input.input_ids)
 
             negative_prompt_embeds = negative_prompt_embeds_text_encoder_output.text_embeds
             uncond_text_encoder_hidden_states = negative_prompt_embeds_text_encoder_output.last_hidden_state
@@ -180,65 +181,76 @@ class UnCLIPImageVariationPipeline(DiffusionPipeline):
             # duplicate unconditional embeddings for each generation per prompt, using mps friendly method
 
             seq_len = negative_prompt_embeds.shape[1]
-            negative_prompt_embeds = negative_prompt_embeds.tile([1, num_images_per_prompt])
-            negative_prompt_embeds = negative_prompt_embeds.reshape([batch_size * num_images_per_prompt, seq_len])
+            negative_prompt_embeds = negative_prompt_embeds.tile(
+                [1, num_images_per_prompt])
+            negative_prompt_embeds = negative_prompt_embeds.reshape(
+                [batch_size * num_images_per_prompt, seq_len])
 
             seq_len = uncond_text_encoder_hidden_states.shape[1]
-            uncond_text_encoder_hidden_states = uncond_text_encoder_hidden_states.tile([1, num_images_per_prompt, 1])
+            uncond_text_encoder_hidden_states = uncond_text_encoder_hidden_states.tile(
+                [1, num_images_per_prompt, 1])
             uncond_text_encoder_hidden_states = uncond_text_encoder_hidden_states.reshape(
-                [batch_size * num_images_per_prompt, seq_len, -1]
-            )
+                [batch_size * num_images_per_prompt, seq_len, -1])
 
             # duplicate uncond_text_mask for each generation per prompt
             seq_len = uncond_text_mask.shape[1]
             uncond_text_mask = uncond_text_mask.tile([1, num_images_per_prompt])
-            uncond_text_mask = uncond_text_mask.reshape([batch_size * num_images_per_prompt, seq_len])
+            uncond_text_mask = uncond_text_mask.reshape(
+                [batch_size * num_images_per_prompt, seq_len])
             # uncond_text_mask = uncond_text_mask.repeat_interleave(num_images_per_prompt, axis=0)
             # done duplicates
 
             # For classifier free guidance, we need to do two forward passes.
             # Here we concatenate the unconditional and text embeddings into a single batch
             # to avoid doing two forward passes
-            prompt_embeds = paddle.concat([negative_prompt_embeds, prompt_embeds])
-            text_encoder_hidden_states = paddle.concat([uncond_text_encoder_hidden_states, text_encoder_hidden_states])
+            prompt_embeds = paddle.concat(
+                [negative_prompt_embeds, prompt_embeds])
+            text_encoder_hidden_states = paddle.concat([
+                uncond_text_encoder_hidden_states, text_encoder_hidden_states
+            ])
 
             text_mask = paddle.concat([uncond_text_mask, text_mask])
 
         return prompt_embeds, text_encoder_hidden_states, text_mask
 
-    def _encode_image(self, image, num_images_per_prompt, image_embeddings: Optional[paddle.Tensor] = None):
+    def _encode_image(self,
+                      image,
+                      num_images_per_prompt,
+                      image_embeddings: Optional[paddle.Tensor]=None):
 
         dtype = self.image_encoder.dtype
 
         if image_embeddings is None:
             if not isinstance(image, paddle.Tensor):
-                image = self.feature_extractor(images=image, return_tensors="pd").pixel_values
+                image = self.feature_extractor(
+                    images=image, return_tensors="pd").pixel_values
 
             image = image.cast(dtype)
             image_embeddings = self.image_encoder(image).image_embeds
 
         batch_size, seq_len = image_embeddings.shape
         image_embeddings = image_embeddings.tile([1, num_images_per_prompt])
-        image_embeddings = image_embeddings.reshape([batch_size * num_images_per_prompt, seq_len])
+        image_embeddings = image_embeddings.reshape(
+            [batch_size * num_images_per_prompt, seq_len])
         # image_embeddings = image_embeddings.repeat_interleave(num_images_per_prompt, axis=0)
 
         return image_embeddings
 
     @paddle.no_grad()
     def __call__(
-        self,
-        image: Optional[Union[PIL.Image.Image, List[PIL.Image.Image], paddle.Tensor]] = None,
-        num_images_per_prompt: int = 1,
-        decoder_num_inference_steps: int = 25,
-        super_res_num_inference_steps: int = 7,
-        generator: Optional[paddle.Generator] = None,
-        decoder_latents: Optional[paddle.Tensor] = None,
-        super_res_latents: Optional[paddle.Tensor] = None,
-        image_embeddings: Optional[paddle.Tensor] = None,
-        decoder_guidance_scale: float = 8.0,
-        output_type: Optional[str] = "pil",
-        return_dict: bool = True,
-    ):
+            self,
+            image: Optional[Union[PIL.Image.Image, List[PIL.Image.Image],
+                                  paddle.Tensor]]=None,
+            num_images_per_prompt: int=1,
+            decoder_num_inference_steps: int=25,
+            super_res_num_inference_steps: int=7,
+            generator: Optional[paddle.Generator]=None,
+            decoder_latents: Optional[paddle.Tensor]=None,
+            super_res_latents: Optional[paddle.Tensor]=None,
+            image_embeddings: Optional[paddle.Tensor]=None,
+            decoder_guidance_scale: float=8.0,
+            output_type: Optional[str]="pil",
+            return_dict: bool=True, ):
         """
         Function invoked when calling the pipeline for generation.
 
@@ -294,22 +306,22 @@ class UnCLIPImageVariationPipeline(DiffusionPipeline):
         do_classifier_free_guidance = decoder_guidance_scale > 1.0
 
         prompt_embeds, text_encoder_hidden_states, text_mask = self._encode_prompt(
-            prompt, num_images_per_prompt, do_classifier_free_guidance
-        )
+            prompt, num_images_per_prompt, do_classifier_free_guidance)
 
-        image_embeddings = self._encode_image(image, num_images_per_prompt, image_embeddings)
+        image_embeddings = self._encode_image(image, num_images_per_prompt,
+                                              image_embeddings)
 
         # decoder
         text_encoder_hidden_states, additive_clip_time_embeddings = self.text_proj(
             image_embeddings=image_embeddings,
             prompt_embeds=prompt_embeds,
             text_encoder_hidden_states=text_encoder_hidden_states,
-            do_classifier_free_guidance=do_classifier_free_guidance,
-        )
+            do_classifier_free_guidance=do_classifier_free_guidance, )
 
-        decoder_text_mask = F.pad(
-            text_mask.unsqueeze(0), (self.text_proj.clip_extra_context_tokens, 0), value=1, data_format="NCL"
-        ).squeeze(0)
+        decoder_text_mask = F.pad(text_mask.unsqueeze(0),
+                                  (self.text_proj.clip_extra_context_tokens, 0),
+                                  value=1,
+                                  data_format="NCL").squeeze(0)
 
         self.decoder_scheduler.set_timesteps(decoder_num_inference_steps)
         decoder_timesteps_tensor = self.decoder_scheduler.timesteps
@@ -324,34 +336,40 @@ class UnCLIPImageVariationPipeline(DiffusionPipeline):
                 text_encoder_hidden_states.dtype,
                 generator,
                 decoder_latents,
-                self.decoder_scheduler,
-            )
+                self.decoder_scheduler, )
 
         for i, t in enumerate(self.progress_bar(decoder_timesteps_tensor)):
             # expand the latents if we are doing classifier free guidance
-            latent_model_input = (
-                paddle.concat([decoder_latents] * 2) if do_classifier_free_guidance else decoder_latents
-            )
+            latent_model_input = (paddle.concat([decoder_latents] * 2)
+                                  if do_classifier_free_guidance else
+                                  decoder_latents)
 
             noise_pred = self.decoder(
                 sample=latent_model_input,
                 timestep=t,
                 encoder_hidden_states=text_encoder_hidden_states,
                 class_labels=additive_clip_time_embeddings,
-                attention_mask=decoder_text_mask,
-            ).sample
+                attention_mask=decoder_text_mask, ).sample
 
             if do_classifier_free_guidance:
                 noise_pred_uncond, noise_pred_text = noise_pred.chunk(2)
                 # paddle.split is not equal torch.split
                 noise_pred_uncond, _ = noise_pred_uncond.split(
-                    [latent_model_input.shape[1], noise_pred_uncond.shape[1] - latent_model_input.shape[1]], axis=1
-                )
+                    [
+                        latent_model_input.shape[1],
+                        noise_pred_uncond.shape[1] - latent_model_input.shape[1]
+                    ],
+                    axis=1)
                 noise_pred_text, predicted_variance = noise_pred_text.split(
-                    [latent_model_input.shape[1], noise_pred_text.shape[1] - latent_model_input.shape[1]], axis=1
-                )
-                noise_pred = noise_pred_uncond + decoder_guidance_scale * (noise_pred_text - noise_pred_uncond)
-                noise_pred = paddle.concat([noise_pred, predicted_variance], axis=1)
+                    [
+                        latent_model_input.shape[1],
+                        noise_pred_text.shape[1] - latent_model_input.shape[1]
+                    ],
+                    axis=1)
+                noise_pred = noise_pred_uncond + decoder_guidance_scale * (
+                    noise_pred_text - noise_pred_uncond)
+                noise_pred = paddle.concat(
+                    [noise_pred, predicted_variance], axis=1)
 
             if i + 1 == decoder_timesteps_tensor.shape[0]:
                 prev_timestep = None
@@ -360,8 +378,11 @@ class UnCLIPImageVariationPipeline(DiffusionPipeline):
 
             # compute the previous noisy sample x_t -> x_t-1
             decoder_latents = self.decoder_scheduler.step(
-                noise_pred, t, decoder_latents, prev_timestep=prev_timestep, generator=generator
-            ).prev_sample
+                noise_pred,
+                t,
+                decoder_latents,
+                prev_timestep=prev_timestep,
+                generator=generator).prev_sample
 
         decoder_latents = decoder_latents.clip(-1, 1)
 
@@ -384,16 +405,18 @@ class UnCLIPImageVariationPipeline(DiffusionPipeline):
                 image_small.dtype,
                 generator,
                 super_res_latents,
-                self.super_res_scheduler,
-            )
+                self.super_res_scheduler, )
 
         interpolate_antialias = {}
         if "antialias" in inspect.signature(F.interpolate).parameters:
             interpolate_antialias["antialias"] = True
 
         image_upscaled = F.interpolate(
-            image_small, size=[height, width], mode="bicubic", align_corners=False, **interpolate_antialias
-        )
+            image_small,
+            size=[height, width],
+            mode="bicubic",
+            align_corners=False,
+            **interpolate_antialias)
 
         for i, t in enumerate(self.progress_bar(super_res_timesteps_tensor)):
             # no classifier free guidance
@@ -404,13 +427,15 @@ class UnCLIPImageVariationPipeline(DiffusionPipeline):
                 unet = self.super_res_first
 
             latent_model_input = paddle.concat(
-                [super_res_latents, image_upscaled.cast(super_res_latents.dtype)], axis=1
-            )
+                [
+                    super_res_latents,
+                    image_upscaled.cast(super_res_latents.dtype)
+                ],
+                axis=1)
 
             noise_pred = unet(
                 sample=latent_model_input,
-                timestep=t,
-            ).sample
+                timestep=t, ).sample
 
             if i + 1 == super_res_timesteps_tensor.shape[0]:
                 prev_timestep = None
@@ -419,8 +444,11 @@ class UnCLIPImageVariationPipeline(DiffusionPipeline):
 
             # compute the previous noisy sample x_t -> x_t-1
             super_res_latents = self.super_res_scheduler.step(
-                noise_pred, t, super_res_latents, prev_timestep=prev_timestep, generator=generator
-            ).prev_sample
+                noise_pred,
+                t,
+                super_res_latents,
+                prev_timestep=prev_timestep,
+                generator=generator).prev_sample
 
         image = super_res_latents
 
@@ -436,6 +464,6 @@ class UnCLIPImageVariationPipeline(DiffusionPipeline):
             image = self.numpy_to_pil(image)
 
         if not return_dict:
-            return (image,)
+            return (image, )
 
         return ImagePipelineOutput(images=image)
