@@ -13,24 +13,26 @@
 # limitations under the License.
 # flake8: noqa
 
-from ...utils import is_paddle_available, is_paddlenlp_available
+from ...utils import (
+    OptionalDependencyNotAvailable,
+    is_paddle_available,
+    is_paddlenlp_available, )
 
-if is_paddlenlp_available() and is_paddle_available():
-    from .modeling_text_unet import UNetFlatConditionModel
-    from .pipeline_versatile_diffusion import VersatileDiffusionPipeline
-    from .pipeline_versatile_diffusion_dual_guided import (
-        VersatileDiffusionDualGuidedPipeline,
-    )
-    from .pipeline_versatile_diffusion_image_variation import (
-        VersatileDiffusionImageVariationPipeline,
-    )
-    from .pipeline_versatile_diffusion_text_to_image import (
-        VersatileDiffusionTextToImagePipeline,
-    )
-else:
+try:
+    if not (is_paddlenlp_available() and is_paddle_available()):
+        raise OptionalDependencyNotAvailable()
+except OptionalDependencyNotAvailable:
     from ...utils.dummy_paddle_and_paddlenlp_objects import (
         VersatileDiffusionDualGuidedPipeline,
         VersatileDiffusionImageVariationPipeline,
         VersatileDiffusionPipeline,
-        VersatileDiffusionTextToImagePipeline,
-    )
+        VersatileDiffusionTextToImagePipeline, )
+else:
+    from .modeling_text_unet import UNetFlatConditionModel
+    from .pipeline_versatile_diffusion import VersatileDiffusionPipeline
+    from .pipeline_versatile_diffusion_dual_guided import (
+        VersatileDiffusionDualGuidedPipeline, )
+    from .pipeline_versatile_diffusion_image_variation import (
+        VersatileDiffusionImageVariationPipeline, )
+    from .pipeline_versatile_diffusion_text_to_image import (
+        VersatileDiffusionTextToImagePipeline, )
