@@ -24,15 +24,13 @@ from paddlenlp.transformers import (
     CLIPImageProcessor,
     CLIPTextModelWithProjection,
     CLIPTokenizer,
-    CLIPVisionModelWithProjection,
-)
+    CLIPVisionModelWithProjection, )
 
 from ...models import (
     AutoencoderKL,
     DualTransformer2DModel,
     Transformer2DModel,
-    UNet2DConditionModel,
-)
+    UNet2DConditionModel, )
 from ...schedulers import KarrasDiffusionSchedulers
 from ...utils import logging, randn_tensor
 from ..pipeline_utils import DiffusionPipeline, ImagePipelineOutput
@@ -82,16 +80,15 @@ class VersatileDiffusionDualGuidedPipeline(DiffusionPipeline):
     _optional_components = ["text_unet"]
 
     def __init__(
-        self,
-        tokenizer: CLIPTokenizer,
-        image_feature_extractor: CLIPImageProcessor,
-        text_encoder: CLIPTextModelWithProjection,
-        image_encoder: CLIPVisionModelWithProjection,
-        image_unet: UNet2DConditionModel,
-        text_unet: UNetFlatConditionModel,
-        vae: AutoencoderKL,
-        scheduler: KarrasDiffusionSchedulers,
-    ):
+            self,
+            tokenizer: CLIPTokenizer,
+            image_feature_extractor: CLIPImageProcessor,
+            text_encoder: CLIPTextModelWithProjection,
+            image_encoder: CLIPVisionModelWithProjection,
+            image_unet: UNet2DConditionModel,
+            text_unet: UNetFlatConditionModel,
+            vae: AutoencoderKL,
+            scheduler: KarrasDiffusionSchedulers, ):
         super().__init__()
         self.register_modules(
             tokenizer=tokenizer,
@@ -101,13 +98,12 @@ class VersatileDiffusionDualGuidedPipeline(DiffusionPipeline):
             image_unet=image_unet,
             text_unet=text_unet,
             vae=vae,
-            scheduler=scheduler,
-        )
-        self.vae_scale_factor = 2 ** (len(self.vae.config.block_out_channels) - 1)
+            scheduler=scheduler, )
+        self.vae_scale_factor = 2**(len(self.vae.config.block_out_channels) - 1)
 
         if self.text_unet is not None and (
-            "dual_cross_attention" not in self.image_unet.config or not self.image_unet.config.dual_cross_attention
-        ):
+                "dual_cross_attention" not in self.image_unet.config or
+                not self.image_unet.config.dual_cross_attention):
             # if loading from a universal checkpoint rather than a saved dual-guided pipeline
             self._convert_to_dual_attention()
 
@@ -124,8 +120,10 @@ class VersatileDiffusionDualGuidedPipeline(DiffusionPipeline):
                 parent_name, index = name.rsplit(".", 1)
                 index = int(index)
 
-                image_transformer = self.image_unet.get_sublayer(parent_name)[index]
-                text_transformer = self.text_unet.get_sublayer(parent_name)[index]
+                image_transformer = self.image_unet.get_sublayer(parent_name)[
+                    index]
+                text_transformer = self.text_unet.get_sublayer(parent_name)[
+                    index]
 
                 config = image_transformer.config
                 dual_transformer = DualTransformer2DModel(
@@ -140,12 +138,12 @@ class VersatileDiffusionDualGuidedPipeline(DiffusionPipeline):
                     sample_size=config.sample_size,
                     num_vector_embeds=config.num_vector_embeds,
                     activation_fn=config.activation_fn,
-                    num_embeds_ada_norm=config.num_embeds_ada_norm,
-                )
+                    num_embeds_ada_norm=config.num_embeds_ada_norm, )
                 dual_transformer.transformers[0] = image_transformer
                 dual_transformer.transformers[1] = text_transformer
 
-                self.image_unet.get_sublayer(parent_name)[index] = dual_transformer
+                self.image_unet.get_sublayer(parent_name)[
+                    index] = dual_transformer
                 self.image_unet.register_to_config(dual_cross_attention=True)
 
     def _revert_dual_attention(self):
@@ -157,10 +155,12 @@ class VersatileDiffusionDualGuidedPipeline(DiffusionPipeline):
             if isinstance(module, DualTransformer2DModel):
                 parent_name, index = name.rsplit(".", 1)
                 index = int(index)
-                self.image_unet.get_sublayer(parent_name)[index] = module.transformers[0]
+                self.image_unet.get_sublayer(parent_name)[
+                    index] = module.transformers[0]
         self.image_unet.register_to_config(dual_cross_attention=False)
 
-    def _encode_text_prompt(self, prompt, num_images_per_prompt, do_classifier_free_guidance):
+    def _encode_text_prompt(self, prompt, num_images_per_prompt,
+                            do_classifier_free_guidance):
         r"""
         Encodes the prompt into text encoder hidden states.
 
@@ -174,9 +174,11 @@ class VersatileDiffusionDualGuidedPipeline(DiffusionPipeline):
         """
 
         def normalize_embeddings(encoder_output):
-            embeds = paddle.matmul(encoder_output.last_hidden_state, self.text_encoder.text_projection)
+            embeds = paddle.matmul(encoder_output.last_hidden_state,
+                                   self.text_encoder.text_projection)
             embeds_pooled = encoder_output.text_embeds
-            embeds = embeds / paddle.norm(embeds_pooled.unsqueeze(1), axis=-1, keepdim=True)
+            embeds = embeds / paddle.norm(
+                embeds_pooled.unsqueeze(1), axis=-1, keepdim=True)
             return embeds
 
         batch_size = len(prompt)
@@ -186,35 +188,35 @@ class VersatileDiffusionDualGuidedPipeline(DiffusionPipeline):
             padding="max_length",
             max_length=self.tokenizer.model_max_length,
             truncation=True,
-            return_tensors="pd",
-        )
+            return_tensors="pd", )
         text_input_ids = text_inputs.input_ids
-        untruncated_ids = self.tokenizer(prompt, padding="longest", return_tensors="pd").input_ids
+        untruncated_ids = self.tokenizer(
+            prompt, padding="longest", return_tensors="pd").input_ids
 
-        if untruncated_ids.shape[-1] >= text_input_ids.shape[-1] and not paddle.equal_all(
-            text_input_ids, untruncated_ids
-        ):
-            removed_text = self.tokenizer.batch_decode(untruncated_ids[:, self.tokenizer.model_max_length - 1 : -1])
+        if untruncated_ids.shape[-1] >= text_input_ids.shape[
+                -1] and not paddle.equal_all(text_input_ids, untruncated_ids):
+            removed_text = self.tokenizer.batch_decode(
+                untruncated_ids[:, self.tokenizer.model_max_length - 1:-1])
             logger.warning(
                 "The following part of your input was truncated because CLIP can only handle sequences up to"
-                f" {self.tokenizer.model_max_length} tokens: {removed_text}"
-            )
+                f" {self.tokenizer.model_max_length} tokens: {removed_text}")
 
-        if hasattr(self.text_encoder.config, "use_attention_mask") and self.text_encoder.config.use_attention_mask:
+        if hasattr(self.text_encoder.config, "use_attention_mask"
+                   ) and self.text_encoder.config.use_attention_mask:
             attention_mask = text_inputs.attention_mask
         else:
             attention_mask = None
 
         prompt_embeds = self.text_encoder(
             text_input_ids,
-            attention_mask=attention_mask,
-        )
+            attention_mask=attention_mask, )
         prompt_embeds = normalize_embeddings(prompt_embeds)
 
         # duplicate text embeddings for each generation per prompt, using mps friendly method
         bs_embed, seq_len, _ = prompt_embeds.shape
         prompt_embeds = prompt_embeds.tile([1, num_images_per_prompt, 1])
-        prompt_embeds = prompt_embeds.reshape([bs_embed * num_images_per_prompt, seq_len, -1])
+        prompt_embeds = prompt_embeds.reshape(
+            [bs_embed * num_images_per_prompt, seq_len, -1])
 
         # get unconditional embeddings for classifier free guidance
         if do_classifier_free_guidance:
@@ -225,33 +227,37 @@ class VersatileDiffusionDualGuidedPipeline(DiffusionPipeline):
                 padding="max_length",
                 max_length=max_length,
                 truncation=True,
-                return_tensors="pd",
-            )
+                return_tensors="pd", )
 
-            if hasattr(self.text_encoder.config, "use_attention_mask") and self.text_encoder.config.use_attention_mask:
+            if hasattr(self.text_encoder.config, "use_attention_mask"
+                       ) and self.text_encoder.config.use_attention_mask:
                 attention_mask = uncond_input.attention_mask
             else:
                 attention_mask = None
 
             negative_prompt_embeds = self.text_encoder(
                 uncond_input.input_ids,
-                attention_mask=attention_mask,
-            )
-            negative_prompt_embeds = normalize_embeddings(negative_prompt_embeds)
+                attention_mask=attention_mask, )
+            negative_prompt_embeds = normalize_embeddings(
+                negative_prompt_embeds)
 
             # duplicate unconditional embeddings for each generation per prompt, using mps friendly method
             seq_len = negative_prompt_embeds.shape[1]
-            negative_prompt_embeds = negative_prompt_embeds.tile([1, num_images_per_prompt, 1])
-            negative_prompt_embeds = negative_prompt_embeds.reshape([batch_size * num_images_per_prompt, seq_len, -1])
+            negative_prompt_embeds = negative_prompt_embeds.tile(
+                [1, num_images_per_prompt, 1])
+            negative_prompt_embeds = negative_prompt_embeds.reshape(
+                [batch_size * num_images_per_prompt, seq_len, -1])
 
             # For classifier free guidance, we need to do two forward passes.
             # Here we concatenate the unconditional and text embeddings into a single batch
             # to avoid doing two forward passes
-            prompt_embeds = paddle.concat([negative_prompt_embeds, prompt_embeds])
+            prompt_embeds = paddle.concat(
+                [negative_prompt_embeds, prompt_embeds])
 
         return prompt_embeds
 
-    def _encode_image_prompt(self, prompt, num_images_per_prompt, do_classifier_free_guidance):
+    def _encode_image_prompt(self, prompt, num_images_per_prompt,
+                             do_classifier_free_guidance):
         r"""
         Encodes the prompt into vision encoder hidden states.
 
@@ -265,7 +271,8 @@ class VersatileDiffusionDualGuidedPipeline(DiffusionPipeline):
         """
 
         def normalize_embeddings(encoder_output):
-            embeds = self.image_encoder.vision_model.ln_post(encoder_output.last_hidden_state)
+            embeds = self.image_encoder.vision_model.ln_post(
+                encoder_output.last_hidden_state)
             embeds = paddle.matmul(embeds, self.image_encoder.vision_projection)
             embeds_pooled = embeds[:, 0:1]
             embeds = embeds / paddle.norm(embeds_pooled, axis=-1, keepdim=True)
@@ -274,7 +281,8 @@ class VersatileDiffusionDualGuidedPipeline(DiffusionPipeline):
         batch_size = len(prompt) if isinstance(prompt, list) else 1
 
         # get prompt text embeddings
-        image_input = self.image_feature_extractor(images=prompt, return_tensors="pd")
+        image_input = self.image_feature_extractor(
+            images=prompt, return_tensors="pd")
         pixel_values = image_input.pixel_values.cast(self.image_encoder.dtype)
         image_embeddings = self.image_encoder(pixel_values)
         image_embeddings = normalize_embeddings(image_embeddings)
@@ -282,25 +290,32 @@ class VersatileDiffusionDualGuidedPipeline(DiffusionPipeline):
         # duplicate image embeddings for each generation per prompt, using mps friendly method
         bs_embed, seq_len, _ = image_embeddings.shape
         image_embeddings = image_embeddings.tile([1, num_images_per_prompt, 1])
-        image_embeddings = image_embeddings.reshape([bs_embed * num_images_per_prompt, seq_len, -1])
+        image_embeddings = image_embeddings.reshape(
+            [bs_embed * num_images_per_prompt, seq_len, -1])
 
         # get unconditional embeddings for classifier free guidance
         if do_classifier_free_guidance:
             uncond_images = [np.zeros((512, 512, 3)) + 0.5] * batch_size
-            uncond_images = self.image_feature_extractor(images=uncond_images, return_tensors="pd")
-            pixel_values = uncond_images.pixel_values.cast(self.image_encoder.dtype)
+            uncond_images = self.image_feature_extractor(
+                images=uncond_images, return_tensors="pd")
+            pixel_values = uncond_images.pixel_values.cast(
+                self.image_encoder.dtype)
             negative_prompt_embeds = self.image_encoder(pixel_values)
-            negative_prompt_embeds = normalize_embeddings(negative_prompt_embeds)
+            negative_prompt_embeds = normalize_embeddings(
+                negative_prompt_embeds)
 
             # duplicate unconditional embeddings for each generation per prompt, using mps friendly method
             seq_len = negative_prompt_embeds.shape[1]
-            negative_prompt_embeds = negative_prompt_embeds.tile([1, num_images_per_prompt, 1])
-            negative_prompt_embeds = negative_prompt_embeds.reshape([batch_size * num_images_per_prompt, seq_len, -1])
+            negative_prompt_embeds = negative_prompt_embeds.tile(
+                [1, num_images_per_prompt, 1])
+            negative_prompt_embeds = negative_prompt_embeds.reshape(
+                [batch_size * num_images_per_prompt, seq_len, -1])
 
             # For classifier free guidance, we need to do two forward passes.
             # Here we concatenate the unconditional and conditional embeddings into a single batch
             # to avoid doing two forward passes
-            image_embeddings = paddle.concat([negative_prompt_embeds, image_embeddings])
+            image_embeddings = paddle.concat(
+                [negative_prompt_embeds, image_embeddings])
 
         return image_embeddings
 
@@ -320,37 +335,54 @@ class VersatileDiffusionDualGuidedPipeline(DiffusionPipeline):
         # eta corresponds to η in DDIM paper: https://arxiv.org/abs/2010.02502
         # and should be between [0, 1]
 
-        accepts_eta = "eta" in set(inspect.signature(self.scheduler.step).parameters.keys())
+        accepts_eta = "eta" in set(
+            inspect.signature(self.scheduler.step).parameters.keys())
         extra_step_kwargs = {}
         if accepts_eta:
             extra_step_kwargs["eta"] = eta
 
         # check if the scheduler accepts generator
-        accepts_generator = "generator" in set(inspect.signature(self.scheduler.step).parameters.keys())
+        accepts_generator = "generator" in set(
+            inspect.signature(self.scheduler.step).parameters.keys())
         if accepts_generator:
             extra_step_kwargs["generator"] = generator
         return extra_step_kwargs
 
     def check_inputs(self, prompt, image, height, width, callback_steps):
-        if not isinstance(prompt, str) and not isinstance(prompt, PIL.Image.Image) and not isinstance(prompt, list):
-            raise ValueError(f"`prompt` has to be of type `str` `PIL.Image` or `list` but is {type(prompt)}")
-        if not isinstance(image, str) and not isinstance(image, PIL.Image.Image) and not isinstance(image, list):
-            raise ValueError(f"`image` has to be of type `str` `PIL.Image` or `list` but is {type(image)}")
-
-        if height % 8 != 0 or width % 8 != 0:
-            raise ValueError(f"`height` and `width` have to be divisible by 8 but are {height} and {width}.")
-
-        if (callback_steps is None) or (
-            callback_steps is not None and (not isinstance(callback_steps, int) or callback_steps <= 0)
-        ):
+        if not isinstance(prompt, str) and not isinstance(
+                prompt, PIL.Image.Image) and not isinstance(prompt, list):
             raise ValueError(
-                f"`callback_steps` has to be a positive integer but is {callback_steps} of type"
-                f" {type(callback_steps)}."
+                f"`prompt` has to be of type `str` `PIL.Image` or `list` but is {type(prompt)}"
+            )
+        if not isinstance(image, str) and not isinstance(
+                image, PIL.Image.Image) and not isinstance(image, list):
+            raise ValueError(
+                f"`image` has to be of type `str` `PIL.Image` or `list` but is {type(image)}"
             )
 
+        if height % 8 != 0 or width % 8 != 0:
+            raise ValueError(
+                f"`height` and `width` have to be divisible by 8 but are {height} and {width}."
+            )
+
+        if (callback_steps is None) or (
+                callback_steps is not None and
+            (not isinstance(callback_steps, int) or callback_steps <= 0)):
+            raise ValueError(
+                f"`callback_steps` has to be a positive integer but is {callback_steps} of type"
+                f" {type(callback_steps)}.")
+
     # Copied from ppdiffusers.pipelines.stable_diffusion.pipeline_stable_diffusion.StableDiffusionPipeline.prepare_latents
-    def prepare_latents(self, batch_size, num_channels_latents, height, width, dtype, generator, latents=None):
-        shape = (batch_size, num_channels_latents, height // self.vae_scale_factor, width // self.vae_scale_factor)
+    def prepare_latents(self,
+                        batch_size,
+                        num_channels_latents,
+                        height,
+                        width,
+                        dtype,
+                        generator,
+                        latents=None):
+        shape = (batch_size, num_channels_latents, height //
+                 self.vae_scale_factor, width // self.vae_scale_factor)
         if isinstance(generator, list) and len(generator) != batch_size:
             raise ValueError(
                 f"You have passed a list of generators of length {len(generator)}, but requested an effective batch"
@@ -364,39 +396,44 @@ class VersatileDiffusionDualGuidedPipeline(DiffusionPipeline):
         latents = latents * self.scheduler.init_noise_sigma
         return latents
 
-    def set_transformer_params(self, mix_ratio: float = 0.5, condition_types: Tuple = ("text", "image")):
+    def set_transformer_params(self,
+                               mix_ratio: float=0.5,
+                               condition_types: Tuple=("text", "image")):
         for name, module in self.image_unet.named_sublayers(include_self=True):
             if isinstance(module, DualTransformer2DModel):
                 module.mix_ratio = mix_ratio
 
                 for i, type in enumerate(condition_types):
                     if type == "text":
-                        module.condition_lengths[i] = self.text_encoder.config.max_position_embeddings
-                        module.transformer_index_for_condition[i] = 1  # use the second (text) transformer
+                        module.condition_lengths[
+                            i] = self.text_encoder.config.max_position_embeddings
+                        module.transformer_index_for_condition[
+                            i] = 1  # use the second (text) transformer
                     else:
                         module.condition_lengths[i] = 257
-                        module.transformer_index_for_condition[i] = 0  # use the first (image) transformer
+                        module.transformer_index_for_condition[
+                            i] = 0  # use the first (image) transformer
 
     @paddle.no_grad()
     def __call__(
-        self,
-        prompt: Union[PIL.Image.Image, List[PIL.Image.Image]],
-        image: Union[str, List[str]],
-        text_to_image_strength: float = 0.5,
-        height: Optional[int] = None,
-        width: Optional[int] = None,
-        num_inference_steps: int = 50,
-        guidance_scale: float = 7.5,
-        num_images_per_prompt: Optional[int] = 1,
-        eta: float = 0.0,
-        generator: Optional[Union[paddle.Generator, List[paddle.Generator]]] = None,
-        latents: Optional[paddle.Tensor] = None,
-        output_type: Optional[str] = "pil",
-        return_dict: bool = True,
-        callback: Optional[Callable[[int, int, paddle.Tensor], None]] = None,
-        callback_steps: Optional[int] = 1,
-        **kwargs,
-    ):
+            self,
+            prompt: Union[PIL.Image.Image, List[PIL.Image.Image]],
+            image: Union[str, List[str]],
+            text_to_image_strength: float=0.5,
+            height: Optional[int]=None,
+            width: Optional[int]=None,
+            num_inference_steps: int=50,
+            guidance_scale: float=7.5,
+            num_images_per_prompt: Optional[int]=1,
+            eta: float=0.0,
+            generator: Optional[Union[paddle.Generator, List[
+                paddle.Generator]]]=None,
+            latents: Optional[paddle.Tensor]=None,
+            output_type: Optional[str]="pil",
+            return_dict: bool=True,
+            callback: Optional[Callable[[int, int, paddle.Tensor], None]]=None,
+            callback_steps: Optional[int]=1,
+            **kwargs, ):
         r"""
         Function invoked when calling the pipeline for generation.
 
@@ -495,9 +532,12 @@ class VersatileDiffusionDualGuidedPipeline(DiffusionPipeline):
         do_classifier_free_guidance = guidance_scale > 1.0
 
         # 3. Encode input prompts
-        prompt_embeds = self._encode_text_prompt(prompt, num_images_per_prompt, do_classifier_free_guidance)
-        image_embeddings = self._encode_image_prompt(image, num_images_per_prompt, do_classifier_free_guidance)
-        dual_prompt_embeddings = paddle.concat([prompt_embeds, image_embeddings], axis=1)
+        prompt_embeds = self._encode_text_prompt(prompt, num_images_per_prompt,
+                                                 do_classifier_free_guidance)
+        image_embeddings = self._encode_image_prompt(
+            image, num_images_per_prompt, do_classifier_free_guidance)
+        dual_prompt_embeddings = paddle.concat(
+            [prompt_embeds, image_embeddings], axis=1)
         prompt_types = ("text", "image")
 
         # 4. Prepare timesteps
@@ -513,8 +553,7 @@ class VersatileDiffusionDualGuidedPipeline(DiffusionPipeline):
             width,
             dual_prompt_embeddings.dtype,
             generator,
-            latents,
-        )
+            latents, )
 
         # 6. Prepare extra step kwargs.
         extra_step_kwargs = self.prepare_extra_step_kwargs(generator, eta)
@@ -525,19 +564,26 @@ class VersatileDiffusionDualGuidedPipeline(DiffusionPipeline):
         # 8. Denoising loop
         for i, t in enumerate(self.progress_bar(timesteps)):
             # expand the latents if we are doing classifier free guidance
-            latent_model_input = paddle.concat([latents] * 2) if do_classifier_free_guidance else latents
-            latent_model_input = self.scheduler.scale_model_input(latent_model_input, t)
+            latent_model_input = paddle.concat(
+                [latents] * 2) if do_classifier_free_guidance else latents
+            latent_model_input = self.scheduler.scale_model_input(
+                latent_model_input, t)
 
             # predict the noise residual
-            noise_pred = self.image_unet(latent_model_input, t, encoder_hidden_states=dual_prompt_embeddings).sample
+            noise_pred = self.image_unet(
+                latent_model_input,
+                t,
+                encoder_hidden_states=dual_prompt_embeddings).sample
 
             # perform guidance
             if do_classifier_free_guidance:
                 noise_pred_uncond, noise_pred_text = noise_pred.chunk(2)
-                noise_pred = noise_pred_uncond + guidance_scale * (noise_pred_text - noise_pred_uncond)
+                noise_pred = noise_pred_uncond + guidance_scale * (
+                    noise_pred_text - noise_pred_uncond)
 
             # compute the previous noisy sample x_t -> x_t-1
-            latents = self.scheduler.step(noise_pred, t, latents, **extra_step_kwargs).prev_sample
+            latents = self.scheduler.step(noise_pred, t, latents,
+                                          **extra_step_kwargs).prev_sample
 
             # call the callback, if provided
             if callback is not None and i % callback_steps == 0:
@@ -551,6 +597,6 @@ class VersatileDiffusionDualGuidedPipeline(DiffusionPipeline):
             image = self.numpy_to_pil(image)
 
         if not return_dict:
-            return (image,)
+            return (image, )
 
         return ImagePipelineOutput(images=image)
