@@ -1,4 +1,4 @@
-# Copyright (c) 2022 PaddlePaddle Authors. All Rights Reserved.
+# Copyright (c) 2023 PaddlePaddle Authors. All Rights Reserved.
 # Copyright 2022 Google Brain and The HuggingFace Team. All rights reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -20,6 +20,7 @@ import math
 import paddle
 
 from ..configuration_utils import ConfigMixin, register_to_config
+from ..utils import randn_tensor
 from .scheduling_utils import SchedulerMixin
 
 
@@ -41,13 +42,18 @@ class ScoreSdeVpScheduler(SchedulerMixin, ConfigMixin):
     order = 1
 
     @register_to_config
-    def __init__(self, num_train_timesteps=2000, beta_min=0.1, beta_max=20, sampling_eps=1e-3):
+    def __init__(self,
+                 num_train_timesteps=2000,
+                 beta_min=0.1,
+                 beta_max=20,
+                 sampling_eps=1e-3):
         self.sigmas = None
         self.discrete_sigmas = None
         self.timesteps = None
 
     def set_timesteps(self, num_inference_steps):
-        self.timesteps = paddle.linspace(1, self.config.sampling_eps, num_inference_steps)
+        self.timesteps = paddle.linspace(1, self.config.sampling_eps,
+                                         num_inference_steps)
 
     def step_pred(self, score, x, t, generator=None):
         if self.timesteps is None:
@@ -57,9 +63,9 @@ class ScoreSdeVpScheduler(SchedulerMixin, ConfigMixin):
 
         # TODO(Patrick) better comments + non-Paddle
         # postprocess model score
-        log_mean_coeff = (
-            -0.25 * t**2 * (self.config.beta_max - self.config.beta_min) - 0.5 * t * self.config.beta_min
-        )
+        log_mean_coeff = (-0.25 * t**2 *
+                          (self.config.beta_max - self.config.beta_min
+                           ) - 0.5 * t * self.config.beta_min)
         std = paddle.sqrt(1.0 - paddle.exp(2.0 * log_mean_coeff))
         std = std.flatten()
         while len(std.shape) < len(score.shape):
@@ -69,7 +75,8 @@ class ScoreSdeVpScheduler(SchedulerMixin, ConfigMixin):
         # compute
         dt = -1.0 / len(self.timesteps)
 
-        beta_t = self.config.beta_min + t * (self.config.beta_max - self.config.beta_min)
+        beta_t = self.config.beta_min + t * (self.config.beta_max -
+                                             self.config.beta_min)
         beta_t = beta_t.flatten()
         while len(beta_t.shape) < len(x.shape):
             beta_t = beta_t.unsqueeze(-1)
@@ -80,7 +87,7 @@ class ScoreSdeVpScheduler(SchedulerMixin, ConfigMixin):
         x_mean = x + drift * dt
 
         # add noise
-        noise = paddle.randn(x.shape, generator=generator)
+        noise = randn_tensor(x.shape, generator=generator, dtype=x.dtype)
         x = x_mean + diffusion * math.sqrt(-dt) * noise
 
         return x, x_mean
