@@ -17,24 +17,23 @@ import os
 from huggingface_hub.constants import HUGGINGFACE_HUB_CACHE, hf_cache_home
 
 
-def str2bool(variable):
-    if isinstance(variable, bool):
-        return variable
-
-    if not isinstance(variable, str):
-        variable = str(variable)
-
-    if variable.lower() == "false":
-        return False
-    elif variable.lower() == "true":
+def str2bool(v):
+    if isinstance(v, bool):
+        return v
+    if not isinstance(v, str):
+        v = str(v)
+    if v.lower() in ("yes", "true", "t", "y", "1"):
         return True
+    elif v.lower() in ("no", "false", "f", "n", "0"):
+        return False
     else:
-        raise ValueError("Not supported value: {}".format(variable))
+        raise ValueError("Not supported value: {}".format(v))
 
 
 ppnlp_cache_home = os.path.expanduser(
-    os.getenv("PPNLP_HOME", os.path.join(os.getenv("XDG_CACHE_HOME", "~/.cache"), "paddlenlp"))
-)
+    os.getenv("PPNLP_HOME",
+              os.path.join(
+                  os.getenv("XDG_CACHE_HOME", "~/.cache"), "paddlenlp")))
 
 ppdiffusers_default_cache_path = os.path.join(ppnlp_cache_home, "ppdiffusers")
 # diffusers_default_cache_path = os.path.join(HUGGINGFACE_HUB_CACHE, "diffusers")
@@ -52,8 +51,10 @@ PPDIFFUSERS_CACHE = ppdiffusers_default_cache_path
 DIFFUSERS_CACHE = diffusers_default_cache_path
 DIFFUSERS_DYNAMIC_MODULE_NAME = "diffusers_modules"
 PPDIFFUSERS_DYNAMIC_MODULE_NAME = "ppdiffusers_modules"
-HF_MODULES_CACHE = os.getenv("HF_MODULES_CACHE", os.path.join(hf_cache_home, "modules"))
-PPDIFFUSERS_MODULES_CACHE = os.getenv("PPDIFFUSERS_MODULES_CACHE", os.path.join(ppnlp_cache_home, "modules"))
+HF_MODULES_CACHE = os.getenv("HF_MODULES_CACHE",
+                             os.path.join(hf_cache_home, "modules"))
+PPDIFFUSERS_MODULES_CACHE = os.getenv("PPDIFFUSERS_MODULES_CACHE",
+                                      os.path.join(ppnlp_cache_home, "modules"))
 
 PADDLE_WEIGHTS_NAME = "model_state.pdparams"
 FASTDEPLOY_WEIGHTS_NAME = "inference.pdiparams"
@@ -62,11 +63,12 @@ WEIGHTS_NAME = PADDLE_WEIGHTS_NAME
 
 TEST_DOWNLOAD_SERVER = "https://paddlenlp.bj.bcebos.com/models/community/ppdiffusers/tests"
 DOWNLOAD_SERVER = "https://bj.bcebos.com/paddlenlp/models/community"
-PPNLP_BOS_RESOLVE_ENDPOINT = os.getenv("PPNLP_ENDPOINT", "https://bj.bcebos.com/paddlenlp")
+PPNLP_BOS_RESOLVE_ENDPOINT = os.getenv("PPNLP_ENDPOINT",
+                                       "https://bj.bcebos.com/paddlenlp")
 DEPRECATED_REVISION_ARGS = ["fp16", "non-ema"]
 TEXT_ENCODER_ATTN_MODULE = ".self_attn"
-LOW_CPU_MEM_USAGE_DEFAULT = str2bool(os.getenv("LOW_CPU_MEM_USAGE_DEFAULT", False))
-
+LOW_CPU_MEM_USAGE_DEFAULT = str2bool(
+    os.getenv("LOW_CPU_MEM_USAGE_DEFAULT", False))
 
 NEG_INF = -1e4
 
@@ -84,4 +86,5 @@ if bool(os.getenv("PATCH_ALLCLOSE", False)):
     def allclose(x, y, rtol=1e-05, atol=1e-08, equal_nan=False, name=None):
         print(x.tolist())
         print(y.tolist())
-        return raw_all_close(x, y, rtol=rtol, atol=atol, equal_nan=equal_nan, name=name)
+        return raw_all_close(
+            x, y, rtol=rtol, atol=atol, equal_nan=equal_nan, name=name)
