@@ -17,6 +17,7 @@ import os
 import os.path
 import re
 import tempfile
+import warnings
 from contextlib import contextmanager
 from functools import partial
 from pathlib import Path
@@ -30,22 +31,25 @@ from huggingface_hub.file_download import _chmod_and_replace, http_get
 from huggingface_hub.utils import (
     EntryNotFoundError,
     RepositoryNotFoundError,
-    RevisionNotFoundError,
-)
+    RevisionNotFoundError, )
 from huggingface_hub.utils import tqdm as hf_tqdm
+from packaging import version
 from requests import HTTPError
 from tqdm.auto import tqdm as base_tqdm
 from tqdm.contrib.concurrent import thread_map
 
+from ..version import VERSION as __version__
 from .constants import (
+    DEPRECATED_REVISION_ARGS,
     HUGGINGFACE_CO_RESOLVE_ENDPOINT,
     PPDIFFUSERS_CACHE,
     PPNLP_BOS_RESOLVE_ENDPOINT,
-)
+    TORCH_SAFETENSORS_WEIGHTS_NAME,
+    WEIGHTS_NAME, )
 from .logging import get_logger
 
 
-def _add_variant(weights_name: str, variant: Optional[str] = None) -> str:
+def _add_variant(weights_name: str, variant: Optional[str]=None) -> str:
     if variant is not None:
         splits = weights_name.split(".")
         splits = splits[:-1] + [variant] + splits[-1:]
@@ -54,33 +58,38 @@ def _add_variant(weights_name: str, variant: Optional[str] = None) -> str:
     return weights_name
 
 
+# https://github.com/huggingface/diffusers/blob/da2ce1a6b92f48cabe9e9d3944c4ee8b007b2871/src/diffusers/utils/hub_utils.py#L246
 def _get_model_file(
-    pretrained_model_name_or_path,
-    *,
-    weights_name,
-    subfolder,
-    cache_dir,
-    force_download=False,
-    revision=None,
-    proxies=None,
-    resume_download=False,
-    local_files_only=None,
-    use_auth_token=None,
-    user_agent=None,
-    from_hf_hub=False,
-):
+        pretrained_model_name_or_path,
+        *,
+        weights_name,
+        subfolder,
+        cache_dir,
+        force_download=False,
+        revision=None,
+        proxies=None,
+        resume_download=False,
+        local_files_only=None,
+        use_auth_token=None,
+        user_agent=None,
+        commit_hash=None,
+        file_lock_timeout=-1,
+        from_hf_hub=False, ):
     pretrained_model_name_or_path = str(pretrained_model_name_or_path)
     if os.path.isfile(pretrained_model_name_or_path):
         return pretrained_model_name_or_path
     elif os.path.isdir(pretrained_model_name_or_path):
-        if os.path.isfile(os.path.join(pretrained_model_name_or_path, weights_name)):
+        if os.path.isfile(
+                os.path.join(pretrained_model_name_or_path, weights_name)):
             # Load from a PyTorch checkpoint
-            model_file = os.path.join(pretrained_model_name_or_path, weights_name)
+            model_file = os.path.join(pretrained_model_name_or_path,
+                                      weights_name)
             return model_file
         elif subfolder is not None and os.path.isfile(
-            os.path.join(pretrained_model_name_or_path, subfolder, weights_name)
-        ):
-            model_file = os.path.join(pretrained_model_name_or_path, subfolder, weights_name)
+                os.path.join(pretrained_model_name_or_path, subfolder,
+                             weights_name)):
+            model_file = os.path.join(pretrained_model_name_or_path, subfolder,
+                                      weights_name)
             return model_file
         else:
             raise EnvironmentError(
@@ -100,7 +109,8 @@ def _get_model_file(
             local_files_only=local_files_only,
             use_auth_token=use_auth_token,
             user_agent=user_agent,
-        )
+            file_lock_timeout=file_lock_timeout,
+            commit_hash=commit_hash, )
 
 
 REPO_TYPES = ["model"]
@@ -110,9 +120,7 @@ REGEX_COMMIT_HASH = re.compile(r"^[0-9a-f]{40}$")
 PPDIFFUSERS_BOS_URL_TEMPLATE = PPNLP_BOS_RESOLVE_ENDPOINT + "/{repo_type}/community/{repo_id}/{revision}/{filename}"
 
 ALLOW_PATTERNS_MAPPING = {
-    "scheduler": [
-        "scheduler_config.json",
-    ],
+    "scheduler": ["scheduler_config.json", ],
     "text_encoder": [
         "model_state.pdparams",
         "config.json",
@@ -156,14 +164,28 @@ ALLOW_PATTERNS_MAPPING = {
         "config.json",
     ],
     "mel": ["mel_config.json"],
+    "melgan": ["model.onnx"],
     "others": [
+        # models
         "model_state.pdparams",
         "model_config.json",
         "config.json",
-        "model_config.json",
+        # scheduler
         "scheduler_config.json",
+        # feature_extractor
         "preprocessor_config.json",
+        # onnx
+        "model.onnx",
         "pipeline.py",
+        # tokenizer
+        "tokenizer_config.json",
+        "vocab.json",
+        "added_tokens.json",
+        "vocab.txt",
+        "special_tokens_map.json",
+        "spiece.model",
+        "merges.txt",
+        "sentencepiece.bpe.model",
     ],
 }
 
@@ -171,13 +193,12 @@ logger = get_logger(__name__)
 
 
 def ppdiffusers_bos_url(
-    repo_id: str,
-    filename: str,
-    *,
-    subfolder: Optional[str] = None,
-    repo_type: Optional[str] = None,
-    revision: Optional[str] = None,
-) -> str:
+        repo_id: str,
+        filename: str,
+        *,
+        subfolder: Optional[str]=None,
+        repo_type: Optional[str]=None,
+        revision: Optional[str]=None, ) -> str:
     if subfolder == "":
         subfolder = None
     if subfolder is not None:
@@ -194,9 +215,9 @@ def ppdiffusers_bos_url(
     return PPDIFFUSERS_BOS_URL_TEMPLATE.format(
         repo_type=repo_type,
         repo_id=repo_id,
-        revision=quote(revision, safe=""),
-        filename=quote(filename),
-    ).replace(f"/{DEFAULT_REVISION}/", "/")
+        revision=quote(
+            revision, safe=""),
+        filename=quote(filename), ).replace(f"/{DEFAULT_REVISION}/", "/")
 
 
 def repo_folder_name(*, repo_id: str, repo_type: str) -> str:
@@ -211,17 +232,16 @@ def repo_folder_name(*, repo_id: str, repo_type: str) -> str:
 
 
 def ppdiffusers_bos_download(
-    repo_id: str,
-    filename: str,
-    *,
-    subfolder: Optional[str] = None,
-    repo_type: Optional[str] = None,
-    revision: Optional[str] = None,
-    cache_dir: Union[str, Path, None] = None,
-    force_download: bool = False,
-    resume_download: bool = False,
-    file_lock_timeout: int = -1,
-):
+        repo_id: str,
+        filename: str,
+        *,
+        subfolder: Optional[str]=None,
+        repo_type: Optional[str]=None,
+        revision: Optional[str]=None,
+        cache_dir: Union[str, Path, None]=None,
+        force_download: bool=False,
+        resume_download: bool=False,
+        file_lock_timeout: int=-1, ):
     if cache_dir is None:
         cache_dir = PPDIFFUSERS_CACHE
     if revision is None:
@@ -239,8 +259,12 @@ def ppdiffusers_bos_download(
         repo_type = REPO_TYPES[0]
 
     if repo_type not in REPO_TYPES:
-        raise ValueError(f"Invalid repo type: {repo_type}. Accepted repo types are:" f" {str(REPO_TYPES)}")
-    storage_folder = os.path.join(cache_dir, repo_folder_name(repo_id=repo_id, repo_type=repo_type))
+        raise ValueError(
+            f"Invalid repo type: {repo_type}. Accepted repo types are:"
+            f" {str(REPO_TYPES)}")
+    storage_folder = os.path.join(
+        cache_dir, repo_folder_name(
+            repo_id=repo_id, repo_type=repo_type))
     os.makedirs(storage_folder, exist_ok=True)
 
     # cross platform transcription of filename, to be used as a local file path.
@@ -254,7 +278,8 @@ def ppdiffusers_bos_download(
     if os.path.exists(pointer_path) and not force_download:
         return pointer_path
 
-    url_to_download = ppdiffusers_bos_url(repo_id, filename, repo_type=repo_type, revision=revision)
+    url_to_download = ppdiffusers_bos_url(
+        repo_id, filename, repo_type=repo_type, revision=revision)
 
     blob_path = os.path.join(storage_folder, filename)
     # Prevent parallel downloads of the same file with a lock.
@@ -290,8 +315,10 @@ def ppdiffusers_bos_download(
                 resume_size = 0
         else:
             temp_file_manager = partial(  # type: ignore
-                tempfile.NamedTemporaryFile, mode="wb", dir=cache_dir, delete=False
-            )
+                tempfile.NamedTemporaryFile,
+                mode="wb",
+                dir=cache_dir,
+                delete=False)
             resume_size = 0
 
         # Download to temporary file, then copy to cache dir once finished.
@@ -304,8 +331,7 @@ def ppdiffusers_bos_download(
                 temp_file,
                 proxies=None,
                 resume_size=resume_size,
-                headers=None,
-            )
+                headers=None, )
 
         logger.info("storing %s in cache at %s", url_to_download, blob_path)
         _chmod_and_replace(temp_file.name, blob_path)
@@ -318,13 +344,12 @@ def ppdiffusers_bos_download(
 
 
 def ppdiffusers_url_download(
-    url_to_download: str,
-    cache_dir: Union[str, Path, None] = None,
-    filename: Optional[str] = None,
-    force_download: bool = False,
-    resume_download: bool = False,
-    file_lock_timeout: int = -1,
-):
+        url_to_download: str,
+        cache_dir: Union[str, Path, None]=None,
+        filename: Optional[str]=None,
+        force_download: bool=False,
+        resume_download: bool=False,
+        file_lock_timeout: int=-1, ):
     if cache_dir is None:
         cache_dir = PPDIFFUSERS_CACHE
     if isinstance(cache_dir, Path):
@@ -364,8 +389,10 @@ def ppdiffusers_url_download(
                 resume_size = 0
         else:
             temp_file_manager = partial(  # type: ignore
-                tempfile.NamedTemporaryFile, mode="wb", dir=cache_dir, delete=False
-            )
+                tempfile.NamedTemporaryFile,
+                mode="wb",
+                dir=cache_dir,
+                delete=False)
             resume_size = 0
 
         # Download to temporary file, then copy to cache dir once finished.
@@ -378,8 +405,7 @@ def ppdiffusers_url_download(
                 temp_file,
                 proxies=None,
                 resume_size=resume_size,
-                headers=None,
-            )
+                headers=None, )
 
         logger.info("storing %s in cache at %s", url_to_download, file_path)
         _chmod_and_replace(temp_file.name, file_path)
@@ -391,22 +417,50 @@ def ppdiffusers_url_download(
 
 
 def bos_hf_download(
-    pretrained_model_name_or_path,
-    *,
-    filename,
-    subfolder,
-    cache_dir,
-    force_download=False,
-    revision=None,
-    from_hf_hub=False,
-    proxies=None,
-    resume_download=False,
-    local_files_only=None,
-    use_auth_token=None,
-    user_agent=None,
-    file_lock_timeout=-1,
-):
+        pretrained_model_name_or_path,
+        *,
+        filename,
+        subfolder,
+        cache_dir,
+        force_download=False,
+        revision=None,
+        from_hf_hub=False,
+        proxies=None,
+        resume_download=False,
+        local_files_only=None,
+        use_auth_token=None,
+        user_agent=None,
+        file_lock_timeout=-1,
+        commit_hash=None, ):
     if from_hf_hub:
+        # 1. First check if deprecated way of loading from branches is used
+        if (revision in DEPRECATED_REVISION_ARGS and
+            (filename == WEIGHTS_NAME or
+             filename == TORCH_SAFETENSORS_WEIGHTS_NAME) and
+                version.parse(version.parse(__version__).base_version) >=
+                version.parse("0.17.0")):
+            try:
+                model_file = hf_hub_download(
+                    pretrained_model_name_or_path,
+                    filename=_add_variant(filename, revision),
+                    cache_dir=cache_dir,
+                    force_download=force_download,
+                    proxies=proxies,
+                    resume_download=resume_download,
+                    local_files_only=local_files_only,
+                    use_auth_token=use_auth_token,
+                    user_agent=user_agent,
+                    subfolder=subfolder,
+                    revision=revision or commit_hash, )
+                warnings.warn(
+                    f"Loading the variant {revision} from {pretrained_model_name_or_path} via `revision='{revision}'` is deprecated. Loading instead from `revision='main'` with `variant={revision}`. Loading model variants via `revision='{revision}'` will be removed in diffusers v1. Please use `variant='{revision}'` instead.",
+                    FutureWarning, )
+                return model_file
+            except:  # noqa: E722
+                warnings.warn(
+                    f"You are loading the variant {revision} from {pretrained_model_name_or_path} via `revision='{revision}'`. This behavior is deprecated and will be removed in diffusers v1. One should use `variant='{revision}'` instead. However, it appears that {pretrained_model_name_or_path} currently does not have a {_add_variant(filename, revision)} file in the 'main' branch of {pretrained_model_name_or_path}. \n The Diffusers team and community would be very grateful if you could open an issue: https://github.com/huggingface/diffusers/issues/new with the title '{pretrained_model_name_or_path} is missing {_add_variant(filename, revision)}' so that the correct variant file can be added.",
+                    FutureWarning, )
+        # 2. Load model file as usual
         try:
             model_file = hf_hub_download(
                 pretrained_model_name_or_path,
@@ -419,8 +473,7 @@ def bos_hf_download(
                 use_auth_token=use_auth_token,
                 user_agent=user_agent,
                 subfolder=subfolder,
-                revision=revision,
-            )
+                revision=revision, )
             return model_file
 
         except RepositoryNotFoundError:
@@ -428,8 +481,7 @@ def bos_hf_download(
                 f"{pretrained_model_name_or_path} is not a local folder and is not a valid model identifier "
                 "listed on 'https://huggingface.co/models'\nIf this is a private repository, make sure to pass a "
                 "token having permission to this repo with `use_auth_token` or log in with `huggingface-cli "
-                "login`."
-            )
+                "login`.")
         except RevisionNotFoundError:
             raise EnvironmentError(
                 f"{revision} is not a valid git identifier (branch name, tag name or commit id) that exists for "
@@ -437,7 +489,9 @@ def bos_hf_download(
                 f"'https://huggingface.co/{pretrained_model_name_or_path}' for available revisions."
             )
         except EntryNotFoundError:
-            raise EnvironmentError(f"{pretrained_model_name_or_path} does not appear to have a file named {filename}.")
+            raise EnvironmentError(
+                f"{pretrained_model_name_or_path} does not appear to have a file named {filename}."
+            )
         except HTTPError as err:
             raise EnvironmentError(
                 f"There was a specific connection error when trying to load {pretrained_model_name_or_path}:\n{err}"
@@ -455,8 +509,7 @@ def bos_hf_download(
                 f"Can't load the model for '{pretrained_model_name_or_path}'. If you were trying to load it from "
                 "'https://huggingface.co/models', make sure you don't have a local directory with the same name. "
                 f"Otherwise, make sure '{pretrained_model_name_or_path}' is the correct path to a directory "
-                f"containing a file named {filename}"
-            )
+                f"containing a file named {filename}")
         except KeyboardInterrupt:
             raise EnvironmentError(
                 "You have interrupted the download, if you want to continue the download, you can set `resume_download=True`!"
@@ -471,8 +524,7 @@ def bos_hf_download(
                 resume_download=resume_download,
                 subfolder=subfolder,
                 revision=revision,
-                file_lock_timeout=file_lock_timeout,
-            )
+                file_lock_timeout=file_lock_timeout, )
             return model_file
         except HTTPError as err:
             raise EnvironmentError(
@@ -480,15 +532,13 @@ def bos_hf_download(
                 f"There was a specific connection error when trying to load '{pretrained_model_name_or_path}'! "
                 f"We couldn't connect to '{PPNLP_BOS_RESOLVE_ENDPOINT}' to load this model, couldn't find it "
                 f"in the cached files and it looks like '{pretrained_model_name_or_path}' is not the path to a "
-                f"directory containing a file named '{filename}'."
-            )
+                f"directory containing a file named '{filename}'.")
         except EnvironmentError:
             raise EnvironmentError(
                 f"Can't load the model for '{pretrained_model_name_or_path}'. If you were trying to load it from "
                 f"'{PPNLP_BOS_RESOLVE_ENDPOINT}', make sure you don't have a local directory with the same name. "
                 f"Otherwise, make sure '{pretrained_model_name_or_path}' is the correct path to a directory "
-                f"containing a file named '{filename}'"
-            )
+                f"containing a file named '{filename}'")
         except KeyboardInterrupt:
             raise EnvironmentError(
                 "You have interrupted the download, if you want to continue the download, you can set `resume_download=True`!"
@@ -515,20 +565,20 @@ def url_file_exists(url: str) -> bool:
 
 
 def ppdiffusers_bos_dir_download(
-    repo_id: str,
-    *,
-    revision: Optional[str] = None,
-    repo_type: Optional[str] = None,
-    cache_dir: Union[str, Path, None] = None,
-    resume_download: bool = False,
-    folder_names: Optional[Union[List[str], str]] = None,
-    max_workers: int = 1,
-    tqdm_class: Optional[base_tqdm] = None,
-    variant: Optional[str] = None,
-    is_fastdeploy_model: Optional[str] = False,
-    file_lock_timeout: int = -1,
-    local_files_only: bool = False,
-) -> str:
+        repo_id: str,
+        *,
+        revision: Optional[str]=None,
+        repo_type: Optional[str]=None,
+        cache_dir: Union[str, Path, None]=None,
+        force_download: bool=False,
+        resume_download: bool=False,
+        folder_names: Optional[Union[List[str], str]]=None,
+        max_workers: int=1,
+        tqdm_class: Optional[base_tqdm]=None,
+        variant: Optional[str]=None,
+        is_fastdeploy_model: Optional[str]=False,
+        file_lock_timeout: int=-1,
+        local_files_only: bool=False, ) -> str:
     # update repo id must end with @fastdeploy
     if is_fastdeploy_model and not repo_id.endswith("@fastdeploy"):
         repo_id = f"{repo_id}@fastdeploy"
@@ -538,25 +588,42 @@ def ppdiffusers_bos_dir_download(
 
     filtered_repo_files = [["model_index.json", None]]
     for subfolder in folder_names:
-        allow_patterns = ALLOW_PATTERNS_MAPPING.get(subfolder, ALLOW_PATTERNS_MAPPING["others"])
+        allow_patterns = ALLOW_PATTERNS_MAPPING.get(
+            subfolder, ALLOW_PATTERNS_MAPPING["others"])
         if is_fastdeploy_model:
-            allow_patterns = [ap for ap in allow_patterns if "pdparams" not in ap]
+            allow_patterns = [
+                ap for ap in allow_patterns if "pdparams" not in ap
+            ]
             allow_patterns.extend(["inference.pdiparams", "inference.pdmodel"])
         for filename in allow_patterns:
+            need_to_check_no_variant_file = False
+            raw_filename = filename
             if "pdparams" in filename:
                 filename = _add_variant(filename, variant)
+                need_to_check_no_variant_file = variant is not None
+
             url = ppdiffusers_bos_url(
                 repo_id,
                 filename=filename,
-                subfolder=subfolder,
-            )
+                subfolder=subfolder, )
             if url_file_exists(url):
-                filtered_repo_files.append(
-                    [
-                        filename,
-                        subfolder,
-                    ]
-                )
+                # exist file
+                filtered_repo_files.append([
+                    filename,
+                    subfolder,
+                ])
+            else:
+                if need_to_check_no_variant_file:
+                    url = ppdiffusers_bos_url(
+                        repo_id,
+                        filename=raw_filename,
+                        subfolder=subfolder, )
+                    if url_file_exists(url):
+                        # exist file
+                        filtered_repo_files.append([
+                            raw_filename,
+                            subfolder,
+                        ])
 
     def _inner_ppdiffusers_bos_download(repo_file_list):
         filename, _subfolder = repo_file_list
@@ -568,8 +635,8 @@ def ppdiffusers_bos_dir_download(
             cache_dir=cache_dir,
             revision=revision,
             resume_download=resume_download,
-            file_lock_timeout=file_lock_timeout,
-        )
+            force_download=force_download,
+            file_lock_timeout=file_lock_timeout, )
 
     thread_map(
         _inner_ppdiffusers_bos_download,
@@ -577,6 +644,5 @@ def ppdiffusers_bos_dir_download(
         desc=f"Fetching {len(filtered_repo_files)} files",
         max_workers=max_workers,
         # User can use its own tqdm class or the default one from `huggingface_hub.utils`
-        tqdm_class=tqdm_class or hf_tqdm,
-    )
+        tqdm_class=tqdm_class or hf_tqdm, )
     return os.path.join(cache_dir, repo_id)
