@@ -13,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-
 import os
 import re
 import sys
@@ -35,21 +34,20 @@ from .import_utils import (
     _torch_version,
     is_fastdeploy_available,
     is_paddle_available,
-    is_torch_available,
-)
+    is_torch_available, )
 from .logging import get_logger
 
 logger = get_logger(__name__)
 
-
 MODEL_CARD_TEMPLATE_PATH = Path(__file__).parent / "model_card_template.md"
 SESSION_ID = uuid4().hex
 HF_HUB_OFFLINE = os.getenv("HF_HUB_OFFLINE", "").upper() in ENV_VARS_TRUE_VALUES
-DISABLE_TELEMETRY = os.getenv("DISABLE_TELEMETRY", "").upper() in ENV_VARS_TRUE_VALUES
+DISABLE_TELEMETRY = os.getenv("DISABLE_TELEMETRY",
+                              "").upper() in ENV_VARS_TRUE_VALUES
 HUGGINGFACE_CO_TELEMETRY = HUGGINGFACE_CO_RESOLVE_ENDPOINT + "/api/telemetry/"
 
 
-def http_user_agent(user_agent: Union[Dict, str, None] = None) -> str:
+def http_user_agent(user_agent: Union[Dict, str, None]=None) -> str:
     """
     Formats a user-agent string with basic info about a request.
     """
@@ -72,7 +70,9 @@ def http_user_agent(user_agent: Union[Dict, str, None] = None) -> str:
     return ua
 
 
-def get_full_repo_name(model_id: str, organization: Optional[str] = None, token: Optional[str] = None):
+def get_full_repo_name(model_id: str,
+                       organization: Optional[str]=None,
+                       token: Optional[str]=None):
     if token is None:
         token = HfFolder.get_token()
     if organization is None:
@@ -87,8 +87,7 @@ def create_model_card(args, model_name):
         raise ValueError(
             "Modelcard rendering is based on Jinja templates."
             " Please make sure to have `jinja` installed before using `create_model_card`."
-            " To install it, please run `pip install Jinja2`."
-        )
+            " To install it, please run `pip install Jinja2`.")
 
     if hasattr(args, "local_rank") and args.local_rank not in [-1, 0]:
         return
@@ -103,35 +102,41 @@ def create_model_card(args, model_name):
             library_name="ppdiffusers",
             tags=[],
             datasets=args.dataset_name,
-            metrics=[],
-        ),
+            metrics=[], ),
         template_path=MODEL_CARD_TEMPLATE_PATH,
         model_name=model_name,
         repo_name=repo_name,
-        dataset_name=args.dataset_name if hasattr(args, "dataset_name") else None,
+        dataset_name=args.dataset_name
+        if hasattr(args, "dataset_name") else None,
         learning_rate=args.learning_rate,
         train_batch_size=args.train_batch_size,
         eval_batch_size=args.eval_batch_size,
         gradient_accumulation_steps=(
-            args.gradient_accumulation_steps if hasattr(args, "gradient_accumulation_steps") else None
-        ),
+            args.gradient_accumulation_steps
+            if hasattr(args, "gradient_accumulation_steps") else None),
         adam_beta1=args.adam_beta1 if hasattr(args, "adam_beta1") else None,
         adam_beta2=args.adam_beta2 if hasattr(args, "adam_beta2") else None,
-        adam_weight_decay=args.adam_weight_decay if hasattr(args, "adam_weight_decay") else None,
-        adam_epsilon=args.adam_epsilon if hasattr(args, "adam_epsilon") else None,
-        lr_scheduler=args.lr_scheduler if hasattr(args, "lr_scheduler") else None,
-        lr_warmup_steps=args.lr_warmup_steps if hasattr(args, "lr_warmup_steps") else None,
-        ema_inv_gamma=args.ema_inv_gamma if hasattr(args, "ema_inv_gamma") else None,
+        adam_weight_decay=args.adam_weight_decay
+        if hasattr(args, "adam_weight_decay") else None,
+        adam_epsilon=args.adam_epsilon
+        if hasattr(args, "adam_epsilon") else None,
+        lr_scheduler=args.lr_scheduler
+        if hasattr(args, "lr_scheduler") else None,
+        lr_warmup_steps=args.lr_warmup_steps
+        if hasattr(args, "lr_warmup_steps") else None,
+        ema_inv_gamma=args.ema_inv_gamma
+        if hasattr(args, "ema_inv_gamma") else None,
         ema_power=args.ema_power if hasattr(args, "ema_power") else None,
-        ema_max_decay=args.ema_max_decay if hasattr(args, "ema_max_decay") else None,
-        mixed_precision=args.mixed_precision,
-    )
+        ema_max_decay=args.ema_max_decay
+        if hasattr(args, "ema_max_decay") else None,
+        mixed_precision=args.mixed_precision, )
 
     card_path = os.path.join(args.output_dir, "README.md")
     model_card.save(card_path)
 
 
-def extract_commit_hash(resolved_file: Optional[str], commit_hash: Optional[str] = None):
+def extract_commit_hash(resolved_file: Optional[str],
+                        commit_hash: Optional[str]=None):
     """
     Extracts the commit hash from a resolved filename toward a cache file.
     """
@@ -150,12 +155,14 @@ def extract_commit_hash(resolved_file: Optional[str], commit_hash: Optional[str]
 # - Diffusers doesn't use custom environment variables to specify the cache path.
 # - There is no need to migrate the cache format, just move the files to the new location.
 hf_cache_home = os.path.expanduser(
-    os.getenv("HF_HOME", os.path.join(os.getenv("XDG_CACHE_HOME", "~/.cache"), "huggingface"))
-)
+    os.getenv("HF_HOME",
+              os.path.join(
+                  os.getenv("XDG_CACHE_HOME", "~/.cache"), "huggingface")))
 old_diffusers_cache = os.path.join(hf_cache_home, "diffusers")
 
 
-def move_cache(old_cache_dir: Optional[str] = None, new_cache_dir: Optional[str] = None) -> None:
+def move_cache(old_cache_dir: Optional[str]=None,
+               new_cache_dir: Optional[str]=None) -> None:
     if new_cache_dir is None:
         new_cache_dir = DIFFUSERS_CACHE
     if old_cache_dir is None:
@@ -166,7 +173,8 @@ def move_cache(old_cache_dir: Optional[str] = None, new_cache_dir: Optional[str]
     # move file blob by blob
     for old_blob_path in old_cache_dir.glob("**/blobs/*"):
         if old_blob_path.is_file() and not old_blob_path.is_symlink():
-            new_blob_path = new_cache_dir / old_blob_path.relative_to(old_cache_dir)
+            new_blob_path = new_cache_dir / old_blob_path.relative_to(
+                old_cache_dir)
             new_blob_path.parent.mkdir(parents=True, exist_ok=True)
             os.replace(old_blob_path, new_blob_path)
             try:
@@ -179,7 +187,8 @@ def move_cache(old_cache_dir: Optional[str] = None, new_cache_dir: Optional[str]
     # At this point, old_cache_dir contains symlinks to the new cache (it can still be used).
 
 
-cache_version_file = os.path.join(DIFFUSERS_CACHE, "version_diffusers_cache.txt")
+cache_version_file = os.path.join(DIFFUSERS_CACHE,
+                                  "version_diffusers_cache.txt")
 if not os.path.isfile(cache_version_file):
     cache_version = 0
 else:
@@ -190,13 +199,13 @@ else:
         cache_version = 0
 
 if cache_version < 1:
-    old_cache_is_not_empty = os.path.isdir(old_diffusers_cache) and len(os.listdir(old_diffusers_cache)) > 0
+    old_cache_is_not_empty = os.path.isdir(old_diffusers_cache) and len(
+        os.listdir(old_diffusers_cache)) > 0
     if old_cache_is_not_empty:
         logger.warning(
             "The cache for model files in Diffusers v0.14.0 has moved to a new location. Moving your "
             "existing cached models. This is a one-time operation, you can interrupt it or run it "
-            "later by calling `diffusers.utils.hub_utils.move_cache()`."
-        )
+            "later by calling `diffusers.utils.hub_utils.move_cache()`.")
         try:
             move_cache()
         except Exception as e:
@@ -204,8 +213,7 @@ if cache_version < 1:
             logger.error(
                 f"There was a problem when trying to move your cache:\n\n{trace}\n{e.__class__.__name__}: {e}\n\nPlease "
                 "file an issue at https://github.com/huggingface/diffusers/issues/new/choose, copy paste this whole "
-                "message and we will do our best to help."
-            )
+                "message and we will do our best to help.")
 
 if cache_version < 1:
     try:
@@ -215,5 +223,4 @@ if cache_version < 1:
     except Exception:
         logger.warning(
             f"There was a problem when trying to write in your cache folder ({DIFFUSERS_CACHE}). Please, ensure "
-            "the directory exists and can be written to."
-        )
+            "the directory exists and can be written to.")
