@@ -27,15 +27,13 @@ from .constants import get_map_location_default
 from .import_utils import (
     is_paddle_available,
     is_safetensors_available,
-    is_torch_available,
-)
+    is_torch_available, )
 from .logging import get_logger
 
 logger = get_logger(__name__)
 
 __all__ = ["smart_load", "torch_load", "safetensors_load"]
 
-
 paddle_suffix = [".pdparams", ".pd"]
 torch_suffix = [".pt", ".pth", ".bin", ".ckpt"]
 safetensors_suffix = [".safetensors"]
@@ -57,7 +55,6 @@ if is_torch_available():
 if is_paddle_available():
     import paddle
 
-
 MZ_ZIP_LOCAL_DIR_HEADER_SIZE = 30
 
 
@@ -73,7 +70,8 @@ def read_prefix_key(path):
     with open(path, "rb") as file_handler:
         end_index = seek_by_string(file_handler, "data.pkl", file_size)
         file_handler.seek(MZ_ZIP_LOCAL_DIR_HEADER_SIZE)
-        prefix_key = file_handler.read(end_index - MZ_ZIP_LOCAL_DIR_HEADER_SIZE - len("/data.pkl"))
+        prefix_key = file_handler.read(end_index - MZ_ZIP_LOCAL_DIR_HEADER_SIZE
+                                       - len("/data.pkl"))
     return prefix_key.decode("latin")
 
 
@@ -93,7 +91,8 @@ def seek_by_string(file_handler, string: str, file_size: int) -> int:
             word_index = 0
 
     if file_handler.tell() >= file_size - 1:
-        raise Exception(f"can't find the find the target string<{string}> in the file")
+        raise Exception(
+            f"can't find the find the target string<{string}> in the file")
     return file_handler.tell()
 
 
@@ -166,18 +165,21 @@ class UnpicklerWrapperStage(pickle.Unpickler):
         return super().find_class(mod_name, name)
 
 
-def _rebuild_tensor_stage(storage, storage_offset, size, stride, requires_grad, backward_hooks):
+def _rebuild_tensor_stage(storage, storage_offset, size, stride, requires_grad,
+                          backward_hooks):
     # if a tensor has shape [M, N] and stride is [1, N], it's column-wise / fortran-style
     # if a tensor has shape [M, N] and stride is [M, 1], it's row-wise / C-style
     # defautls to C-style
-    if stride is not None and len(stride) > 1 and stride[0] == 1 and stride[1] > 1:
+    if stride is not None and len(stride) > 1 and stride[0] == 1 and stride[
+            1] > 1:
         order = "F"
     else:
         order = "C"
 
     # fix bug when load https://dl.fbaipublicfiles.com/segment_anything/sam_vit_h_4b8939.pth
     numel = int(np.prod(size))
-    return storage[storage_offset : storage_offset + numel].reshape(size, order=order)
+    return storage[storage_offset:storage_offset + numel].reshape(
+        size, order=order)
 
 
 def _rebuild_parameter(data, requires_grad, backward_hooks):
@@ -207,7 +209,8 @@ def torch_load(path: str, **pickle_load_args):
 
         def load_tensor(dtype, numel, key, location):
             name = f"{prefix_key}/data/{key}"
-            typed_storage = np.frombuffer(torch_zip.open(name).read()[:numel], dtype=dtype)
+            typed_storage = np.frombuffer(
+                torch_zip.open(name).read()[:numel], dtype=dtype)
             return typed_storage
 
         def persistent_load(saved_id):
@@ -225,13 +228,15 @@ def torch_load(path: str, **pickle_load_args):
                 typed_storage = loaded_storages[key]
             else:
                 nbytes = numel * _element_size(dtype)
-                typed_storage = load_tensor(dtype, nbytes, key, _maybe_decode_ascii(location))
+                typed_storage = load_tensor(dtype, nbytes, key,
+                                            _maybe_decode_ascii(location))
                 loaded_storages[key] = typed_storage
 
             return typed_storage
 
         data_iostream = torch_zip.open(f"{prefix_key}/data.pkl").read()
-        unpickler_stage = UnpicklerWrapperStage(io.BytesIO(data_iostream), **pickle_load_args)
+        unpickler_stage = UnpicklerWrapperStage(
+            io.BytesIO(data_iostream), **pickle_load_args)
         unpickler_stage.persistent_load = persistent_load
         state_dict = unpickler_stage.load()
         torch_zip.close()
@@ -260,18 +265,18 @@ def convert_to_paddle(state_dict, return_numpy=False, return_global_step=False):
         # if "position_id" in k and "int" not in str(v.dtype):
         #     v = v.numpy().astype("int64") if hasattr(v, "numpy") else v.astype("int64")
         if v.ndim == 0:
-            v = v.reshape((1,))
+            v = v.reshape((1, ))
         if not return_numpy:
             # support bfloat16
             if "torch.bfloat16" in str(v.dtype):
                 v = v.float()
                 pd_state_dict[k] = (
                     paddle.to_tensor(v.numpy()).cast(paddle.bfloat16)
-                    if hasattr(v, "numpy")
-                    else paddle.to_tensor(v).cast(paddle.bfloat16)
-                )
+                    if hasattr(v, "numpy") else
+                    paddle.to_tensor(v).cast(paddle.bfloat16))
             else:
-                pd_state_dict[k] = paddle.to_tensor(v.numpy()) if hasattr(v, "numpy") else paddle.to_tensor(v)
+                pd_state_dict[k] = paddle.to_tensor(v.numpy()) if hasattr(
+                    v, "numpy") else paddle.to_tensor(v)
         else:
             pd_state_dict[k] = v.numpy() if hasattr(v, "numpy") else v
 
@@ -286,7 +291,7 @@ def convert_to_numpy(state_dict):
         # if "position_id" in k and "int" not in str(v.dtype):
         #     v = v.numpy().astype("int64") if hasattr(v, "numpy") else v.astype("int64")
         if v.ndim == 0:
-            v = v.reshape((1,))
+            v = v.reshape((1, ))
     return pd_state_dict
 
 
@@ -306,18 +311,19 @@ def safetensors_load(path: str):
 
             data = load_file(path)
     else:
-        raise ImportError("`safetensors_load` requires the `safetensors library: `pip install safetensors`.")
+        raise ImportError(
+            "`safetensors_load` requires the `safetensors library: `pip install safetensors`."
+        )
 
     return data
 
 
 def smart_load(
-    path: str,
-    map_location: str = None,
-    return_numpy: bool = False,
-    return_global_step: bool = False,
-    return_is_torch_weight: bool = False,
-):
+        path: str,
+        map_location: str=None,
+        return_numpy: bool=False,
+        return_global_step: bool=False,
+        return_is_torch_weight: bool=False, ):
     if map_location is None:
         map_location = get_map_location_default()
 
@@ -330,36 +336,46 @@ def smart_load(
             return state_dict
 
         if suffix in torch_suffix:
-            state_dict = convert_to_paddle(torch_load(path), return_numpy, return_global_step)
+            state_dict = convert_to_paddle(
+                torch_load(path), return_numpy, return_global_step)
             if return_is_torch_weight:
                 state_dict["is_torch_weight"] = True
             return state_dict
 
         if suffix in safetensors_suffix:
-            state_dict = convert_to_paddle(safetensors_load(path), return_numpy, return_global_step)
+            state_dict = convert_to_paddle(
+                safetensors_load(path), return_numpy, return_global_step)
             if return_is_torch_weight:
                 state_dict["is_torch_weight"] = True
             return state_dict
 
         # must use safetensors_load first
         try:
-            state_dict = convert_to_paddle(safetensors_load(path), return_numpy, return_global_step)
+            state_dict = convert_to_paddle(
+                safetensors_load(path), return_numpy, return_global_step)
             if return_is_torch_weight:
                 state_dict["is_torch_weight"] = True
             return state_dict
         except Exception:
             logger.info(f"Cant load file {name} with safetensors!")
         try:
-            state_dict = convert_to_paddle(torch_load(path), return_numpy, return_global_step)
+            state_dict = convert_to_paddle(
+                torch_load(path), return_numpy, return_global_step)
             if return_is_torch_weight:
                 state_dict["is_torch_weight"] = True
             return state_dict
         except Exception:
-            logger.info(f"Cant load file {name} with torch! We will try to load this with safetensors!")
+            logger.info(
+                f"Cant load file {name} with torch! We will try to load this with safetensors!"
+            )
         try:
             state_dict = paddle.load(path, return_numpy=return_numpy)
             return state_dict
         except Exception:
-            logger.info(f"Cant load file {name} with paddle! We will try to load this with torch/safetensors!")
+            logger.info(
+                f"Cant load file {name} with paddle! We will try to load this with torch/safetensors!"
+            )
     if state_dict is None:
-        raise ValueError(f"Cant load {name}, currently we only support ['torch', 'safetensors', 'paddle']!")
+        raise ValueError(
+            f"Cant load {name}, currently we only support ['torch', 'safetensors', 'paddle']!"
+        )
