@@ -39,8 +39,7 @@ from .import_utils import (
     is_opencv_available,
     is_paddle_available,
     is_paddle_version,
-    is_torch_available,
-)
+    is_torch_available, )
 from .logging import get_logger
 
 global_rng = random.Random()
@@ -57,8 +56,7 @@ if is_paddle_available():
         if paddle_device not in available_backends:
             raise ValueError(
                 f"unknown paddle backend for ppdiffusers tests: {paddle_device}. Available backends are:"
-                f" {available_backends}"
-            )
+                f" {available_backends}")
         logger.info(f"paddle_device overrode to {paddle_device}")
     else:
         paddle_device = "gpu" if paddle.is_compiled_with_cuda() else "cpu"
@@ -85,15 +83,19 @@ def paddle_all_close(a, b, *args, **kwargs):
     return True
 
 
-def print_tensor_test(tensor, filename="test_corrections.txt", expected_tensor_name="expected_slice"):
+def print_tensor_test(tensor,
+                      filename="test_corrections.txt",
+                      expected_tensor_name="expected_slice"):
     test_name = os.environ.get("PYTEST_CURRENT_TEST")
     if not paddle.is_tensor(tensor):
         tensor = paddle.to_tensor(tensor)
 
-    tensor_str = str(tensor.detach().cpu().flatten().cast("float32")).replace("\n", "")
+    tensor_str = str(tensor.detach().cpu().flatten().cast("float32")).replace(
+        "\n", "")
     # format is usually:
     # expected_slice = np.array([-0.5713, -0.3018, -0.9814, 0.04663, -0.879, 0.76, -1.734, 0.1044, 1.161])
-    output_str = tensor_str.replace("tensor", f"{expected_tensor_name} = np.array")
+    output_str = tensor_str.replace("tensor",
+                                    f"{expected_tensor_name} = np.array")
     test_file, test_class, test_fn = test_name.split("::")
     test_fn = test_fn.split()[0]
     with open(filename, "a") as f:
@@ -181,28 +183,28 @@ def require_paddle_2_5(test_case):
     """
     Decorator marking a test that requires Paddle 2.5. These tests are skipped when it isn't installed.
     """
-    return unittest.skipUnless(is_paddle_available() and is_paddle_version(">=", "2.5.0"), "test requires Paddle 2.5")(
-        test_case
-    )
+    return unittest.skipUnless(is_paddle_available() and is_paddle_version(
+        ">=", "2.5.0"), "test requires Paddle 2.5")(test_case)
 
 
 def require_paddle(test_case):
     """
     Decorator marking a test that requires Paddle. These tests are skipped when Paddle isn't installed.
     """
-    return unittest.skipUnless(is_paddle_available(), "test requires Paddle")(test_case)
+    return unittest.skipUnless(is_paddle_available(),
+                               "test requires Paddle")(test_case)
 
 
 def require_torch(test_case):
     """Decorator marking a test that requires TORCH."""
-    return unittest.skipUnless(is_torch_available(), "test requires TORCH")(test_case)
+    return unittest.skipUnless(is_torch_available(),
+                               "test requires TORCH")(test_case)
 
 
 def require_paddle_gpu(test_case):
     """Decorator marking a test that requires CUDA and Paddle."""
-    return unittest.skipUnless(is_paddle_available() and paddle_device == "gpu", "test requires Paddle+CUDA")(
-        test_case
-    )
+    return unittest.skipUnless(is_paddle_available() and paddle_device == "gpu",
+                               "test requires Paddle+CUDA")(test_case)
 
 
 def require_compel(test_case):
@@ -210,29 +212,35 @@ def require_compel(test_case):
     Decorator marking a test that requires compel: https://github.com/damian0815/compel. These tests are skipped when
     the library is not installed.
     """
-    return unittest.skipUnless(is_compel_available(), "test requires compel")(test_case)
+    return unittest.skipUnless(is_compel_available(),
+                               "test requires compel")(test_case)
 
 
 def require_fastdeploy(test_case):
     """
     Decorator marking a test that requires fastdeploy. These tests are skipped when fastdeploy isn't installed.
     """
-    return unittest.skipUnless(is_fastdeploy_available(), "test requires fastdeploy")(test_case)
+    return unittest.skipUnless(is_fastdeploy_available(),
+                               "test requires fastdeploy")(test_case)
 
 
 def require_note_seq(test_case):
     """
     Decorator marking a test that requires note_seq. These tests are skipped when note_seq isn't installed.
     """
-    return unittest.skipUnless(is_note_seq_available(), "test requires note_seq")(test_case)
+    return unittest.skipUnless(is_note_seq_available(),
+                               "test requires note_seq")(test_case)
 
 
-def load_numpy(arry: Union[str, np.ndarray], local_path: Optional[str] = None) -> np.ndarray:
+def load_numpy(arry: Union[str, np.ndarray],
+               local_path: Optional[str]=None) -> np.ndarray:
     if isinstance(arry, str):
         # local_path = "/home/patrick_huggingface_co/"
         if local_path is not None:
             # local_path can be passed to correct images of tests
-            return os.path.join(local_path, "/".join([arry.split("/")[-5], arry.split("/")[-2], arry.split("/")[-1]]))
+            return os.path.join(local_path, "/".join([
+                arry.split("/")[-5], arry.split("/")[-2], arry.split("/")[-1]
+            ]))
         elif arry.startswith("http://") or arry.startswith("https://"):
             response = requests.get(arry)
             response.raise_for_status()
@@ -248,8 +256,7 @@ def load_numpy(arry: Union[str, np.ndarray], local_path: Optional[str] = None) -
     else:
         raise ValueError(
             "Incorrect format used for numpy ndarray. Should be an url linking to an image, a local path, or a"
-            " ndarray."
-        )
+            " ndarray.")
 
     return arry
 
@@ -312,17 +319,20 @@ def preprocess_image(image: PIL.Image, batch_size: int):
     return 2.0 * image - 1.0
 
 
-def export_to_video(video_frames: List[np.ndarray], output_video_path: str = None) -> str:
+def export_to_video(video_frames: List[np.ndarray],
+                    output_video_path: str=None) -> str:
     if is_opencv_available():
         import cv2
     else:
-        raise ImportError(BACKENDS_MAPPING["opencv"][1].format("export_to_video"))
+        raise ImportError(BACKENDS_MAPPING["opencv"][1].format(
+            "export_to_video"))
     if output_video_path is None:
         output_video_path = tempfile.NamedTemporaryFile(suffix=".mp4").name
 
     fourcc = cv2.VideoWriter_fourcc(*"mp4v")
     h, w, c = video_frames[0].shape
-    video_writer = cv2.VideoWriter(output_video_path, fourcc, fps=8, frameSize=(w, h))
+    video_writer = cv2.VideoWriter(
+        output_video_path, fourcc, fps=8, frameSize=(w, h))
     for i in range(len(video_frames)):
         img = cv2.cvtColor(video_frames[i], cv2.COLOR_RGB2BGR)
         video_writer.write(img)
@@ -332,8 +342,8 @@ def export_to_video(video_frames: List[np.ndarray], output_video_path: str = Non
 def load_hf_numpy(path) -> np.ndarray:
     if not path.startswith("http://") or path.startswith("https://"):
         path = os.path.join(
-            "https://huggingface.co/datasets/fusing/diffusers-testing/resolve/main", urllib.parse.quote(path)
-        )
+            "https://huggingface.co/datasets/fusing/diffusers-testing/resolve/main",
+            urllib.parse.quote(path))
 
     return load_numpy(path)
 
@@ -341,8 +351,8 @@ def load_hf_numpy(path) -> np.ndarray:
 def load_ppnlp_numpy(path) -> np.ndarray:
     if not path.startswith("http://") or path.startswith("https://"):
         path = os.path.join(
-            "https://paddlenlp.bj.bcebos.com/models/community/CompVis/data/diffusers-testing", urllib.parse.quote(path)
-        )
+            "https://paddlenlp.bj.bcebos.com/models/community/CompVis/data/diffusers-testing",
+            urllib.parse.quote(path))
     return load_numpy(path)
 
 
@@ -433,7 +443,9 @@ def pytest_terminal_summary_main(tr, id):
             f.write("slowest durations\n")
             for i, rep in enumerate(dlist):
                 if rep.duration < durations_min:
-                    f.write(f"{len(dlist)-i} durations < {durations_min} secs were omitted")
+                    f.write(
+                        f"{len(dlist)-i} durations < {durations_min} secs were omitted"
+                    )
                     break
                 f.write(f"{rep.duration:02.2f}s {rep.when:<8} {rep.nodeid}\n")
 
@@ -447,16 +459,18 @@ def pytest_terminal_summary_main(tr, id):
             msg = tr._getfailureheadline(rep)
             tr.write_sep("_", msg, red=True, bold=True)
             # chop off the optional leading extra frames, leaving only the last one
-            longrepr = re.sub(r".*_ _ _ (_ ){10,}_ _ ", "", rep.longreprtext, 0, re.M | re.S)
+            longrepr = re.sub(r".*_ _ _ (_ ){10,}_ _ ", "", rep.longreprtext, 0,
+                              re.M | re.S)
             tr._tw.line(longrepr)
             # note: not printing out any rep.sections to keep the report short
 
-    # use ready-made report funcs, we are just hijacking the filehandle to log to a dedicated file each
-    # adapted from https://github.com/pytest-dev/pytest/blob/897f151e/src/_pytest/terminal.py#L814
-    # note: some pytest plugins may interfere by hijacking the default `terminalreporter` (e.g.
-    # pytest-instafail does that)
+        # use ready-made report funcs, we are just hijacking the filehandle to log to a dedicated file each
+        # adapted from https://github.com/pytest-dev/pytest/blob/897f151e/src/_pytest/terminal.py#L814
+        # note: some pytest plugins may interfere by hijacking the default `terminalreporter` (e.g.
+        # pytest-instafail does that)
+
+        # report failures with line/short/long styles
 
-    # report failures with line/short/long styles
     config.option.tbstyle = "auto"  # full tb
     with open(report_files["failures_long"], "w") as f:
         tr._tw = create_terminal_writer(config, f)
