@@ -33,8 +33,7 @@ class KarrasVePipelineFastTests(unittest.TestCase):
             in_channels=3,
             out_channels=3,
             down_block_types=("DownBlock2D", "AttnDownBlock2D"),
-            up_block_types=("AttnUpBlock2D", "UpBlock2D"),
-        )
+            up_block_types=("AttnUpBlock2D", "UpBlock2D"), )
         return model
 
     def test_inference(self):
@@ -43,15 +42,22 @@ class KarrasVePipelineFastTests(unittest.TestCase):
         pipe = KarrasVePipeline(unet=unet, scheduler=scheduler)
         pipe.set_progress_bar_config(disable=None)
         generator = paddle.Generator().manual_seed(0)
-        image = pipe(num_inference_steps=2, generator=generator, output_type="numpy").images
+        image = pipe(
+            num_inference_steps=2, generator=generator,
+            output_type="numpy").images
         generator = paddle.Generator().manual_seed(0)
-        image_from_tuple = pipe(num_inference_steps=2, generator=generator, output_type="numpy", return_dict=False)[0]
+        image_from_tuple = pipe(
+            num_inference_steps=2,
+            generator=generator,
+            output_type="numpy",
+            return_dict=False)[0]
         image_slice = image[0, -3:, -3:, -1]
         image_from_tuple_slice = image_from_tuple[0, -3:, -3:, -1]
         assert image.shape == (1, 32, 32, 3)
         expected_slice = np.array([0.0, 1.0, 1.0, 0.0, 1.0, 1.0, 1.0, 1.0, 1.0])
         assert np.abs(image_slice.flatten() - expected_slice).max() < 0.01
-        assert np.abs(image_from_tuple_slice.flatten() - expected_slice).max() < 0.01
+        assert np.abs(image_from_tuple_slice.flatten() - expected_slice).max(
+        ) < 0.01
 
 
 @slow
@@ -64,10 +70,13 @@ class KarrasVePipelineIntegrationTests(unittest.TestCase):
         pipe = KarrasVePipeline(unet=model, scheduler=scheduler)
         pipe.set_progress_bar_config(disable=None)
         generator = paddle.Generator().manual_seed(0)
-        image = pipe(num_inference_steps=20, generator=generator, output_type="numpy").images
+        image = pipe(
+            num_inference_steps=20, generator=generator,
+            output_type="numpy").images
         image_slice = image[0, -3:, -3:, -1]
         assert image.shape == (1, 256, 256, 3)
-        expected_slice = np.array(
-            [0.7528239, 0.7529462, 0.76014197, 0.75482357, 0.75692874, 0.7577723, 0.760527, 0.758951, 0.7599246]
-        )
+        expected_slice = np.array([
+            0.7528239, 0.7529462, 0.76014197, 0.75482357, 0.75692874, 0.7577723,
+            0.760527, 0.758951, 0.7599246
+        ])
         assert np.abs(image_slice.flatten() - expected_slice).max() < 0.01
