@@ -24,14 +24,12 @@ from ppdiffusers import (
     AutoencoderKL,
     DDIMScheduler,
     LDMTextToImagePipeline,
-    UNet2DConditionModel,
-)
+    UNet2DConditionModel, )
 from ppdiffusers.utils.testing_utils import (
     load_numpy,
     nightly,
     require_paddle_gpu,
-    slow,
-)
+    slow, )
 
 from ..pipeline_params import TEXT_TO_IMAGE_BATCH_PARAMS, TEXT_TO_IMAGE_PARAMS
 from ..test_pipelines_common import PipelineTesterMixin
@@ -63,15 +61,13 @@ class LDMTextToImagePipelineFastTests(PipelineTesterMixin, unittest.TestCase):
             out_channels=4,
             down_block_types=("DownBlock2D", "CrossAttnDownBlock2D"),
             up_block_types=("CrossAttnUpBlock2D", "UpBlock2D"),
-            cross_attention_dim=32,
-        )
+            cross_attention_dim=32, )
         scheduler = DDIMScheduler(
             beta_start=0.00085,
             beta_end=0.012,
             beta_schedule="scaled_linear",
             clip_sample=False,
-            set_alpha_to_one=False,
-        )
+            set_alpha_to_one=False, )
         paddle.seed(0)
         vae = AutoencoderKL(
             block_out_channels=(32, 64),
@@ -79,8 +75,7 @@ class LDMTextToImagePipelineFastTests(PipelineTesterMixin, unittest.TestCase):
             out_channels=3,
             down_block_types=("DownEncoderBlock2D", "DownEncoderBlock2D"),
             up_block_types=("UpDecoderBlock2D", "UpDecoderBlock2D"),
-            latent_channels=4,
-        )
+            latent_channels=4, )
         paddle.seed(0)
         text_encoder_config = CLIPTextConfig(
             bos_token_id=0,
@@ -91,11 +86,17 @@ class LDMTextToImagePipelineFastTests(PipelineTesterMixin, unittest.TestCase):
             num_attention_heads=4,
             num_hidden_layers=5,
             pad_token_id=1,
-            vocab_size=1000,
-        )
+            vocab_size=1000, )
         text_encoder = CLIPTextModel(text_encoder_config).eval()
-        tokenizer = CLIPTokenizer.from_pretrained("hf-internal-testing/tiny-random-clip")
-        components = {"unet": unet, "scheduler": scheduler, "vqvae": vae, "bert": text_encoder, "tokenizer": tokenizer}
+        tokenizer = CLIPTokenizer.from_pretrained(
+            "hf-internal-testing/tiny-random-clip")
+        components = {
+            "unet": unet,
+            "scheduler": scheduler,
+            "vqvae": vae,
+            "bert": text_encoder,
+            "tokenizer": tokenizer
+        }
         return components
 
     def get_dummy_inputs(self, seed=0):
@@ -118,9 +119,10 @@ class LDMTextToImagePipelineFastTests(PipelineTesterMixin, unittest.TestCase):
         image = pipe(**inputs).images
         assert image.shape == (1, 64, 64, 3)
         image_slice = image[0, -3:, -3:, -1]
-        expected_slice = np.array(
-            [0.28524342, 0.23806289, 0.38151595, 0.21939021, 0.26112252, 0.5172909, 0.25647423, 0.25049314, 0.47979864]
-        )
+        expected_slice = np.array([
+            0.28524342, 0.23806289, 0.38151595, 0.21939021, 0.26112252,
+            0.5172909, 0.25647423, 0.25049314, 0.47979864
+        ])
         assert np.abs(image_slice.flatten() - expected_slice).max() < 0.001
 
 
@@ -147,13 +149,17 @@ class LDMTextToImagePipelineSlowTests(unittest.TestCase):
         return inputs
 
     def test_ldm_default_ddim(self):
-        pipe = LDMTextToImagePipeline.from_pretrained("CompVis/ldm-text2im-large-256")
+        pipe = LDMTextToImagePipeline.from_pretrained(
+            "CompVis/ldm-text2im-large-256")
         pipe.set_progress_bar_config(disable=None)
         inputs = self.get_inputs()
         image = pipe(**inputs).images
         image_slice = image[0, -3:, -3:, -1].flatten()
         assert image.shape == (1, 256, 256, 3)
-        expected_slice = np.array([0.51825, 0.5285, 0.52543, 0.54258, 0.52304, 0.52569, 0.54363, 0.55276, 0.56878])
+        expected_slice = np.array([
+            0.51825, 0.5285, 0.52543, 0.54258, 0.52304, 0.52569, 0.54363,
+            0.55276, 0.56878
+        ])
         max_diff = np.abs(expected_slice - image_slice).max()
         assert max_diff < 0.02
 
@@ -181,7 +187,8 @@ class LDMTextToImagePipelineNightlyTests(unittest.TestCase):
         return inputs
 
     def test_ldm_default_ddim(self):
-        pipe = LDMTextToImagePipeline.from_pretrained("CompVis/ldm-text2im-large-256")
+        pipe = LDMTextToImagePipeline.from_pretrained(
+            "CompVis/ldm-text2im-large-256")
         pipe.set_progress_bar_config(disable=None)
         inputs = self.get_inputs()
         image = pipe(**inputs).images[0]
