@@ -30,7 +30,8 @@ class LDMSuperResolutionPipelineFastTests(unittest.TestCase):
         batch_size = 1
         num_channels = 3
         sizes = 32, 32
-        image = floats_tensor((batch_size, num_channels) + sizes, rng=random.Random(0))
+        image = floats_tensor(
+            (batch_size, num_channels) + sizes, rng=random.Random(0))
         return image
 
     @property
@@ -43,8 +44,7 @@ class LDMSuperResolutionPipelineFastTests(unittest.TestCase):
             in_channels=6,
             out_channels=3,
             down_block_types=("DownBlock2D", "AttnDownBlock2D"),
-            up_block_types=("AttnUpBlock2D", "UpBlock2D"),
-        )
+            up_block_types=("AttnUpBlock2D", "UpBlock2D"), )
         return model
 
     @property
@@ -56,24 +56,28 @@ class LDMSuperResolutionPipelineFastTests(unittest.TestCase):
             out_channels=3,
             down_block_types=["DownEncoderBlock2D", "DownEncoderBlock2D"],
             up_block_types=["UpDecoderBlock2D", "UpDecoderBlock2D"],
-            latent_channels=3,
-        )
+            latent_channels=3, )
         return model
 
     def test_inference_superresolution(self):
         unet = self.dummy_uncond_unet
         scheduler = DDIMScheduler()
         vqvae = self.dummy_vq_model
-        ldm = LDMSuperResolutionPipeline(unet=unet, vqvae=vqvae, scheduler=scheduler)
+        ldm = LDMSuperResolutionPipeline(
+            unet=unet, vqvae=vqvae, scheduler=scheduler)
         ldm.set_progress_bar_config(disable=None)
         init_image = self.dummy_image
         generator = paddle.Generator().manual_seed(0)
-        image = ldm(image=init_image, generator=generator, num_inference_steps=2, output_type="numpy").images
+        image = ldm(image=init_image,
+                    generator=generator,
+                    num_inference_steps=2,
+                    output_type="numpy").images
         image_slice = image[0, -3:, -3:, -1]
         assert image.shape == (1, 64, 64, 3)
-        expected_slice = np.array(
-            [0.12982202, 0.8338444, 0.46506804, 0.5459576, 0.6662215, 0.38444045, 0.72195464, 0.5719301, 0.36579454]
-        )
+        expected_slice = np.array([
+            0.12982202, 0.8338444, 0.46506804, 0.5459576, 0.6662215, 0.38444045,
+            0.72195464, 0.5719301, 0.36579454
+        ])
         assert np.abs(image_slice.flatten() - expected_slice).max() < 0.05
 
     def test_inference_superresolution_fp16(self):
@@ -82,10 +86,12 @@ class LDMSuperResolutionPipelineFastTests(unittest.TestCase):
         vqvae = self.dummy_vq_model
         unet = unet.to(dtype=paddle.float16)
         vqvae = vqvae.to(dtype=paddle.float16)
-        ldm = LDMSuperResolutionPipeline(unet=unet, vqvae=vqvae, scheduler=scheduler)
+        ldm = LDMSuperResolutionPipeline(
+            unet=unet, vqvae=vqvae, scheduler=scheduler)
         ldm.set_progress_bar_config(disable=None)
         init_image = self.dummy_image
-        image = ldm(init_image, num_inference_steps=2, output_type="numpy").images
+        image = ldm(init_image, num_inference_steps=2,
+                    output_type="numpy").images
         assert image.shape == (1, 64, 64, 3)
 
 
@@ -96,12 +102,20 @@ class LDMSuperResolutionPipelineIntegrationTests(unittest.TestCase):
         init_image = load_image(
             "https://huggingface.co/datasets/hf-internal-testing/diffusers-images/resolve/main/vq_diffusion/teddy_bear_pool.png"
         )
-        init_image = init_image.resize((64, 64), resample=PIL_INTERPOLATION["lanczos"])
-        ldm = LDMSuperResolutionPipeline.from_pretrained("duongna/ldm-super-resolution")
+        init_image = init_image.resize(
+            (64, 64), resample=PIL_INTERPOLATION["lanczos"])
+        ldm = LDMSuperResolutionPipeline.from_pretrained(
+            "duongna/ldm-super-resolution")
         ldm.set_progress_bar_config(disable=None)
         generator = paddle.Generator().manual_seed(0)
-        image = ldm(image=init_image, generator=generator, num_inference_steps=20, output_type="numpy").images
+        image = ldm(image=init_image,
+                    generator=generator,
+                    num_inference_steps=20,
+                    output_type="numpy").images
         image_slice = image[0, -3:, -3:, -1]
         assert image.shape == (1, 256, 256, 3)
-        expected_slice = np.array([0.7644, 0.7679, 0.7642, 0.7633, 0.7666, 0.756, 0.7425, 0.7257, 0.6907])
+        expected_slice = np.array([
+            0.7644, 0.7679, 0.7642, 0.7633, 0.7666, 0.756, 0.7425, 0.7257,
+            0.6907
+        ])
         assert np.abs(image_slice.flatten() - expected_slice).max() < 0.05
