@@ -21,8 +21,7 @@ import numpy as np
 import paddle
 from ..pipeline_params import (
     TEXT_TO_IMAGE_BATCH_PARAMS,
-    TEXT_TO_IMAGE_PARAMS,
-)
+    TEXT_TO_IMAGE_PARAMS, )
 from ..test_pipelines_common import PipelineTesterMixin
 
 from paddlenlp.transformers import CLIPTextConfig, CLIPTextModel, CLIPTokenizer
@@ -36,8 +35,7 @@ from ppdiffusers import (
     PNDMScheduler,
     StableDiffusionPipeline,
     UNet2DConditionModel,
-    logging,
-)
+    logging, )
 from ppdiffusers.utils import load_numpy, nightly, slow
 from ppdiffusers.utils.testing_utils import CaptureLogger, require_paddle_gpu
 
@@ -59,15 +57,13 @@ class StableDiffusionPipelineFastTests(PipelineTesterMixin, unittest.TestCase):
             out_channels=4,
             down_block_types=("DownBlock2D", "CrossAttnDownBlock2D"),
             up_block_types=("CrossAttnUpBlock2D", "UpBlock2D"),
-            cross_attention_dim=32,
-        )
+            cross_attention_dim=32, )
         scheduler = DDIMScheduler(
             beta_start=0.00085,
             beta_end=0.012,
             beta_schedule="scaled_linear",
             clip_sample=False,
-            set_alpha_to_one=False,
-        )
+            set_alpha_to_one=False, )
         paddle.seed(0)
         vae = AutoencoderKL(
             block_out_channels=[32, 64],
@@ -75,8 +71,7 @@ class StableDiffusionPipelineFastTests(PipelineTesterMixin, unittest.TestCase):
             out_channels=3,
             down_block_types=["DownEncoderBlock2D", "DownEncoderBlock2D"],
             up_block_types=["UpDecoderBlock2D", "UpDecoderBlock2D"],
-            latent_channels=4,
-        )
+            latent_channels=4, )
         paddle.seed(0)
         text_encoder_config = CLIPTextConfig(
             bos_token_id=0,
@@ -87,10 +82,10 @@ class StableDiffusionPipelineFastTests(PipelineTesterMixin, unittest.TestCase):
             num_attention_heads=4,
             num_hidden_layers=5,
             pad_token_id=1,
-            vocab_size=1000,
-        )
+            vocab_size=1000, )
         text_encoder = CLIPTextModel(text_encoder_config).eval()
-        tokenizer = CLIPTokenizer.from_pretrained("hf-internal-testing/tiny-random-clip")
+        tokenizer = CLIPTokenizer.from_pretrained(
+            "hf-internal-testing/tiny-random-clip")
         components = {
             "unet": unet,
             "scheduler": scheduler,
@@ -123,9 +118,10 @@ class StableDiffusionPipelineFastTests(PipelineTesterMixin, unittest.TestCase):
         image = output.images
         image_slice = image[0, -3:, -3:, -1]
         assert image.shape == (1, 64, 64, 3)
-        expected_slice = np.array(
-            [0.28519553, 0.23807192, 0.38150552, 0.21930423, 0.26092762, 0.51721215, 0.25639117, 0.25039536, 0.47978917]
-        )
+        expected_slice = np.array([
+            0.28519553, 0.23807192, 0.38150552, 0.21930423, 0.26092762,
+            0.51721215, 0.25639117, 0.25039536, 0.47978917
+        ])
         assert np.abs(image_slice.flatten() - expected_slice).max() < 0.01
 
     def test_stable_diffusion_lora(self):
@@ -164,14 +160,14 @@ class StableDiffusionPipelineFastTests(PipelineTesterMixin, unittest.TestCase):
             padding="max_length",
             max_length=sd_pipe.tokenizer.model_max_length,
             truncation=True,
-            return_tensors="pd",
-        )
+            return_tensors="pd", )
         text_inputs = text_inputs["input_ids"]
         prompt_embeds = sd_pipe.text_encoder(text_inputs)[0]
         inputs["prompt_embeds"] = prompt_embeds
         output = sd_pipe(**inputs)
         image_slice_2 = output.images[0, -3:, -3:, -1]
-        assert np.abs(image_slice_1.flatten() - image_slice_2.flatten()).max() < 0.0001
+        assert np.abs(image_slice_1.flatten() - image_slice_2.flatten()).max(
+        ) < 0.0001
 
     def test_stable_diffusion_negative_prompt_embeds(self):
         components = self.get_dummy_components()
@@ -192,14 +188,14 @@ class StableDiffusionPipelineFastTests(PipelineTesterMixin, unittest.TestCase):
                 padding="max_length",
                 max_length=sd_pipe.tokenizer.model_max_length,
                 truncation=True,
-                return_tensors="pd",
-            )
+                return_tensors="pd", )
             text_inputs = text_inputs["input_ids"]
             embeds.append(sd_pipe.text_encoder(text_inputs)[0])
         inputs["prompt_embeds"], inputs["negative_prompt_embeds"] = embeds
         output = sd_pipe(**inputs)
         image_slice_2 = output.images[0, -3:, -3:, -1]
-        assert np.abs(image_slice_1.flatten() - image_slice_2.flatten()).max() < 0.0001
+        assert np.abs(image_slice_1.flatten() - image_slice_2.flatten()).max(
+        ) < 0.0001
 
     def test_stable_diffusion_ddim_factor_8(self):
         components = self.get_dummy_components()
@@ -210,9 +206,10 @@ class StableDiffusionPipelineFastTests(PipelineTesterMixin, unittest.TestCase):
         image = output.images
         image_slice = image[0, -3:, -3:, -1]
         assert image.shape == (1, 136, 136, 3)
-        expected_slice = np.array(
-            [0.39545745, 0.94682777, 0.6828775 , 0.42496994, 0.49475053, 0.48353004, 0.27300328, 0.30724254, 0.50566095]
-        )
+        expected_slice = np.array([
+            0.39545745, 0.94682777, 0.6828775, 0.42496994, 0.49475053,
+            0.48353004, 0.27300328, 0.30724254, 0.50566095
+        ])
 
         assert np.abs(image_slice.flatten() - expected_slice).max() < 0.01
 
@@ -226,15 +223,16 @@ class StableDiffusionPipelineFastTests(PipelineTesterMixin, unittest.TestCase):
         image = output.images
         image_slice = image[0, -3:, -3:, -1]
         assert image.shape == (1, 64, 64, 3)
-        expected_slice = np.array(
-            [0.18620703, 0.24143961, 0.3609084 , 0.21810293, 0.27230006, 0.51992655, 0.22248471, 0.2213102 , 0.44538254]
-        )
+        expected_slice = np.array([
+            0.18620703, 0.24143961, 0.3609084, 0.21810293, 0.27230006,
+            0.51992655, 0.22248471, 0.2213102, 0.44538254
+        ])
         assert np.abs(image_slice.flatten() - expected_slice).max() < 0.01
 
     def test_stable_diffusion_no_safety_checker(self):
         pipe = StableDiffusionPipeline.from_pretrained(
-            "hf-internal-testing/tiny-stable-diffusion-lms-pipe", safety_checker=None
-        )
+            "hf-internal-testing/tiny-stable-diffusion-lms-pipe",
+            safety_checker=None)
         assert isinstance(pipe, StableDiffusionPipeline)
         assert isinstance(pipe.scheduler, LMSDiscreteScheduler)
         assert pipe.safety_checker is None
@@ -242,7 +240,8 @@ class StableDiffusionPipelineFastTests(PipelineTesterMixin, unittest.TestCase):
         assert image is not None
         with tempfile.TemporaryDirectory() as tmpdirname:
             pipe.save_pretrained(tmpdirname)
-            pipe = StableDiffusionPipeline.from_pretrained(tmpdirname, from_diffusers=False)
+            pipe = StableDiffusionPipeline.from_pretrained(
+                tmpdirname, from_diffusers=False)
         assert pipe.safety_checker is None
         image = pipe("example prompt", num_inference_steps=2).images[0]
         assert image is not None
@@ -250,52 +249,59 @@ class StableDiffusionPipelineFastTests(PipelineTesterMixin, unittest.TestCase):
     def test_stable_diffusion_k_lms(self):
         components = self.get_dummy_components()
         sd_pipe = StableDiffusionPipeline(**components)
-        sd_pipe.scheduler = LMSDiscreteScheduler.from_config(sd_pipe.scheduler.config)
+        sd_pipe.scheduler = LMSDiscreteScheduler.from_config(
+            sd_pipe.scheduler.config)
         sd_pipe.set_progress_bar_config(disable=None)
         inputs = self.get_dummy_inputs()
         output = sd_pipe(**inputs)
         image = output.images
         image_slice = image[0, -3:, -3:, -1]
         assert image.shape == (1, 64, 64, 3)
-        expected_slice = np.array(
-            [0.29910105, 0.22905633, 0.37701294, 0.21332851, 0.26000416, 0.52840894, 0.25865072, 0.25947532, 0.47509664]
-        )
+        expected_slice = np.array([
+            0.29910105, 0.22905633, 0.37701294, 0.21332851, 0.26000416,
+            0.52840894, 0.25865072, 0.25947532, 0.47509664
+        ])
 
         assert np.abs(image_slice.flatten() - expected_slice).max() < 0.01
 
     def test_stable_diffusion_k_euler_ancestral(self):
         components = self.get_dummy_components()
         sd_pipe = StableDiffusionPipeline(**components)
-        sd_pipe.scheduler = EulerAncestralDiscreteScheduler.from_config(sd_pipe.scheduler.config)
+        sd_pipe.scheduler = EulerAncestralDiscreteScheduler.from_config(
+            sd_pipe.scheduler.config)
         sd_pipe.set_progress_bar_config(disable=None)
         inputs = self.get_dummy_inputs()
         output = sd_pipe(**inputs)
         image = output.images
         image_slice = image[0, -3:, -3:, -1]
         assert image.shape == (1, 64, 64, 3)
-        expected_slice = np.array(
-            [0.29917336, 0.22854236, 0.37669897, 0.2137424 , 0.25940597, 0.528258  , 0.25919583, 0.2594489 , 0.47522712]
-        )
+        expected_slice = np.array([
+            0.29917336, 0.22854236, 0.37669897, 0.2137424, 0.25940597, 0.528258,
+            0.25919583, 0.2594489, 0.47522712
+        ])
         assert np.abs(image_slice.flatten() - expected_slice).max() < 0.01
 
     def test_stable_diffusion_k_euler(self):
         components = self.get_dummy_components()
         sd_pipe = StableDiffusionPipeline(**components)
-        sd_pipe.scheduler = EulerDiscreteScheduler.from_config(sd_pipe.scheduler.config)
+        sd_pipe.scheduler = EulerDiscreteScheduler.from_config(
+            sd_pipe.scheduler.config)
         sd_pipe.set_progress_bar_config(disable=None)
         inputs = self.get_dummy_inputs()
         output = sd_pipe(**inputs)
         image = output.images
         image_slice = image[0, -3:, -3:, -1]
         assert image.shape == (1, 64, 64, 3)
-        expected_slice = np.array(
-            [0.29910135, 0.22905621, 0.3770129 , 0.21332836, 0.26000386,  0.52840906, 0.2586509 , 0.2594754 , 0.47509673]
-        )
+        expected_slice = np.array([
+            0.29910135, 0.22905621, 0.3770129, 0.21332836, 0.26000386,
+            0.52840906, 0.2586509, 0.2594754, 0.47509673
+        ])
         assert np.abs(image_slice.flatten() - expected_slice).max() < 0.01
 
     def test_stable_diffusion_vae_slicing(self):
         components = self.get_dummy_components()
-        components["scheduler"] = LMSDiscreteScheduler.from_config(components["scheduler"].config)
+        components["scheduler"] = LMSDiscreteScheduler.from_config(components[
+            "scheduler"].config)
         sd_pipe = StableDiffusionPipeline(**components)
         sd_pipe.set_progress_bar_config(disable=None)
         image_count = 4
@@ -306,7 +312,8 @@ class StableDiffusionPipelineFastTests(PipelineTesterMixin, unittest.TestCase):
         inputs = self.get_dummy_inputs()
         inputs["prompt"] = [inputs["prompt"]] * image_count
         output_2 = sd_pipe(**inputs)
-        assert np.abs(output_2.images.flatten() - output_1.images.flatten()).max() < 0.003
+        assert np.abs(output_2.images.flatten() - output_1.images.flatten(
+        )).max() < 0.003
 
     def test_stable_diffusion_vae_tiling(self):
         components = self.get_dummy_components()
@@ -320,14 +327,25 @@ class StableDiffusionPipelineFastTests(PipelineTesterMixin, unittest.TestCase):
 
         # Test that tiled decode at 512x512 yields the same result as the non-tiled decode
         generator = paddle.Generator().manual_seed(0)
-        output_1 = sd_pipe([prompt], generator=generator, guidance_scale=6.0, num_inference_steps=2, output_type="np")
+        output_1 = sd_pipe(
+            [prompt],
+            generator=generator,
+            guidance_scale=6.0,
+            num_inference_steps=2,
+            output_type="np")
 
         # make sure tiled vae decode yields the same result
         sd_pipe.enable_vae_tiling()
         generator = paddle.Generator().manual_seed(0)
-        output_2 = sd_pipe([prompt], generator=generator, guidance_scale=6.0, num_inference_steps=2, output_type="np")
+        output_2 = sd_pipe(
+            [prompt],
+            generator=generator,
+            guidance_scale=6.0,
+            num_inference_steps=2,
+            output_type="np")
 
-        assert np.abs(output_2.images.flatten() - output_1.images.flatten()).max() < 5e-1
+        assert np.abs(output_2.images.flatten() - output_1.images.flatten(
+        )).max() < 5e-1
 
     def test_stable_diffusion_negative_prompt(self):
         components = self.get_dummy_components()
@@ -340,9 +358,10 @@ class StableDiffusionPipelineFastTests(PipelineTesterMixin, unittest.TestCase):
         image = output.images
         image_slice = image[0, -3:, -3:, -1]
         assert image.shape == (1, 64, 64, 3)
-        expected_slice = np.array(
-            [0.16709289, 0.26912582, 0.35834038, 0.23045751, 0.30960953, 0.5324909 , 0.20372942, 0.2368694 , 0.43633103]
-        )
+        expected_slice = np.array([
+            0.16709289, 0.26912582, 0.35834038, 0.23045751, 0.30960953,
+            0.5324909, 0.20372942, 0.2368694, 0.43633103
+        ])
         assert np.abs(image_slice.flatten() - expected_slice).max() < 0.01
 
     def test_stable_diffusion_num_images_per_prompt(self):
@@ -354,43 +373,51 @@ class StableDiffusionPipelineFastTests(PipelineTesterMixin, unittest.TestCase):
         images = sd_pipe(prompt, num_inference_steps=2, output_type="np").images
         assert images.shape == (1, 64, 64, 3)
         batch_size = 2
-        images = sd_pipe([prompt] * batch_size, num_inference_steps=2, output_type="np").images
+        images = sd_pipe(
+            [prompt] * batch_size, num_inference_steps=2,
+            output_type="np").images
         assert images.shape == (batch_size, 64, 64, 3)
         num_images_per_prompt = 2
         images = sd_pipe(
-            prompt, num_inference_steps=2, output_type="np", num_images_per_prompt=num_images_per_prompt
-        ).images
+            prompt,
+            num_inference_steps=2,
+            output_type="np",
+            num_images_per_prompt=num_images_per_prompt).images
         assert images.shape == (num_images_per_prompt, 64, 64, 3)
         batch_size = 2
         images = sd_pipe(
-            [prompt] * batch_size, num_inference_steps=2, output_type="np", num_images_per_prompt=num_images_per_prompt
-        ).images
+            [prompt] * batch_size,
+            num_inference_steps=2,
+            output_type="np",
+            num_images_per_prompt=num_images_per_prompt).images
         assert images.shape == (batch_size * num_images_per_prompt, 64, 64, 3)
 
     def test_stable_diffusion_long_prompt(self):
         components = self.get_dummy_components()
-        components["scheduler"] = LMSDiscreteScheduler.from_config(components["scheduler"].config)
+        components["scheduler"] = LMSDiscreteScheduler.from_config(components[
+            "scheduler"].config)
         sd_pipe = StableDiffusionPipeline(**components)
         sd_pipe.set_progress_bar_config(disable=None)
         do_classifier_free_guidance = True
         negative_prompt = None
         num_images_per_prompt = 1
-        logger = logging.get_logger("ppdiffusers.pipelines.stable_diffusion.pipeline_stable_diffusion")
+        logger = logging.get_logger(
+            "ppdiffusers.pipelines.stable_diffusion.pipeline_stable_diffusion")
         prompt = 25 * "@"
         with CaptureLogger(logger) as cap_logger_3:
             text_embeddings_3 = sd_pipe._encode_prompt(
-                prompt, num_images_per_prompt, do_classifier_free_guidance, negative_prompt
-            )
+                prompt, num_images_per_prompt, do_classifier_free_guidance,
+                negative_prompt)
         prompt = 100 * "@"
         with CaptureLogger(logger) as cap_logger:
             text_embeddings = sd_pipe._encode_prompt(
-                prompt, num_images_per_prompt, do_classifier_free_guidance, negative_prompt
-            )
+                prompt, num_images_per_prompt, do_classifier_free_guidance,
+                negative_prompt)
         negative_prompt = "Hello"
         with CaptureLogger(logger) as cap_logger_2:
             text_embeddings_2 = sd_pipe._encode_prompt(
-                prompt, num_images_per_prompt, do_classifier_free_guidance, negative_prompt
-            )
+                prompt, num_images_per_prompt, do_classifier_free_guidance,
+                negative_prompt)
         assert text_embeddings_3.shape == text_embeddings_2.shape == text_embeddings.shape
         assert text_embeddings.shape[1] == 77
         assert cap_logger.out == cap_logger_2.out
@@ -399,14 +426,20 @@ class StableDiffusionPipelineFastTests(PipelineTesterMixin, unittest.TestCase):
 
     def test_stable_diffusion_height_width_opt(self):
         components = self.get_dummy_components()
-        components["scheduler"] = LMSDiscreteScheduler.from_config(components["scheduler"].config)
+        components["scheduler"] = LMSDiscreteScheduler.from_config(components[
+            "scheduler"].config)
         sd_pipe = StableDiffusionPipeline(**components)
         sd_pipe.set_progress_bar_config(disable=None)
         prompt = "hey"
         output = sd_pipe(prompt, num_inference_steps=1, output_type="np")
         image_shape = output.images[0].shape[:2]
         assert image_shape == (64, 64)
-        output = sd_pipe(prompt, num_inference_steps=1, height=96, width=96, output_type="np")
+        output = sd_pipe(
+            prompt,
+            num_inference_steps=1,
+            height=96,
+            width=96,
+            output_type="np")
         image_shape = output.images[0].shape[:2]
         assert image_shape == (96, 96)
         config = dict(sd_pipe.unet.config)
@@ -440,56 +473,78 @@ class StableDiffusionPipelineSlowTests(unittest.TestCase):
         return inputs
 
     def test_stable_diffusion_1_1_pndm(self):
-        sd_pipe = StableDiffusionPipeline.from_pretrained("CompVis/stable-diffusion-v1-1")
+        sd_pipe = StableDiffusionPipeline.from_pretrained(
+            "CompVis/stable-diffusion-v1-1")
         sd_pipe.set_progress_bar_config(disable=None)
         inputs = self.get_inputs()
         image = sd_pipe(**inputs).images
         image_slice = image[0, -3:, -3:, -1].flatten()
         assert image.shape == (1, 512, 512, 3)
-        expected_slice = np.array([0.43625, 0.43554, 0.3667, 0.4066, 0.39703, 0.38658, 0.43936, 0.43557, 0.40592])
+        expected_slice = np.array([
+            0.43625, 0.43554, 0.3667, 0.4066, 0.39703, 0.38658, 0.43936,
+            0.43557, 0.40592
+        ])
         assert np.abs(image_slice - expected_slice).max() < 0.0001
 
     def test_stable_diffusion_1_4_pndm(self):
-        sd_pipe = StableDiffusionPipeline.from_pretrained("CompVis/stable-diffusion-v1-4")
+        sd_pipe = StableDiffusionPipeline.from_pretrained(
+            "CompVis/stable-diffusion-v1-4")
         sd_pipe.set_progress_bar_config(disable=None)
         inputs = self.get_inputs()
         image = sd_pipe(**inputs).images
         image_slice = image[0, -3:, -3:, -1].flatten()
         assert image.shape == (1, 512, 512, 3)
-        expected_slice = np.array([0.574, 0.47841, 0.31625, 0.63583, 0.58306, 0.55056, 0.50825, 0.56306, 0.55748])
+        expected_slice = np.array([
+            0.574, 0.47841, 0.31625, 0.63583, 0.58306, 0.55056, 0.50825,
+            0.56306, 0.55748
+        ])
         assert np.abs(image_slice - expected_slice).max() < 0.0001
 
     def test_stable_diffusion_ddim(self):
-        sd_pipe = StableDiffusionPipeline.from_pretrained("CompVis/stable-diffusion-v1-4", safety_checker=None)
+        sd_pipe = StableDiffusionPipeline.from_pretrained(
+            "CompVis/stable-diffusion-v1-4", safety_checker=None)
         sd_pipe.scheduler = DDIMScheduler.from_config(sd_pipe.scheduler.config)
         sd_pipe.set_progress_bar_config(disable=None)
         inputs = self.get_inputs()
         image = sd_pipe(**inputs).images
         image_slice = image[0, -3:, -3:, -1].flatten()
         assert image.shape == (1, 512, 512, 3)
-        expected_slice = np.array([0.38019, 0.28647, 0.27321, 0.40377, 0.3829, 0.35446, 0.39218, 0.38165, 0.42239])
+        expected_slice = np.array([
+            0.38019, 0.28647, 0.27321, 0.40377, 0.3829, 0.35446, 0.39218,
+            0.38165, 0.42239
+        ])
         assert np.abs(image_slice - expected_slice).max() < 0.0001
 
     def test_stable_diffusion_lms(self):
-        sd_pipe = StableDiffusionPipeline.from_pretrained("CompVis/stable-diffusion-v1-4", safety_checker=None)
-        sd_pipe.scheduler = LMSDiscreteScheduler.from_config(sd_pipe.scheduler.config)
+        sd_pipe = StableDiffusionPipeline.from_pretrained(
+            "CompVis/stable-diffusion-v1-4", safety_checker=None)
+        sd_pipe.scheduler = LMSDiscreteScheduler.from_config(
+            sd_pipe.scheduler.config)
         sd_pipe.set_progress_bar_config(disable=None)
         inputs = self.get_inputs()
         image = sd_pipe(**inputs).images
         image_slice = image[0, -3:, -3:, -1].flatten()
         assert image.shape == (1, 512, 512, 3)
-        expected_slice = np.array([0.10542, 0.0962, 0.07332, 0.09015, 0.09382, 0.07597, 0.08496, 0.07806, 0.06455])
+        expected_slice = np.array([
+            0.10542, 0.0962, 0.07332, 0.09015, 0.09382, 0.07597, 0.08496,
+            0.07806, 0.06455
+        ])
         assert np.abs(image_slice - expected_slice).max() < 0.0001
 
     def test_stable_diffusion_dpm(self):
-        sd_pipe = StableDiffusionPipeline.from_pretrained("CompVis/stable-diffusion-v1-4", safety_checker=None)
-        sd_pipe.scheduler = DPMSolverMultistepScheduler.from_config(sd_pipe.scheduler.config)
+        sd_pipe = StableDiffusionPipeline.from_pretrained(
+            "CompVis/stable-diffusion-v1-4", safety_checker=None)
+        sd_pipe.scheduler = DPMSolverMultistepScheduler.from_config(
+            sd_pipe.scheduler.config)
         sd_pipe.set_progress_bar_config(disable=None)
         inputs = self.get_inputs()
         image = sd_pipe(**inputs).images
         image_slice = image[0, -3:, -3:, -1].flatten()
         assert image.shape == (1, 512, 512, 3)
-        expected_slice = np.array([0.03503, 0.03494, 0.01087, 0.03128, 0.02552, 0.00803, 0.00742, 0.00372, 0.0])
+        expected_slice = np.array([
+            0.03503, 0.03494, 0.01087, 0.03128, 0.02552, 0.00803, 0.00742,
+            0.00372, 0.0
+        ])
         assert np.abs(image_slice - expected_slice).max() < 0.0001
 
     # def test_stable_diffusion_attention_slicing(self):
@@ -530,7 +585,8 @@ class StableDiffusionPipelineSlowTests(unittest.TestCase):
     #     assert np.abs(image_sliced - image).max() < 0.01
 
     def test_stable_diffusion_fp16_vs_autocast(self):
-        pipe = StableDiffusionPipeline.from_pretrained("CompVis/stable-diffusion-v1-4", paddle_dtype=paddle.float16)
+        pipe = StableDiffusionPipeline.from_pretrained(
+            "CompVis/stable-diffusion-v1-4", paddle_dtype=paddle.float16)
         pipe.set_progress_bar_config(disable=None)
         inputs = self.get_inputs(dtype="float16")
         image_fp16 = pipe(**inputs).images
@@ -543,7 +599,8 @@ class StableDiffusionPipelineSlowTests(unittest.TestCase):
     def test_stable_diffusion_intermediate_state(self):
         number_of_steps = 0
 
-        def callback_fn(step: int, timestep: int, latents: paddle.Tensor) -> None:
+        def callback_fn(step: int, timestep: int,
+                        latents: paddle.Tensor) -> None:
             callback_fn.has_been_called = True
             nonlocal number_of_steps
             number_of_steps += 1
@@ -551,19 +608,26 @@ class StableDiffusionPipelineSlowTests(unittest.TestCase):
                 latents = latents.detach().cpu().numpy()
                 assert latents.shape == (1, 4, 64, 64)
                 latents_slice = latents[0, -3:, -3:, -1]
-                expected_slice = np.array([-0.5693, -0.3018, -0.9746, 0.0518, -0.877, 0.7559, -1.7402, 0.1022, 1.1582])
-                assert np.abs(latents_slice.flatten() - expected_slice).max() < 0.05
+                expected_slice = np.array([
+                    -0.5693, -0.3018, -0.9746, 0.0518, -0.877, 0.7559, -1.7402,
+                    0.1022, 1.1582
+                ])
+                assert np.abs(latents_slice.flatten() - expected_slice).max(
+                ) < 0.05
             elif step == 2:
                 latents = latents.detach().cpu().numpy()
                 assert latents.shape == (1, 4, 64, 64)
                 latents_slice = latents[0, -3:, -3:, -1]
-                expected_slice = np.array(
-                    [-0.1958, -0.2993, -1.0166, -0.5005, -0.481, 0.6162, -0.9492, 0.6621, 1.4492]
-                )
-                assert np.abs(latents_slice.flatten() - expected_slice).max() < 0.05
+                expected_slice = np.array([
+                    -0.1958, -0.2993, -1.0166, -0.5005, -0.481, 0.6162, -0.9492,
+                    0.6621, 1.4492
+                ])
+                assert np.abs(latents_slice.flatten() - expected_slice).max(
+                ) < 0.05
 
         callback_fn.has_been_called = False
-        pipe = StableDiffusionPipeline.from_pretrained("CompVis/stable-diffusion-v1-4", paddle_dtype=paddle.float16)
+        pipe = StableDiffusionPipeline.from_pretrained(
+            "CompVis/stable-diffusion-v1-4", paddle_dtype=paddle.float16)
         pipe.set_progress_bar_config(disable=None)
         pipe.enable_attention_slicing()
         inputs = self.get_inputs(dtype="float16")
@@ -595,7 +659,8 @@ class StableDiffusionPipelineNightlyTests(unittest.TestCase):
         return inputs
 
     def test_stable_diffusion_1_4_pndm(self):
-        sd_pipe = StableDiffusionPipeline.from_pretrained("CompVis/stable-diffusion-v1-4")
+        sd_pipe = StableDiffusionPipeline.from_pretrained(
+            "CompVis/stable-diffusion-v1-4")
         sd_pipe.set_progress_bar_config(disable=None)
         inputs = self.get_inputs()
         image = sd_pipe(**inputs).images[0]
@@ -606,22 +671,22 @@ class StableDiffusionPipelineNightlyTests(unittest.TestCase):
         assert max_diff < 0.001
 
     def test_stable_diffusion_1_5_pndm(self):
-        sd_pipe = StableDiffusionPipeline.from_pretrained("runwayml/stable-diffusion-v1-5")
+        sd_pipe = StableDiffusionPipeline.from_pretrained(
+            "runwayml/stable-diffusion-v1-5")
         sd_pipe.set_progress_bar_config(disable=None)
         inputs = self.get_inputs()
         image = sd_pipe(**inputs).images[0]
-        expected_image = np.array(
-            [
-                [0.7839468, 0.6564859, 0.48896512],
-                [0.78088367, 0.6400461, 0.447728],
-                [0.81458974, 0.67865074, 0.51496047],
-            ]
-        )
+        expected_image = np.array([
+            [0.7839468, 0.6564859, 0.48896512],
+            [0.78088367, 0.6400461, 0.447728],
+            [0.81458974, 0.67865074, 0.51496047],
+        ])
         max_diff = np.abs(expected_image - image[0][0:3]).max()
         assert max_diff < 0.001
 
     def test_stable_diffusion_ddim(self):
-        sd_pipe = StableDiffusionPipeline.from_pretrained("CompVis/stable-diffusion-v1-4")
+        sd_pipe = StableDiffusionPipeline.from_pretrained(
+            "CompVis/stable-diffusion-v1-4")
         sd_pipe.scheduler = DDIMScheduler.from_config(sd_pipe.scheduler.config)
         sd_pipe.set_progress_bar_config(disable=None)
         inputs = self.get_inputs()
@@ -633,8 +698,10 @@ class StableDiffusionPipelineNightlyTests(unittest.TestCase):
         assert max_diff < 0.001
 
     def test_stable_diffusion_lms(self):
-        sd_pipe = StableDiffusionPipeline.from_pretrained("CompVis/stable-diffusion-v1-4")
-        sd_pipe.scheduler = LMSDiscreteScheduler.from_config(sd_pipe.scheduler.config)
+        sd_pipe = StableDiffusionPipeline.from_pretrained(
+            "CompVis/stable-diffusion-v1-4")
+        sd_pipe.scheduler = LMSDiscreteScheduler.from_config(
+            sd_pipe.scheduler.config)
         sd_pipe.set_progress_bar_config(disable=None)
         inputs = self.get_inputs()
         image = sd_pipe(**inputs).images[0]
@@ -645,30 +712,32 @@ class StableDiffusionPipelineNightlyTests(unittest.TestCase):
         assert max_diff < 0.001
 
     def test_stable_diffusion_euler(self):
-        sd_pipe = StableDiffusionPipeline.from_pretrained("CompVis/stable-diffusion-v1-4")
-        sd_pipe.scheduler = EulerDiscreteScheduler.from_config(sd_pipe.scheduler.config)
+        sd_pipe = StableDiffusionPipeline.from_pretrained(
+            "CompVis/stable-diffusion-v1-4")
+        sd_pipe.scheduler = EulerDiscreteScheduler.from_config(
+            sd_pipe.scheduler.config)
         sd_pipe.set_progress_bar_config(disable=None)
         inputs = self.get_inputs()
         image = sd_pipe(**inputs).images[0]
-        expected_image = np.array(
-            [
-                [0.7907467, 0.69895816, 0.5911293],
-                [0.7878128, 0.6815276, 0.55695873],
-                [0.79491043, 0.69076216, 0.58900857],
-            ]
-        )
+        expected_image = np.array([
+            [0.7907467, 0.69895816, 0.5911293],
+            [0.7878128, 0.6815276, 0.55695873],
+            [0.79491043, 0.69076216, 0.58900857],
+        ])
         max_diff = np.abs(expected_image - image[0][0:3]).max()
         assert max_diff < 0.001
 
     def test_stable_diffusion_dpm(self):
-        sd_pipe = StableDiffusionPipeline.from_pretrained("CompVis/stable-diffusion-v1-4")
-        sd_pipe.scheduler = DPMSolverMultistepScheduler.from_config(sd_pipe.scheduler.config)
+        sd_pipe = StableDiffusionPipeline.from_pretrained(
+            "CompVis/stable-diffusion-v1-4")
+        sd_pipe.scheduler = DPMSolverMultistepScheduler.from_config(
+            sd_pipe.scheduler.config)
         sd_pipe.set_progress_bar_config(disable=None)
         inputs = self.get_inputs()
         inputs["num_inference_steps"] = 25
         image = sd_pipe(**inputs).images[0]
-        expected_image = np.array(
-            [[0.8398815, 0.7510048, 0.6475117], [0.8548264, 0.75703114, 0.63529825], [0.8559129, 0.75676, 0.6597851]]
-        )
+        expected_image = np.array([[0.8398815, 0.7510048, 0.6475117],
+                                   [0.8548264, 0.75703114, 0.63529825],
+                                   [0.8559129, 0.75676, 0.6597851]])
         max_diff = np.abs(expected_image - image[0][0:3]).max()
         assert max_diff < 0.001
