@@ -28,22 +28,20 @@ from ppdiffusers import (
     LMSDiscreteScheduler,
     PNDMScheduler,
     StableDiffusionInpaintPipeline,
-    UNet2DConditionModel,
-)
+    UNet2DConditionModel, )
 from ppdiffusers.pipelines.stable_diffusion.pipeline_stable_diffusion_inpaint import (
-    prepare_mask_and_masked_image,
-)
+    prepare_mask_and_masked_image, )
 from ppdiffusers.utils import floats_tensor, load_image, load_numpy, nightly, slow
 from ppdiffusers.utils.testing_utils import require_paddle_gpu
 
 from ..pipeline_params import (
     TEXT_GUIDED_IMAGE_INPAINTING_BATCH_PARAMS,
-    TEXT_GUIDED_IMAGE_INPAINTING_PARAMS,
-)
+    TEXT_GUIDED_IMAGE_INPAINTING_PARAMS, )
 from ..test_pipelines_common import PipelineTesterMixin
 
 
-class StableDiffusionInpaintPipelineFastTests(PipelineTesterMixin, unittest.TestCase):
+class StableDiffusionInpaintPipelineFastTests(PipelineTesterMixin,
+                                              unittest.TestCase):
     pipeline_class = StableDiffusionInpaintPipeline
     params = TEXT_GUIDED_IMAGE_INPAINTING_PARAMS
     batch_params = TEXT_GUIDED_IMAGE_INPAINTING_BATCH_PARAMS
@@ -58,8 +56,7 @@ class StableDiffusionInpaintPipelineFastTests(PipelineTesterMixin, unittest.Test
             out_channels=4,
             down_block_types=("DownBlock2D", "CrossAttnDownBlock2D"),
             up_block_types=("CrossAttnUpBlock2D", "UpBlock2D"),
-            cross_attention_dim=32,
-        )
+            cross_attention_dim=32, )
         scheduler = PNDMScheduler(skip_prk_steps=True)
         paddle.seed(0)
         vae = AutoencoderKL(
@@ -68,8 +65,7 @@ class StableDiffusionInpaintPipelineFastTests(PipelineTesterMixin, unittest.Test
             out_channels=3,
             down_block_types=["DownEncoderBlock2D", "DownEncoderBlock2D"],
             up_block_types=["UpDecoderBlock2D", "UpDecoderBlock2D"],
-            latent_channels=4,
-        )
+            latent_channels=4, )
         paddle.seed(0)
         text_encoder_config = CLIPTextConfig(
             bos_token_id=0,
@@ -80,10 +76,10 @@ class StableDiffusionInpaintPipelineFastTests(PipelineTesterMixin, unittest.Test
             num_attention_heads=4,
             num_hidden_layers=5,
             pad_token_id=1,
-            vocab_size=1000,
-        )
+            vocab_size=1000, )
         text_encoder = CLIPTextModel(text_encoder_config).eval()
-        tokenizer = CLIPTokenizer.from_pretrained("hf-internal-testing/tiny-random-clip")
+        tokenizer = CLIPTokenizer.from_pretrained(
+            "hf-internal-testing/tiny-random-clip")
         components = {
             "unet": unet,
             "scheduler": scheduler,
@@ -98,8 +94,10 @@ class StableDiffusionInpaintPipelineFastTests(PipelineTesterMixin, unittest.Test
     def get_dummy_inputs(self, seed=0):
         image = floats_tensor((1, 3, 32, 32), rng=random.Random(seed))
         image = image.cpu().transpose(perm=[0, 2, 3, 1])[0]
-        init_image = Image.fromarray(np.uint8(image)).convert("RGB").resize((64, 64))
-        mask_image = Image.fromarray(np.uint8(image + 4)).convert("RGB").resize((64, 64))
+        init_image = Image.fromarray(np.uint8(image)).convert("RGB").resize(
+            (64, 64))
+        mask_image = Image.fromarray(np.uint8(image + 4)).convert("RGB").resize(
+            (64, 64))
         generator = paddle.Generator().manual_seed(seed)
 
         inputs = {
@@ -121,9 +119,10 @@ class StableDiffusionInpaintPipelineFastTests(PipelineTesterMixin, unittest.Test
         image = sd_pipe(**inputs).images
         image_slice = image[0, -3:, -3:, -1]
         assert image.shape == (1, 64, 64, 3)
-        expected_slice = np.array(
-            [0.55786943, 0.628228, 0.49147403, 0.3191774, 0.39249492, 0.46521175, 0.29909956, 0.21160087, 0.42932406]
-        )
+        expected_slice = np.array([
+            0.55786943, 0.628228, 0.49147403, 0.3191774, 0.39249492, 0.46521175,
+            0.29909956, 0.21160087, 0.42932406
+        ])
         assert np.abs(image_slice.flatten() - expected_slice).max() < 0.01
 
     def test_stable_diffusion_inpaint_image_tensor(self):
@@ -135,11 +134,11 @@ class StableDiffusionInpaintPipelineFastTests(PipelineTesterMixin, unittest.Test
         out_pil = output.images
         inputs = self.get_dummy_inputs()
         inputs["image"] = (
-            paddle.to_tensor(np.array(inputs["image"]) / 127.5 - 1).transpose(perm=[2, 0, 1]).unsqueeze(axis=0)
-        )
+            paddle.to_tensor(np.array(inputs["image"]) / 127.5 - 1).transpose(
+                perm=[2, 0, 1]).unsqueeze(axis=0))
         inputs["mask_image"] = (
-            paddle.to_tensor(np.array(inputs["mask_image"]) / 255).transpose(perm=[2, 0, 1])[:1].unsqueeze(axis=0)
-        )
+            paddle.to_tensor(np.array(inputs["mask_image"]) / 255).transpose(
+                perm=[2, 0, 1])[:1].unsqueeze(axis=0))
         output = sd_pipe(**inputs)
         out_tensor = output.images
         assert out_pil.shape == (1, 64, 64, 3)
@@ -163,10 +162,13 @@ class StableDiffusionInpaintPipelineSlowTests(unittest.TestCase):
 
     def get_inputs(self, dtype="float32", seed=0):
         generator = paddle.Generator().manual_seed(seed)
-        init_image = load_image("https://paddlenlp.bj.bcebos.com/data/images/input_bench_image.png")
-        mask_image = load_image("https://paddlenlp.bj.bcebos.com/data/images/input_bench_mask.png")
+        init_image = load_image(
+            "https://paddlenlp.bj.bcebos.com/data/images/input_bench_image.png")
+        mask_image = load_image(
+            "https://paddlenlp.bj.bcebos.com/data/images/input_bench_mask.png")
         inputs = {
-            "prompt": "Face of a yellow cat, high resolution, sitting on a park bench",
+            "prompt":
+            "Face of a yellow cat, high resolution, sitting on a park bench",
             "image": init_image,
             "mask_image": mask_image,
             "generator": generator,
@@ -178,36 +180,39 @@ class StableDiffusionInpaintPipelineSlowTests(unittest.TestCase):
 
     def test_stable_diffusion_inpaint_ddim(self):
         pipe = StableDiffusionInpaintPipeline.from_pretrained(
-            "runwayml/stable-diffusion-inpainting", safety_checker=None
-        )
+            "runwayml/stable-diffusion-inpainting", safety_checker=None)
         pipe.set_progress_bar_config(disable=None)
         pipe.enable_attention_slicing()
         inputs = self.get_inputs()
         image = pipe(**inputs).images
         image_slice = image[0, 253:256, 253:256, -1].flatten()
         assert image.shape == (1, 512, 512, 3)
-        expected_slice = np.array([0.05978, 0.10983, 0.10514, 0.07922, 0.08483, 0.08587, 0.05302, 0.03218, 0.01636])
+        expected_slice = np.array([
+            0.05978, 0.10983, 0.10514, 0.07922, 0.08483, 0.08587, 0.05302,
+            0.03218, 0.01636
+        ])
         assert np.abs(expected_slice - image_slice).max() < 0.0001
 
     def test_stable_diffusion_inpaint_fp16(self):
         pipe = StableDiffusionInpaintPipeline.from_pretrained(
-            "runwayml/stable-diffusion-inpainting", paddle_dtype=paddle.float16, safety_checker=None
-        )
+            "runwayml/stable-diffusion-inpainting",
+            paddle_dtype=paddle.float16,
+            safety_checker=None)
         pipe.set_progress_bar_config(disable=None)
         pipe.enable_attention_slicing()
         inputs = self.get_inputs(dtype="float16")
         image = pipe(**inputs).images
         image_slice = image[0, 253:256, 253:256, -1].flatten()
         assert image.shape == (1, 512, 512, 3)
-        expected_slice = np.array(
-            [0.9921875, 0.9477539, 0.90234375, 0.96484375, 0.9189453, 0.875, 0.9316406, 0.9013672, 0.875]
-        )
+        expected_slice = np.array([
+            0.9921875, 0.9477539, 0.90234375, 0.96484375, 0.9189453, 0.875,
+            0.9316406, 0.9013672, 0.875
+        ])
         assert np.abs(expected_slice - image_slice).max() < 0.05
 
     def test_stable_diffusion_inpaint_pndm(self):
         pipe = StableDiffusionInpaintPipeline.from_pretrained(
-            "runwayml/stable-diffusion-inpainting", safety_checker=None
-        )
+            "runwayml/stable-diffusion-inpainting", safety_checker=None)
         pipe.scheduler = PNDMScheduler.from_config(pipe.scheduler.config)
         pipe.set_progress_bar_config(disable=None)
         pipe.enable_attention_slicing()
@@ -215,13 +220,15 @@ class StableDiffusionInpaintPipelineSlowTests(unittest.TestCase):
         image = pipe(**inputs).images
         image_slice = image[0, 253:256, 253:256, -1].flatten()
         assert image.shape == (1, 512, 512, 3)
-        expected_slice = np.array([0.06892, 0.06994, 0.07905, 0.05366, 0.04709, 0.04890, 0.04107, 0.05083, 0.04180])
+        expected_slice = np.array([
+            0.06892, 0.06994, 0.07905, 0.05366, 0.04709, 0.04890, 0.04107,
+            0.05083, 0.04180
+        ])
         assert np.abs(expected_slice - image_slice).max() < 0.0001
 
     def test_stable_diffusion_inpaint_k_lms(self):
         pipe = StableDiffusionInpaintPipeline.from_pretrained(
-            "runwayml/stable-diffusion-inpainting", safety_checker=None
-        )
+            "runwayml/stable-diffusion-inpainting", safety_checker=None)
         pipe.scheduler = LMSDiscreteScheduler.from_config(pipe.scheduler.config)
         pipe.set_progress_bar_config(disable=None)
         pipe.enable_attention_slicing()
@@ -229,7 +236,10 @@ class StableDiffusionInpaintPipelineSlowTests(unittest.TestCase):
         image = pipe(**inputs).images
         image_slice = image[0, 253:256, 253:256, -1].flatten()
         assert image.shape == (1, 512, 512, 3)
-        expected_slice = np.array([0.23513, 0.22413, 0.29442, 0.24243, 0.26214, 0.30329, 0.26431, 0.25025, 0.25197])
+        expected_slice = np.array([
+            0.23513, 0.22413, 0.29442, 0.24243, 0.26214, 0.30329, 0.26431,
+            0.25025, 0.25197
+        ])
         assert np.abs(expected_slice - image_slice).max() < 0.0001
 
 
@@ -243,10 +253,13 @@ class StableDiffusionInpaintPipelineNightlyTests(unittest.TestCase):
 
     def get_inputs(self, dtype="float32", seed=0):
         generator = paddle.Generator().manual_seed(seed)
-        init_image = load_image("https://paddlenlp.bj.bcebos.com/data/images/input_bench_image.png")
-        mask_image = load_image("https://paddlenlp.bj.bcebos.com/data/images/input_bench_mask.png")
+        init_image = load_image(
+            "https://paddlenlp.bj.bcebos.com/data/images/input_bench_image.png")
+        mask_image = load_image(
+            "https://paddlenlp.bj.bcebos.com/data/images/input_bench_mask.png")
         inputs = {
-            "prompt": "Face of a yellow cat, high resolution, sitting on a park bench",
+            "prompt":
+            "Face of a yellow cat, high resolution, sitting on a park bench",
             "image": init_image,
             "mask_image": mask_image,
             "generator": generator,
@@ -257,40 +270,52 @@ class StableDiffusionInpaintPipelineNightlyTests(unittest.TestCase):
         return inputs
 
     def test_inpaint_ddim(self):
-        sd_pipe = StableDiffusionInpaintPipeline.from_pretrained("runwayml/stable-diffusion-inpainting")
+        sd_pipe = StableDiffusionInpaintPipeline.from_pretrained(
+            "runwayml/stable-diffusion-inpainting")
         sd_pipe
         sd_pipe.set_progress_bar_config(disable=None)
         inputs = self.get_inputs()
         image = sd_pipe(**inputs).images[0]
-        expected_image = load_numpy("https://paddlenlp.bj.bcebos.com/data/images/stable_diffusion_inpaint_ddim.npy")
+        expected_image = load_numpy(
+            "https://paddlenlp.bj.bcebos.com/data/images/stable_diffusion_inpaint_ddim.npy"
+        )
         max_diff = np.abs(expected_image - image).max()
         assert max_diff < 0.001
 
     def test_inpaint_pndm(self):
-        sd_pipe = StableDiffusionInpaintPipeline.from_pretrained("runwayml/stable-diffusion-inpainting")
+        sd_pipe = StableDiffusionInpaintPipeline.from_pretrained(
+            "runwayml/stable-diffusion-inpainting")
         sd_pipe.scheduler = PNDMScheduler.from_config(sd_pipe.scheduler.config)
         sd_pipe
         sd_pipe.set_progress_bar_config(disable=None)
         inputs = self.get_inputs()
         image = sd_pipe(**inputs).images[0]
-        expected_image = load_numpy("https://paddlenlp.bj.bcebos.com/data/images/stable_diffusion_inpaint_pndm.npy")
+        expected_image = load_numpy(
+            "https://paddlenlp.bj.bcebos.com/data/images/stable_diffusion_inpaint_pndm.npy"
+        )
         max_diff = np.abs(expected_image - image).max()
         assert max_diff < 0.001
 
     def test_inpaint_lms(self):
-        sd_pipe = StableDiffusionInpaintPipeline.from_pretrained("runwayml/stable-diffusion-inpainting")
-        sd_pipe.scheduler = LMSDiscreteScheduler.from_config(sd_pipe.scheduler.config)
+        sd_pipe = StableDiffusionInpaintPipeline.from_pretrained(
+            "runwayml/stable-diffusion-inpainting")
+        sd_pipe.scheduler = LMSDiscreteScheduler.from_config(
+            sd_pipe.scheduler.config)
         sd_pipe
         sd_pipe.set_progress_bar_config(disable=None)
         inputs = self.get_inputs()
         image = sd_pipe(**inputs).images[0]
-        expected_image = load_numpy("https://paddlenlp.bj.bcebos.com/data/images/stable_diffusion_inpaint_lms.npy")
+        expected_image = load_numpy(
+            "https://paddlenlp.bj.bcebos.com/data/images/stable_diffusion_inpaint_lms.npy"
+        )
         max_diff = np.abs(expected_image - image).max()
         assert max_diff < 0.001
 
     def test_inpaint_dpm(self):
-        sd_pipe = StableDiffusionInpaintPipeline.from_pretrained("runwayml/stable-diffusion-inpainting")
-        sd_pipe.scheduler = DPMSolverMultistepScheduler.from_config(sd_pipe.scheduler.config)
+        sd_pipe = StableDiffusionInpaintPipeline.from_pretrained(
+            "runwayml/stable-diffusion-inpainting")
+        sd_pipe.scheduler = DPMSolverMultistepScheduler.from_config(
+            sd_pipe.scheduler.config)
         sd_pipe
         sd_pipe.set_progress_bar_config(disable=None)
         inputs = self.get_inputs()
@@ -303,7 +328,8 @@ class StableDiffusionInpaintPipelineNightlyTests(unittest.TestCase):
         assert max_diff < 0.001
 
 
-class StableDiffusionInpaintingPrepareMaskAndMaskedImageTests(unittest.TestCase):
+class StableDiffusionInpaintingPrepareMaskAndMaskedImageTests(
+        unittest.TestCase):
     def test_pil_inputs(self):
         im = np.random.randint(0, 255, (32, 32, 3), dtype=np.uint8)
         im = Image.fromarray(im)
@@ -331,7 +357,8 @@ class StableDiffusionInpaintingPrepareMaskAndMaskedImageTests(unittest.TestCase)
         mask_np = np.random.randint(0, 255, (32, 32), dtype=np.uint8) > 127.5
         mask_pil = Image.fromarray((mask_np * 255).astype(np.uint8))
         t_mask_np, t_masked_np = prepare_mask_and_masked_image(im_np, mask_np)
-        t_mask_pil, t_masked_pil = prepare_mask_and_masked_image(im_pil, mask_pil)
+        t_mask_pil, t_masked_pil = prepare_mask_and_masked_image(im_pil,
+                                                                 mask_pil)
         self.assertTrue((t_mask_np == t_mask_pil).all())
         self.assertTrue((t_masked_np == t_masked_pil).all())
 
@@ -342,8 +369,7 @@ class StableDiffusionInpaintingPrepareMaskAndMaskedImageTests(unittest.TestCase)
         mask_np = mask_tensor.numpy()
 
         t_mask_tensor, t_masked_tensor = prepare_mask_and_masked_image(
-            im_tensor / 127.5 - 1, mask_tensor.cast("int64")
-        )
+            im_tensor / 127.5 - 1, mask_tensor.cast("int64"))
         t_mask_np, t_masked_np = prepare_mask_and_masked_image(im_np, mask_np)
 
         self.assertTrue((t_mask_tensor == t_mask_np).all())
@@ -355,8 +381,7 @@ class StableDiffusionInpaintingPrepareMaskAndMaskedImageTests(unittest.TestCase)
         im_np = im_tensor.numpy().transpose(1, 2, 0)
         mask_np = mask_tensor.numpy()[0]
         t_mask_tensor, t_masked_tensor = prepare_mask_and_masked_image(
-            im_tensor / 127.5 - 1, mask_tensor.cast("int64")
-        )
+            im_tensor / 127.5 - 1, mask_tensor.cast("int64"))
         t_mask_np, t_masked_np = prepare_mask_and_masked_image(im_np, mask_np)
         self.assertTrue((t_mask_tensor == t_mask_np).all())
         self.assertTrue((t_masked_tensor == t_masked_np).all())
@@ -367,8 +392,7 @@ class StableDiffusionInpaintingPrepareMaskAndMaskedImageTests(unittest.TestCase)
         im_np = im_tensor.numpy()[0].transpose(1, 2, 0)
         mask_np = mask_tensor.numpy()
         t_mask_tensor, t_masked_tensor = prepare_mask_and_masked_image(
-            im_tensor / 127.5 - 1, mask_tensor.cast("int64")
-        )
+            im_tensor / 127.5 - 1, mask_tensor.cast("int64"))
         t_mask_np, t_masked_np = prepare_mask_and_masked_image(im_np, mask_np)
         self.assertTrue((t_mask_tensor == t_mask_np).all())
         self.assertTrue((t_masked_tensor == t_masked_np).all())
@@ -379,20 +403,19 @@ class StableDiffusionInpaintingPrepareMaskAndMaskedImageTests(unittest.TestCase)
         im_np = im_tensor.numpy()[0].transpose(1, 2, 0)
         mask_np = mask_tensor.numpy()[0]
         t_mask_tensor, t_masked_tensor = prepare_mask_and_masked_image(
-            im_tensor / 127.5 - 1, mask_tensor.cast("int64")
-        )
+            im_tensor / 127.5 - 1, mask_tensor.cast("int64"))
         t_mask_np, t_masked_np = prepare_mask_and_masked_image(im_np, mask_np)
         self.assertTrue((t_mask_tensor == t_mask_np).all())
         self.assertTrue((t_masked_tensor == t_masked_np).all())
 
     def test_paddle_4D_4D_inputs(self):
         im_tensor = paddle.randint(0, 255, (1, 3, 32, 32)).cast("uint8")
-        mask_tensor = paddle.randint(0, 255, (1, 1, 32, 32)).cast("uint8") > 127.5
+        mask_tensor = paddle.randint(0, 255,
+                                     (1, 1, 32, 32)).cast("uint8") > 127.5
         im_np = im_tensor.numpy()[0].transpose(1, 2, 0)
         mask_np = mask_tensor.numpy()[0][0]
         t_mask_tensor, t_masked_tensor = prepare_mask_and_masked_image(
-            im_tensor / 127.5 - 1, mask_tensor.cast("int64")
-        )
+            im_tensor / 127.5 - 1, mask_tensor.cast("int64"))
         t_mask_np, t_masked_np = prepare_mask_and_masked_image(im_np, mask_np)
         self.assertTrue((t_mask_tensor == t_mask_np.cast("float64")).all())
         self.assertTrue((t_masked_tensor == t_masked_np).all())
@@ -403,9 +426,11 @@ class StableDiffusionInpaintingPrepareMaskAndMaskedImageTests(unittest.TestCase)
         im_nps = [im.numpy().transpose(1, 2, 0) for im in im_tensor]
         mask_nps = [mask.numpy() for mask in mask_tensor]
         t_mask_tensor, t_masked_tensor = prepare_mask_and_masked_image(
-            im_tensor / 127.5 - 1, mask_tensor.cast("int64")
-        )
-        nps = [prepare_mask_and_masked_image(i, m) for i, m in zip(im_nps, mask_nps)]
+            im_tensor / 127.5 - 1, mask_tensor.cast("int64"))
+        nps = [
+            prepare_mask_and_masked_image(i, m)
+            for i, m in zip(im_nps, mask_nps)
+        ]
         t_mask_np = paddle.concat(x=[n[0] for n in nps])
         t_masked_np = paddle.concat(x=[n[1] for n in nps])
         self.assertTrue((t_mask_tensor == t_mask_np).all())
@@ -418,9 +443,11 @@ class StableDiffusionInpaintingPrepareMaskAndMaskedImageTests(unittest.TestCase)
         im_nps = [im.numpy().transpose(1, 2, 0) for im in im_tensor]
         mask_nps = [mask.numpy() for mask in mask_tensor]
         t_mask_tensor, t_masked_tensor = prepare_mask_and_masked_image(
-            im_tensor / 127.5 - 1, mask_tensor.cast("int64")
-        )
-        nps = [prepare_mask_and_masked_image(i, m) for i, m in zip(im_nps, mask_nps)]
+            im_tensor / 127.5 - 1, mask_tensor.cast("int64"))
+        nps = [
+            prepare_mask_and_masked_image(i, m)
+            for i, m in zip(im_nps, mask_nps)
+        ]
         t_mask_np = paddle.concat(x=[n[0] for n in nps])
         t_masked_np = paddle.concat(x=[n[1] for n in nps])
         self.assertTrue((t_mask_tensor == t_mask_np).all())
@@ -428,28 +455,44 @@ class StableDiffusionInpaintingPrepareMaskAndMaskedImageTests(unittest.TestCase)
 
     def test_shape_mismatch(self):
         with self.assertRaises(AssertionError):
-            prepare_mask_and_masked_image(paddle.randn(shape=[3, 32, 32]), paddle.randn(shape=[64, 64]))
+            prepare_mask_and_masked_image(
+                paddle.randn(shape=[3, 32, 32]), paddle.randn(shape=[64, 64]))
         with self.assertRaises(AssertionError):
-            prepare_mask_and_masked_image(paddle.randn(shape=[2, 3, 32, 32]), paddle.randn(shape=[4, 64, 64]))
+            prepare_mask_and_masked_image(
+                paddle.randn(shape=[2, 3, 32, 32]),
+                paddle.randn(shape=[4, 64, 64]))
         with self.assertRaises(AssertionError):
-            prepare_mask_and_masked_image(paddle.randn(shape=[2, 3, 32, 32]), paddle.randn(shape=[4, 1, 64, 64]))
+            prepare_mask_and_masked_image(
+                paddle.randn(shape=[2, 3, 32, 32]),
+                paddle.randn(shape=[4, 1, 64, 64]))
 
     def test_type_mismatch(self):
         with self.assertRaises(TypeError):
-            prepare_mask_and_masked_image(paddle.rand(shape=[3, 32, 32]), paddle.rand(shape=[3, 32, 32]).numpy())
+            prepare_mask_and_masked_image(
+                paddle.rand(shape=[3, 32, 32]),
+                paddle.rand(shape=[3, 32, 32]).numpy())
         with self.assertRaises(TypeError):
-            prepare_mask_and_masked_image(paddle.rand(shape=[3, 32, 32]).numpy(), paddle.rand(shape=[3, 32, 32]))
+            prepare_mask_and_masked_image(
+                paddle.rand(shape=[3, 32, 32]).numpy(),
+                paddle.rand(shape=[3, 32, 32]))
 
     def test_channels_first(self):
         with self.assertRaises(AssertionError):
-            prepare_mask_and_masked_image(paddle.rand(shape=[32, 32, 3]), paddle.rand(shape=[3, 32, 32]))
+            prepare_mask_and_masked_image(
+                paddle.rand(shape=[32, 32, 3]), paddle.rand(shape=[3, 32, 32]))
 
     def test_tensor_range(self):
         with self.assertRaises(ValueError):
-            prepare_mask_and_masked_image(paddle.ones(shape=[3, 32, 32]) * 2, paddle.rand(shape=[32, 32]))
+            prepare_mask_and_masked_image(
+                paddle.ones(shape=[3, 32, 32]) * 2, paddle.rand(shape=[32, 32]))
         with self.assertRaises(ValueError):
-            prepare_mask_and_masked_image(paddle.ones(shape=[3, 32, 32]) * -2, paddle.rand(shape=[32, 32]))
+            prepare_mask_and_masked_image(
+                paddle.ones(shape=[3, 32, 32]) * -2,
+                paddle.rand(shape=[32, 32]))
         with self.assertRaises(ValueError):
-            prepare_mask_and_masked_image(paddle.rand(shape=[3, 32, 32]), paddle.ones(shape=[32, 32]) * 2)
+            prepare_mask_and_masked_image(
+                paddle.rand(shape=[3, 32, 32]), paddle.ones(shape=[32, 32]) * 2)
         with self.assertRaises(ValueError):
-            prepare_mask_and_masked_image(paddle.rand(shape=[3, 32, 32]), paddle.ones(shape=[32, 32]) * -1)
+            prepare_mask_and_masked_image(
+                paddle.rand(shape=[3, 32, 32]),
+                paddle.ones(shape=[32, 32]) * -1)
