@@ -31,8 +31,7 @@ from ppdiffusers import (
     StableDiffusionInpaintPipelineLegacy,
     UNet2DConditionModel,
     UNet2DModel,
-    VQModel,
-)
+    VQModel, )
 from ppdiffusers.utils import floats_tensor, load_image, nightly, slow
 from ppdiffusers.utils.testing_utils import load_numpy, preprocess_image, require_paddle_gpu
 
@@ -48,7 +47,8 @@ class StableDiffusionInpaintLegacyPipelineFastTests(unittest.TestCase):
         batch_size = 1
         num_channels = 3
         sizes = 32, 32
-        image = floats_tensor((batch_size, num_channels) + sizes, rng=random.Random(0))
+        image = floats_tensor(
+            (batch_size, num_channels) + sizes, rng=random.Random(0))
         return image
 
     @property
@@ -61,8 +61,7 @@ class StableDiffusionInpaintLegacyPipelineFastTests(unittest.TestCase):
             in_channels=3,
             out_channels=3,
             down_block_types=("DownBlock2D", "AttnDownBlock2D"),
-            up_block_types=("AttnUpBlock2D", "UpBlock2D"),
-        )
+            up_block_types=("AttnUpBlock2D", "UpBlock2D"), )
         return model
 
     @property
@@ -76,8 +75,7 @@ class StableDiffusionInpaintLegacyPipelineFastTests(unittest.TestCase):
             out_channels=4,
             down_block_types=("DownBlock2D", "CrossAttnDownBlock2D"),
             up_block_types=("CrossAttnUpBlock2D", "UpBlock2D"),
-            cross_attention_dim=32,
-        )
+            cross_attention_dim=32, )
         return model
 
     @property
@@ -91,8 +89,7 @@ class StableDiffusionInpaintLegacyPipelineFastTests(unittest.TestCase):
             out_channels=4,
             down_block_types=("DownBlock2D", "CrossAttnDownBlock2D"),
             up_block_types=("CrossAttnUpBlock2D", "UpBlock2D"),
-            cross_attention_dim=32,
-        )
+            cross_attention_dim=32, )
         return model
 
     @property
@@ -104,8 +101,7 @@ class StableDiffusionInpaintLegacyPipelineFastTests(unittest.TestCase):
             out_channels=3,
             down_block_types=["DownEncoderBlock2D", "DownEncoderBlock2D"],
             up_block_types=["UpDecoderBlock2D", "UpDecoderBlock2D"],
-            latent_channels=3,
-        )
+            latent_channels=3, )
         return model
 
     @property
@@ -117,8 +113,7 @@ class StableDiffusionInpaintLegacyPipelineFastTests(unittest.TestCase):
             out_channels=3,
             down_block_types=["DownEncoderBlock2D", "DownEncoderBlock2D"],
             up_block_types=["UpDecoderBlock2D", "UpDecoderBlock2D"],
-            latent_channels=4,
-        )
+            latent_channels=4, )
         return model
 
     @property
@@ -133,8 +128,7 @@ class StableDiffusionInpaintLegacyPipelineFastTests(unittest.TestCase):
             num_attention_heads=4,
             num_hidden_layers=5,
             pad_token_id=1,
-            vocab_size=1000,
-        )
+            vocab_size=1000, )
         return CLIPTextModel(config).eval()
 
     @property
@@ -157,10 +151,12 @@ class StableDiffusionInpaintLegacyPipelineFastTests(unittest.TestCase):
         scheduler = PNDMScheduler(skip_prk_steps=True)
         vae = self.dummy_vae
         bert = self.dummy_text_encoder
-        tokenizer = CLIPTokenizer.from_pretrained("hf-internal-testing/tiny-random-clip")
+        tokenizer = CLIPTokenizer.from_pretrained(
+            "hf-internal-testing/tiny-random-clip")
         image = self.dummy_image.cpu().transpose(perm=[0, 2, 3, 1])[0]
         init_image = Image.fromarray(np.uint8(image)).convert("RGB")
-        mask_image = Image.fromarray(np.uint8(image + 4)).convert("RGB").resize((32, 32))
+        mask_image = Image.fromarray(np.uint8(image + 4)).convert("RGB").resize(
+            (32, 32))
         sd_pipe = StableDiffusionInpaintPipelineLegacy(
             unet=unet,
             scheduler=scheduler,
@@ -168,8 +164,7 @@ class StableDiffusionInpaintLegacyPipelineFastTests(unittest.TestCase):
             text_encoder=bert,
             tokenizer=tokenizer,
             safety_checker=None,
-            feature_extractor=self.dummy_extractor,
-        )
+            feature_extractor=self.dummy_extractor, )
         sd_pipe.set_progress_bar_config(disable=None)
         prompt = "A painting of a squirrel eating a burger"
         generator = paddle.Generator().manual_seed(0)
@@ -180,8 +175,7 @@ class StableDiffusionInpaintLegacyPipelineFastTests(unittest.TestCase):
             num_inference_steps=2,
             output_type="np",
             image=init_image,
-            mask_image=mask_image,
-        )
+            mask_image=mask_image, )
         image = output.images
         generator = paddle.Generator().manual_seed(0)
         image_from_tuple = sd_pipe(
@@ -192,23 +186,25 @@ class StableDiffusionInpaintLegacyPipelineFastTests(unittest.TestCase):
             output_type="np",
             image=init_image,
             mask_image=mask_image,
-            return_dict=False,
-        )[0]
+            return_dict=False, )[0]
         image_slice = image[0, -3:, -3:, -1]
         image_from_tuple_slice = image_from_tuple[0, -3:, -3:, -1]
         assert image.shape == (1, 32, 32, 3)
-        expected_slice = np.array(
-            [0.0, 0.42294562, 0.31831095, 0.11458772, 0.57409716, 0.6021224, 0.3139254, 0.6612497, 0.51271075]
-        )
+        expected_slice = np.array([
+            0.0, 0.42294562, 0.31831095, 0.11458772, 0.57409716, 0.6021224,
+            0.3139254, 0.6612497, 0.51271075
+        ])
         assert np.abs(image_slice.flatten() - expected_slice).max() < 0.01
-        assert np.abs(image_from_tuple_slice.flatten() - expected_slice).max() < 0.01
+        assert np.abs(image_from_tuple_slice.flatten() - expected_slice).max(
+        ) < 0.01
 
     def test_stable_diffusion_inpaint_legacy_batched(self):
         unet = self.dummy_cond_unet
         scheduler = PNDMScheduler(skip_prk_steps=True)
         vae = self.dummy_vae
         bert = self.dummy_text_encoder
-        tokenizer = CLIPTokenizer.from_pretrained("hf-internal-testing/tiny-random-clip")
+        tokenizer = CLIPTokenizer.from_pretrained(
+            "hf-internal-testing/tiny-random-clip")
 
         image = self.dummy_image.permute(0, 2, 3, 1)[0]
         init_image = Image.fromarray(np.uint8(image)).convert("RGB")
@@ -223,8 +219,7 @@ class StableDiffusionInpaintLegacyPipelineFastTests(unittest.TestCase):
             text_encoder=bert,
             tokenizer=tokenizer,
             safety_checker=None,
-            feature_extractor=self.dummy_extractor,
-        )
+            feature_extractor=self.dummy_extractor, )
         sd_pipe.set_progress_bar_config(disable=None)
 
         prompt = "A painting of a squirrel eating a burger"
@@ -236,16 +231,21 @@ class StableDiffusionInpaintLegacyPipelineFastTests(unittest.TestCase):
             num_inference_steps=2,
             output_type="np",
             image=init_images_tens,
-            mask_image=init_masks_tens,
-        ).images
+            mask_image=init_masks_tens, ).images
 
         assert images.shape == (2, 32, 32, 3)
 
         image_slice_0 = images[0, -3:, -3:, -1].flatten()
         image_slice_1 = images[1, -3:, -3:, -1].flatten()
 
-        expected_slice_0 = np.array([0.36070424, 0.6893935 , 0.5395819 , 0.43957978, 0.52270013, 0.41502672, 0.5263115 , 0.57829964, 0.61257005])
-        expected_slice_1 = np.array([0.5639288 , 0.6165064 , 0.6162699 , 0.6441643 , 0.56632555, 0.39611217, 0.62690437, 0.5277921 , 0.5135379])
+        expected_slice_0 = np.array([
+            0.36070424, 0.6893935, 0.5395819, 0.43957978, 0.52270013,
+            0.41502672, 0.5263115, 0.57829964, 0.61257005
+        ])
+        expected_slice_1 = np.array([
+            0.5639288, 0.6165064, 0.6162699, 0.6441643, 0.56632555, 0.39611217,
+            0.62690437, 0.5277921, 0.5135379
+        ])
 
         assert np.abs(expected_slice_0 - image_slice_0).max() < 1e-2
         assert np.abs(expected_slice_1 - image_slice_1).max() < 1e-2
@@ -255,10 +255,12 @@ class StableDiffusionInpaintLegacyPipelineFastTests(unittest.TestCase):
         scheduler = PNDMScheduler(skip_prk_steps=True)
         vae = self.dummy_vae
         bert = self.dummy_text_encoder
-        tokenizer = CLIPTokenizer.from_pretrained("hf-internal-testing/tiny-random-clip")
+        tokenizer = CLIPTokenizer.from_pretrained(
+            "hf-internal-testing/tiny-random-clip")
         image = self.dummy_image.cpu().transpose(perm=[0, 2, 3, 1])[0]
         init_image = Image.fromarray(np.uint8(image)).convert("RGB")
-        mask_image = Image.fromarray(np.uint8(image + 4)).convert("RGB").resize((32, 32))
+        mask_image = Image.fromarray(np.uint8(image + 4)).convert("RGB").resize(
+            (32, 32))
         sd_pipe = StableDiffusionInpaintPipelineLegacy(
             unet=unet,
             scheduler=scheduler,
@@ -266,8 +268,7 @@ class StableDiffusionInpaintLegacyPipelineFastTests(unittest.TestCase):
             text_encoder=bert,
             tokenizer=tokenizer,
             safety_checker=None,
-            feature_extractor=self.dummy_extractor,
-        )
+            feature_extractor=self.dummy_extractor, )
         sd_pipe.set_progress_bar_config(disable=None)
         prompt = "A painting of a squirrel eating a burger"
         negative_prompt = "french fries"
@@ -280,14 +281,14 @@ class StableDiffusionInpaintLegacyPipelineFastTests(unittest.TestCase):
             num_inference_steps=2,
             output_type="np",
             image=init_image,
-            mask_image=mask_image,
-        )
+            mask_image=mask_image, )
         image = output.images
         image_slice = image[0, -3:, -3:, -1]
         assert image.shape == (1, 32, 32, 3)
-        expected_slice = np.array(
-            [0.0, 0.42320636, 0.3191024, 0.11486277, 0.5742749, 0.6025071, 0.31415784, 0.66176593, 0.5128486]
-        )
+        expected_slice = np.array([
+            0.0, 0.42320636, 0.3191024, 0.11486277, 0.5742749, 0.6025071,
+            0.31415784, 0.66176593, 0.5128486
+        ])
         assert np.abs(image_slice.flatten() - expected_slice).max() < 0.01
 
     def test_stable_diffusion_inpaint_legacy_num_images_per_prompt(self):
@@ -295,10 +296,12 @@ class StableDiffusionInpaintLegacyPipelineFastTests(unittest.TestCase):
         scheduler = PNDMScheduler(skip_prk_steps=True)
         vae = self.dummy_vae
         bert = self.dummy_text_encoder
-        tokenizer = CLIPTokenizer.from_pretrained("hf-internal-testing/tiny-random-clip")
+        tokenizer = CLIPTokenizer.from_pretrained(
+            "hf-internal-testing/tiny-random-clip")
         image = self.dummy_image.cpu().transpose(perm=[0, 2, 3, 1])[0]
         init_image = Image.fromarray(np.uint8(image)).convert("RGB")
-        mask_image = Image.fromarray(np.uint8(image + 4)).convert("RGB").resize((32, 32))
+        mask_image = Image.fromarray(np.uint8(image + 4)).convert("RGB").resize(
+            (32, 32))
         sd_pipe = StableDiffusionInpaintPipelineLegacy(
             unet=unet,
             scheduler=scheduler,
@@ -306,18 +309,23 @@ class StableDiffusionInpaintLegacyPipelineFastTests(unittest.TestCase):
             text_encoder=bert,
             tokenizer=tokenizer,
             safety_checker=None,
-            feature_extractor=self.dummy_extractor,
-        )
+            feature_extractor=self.dummy_extractor, )
         sd_pipe.set_progress_bar_config(disable=None)
         prompt = "A painting of a squirrel eating a burger"
         images = sd_pipe(
-            prompt, num_inference_steps=2, output_type="np", image=init_image, mask_image=mask_image
-        ).images
+            prompt,
+            num_inference_steps=2,
+            output_type="np",
+            image=init_image,
+            mask_image=mask_image).images
         assert images.shape == (1, 32, 32, 3)
         batch_size = 2
         images = sd_pipe(
-            [prompt] * batch_size, num_inference_steps=2, output_type="np", image=init_image, mask_image=mask_image
-        ).images
+            [prompt] * batch_size,
+            num_inference_steps=2,
+            output_type="np",
+            image=init_image,
+            mask_image=mask_image).images
         assert images.shape == (batch_size, 32, 32, 3)
         num_images_per_prompt = 2
         images = sd_pipe(
@@ -326,8 +334,7 @@ class StableDiffusionInpaintLegacyPipelineFastTests(unittest.TestCase):
             output_type="np",
             image=init_image,
             mask_image=mask_image,
-            num_images_per_prompt=num_images_per_prompt,
-        ).images
+            num_images_per_prompt=num_images_per_prompt, ).images
         assert images.shape == (num_images_per_prompt, 32, 32, 3)
         batch_size = 2
         images = sd_pipe(
@@ -336,8 +343,7 @@ class StableDiffusionInpaintLegacyPipelineFastTests(unittest.TestCase):
             output_type="np",
             image=init_image,
             mask_image=mask_image,
-            num_images_per_prompt=num_images_per_prompt,
-        ).images
+            num_images_per_prompt=num_images_per_prompt, ).images
         assert images.shape == (batch_size * num_images_per_prompt, 32, 32, 3)
 
 
@@ -352,11 +358,9 @@ class StableDiffusionInpaintLegacyPipelineSlowTests(unittest.TestCase):
     def get_inputs(self, seed=0):
         generator = paddle.Generator().manual_seed(seed)
         init_image = load_image(
-            "https://paddlenlp.bj.bcebos.com/data/images/input_bench_image.png"
-        )
+            "https://paddlenlp.bj.bcebos.com/data/images/input_bench_image.png")
         mask_image = load_image(
-            "https://paddlenlp.bj.bcebos.com/data/images/input_bench_mask.png"
-        )
+            "https://paddlenlp.bj.bcebos.com/data/images/input_bench_mask.png")
         inputs = {
             "prompt": "A red cat sitting on a park bench",
             "image": init_image,
@@ -371,23 +375,22 @@ class StableDiffusionInpaintLegacyPipelineSlowTests(unittest.TestCase):
 
     def test_stable_diffusion_inpaint_legacy_pndm(self):
         pipe = StableDiffusionInpaintPipelineLegacy.from_pretrained(
-            "CompVis/stable-diffusion-v1-4", safety_checker=None
-        )
+            "CompVis/stable-diffusion-v1-4", safety_checker=None)
         pipe.set_progress_bar_config(disable=None)
         pipe.enable_attention_slicing()
         inputs = self.get_inputs()
         image = pipe(**inputs).images
         image_slice = image[0, 253:256, 253:256, -1].flatten()
         assert image.shape == (1, 512, 512, 3)
-        expected_slice = np.array(
-            [0.27226633, 0.29068208, 0.3450312, 0.21444553, 0.26328486, 0.34392387, 0.18026042, 0.24961185, 0.3214044]
-        )
+        expected_slice = np.array([
+            0.27226633, 0.29068208, 0.3450312, 0.21444553, 0.26328486,
+            0.34392387, 0.18026042, 0.24961185, 0.3214044
+        ])
         assert np.abs(expected_slice - image_slice).max() < 0.0001
-    
+
     def test_stable_diffusion_inpaint_legacy_batched(self):
         pipe = StableDiffusionInpaintPipelineLegacy.from_pretrained(
-            "CompVis/stable-diffusion-v1-4", safety_checker=None
-        )
+            "CompVis/stable-diffusion-v1-4", safety_checker=None)
         pipe.set_progress_bar_config(disable=None)
         pipe.enable_attention_slicing()
 
@@ -407,20 +410,21 @@ class StableDiffusionInpaintLegacyPipelineSlowTests(unittest.TestCase):
         image_slice_0 = image[0, 253:256, 253:256, -1].flatten()
         image_slice_1 = image[1, 253:256, 253:256, -1].flatten()
 
-        expected_slice_0 = np.array(
-            [0.27526367, 0.29158682, 0.35184938, 0.21504477, 0.26708275, 0.35169, 0.18185198, 0.2572803 , 0.32425082]
-        )
-        expected_slice_1 = np.array(
-            [0.        , 0.18929192, 0.7068148 , 0.07977328, 0.13444492, 0.5016247 , 0.49761847, 0.2830933 , 0.36412603] 
-        )
+        expected_slice_0 = np.array([
+            0.27526367, 0.29158682, 0.35184938, 0.21504477, 0.26708275, 0.35169,
+            0.18185198, 0.2572803, 0.32425082
+        ])
+        expected_slice_1 = np.array([
+            0., 0.18929192, 0.7068148, 0.07977328, 0.13444492, 0.5016247,
+            0.49761847, 0.2830933, 0.36412603
+        ])
 
         assert np.abs(expected_slice_0 - image_slice_0).max() < 1e-4
         assert np.abs(expected_slice_1 - image_slice_1).max() < 1e-4
 
     def test_stable_diffusion_inpaint_legacy_k_lms(self):
         pipe = StableDiffusionInpaintPipelineLegacy.from_pretrained(
-            "CompVis/stable-diffusion-v1-4", safety_checker=None
-        )
+            "CompVis/stable-diffusion-v1-4", safety_checker=None)
         pipe.scheduler = LMSDiscreteScheduler.from_config(pipe.scheduler.config)
         pipe.set_progress_bar_config(disable=None)
         pipe.enable_attention_slicing()
@@ -428,15 +432,17 @@ class StableDiffusionInpaintLegacyPipelineSlowTests(unittest.TestCase):
         image = pipe(**inputs).images
         image_slice = image[0, 253:256, 253:256, -1].flatten()
         assert image.shape == (1, 512, 512, 3)
-        expected_slice = np.array(
-            [0.29036117, 0.28907132, 0.32839334, 0.26510137, 0.2820784, 0.31148806, 0.29358387, 0.29515788, 0.28257304]
-        )
+        expected_slice = np.array([
+            0.29036117, 0.28907132, 0.32839334, 0.26510137, 0.2820784,
+            0.31148806, 0.29358387, 0.29515788, 0.28257304
+        ])
         assert np.abs(expected_slice - image_slice).max() < 0.0001
 
     def test_stable_diffusion_inpaint_legacy_intermediate_state(self):
         number_of_steps = 0
 
-        def callback_fn(step: int, timestep: int, latents: paddle.Tensor) -> None:
+        def callback_fn(step: int, timestep: int,
+                        latents: paddle.Tensor) -> None:
             callback_fn.has_been_called = True
             nonlocal number_of_steps
             number_of_steps += 1
@@ -444,19 +450,28 @@ class StableDiffusionInpaintLegacyPipelineSlowTests(unittest.TestCase):
                 latents = latents.detach().cpu().numpy()
                 assert latents.shape == (1, 4, 64, 64)
                 latents_slice = latents[0, -3:, -3:, -1]
-                expected_slice = np.array([-0.103, 1.415, -0.02197, -0.5103, -0.5903, 0.1953, 0.75, 0.3477, -1.356])
-                assert np.abs(latents_slice.flatten() - expected_slice).max() < 0.001
+                expected_slice = np.array([
+                    -0.103, 1.415, -0.02197, -0.5103, -0.5903, 0.1953, 0.75,
+                    0.3477, -1.356
+                ])
+                assert np.abs(latents_slice.flatten() - expected_slice).max(
+                ) < 0.001
             elif step == 2:
                 latents = latents.detach().cpu().numpy()
                 assert latents.shape == (1, 4, 64, 64)
                 latents_slice = latents[0, -3:, -3:, -1]
-                expected_slice = np.array([0.4802, 1.154, 0.628, 0.2322, 0.2593, -0.1455, 0.7075, -0.1617, -0.5615])
-                assert np.abs(latents_slice.flatten() - expected_slice).max() < 0.001
+                expected_slice = np.array([
+                    0.4802, 1.154, 0.628, 0.2322, 0.2593, -0.1455, 0.7075,
+                    -0.1617, -0.5615
+                ])
+                assert np.abs(latents_slice.flatten() - expected_slice).max(
+                ) < 0.001
 
         callback_fn.has_been_called = False
         pipe = StableDiffusionInpaintPipelineLegacy.from_pretrained(
-            "CompVis/stable-diffusion-v1-4", safety_checker=None, paddle_dtype=paddle.float16
-        )
+            "CompVis/stable-diffusion-v1-4",
+            safety_checker=None,
+            paddle_dtype=paddle.float16)
         pipe.set_progress_bar_config(disable=None)
         pipe.enable_attention_slicing()
         inputs = self.get_inputs()
@@ -494,17 +509,20 @@ class StableDiffusionInpaintLegacyPipelineNightlyTests(unittest.TestCase):
         return inputs
 
     def test_inpaint_pndm(self):
-        sd_pipe = StableDiffusionInpaintPipelineLegacy.from_pretrained("runwayml/stable-diffusion-v1-5")
+        sd_pipe = StableDiffusionInpaintPipelineLegacy.from_pretrained(
+            "runwayml/stable-diffusion-v1-5")
         sd_pipe
         sd_pipe.set_progress_bar_config(disable=None)
         inputs = self.get_inputs()
         image = sd_pipe(**inputs).images[0]
-        expected_image = np.array([[0.7330009, 0.80003107, 0.8268216], [0.73606366, 0.801595, 0.8470554]])
+        expected_image = np.array([[0.7330009, 0.80003107, 0.8268216],
+                                   [0.73606366, 0.801595, 0.8470554]])
         max_diff = np.abs(expected_image - image[0][0:2]).max()
         assert max_diff < 0.001
 
     def test_inpaint_ddim(self):
-        sd_pipe = StableDiffusionInpaintPipelineLegacy.from_pretrained("runwayml/stable-diffusion-v1-5")
+        sd_pipe = StableDiffusionInpaintPipelineLegacy.from_pretrained(
+            "runwayml/stable-diffusion-v1-5")
         sd_pipe.scheduler = DDIMScheduler.from_config(sd_pipe.scheduler.config)
         sd_pipe
         sd_pipe.set_progress_bar_config(disable=None)
@@ -513,29 +531,36 @@ class StableDiffusionInpaintLegacyPipelineNightlyTests(unittest.TestCase):
         expected_image = load_numpy(
             "https://huggingface.co/datasets/diffusers/test-arrays/resolve/main/stable_diffusion_inpaint_legacy/stable_diffusion_1_5_ddim.npy"
         )
-        expected_image = np.array([[0.7290994, 0.794852, 0.82096446], [0.7330909, 0.79727536, 0.8420528]])
+        expected_image = np.array([[0.7290994, 0.794852, 0.82096446],
+                                   [0.7330909, 0.79727536, 0.8420528]])
         max_diff = np.abs(expected_image - image[0][0:2]).max()
         assert max_diff < 0.001
 
     def test_inpaint_lms(self):
-        sd_pipe = StableDiffusionInpaintPipelineLegacy.from_pretrained("runwayml/stable-diffusion-v1-5")
-        sd_pipe.scheduler = LMSDiscreteScheduler.from_config(sd_pipe.scheduler.config)
+        sd_pipe = StableDiffusionInpaintPipelineLegacy.from_pretrained(
+            "runwayml/stable-diffusion-v1-5")
+        sd_pipe.scheduler = LMSDiscreteScheduler.from_config(
+            sd_pipe.scheduler.config)
         sd_pipe
         sd_pipe.set_progress_bar_config(disable=None)
         inputs = self.get_inputs()
         image = sd_pipe(**inputs).images[0]
-        expected_image = np.array([[0.74595624, 0.81757987, 0.84589916], [0.74728143, 0.81736475, 0.86543]])
+        expected_image = np.array([[0.74595624, 0.81757987, 0.84589916],
+                                   [0.74728143, 0.81736475, 0.86543]])
         max_diff = np.abs(expected_image - image[0][0:2]).max()
         assert max_diff < 0.001
 
     def test_inpaint_dpm(self):
-        sd_pipe = StableDiffusionInpaintPipelineLegacy.from_pretrained("runwayml/stable-diffusion-v1-5")
-        sd_pipe.scheduler = DPMSolverMultistepScheduler.from_config(sd_pipe.scheduler.config)
+        sd_pipe = StableDiffusionInpaintPipelineLegacy.from_pretrained(
+            "runwayml/stable-diffusion-v1-5")
+        sd_pipe.scheduler = DPMSolverMultistepScheduler.from_config(
+            sd_pipe.scheduler.config)
         sd_pipe
         sd_pipe.set_progress_bar_config(disable=None)
         inputs = self.get_inputs()
         inputs["num_inference_steps"] = 30
         image = sd_pipe(**inputs).images[0]
-        expected_image = np.array([[0.7310472, 0.7970823, 0.8231524], [0.7348697, 0.799358, 0.8439586]])
+        expected_image = np.array([[0.7310472, 0.7970823, 0.8231524],
+                                   [0.7348697, 0.799358, 0.8439586]])
         max_diff = np.abs(expected_image - image[0][0:2]).max()
         assert max_diff < 0.001
