@@ -30,8 +30,7 @@ from ppdiffusers import (
     PNDMScheduler,
     StableDiffusionPipeline,
     UNet2DConditionModel,
-    logging,
-)
+    logging, )
 from ppdiffusers.utils import load_numpy, nightly, slow
 from ppdiffusers.utils.testing_utils import CaptureLogger, require_paddle_gpu
 
@@ -56,15 +55,13 @@ class StableDiffusion2PipelineFastTests(PipelineTesterMixin, unittest.TestCase):
             up_block_types=("CrossAttnUpBlock2D", "UpBlock2D"),
             cross_attention_dim=32,
             attention_head_dim=(2, 4),
-            use_linear_projection=True,
-        )
+            use_linear_projection=True, )
         scheduler = DDIMScheduler(
             beta_start=0.00085,
             beta_end=0.012,
             beta_schedule="scaled_linear",
             clip_sample=False,
-            set_alpha_to_one=False,
-        )
+            set_alpha_to_one=False, )
         paddle.seed(0)
         vae = AutoencoderKL(
             block_out_channels=[32, 64],
@@ -73,8 +70,7 @@ class StableDiffusion2PipelineFastTests(PipelineTesterMixin, unittest.TestCase):
             down_block_types=["DownEncoderBlock2D", "DownEncoderBlock2D"],
             up_block_types=["UpDecoderBlock2D", "UpDecoderBlock2D"],
             latent_channels=4,
-            sample_size=128,
-        )
+            sample_size=128, )
         paddle.seed(0)
         text_encoder_config = CLIPTextConfig(
             bos_token_id=0,
@@ -87,10 +83,10 @@ class StableDiffusion2PipelineFastTests(PipelineTesterMixin, unittest.TestCase):
             pad_token_id=1,
             vocab_size=1000,
             hidden_act="gelu",
-            projection_dim=512,
-        )
+            projection_dim=512, )
         text_encoder = CLIPTextModel(text_encoder_config).eval()
-        tokenizer = CLIPTokenizer.from_pretrained("hf-internal-testing/tiny-random-clip")
+        tokenizer = CLIPTokenizer.from_pretrained(
+            "hf-internal-testing/tiny-random-clip")
         components = {
             "unet": unet,
             "scheduler": scheduler,
@@ -122,9 +118,10 @@ class StableDiffusion2PipelineFastTests(PipelineTesterMixin, unittest.TestCase):
         image = sd_pipe(**inputs).images
         image_slice = image[0, -3:, -3:, -1]
         assert image.shape == (1, 64, 64, 3)
-        expected_slice = np.array(
-            [0.3505131, 0.36318004, 0.39201266, 0.12107915, 0.27704653, 0.40363187, 0.09379572, 0.16225743, 0.36048344]
-        )
+        expected_slice = np.array([
+            0.3505131, 0.36318004, 0.39201266, 0.12107915, 0.27704653,
+            0.40363187, 0.09379572, 0.16225743, 0.36048344
+        ])
         assert np.abs(image_slice.flatten() - expected_slice).max() < 0.01
 
     def test_stable_diffusion_pndm(self):
@@ -136,77 +133,86 @@ class StableDiffusion2PipelineFastTests(PipelineTesterMixin, unittest.TestCase):
         image = sd_pipe(**inputs).images
         image_slice = image[0, -3:, -3:, -1]
         assert image.shape == (1, 64, 64, 3)
-        expected_slice = np.array(
-            [0.25144678, 0.35438284, 0.3613463, 0.11020249, 0.3101831, 0.42739886, 0.1142821, 0.17371863, 0.35148838]
-        )
+        expected_slice = np.array([
+            0.25144678, 0.35438284, 0.3613463, 0.11020249, 0.3101831,
+            0.42739886, 0.1142821, 0.17371863, 0.35148838
+        ])
         assert np.abs(image_slice.flatten() - expected_slice).max() < 0.01
 
     def test_stable_diffusion_k_lms(self):
         components = self.get_dummy_components()
-        components["scheduler"] = LMSDiscreteScheduler.from_config(components["scheduler"].config)
+        components["scheduler"] = LMSDiscreteScheduler.from_config(components[
+            "scheduler"].config)
         sd_pipe = StableDiffusionPipeline(**components)
         sd_pipe.set_progress_bar_config(disable=None)
         inputs = self.get_dummy_inputs()
         image = sd_pipe(**inputs).images
         image_slice = image[0, -3:, -3:, -1]
         assert image.shape == (1, 64, 64, 3)
-        expected_slice = np.array(
-            [0.3676631, 0.38155898, 0.4023114, 0.11294425, 0.2891888, 0.40432304, 0.08882684, 0.1466648, 0.33633134]
-        )
+        expected_slice = np.array([
+            0.3676631, 0.38155898, 0.4023114, 0.11294425, 0.2891888, 0.40432304,
+            0.08882684, 0.1466648, 0.33633134
+        ])
         assert np.abs(image_slice.flatten() - expected_slice).max() < 0.01
 
     def test_stable_diffusion_k_euler_ancestral(self):
         components = self.get_dummy_components()
-        components["scheduler"] = EulerAncestralDiscreteScheduler.from_config(components["scheduler"].config)
+        components["scheduler"] = EulerAncestralDiscreteScheduler.from_config(
+            components["scheduler"].config)
         sd_pipe = StableDiffusionPipeline(**components)
         sd_pipe.set_progress_bar_config(disable=None)
         inputs = self.get_dummy_inputs()
         image = sd_pipe(**inputs).images
         image_slice = image[0, -3:, -3:, -1]
         assert image.shape == (1, 64, 64, 3)
-        expected_slice = np.array(
-            [0.36797395, 0.38137895, 0.40199342, 0.11330777, 0.2886864, 0.40422022, 0.08929691, 0.14658183, 0.3363046]
-        )
+        expected_slice = np.array([
+            0.36797395, 0.38137895, 0.40199342, 0.11330777, 0.2886864,
+            0.40422022, 0.08929691, 0.14658183, 0.3363046
+        ])
         assert np.abs(image_slice.flatten() - expected_slice).max() < 0.01
 
     def test_stable_diffusion_k_euler(self):
         components = self.get_dummy_components()
-        components["scheduler"] = EulerDiscreteScheduler.from_config(components["scheduler"].config)
+        components["scheduler"] = EulerDiscreteScheduler.from_config(components[
+            "scheduler"].config)
         sd_pipe = StableDiffusionPipeline(**components)
         sd_pipe.set_progress_bar_config(disable=None)
         inputs = self.get_dummy_inputs()
         image = sd_pipe(**inputs).images
         image_slice = image[0, -3:, -3:, -1]
         assert image.shape == (1, 64, 64, 3)
-        expected_slice = np.array(
-            [0.36766386, 0.3815591, 0.40231153, 0.11294428, 0.28918856, 0.40432304, 0.08882678, 0.14666462, 0.3363313]
-        )
+        expected_slice = np.array([
+            0.36766386, 0.3815591, 0.40231153, 0.11294428, 0.28918856,
+            0.40432304, 0.08882678, 0.14666462, 0.3363313
+        ])
         assert np.abs(image_slice.flatten() - expected_slice).max() < 0.01
 
     def test_stable_diffusion_long_prompt(self):
         components = self.get_dummy_components()
-        components["scheduler"] = LMSDiscreteScheduler.from_config(components["scheduler"].config)
+        components["scheduler"] = LMSDiscreteScheduler.from_config(components[
+            "scheduler"].config)
         sd_pipe = StableDiffusionPipeline(**components)
         sd_pipe.set_progress_bar_config(disable=None)
         do_classifier_free_guidance = True
         negative_prompt = None
         num_images_per_prompt = 1
-        logger = logging.get_logger("ppdiffusers.pipelines.stable_diffusion.pipeline_stable_diffusion")
+        logger = logging.get_logger(
+            "ppdiffusers.pipelines.stable_diffusion.pipeline_stable_diffusion")
         prompt = 25 * "@"
         with CaptureLogger(logger) as cap_logger_3:
             text_embeddings_3 = sd_pipe._encode_prompt(
-                prompt, num_images_per_prompt, do_classifier_free_guidance, negative_prompt
-            )
+                prompt, num_images_per_prompt, do_classifier_free_guidance,
+                negative_prompt)
         prompt = 100 * "@"
         with CaptureLogger(logger) as cap_logger:
             text_embeddings = sd_pipe._encode_prompt(
-                prompt, num_images_per_prompt, do_classifier_free_guidance, negative_prompt
-            )
+                prompt, num_images_per_prompt, do_classifier_free_guidance,
+                negative_prompt)
         negative_prompt = "Hello"
         with CaptureLogger(logger) as cap_logger_2:
             text_embeddings_2 = sd_pipe._encode_prompt(
-                prompt, num_images_per_prompt, do_classifier_free_guidance, negative_prompt
-            )
+                prompt, num_images_per_prompt, do_classifier_free_guidance,
+                negative_prompt)
         assert text_embeddings_3.shape == text_embeddings_2.shape == text_embeddings.shape
         assert text_embeddings.shape[1] == 77
         assert cap_logger.out == cap_logger_2.out
@@ -237,35 +243,47 @@ class StableDiffusion2PipelineSlowTests(unittest.TestCase):
         return inputs
 
     def test_stable_diffusion_default_ddim(self):
-        pipe = StableDiffusionPipeline.from_pretrained("stabilityai/stable-diffusion-2-base")
+        pipe = StableDiffusionPipeline.from_pretrained(
+            "stabilityai/stable-diffusion-2-base")
         pipe.set_progress_bar_config(disable=None)
         inputs = self.get_inputs()
         image = pipe(**inputs).images
         image_slice = image[0, -3:, -3:, -1].flatten()
         assert image.shape == (1, 512, 512, 3)
-        expected_slice = np.array([0.49493, 0.47896, 0.40798, 0.54214, 0.53212, 0.48202, 0.47656, 0.46329, 0.48506])
+        expected_slice = np.array([
+            0.49493, 0.47896, 0.40798, 0.54214, 0.53212, 0.48202, 0.47656,
+            0.46329, 0.48506
+        ])
         assert np.abs(image_slice - expected_slice).max() < 0.0001
 
     def test_stable_diffusion_pndm(self):
-        pipe = StableDiffusionPipeline.from_pretrained("stabilityai/stable-diffusion-2-base")
+        pipe = StableDiffusionPipeline.from_pretrained(
+            "stabilityai/stable-diffusion-2-base")
         pipe.scheduler = PNDMScheduler.from_config(pipe.scheduler.config)
         pipe.set_progress_bar_config(disable=None)
         inputs = self.get_inputs()
         image = pipe(**inputs).images
         image_slice = image[0, -3:, -3:, -1].flatten()
         assert image.shape == (1, 512, 512, 3)
-        expected_slice = np.array([0.49493, 0.47896, 0.40798, 0.54214, 0.53212, 0.48202, 0.47656, 0.46329, 0.48506])
+        expected_slice = np.array([
+            0.49493, 0.47896, 0.40798, 0.54214, 0.53212, 0.48202, 0.47656,
+            0.46329, 0.48506
+        ])
         assert np.abs(image_slice - expected_slice).max() < 0.0001
 
     def test_stable_diffusion_k_lms(self):
-        pipe = StableDiffusionPipeline.from_pretrained("stabilityai/stable-diffusion-2-base")
+        pipe = StableDiffusionPipeline.from_pretrained(
+            "stabilityai/stable-diffusion-2-base")
         pipe.scheduler = LMSDiscreteScheduler.from_config(pipe.scheduler.config)
         pipe.set_progress_bar_config(disable=None)
         inputs = self.get_inputs()
         image = pipe(**inputs).images
         image_slice = image[0, -3:, -3:, -1].flatten()
         assert image.shape == (1, 512, 512, 3)
-        expected_slice = np.array([0.1044, 0.13115, 0.111, 0.10141, 0.1144, 0.07215, 0.11332, 0.09693, 0.10006])
+        expected_slice = np.array([
+            0.1044, 0.13115, 0.111, 0.10141, 0.1144, 0.07215, 0.11332, 0.09693,
+            0.10006
+        ])
         assert np.abs(image_slice - expected_slice).max() < 0.0001
 
     # def test_stable_diffusion_attention_slicing(self):
@@ -288,7 +306,8 @@ class StableDiffusion2PipelineSlowTests(unittest.TestCase):
     def test_stable_diffusion_text2img_intermediate_state(self):
         number_of_steps = 0
 
-        def callback_fn(step: int, timestep: int, latents: paddle.Tensor) -> None:
+        def callback_fn(step: int, timestep: int,
+                        latents: paddle.Tensor) -> None:
             callback_fn.has_been_called = True
             nonlocal number_of_steps
             number_of_steps += 1
@@ -296,21 +315,26 @@ class StableDiffusion2PipelineSlowTests(unittest.TestCase):
                 latents = latents.detach().cpu().numpy()
                 assert latents.shape == (1, 4, 64, 64)
                 latents_slice = latents[0, -3:, -3:, -1]
-                expected_slice = np.array(
-                    [-0.3862, -0.4507, -1.1729, 0.0686, -1.1045, 0.7124, -1.8301, 0.1903, 1.2773]
-                )
-                assert np.abs(latents_slice.flatten() - expected_slice).max() < 0.05
+                expected_slice = np.array([
+                    -0.3862, -0.4507, -1.1729, 0.0686, -1.1045, 0.7124, -1.8301,
+                    0.1903, 1.2773
+                ])
+                assert np.abs(latents_slice.flatten() - expected_slice).max(
+                ) < 0.05
             elif step == 2:
                 latents = latents.detach().cpu().numpy()
                 assert latents.shape == (1, 4, 64, 64)
                 latents_slice = latents[0, -3:, -3:, -1]
-                expected_slice = np.array([0.272, -0.1863, -0.7383, -0.5029, -0.7534, 0.397, -0.7646, 0.4468, 1.2686])
-                assert np.abs(latents_slice.flatten() - expected_slice).max() < 0.05
+                expected_slice = np.array([
+                    0.272, -0.1863, -0.7383, -0.5029, -0.7534, 0.397, -0.7646,
+                    0.4468, 1.2686
+                ])
+                assert np.abs(latents_slice.flatten() - expected_slice).max(
+                ) < 0.05
 
         callback_fn.has_been_called = False
         pipe = StableDiffusionPipeline.from_pretrained(
-            "stabilityai/stable-diffusion-2-base", paddle_dtype=paddle.float16
-        )
+            "stabilityai/stable-diffusion-2-base", paddle_dtype=paddle.float16)
         pipe.set_progress_bar_config(disable=None)
         pipe.enable_attention_slicing()
         inputs = self.get_inputs(dtype="float16")
@@ -342,7 +366,8 @@ class StableDiffusion2PipelineNightlyTests(unittest.TestCase):
         return inputs
 
     def test_stable_diffusion_2_0_default_ddim(self):
-        sd_pipe = StableDiffusionPipeline.from_pretrained("stabilityai/stable-diffusion-2-base")
+        sd_pipe = StableDiffusionPipeline.from_pretrained(
+            "stabilityai/stable-diffusion-2-base")
         sd_pipe.set_progress_bar_config(disable=None)
         inputs = self.get_inputs()
         image = sd_pipe(**inputs).images[0]
@@ -353,7 +378,8 @@ class StableDiffusion2PipelineNightlyTests(unittest.TestCase):
         assert max_diff < 0.01
 
     def test_stable_diffusion_2_1_default_pndm(self):
-        sd_pipe = StableDiffusionPipeline.from_pretrained("stabilityai/stable-diffusion-2-1-base")
+        sd_pipe = StableDiffusionPipeline.from_pretrained(
+            "stabilityai/stable-diffusion-2-1-base")
         sd_pipe.set_progress_bar_config(disable=None)
         inputs = self.get_inputs()
         image = sd_pipe(**inputs).images[0]
@@ -364,7 +390,8 @@ class StableDiffusion2PipelineNightlyTests(unittest.TestCase):
         assert max_diff < 0.01
 
     def test_stable_diffusion_ddim(self):  # not pass
-        sd_pipe = StableDiffusionPipeline.from_pretrained("stabilityai/stable-diffusion-2-1-base")
+        sd_pipe = StableDiffusionPipeline.from_pretrained(
+            "stabilityai/stable-diffusion-2-1-base")
         sd_pipe.scheduler = DDIMScheduler.from_config(sd_pipe.scheduler.config)
         sd_pipe.set_progress_bar_config(disable=None)
         inputs = self.get_inputs()
@@ -376,8 +403,10 @@ class StableDiffusion2PipelineNightlyTests(unittest.TestCase):
         assert max_diff < 0.01
 
     def test_stable_diffusion_lms(self):
-        sd_pipe = StableDiffusionPipeline.from_pretrained("stabilityai/stable-diffusion-2-1-base")
-        sd_pipe.scheduler = LMSDiscreteScheduler.from_config(sd_pipe.scheduler.config)
+        sd_pipe = StableDiffusionPipeline.from_pretrained(
+            "stabilityai/stable-diffusion-2-1-base")
+        sd_pipe.scheduler = LMSDiscreteScheduler.from_config(
+            sd_pipe.scheduler.config)
         sd_pipe.set_progress_bar_config(disable=None)
         inputs = self.get_inputs()
         image = sd_pipe(**inputs).images[0]
@@ -388,8 +417,10 @@ class StableDiffusion2PipelineNightlyTests(unittest.TestCase):
         assert max_diff < 0.01
 
     def test_stable_diffusion_euler(self):
-        sd_pipe = StableDiffusionPipeline.from_pretrained("stabilityai/stable-diffusion-2-1-base")
-        sd_pipe.scheduler = EulerDiscreteScheduler.from_config(sd_pipe.scheduler.config)
+        sd_pipe = StableDiffusionPipeline.from_pretrained(
+            "stabilityai/stable-diffusion-2-1-base")
+        sd_pipe.scheduler = EulerDiscreteScheduler.from_config(
+            sd_pipe.scheduler.config)
         sd_pipe.set_progress_bar_config(disable=None)
         inputs = self.get_inputs()
         image = sd_pipe(**inputs).images[0]
@@ -400,8 +431,10 @@ class StableDiffusion2PipelineNightlyTests(unittest.TestCase):
         assert max_diff < 0.01
 
     def test_stable_diffusion_dpm(self):  # not pass
-        sd_pipe = StableDiffusionPipeline.from_pretrained("stabilityai/stable-diffusion-2-1-base")
-        sd_pipe.scheduler = DPMSolverMultistepScheduler.from_config(sd_pipe.scheduler.config)
+        sd_pipe = StableDiffusionPipeline.from_pretrained(
+            "stabilityai/stable-diffusion-2-1-base")
+        sd_pipe.scheduler = DPMSolverMultistepScheduler.from_config(
+            sd_pipe.scheduler.config)
         sd_pipe.set_progress_bar_config(disable=None)
         inputs = self.get_inputs()
         inputs["num_inference_steps"] = 25
