@@ -24,8 +24,7 @@ from ppdiffusers import (
     AutoencoderKL,
     DDIMScheduler,
     StableDiffusionAttendAndExcitePipeline,
-    UNet2DConditionModel,
-)
+    UNet2DConditionModel, )
 from ppdiffusers.utils import load_numpy, slow
 from ppdiffusers.utils.testing_utils import require_paddle_gpu
 
@@ -33,7 +32,8 @@ from ..pipeline_params import TEXT_TO_IMAGE_BATCH_PARAMS, TEXT_TO_IMAGE_PARAMS
 from ..test_pipelines_common import PipelineTesterMixin
 
 
-class StableDiffusionAttendAndExcitePipelineFastTests(PipelineTesterMixin, unittest.TestCase):
+class StableDiffusionAttendAndExcitePipelineFastTests(PipelineTesterMixin,
+                                                      unittest.TestCase):
     pipeline_class = StableDiffusionAttendAndExcitePipeline
     test_attention_slicing = False
     params = TEXT_TO_IMAGE_PARAMS
@@ -51,15 +51,13 @@ class StableDiffusionAttendAndExcitePipelineFastTests(PipelineTesterMixin, unitt
             up_block_types=("CrossAttnUpBlock2D", "UpBlock2D"),
             cross_attention_dim=32,
             attention_head_dim=(2, 4),
-            use_linear_projection=True,
-        )
+            use_linear_projection=True, )
         scheduler = DDIMScheduler(
             beta_start=0.00085,
             beta_end=0.012,
             beta_schedule="scaled_linear",
             clip_sample=False,
-            set_alpha_to_one=False,
-        )
+            set_alpha_to_one=False, )
         paddle.seed(0)
         vae = AutoencoderKL(
             block_out_channels=[32, 64],
@@ -68,8 +66,7 @@ class StableDiffusionAttendAndExcitePipelineFastTests(PipelineTesterMixin, unitt
             down_block_types=["DownEncoderBlock2D", "DownEncoderBlock2D"],
             up_block_types=["UpDecoderBlock2D", "UpDecoderBlock2D"],
             latent_channels=4,
-            sample_size=128,
-        )
+            sample_size=128, )
         paddle.seed(0)
         text_encoder_config = CLIPTextConfig(
             bos_token_id=0,
@@ -82,10 +79,10 @@ class StableDiffusionAttendAndExcitePipelineFastTests(PipelineTesterMixin, unitt
             pad_token_id=1,
             vocab_size=1000,
             hidden_act="gelu",
-            projection_dim=512,
-        )
+            projection_dim=512, )
         text_encoder = CLIPTextModel(text_encoder_config).eval()
-        tokenizer = CLIPTokenizer.from_pretrained("hf-internal-testing/tiny-random-clip")
+        tokenizer = CLIPTokenizer.from_pretrained(
+            "hf-internal-testing/tiny-random-clip")
         components = {
             "unet": unet,
             "scheduler": scheduler,
@@ -108,7 +105,9 @@ class StableDiffusionAttendAndExcitePipelineFastTests(PipelineTesterMixin, unitt
             "guidance_scale": 6.0,
             "output_type": "numpy",
             "max_iter_to_alter": 2,
-            "thresholds": {(0): 0.7},
+            "thresholds": {
+                (0): 0.7
+            },
         }
         return inputs
 
@@ -120,19 +119,17 @@ class StableDiffusionAttendAndExcitePipelineFastTests(PipelineTesterMixin, unitt
         image = pipe(**inputs).images
         image_slice = image[0, -3:, -3:, -1]
         self.assertEqual(image.shape, (1, 64, 64, 3))
-        expected_slice = np.array(
-            [
-                0.33271241188049316,
-                0.3123358190059662,
-                0.44427454471588135,
-                0.08615309000015259,
-                0.26107650995254517,
-                0.4551312029361725,
-                0.06545555591583252,
-                0.1626836657524109,
-                0.3982071578502655,
-            ]
-        )
+        expected_slice = np.array([
+            0.33271241188049316,
+            0.3123358190059662,
+            0.44427454471588135,
+            0.08615309000015259,
+            0.26107650995254517,
+            0.4551312029361725,
+            0.06545555591583252,
+            0.1626836657524109,
+            0.3982071578502655,
+        ])
         max_diff = np.abs(image_slice.flatten() - expected_slice).max()
         self.assertLessEqual(max_diff, 0.001)
 
@@ -152,8 +149,9 @@ class StableDiffusionAttendAndExcitePipelineIntegrationTests(unittest.TestCase):
     def test_attend_and_excite_fp16(self):
         generator = paddle.Generator().manual_seed(seed=51)
         pipe = StableDiffusionAttendAndExcitePipeline.from_pretrained(
-            "CompVis/stable-diffusion-v1-4", safety_checker=None, paddle_dtype=paddle.float16
-        )
+            "CompVis/stable-diffusion-v1-4",
+            safety_checker=None,
+            paddle_dtype=paddle.float16)
 
         prompt = "a painting of an elephant with glasses"
         token_indices = [5, 7]
@@ -164,8 +162,7 @@ class StableDiffusionAttendAndExcitePipelineIntegrationTests(unittest.TestCase):
             generator=generator,
             num_inference_steps=5,
             max_iter_to_alter=5,
-            output_type="numpy",
-        ).images[0]
+            output_type="numpy", ).images[0]
         expected_image = load_numpy(
             "https://huggingface.co/datasets/hf-internal-testing/diffusers-images/resolve/main/attend-and-excite/elephant_glasses.npy"
         )
