@@ -27,8 +27,7 @@ from ppdiffusers import (
     DDIMScheduler,
     DDPMScheduler,
     StableDiffusionUpscalePipeline,
-    UNet2DConditionModel,
-)
+    UNet2DConditionModel, )
 from ppdiffusers.utils import floats_tensor, load_image, slow
 from ppdiffusers.utils.testing_utils import require_paddle_gpu
 
@@ -44,7 +43,8 @@ class StableDiffusionUpscalePipelineFastTests(unittest.TestCase):
         batch_size = 1
         num_channels = 3
         sizes = (32, 32)
-        image = floats_tensor((batch_size, num_channels) + sizes, rng=random.Random(0))
+        image = floats_tensor(
+            (batch_size, num_channels) + sizes, rng=random.Random(0))
         return image
 
     @property
@@ -56,15 +56,16 @@ class StableDiffusionUpscalePipelineFastTests(unittest.TestCase):
             sample_size=32,
             in_channels=7,
             out_channels=4,
-            down_block_types=("DownBlock2D", "CrossAttnDownBlock2D", "CrossAttnDownBlock2D"),
-            up_block_types=("CrossAttnUpBlock2D", "CrossAttnUpBlock2D", "UpBlock2D"),
+            down_block_types=("DownBlock2D", "CrossAttnDownBlock2D",
+                              "CrossAttnDownBlock2D"),
+            up_block_types=("CrossAttnUpBlock2D", "CrossAttnUpBlock2D",
+                            "UpBlock2D"),
             cross_attention_dim=32,
             # SD2-specific config below
             attention_head_dim=8,
             use_linear_projection=True,
             only_cross_attention=(True, True, False),
-            num_class_embeds=100,
-        )
+            num_class_embeds=100, )
         return model
 
     @property
@@ -74,10 +75,13 @@ class StableDiffusionUpscalePipelineFastTests(unittest.TestCase):
             block_out_channels=[32, 32, 64],
             in_channels=3,
             out_channels=3,
-            down_block_types=["DownEncoderBlock2D", "DownEncoderBlock2D", "DownEncoderBlock2D"],
-            up_block_types=["UpDecoderBlock2D", "UpDecoderBlock2D", "UpDecoderBlock2D"],
-            latent_channels=4,
-        )
+            down_block_types=[
+                "DownEncoderBlock2D", "DownEncoderBlock2D", "DownEncoderBlock2D"
+            ],
+            up_block_types=[
+                "UpDecoderBlock2D", "UpDecoderBlock2D", "UpDecoderBlock2D"
+            ],
+            latent_channels=4, )
         return model
 
     @property
@@ -95,8 +99,7 @@ class StableDiffusionUpscalePipelineFastTests(unittest.TestCase):
             vocab_size=1000,
             # SD2-specific config below
             hidden_act="gelu",
-            projection_dim=512,
-        )
+            projection_dim=512, )
         return CLIPTextModel(config).eval()
 
     def test_stable_diffusion_upscale(self):
@@ -105,9 +108,11 @@ class StableDiffusionUpscalePipelineFastTests(unittest.TestCase):
         scheduler = DDIMScheduler(prediction_type="v_prediction")
         vae = self.dummy_vae
         text_encoder = self.dummy_text_encoder
-        tokenizer = CLIPTokenizer.from_pretrained("hf-internal-testing/tiny-random-clip")
+        tokenizer = CLIPTokenizer.from_pretrained(
+            "hf-internal-testing/tiny-random-clip")
         image = self.dummy_image.cpu().transpose(perm=[0, 2, 3, 1])[0]
-        low_res_image = Image.fromarray(np.uint8(image)).convert("RGB").resize((64, 64))
+        low_res_image = Image.fromarray(np.uint8(image)).convert("RGB").resize(
+            (64, 64))
         sd_pipe = StableDiffusionUpscalePipeline(
             unet=unet,
             low_res_scheduler=low_res_scheduler,
@@ -115,8 +120,7 @@ class StableDiffusionUpscalePipelineFastTests(unittest.TestCase):
             vae=vae,
             text_encoder=text_encoder,
             tokenizer=tokenizer,
-            max_noise_level=350,
-        )
+            max_noise_level=350, )
         sd_pipe.set_progress_bar_config(disable=None)
         prompt = "A painting of a squirrel eating a burger"
         generator = paddle.Generator().manual_seed(0)
@@ -127,8 +131,7 @@ class StableDiffusionUpscalePipelineFastTests(unittest.TestCase):
             guidance_scale=6.0,
             noise_level=20,
             num_inference_steps=2,
-            output_type="np",
-        )
+            output_type="np", )
         image = output.images
         generator = paddle.Generator().manual_seed(0)
         image_from_tuple = sd_pipe(
@@ -139,17 +142,19 @@ class StableDiffusionUpscalePipelineFastTests(unittest.TestCase):
             noise_level=20,
             num_inference_steps=2,
             output_type="np",
-            return_dict=False,
-        )[0]
+            return_dict=False, )[0]
         image_slice = image[0, -3:, -3:, -1]
         image_from_tuple_slice = image_from_tuple[0, -3:, -3:, -1]
         expected_height_width = low_res_image.size[0] * 4
-        assert image.shape == (1, expected_height_width, expected_height_width, 3)
-        expected_slice = np.array(
-            [0.0, 0.0, 0.3616839, 0.0, 0.04877859, 0.59195685, 0.23902711, 0.00838843, 0.5172206]
-        )
+        assert image.shape == (1, expected_height_width, expected_height_width,
+                               3)
+        expected_slice = np.array([
+            0.0, 0.0, 0.3616839, 0.0, 0.04877859, 0.59195685, 0.23902711,
+            0.00838843, 0.5172206
+        ])
         assert np.abs(image_slice.flatten() - expected_slice).max() < 0.01
-        assert np.abs(image_from_tuple_slice.flatten() - expected_slice).max() < 0.01
+        assert np.abs(image_from_tuple_slice.flatten() - expected_slice).max(
+        ) < 0.01
 
     def test_stable_diffusion_upscale_batch(self):
         unet = self.dummy_cond_unet_upscale
@@ -157,9 +162,11 @@ class StableDiffusionUpscalePipelineFastTests(unittest.TestCase):
         scheduler = DDIMScheduler(prediction_type="v_prediction")
         vae = self.dummy_vae
         text_encoder = self.dummy_text_encoder
-        tokenizer = CLIPTokenizer.from_pretrained("hf-internal-testing/tiny-random-clip")
+        tokenizer = CLIPTokenizer.from_pretrained(
+            "hf-internal-testing/tiny-random-clip")
         image = self.dummy_image.cpu().transpose(perm=[0, 2, 3, 1])[0]
-        low_res_image = Image.fromarray(np.uint8(image)).convert("RGB").resize((64, 64))
+        low_res_image = Image.fromarray(np.uint8(image)).convert("RGB").resize(
+            (64, 64))
         sd_pipe = StableDiffusionUpscalePipeline(
             unet=unet,
             low_res_scheduler=low_res_scheduler,
@@ -167,8 +174,7 @@ class StableDiffusionUpscalePipelineFastTests(unittest.TestCase):
             vae=vae,
             text_encoder=text_encoder,
             tokenizer=tokenizer,
-            max_noise_level=350,
-        )
+            max_noise_level=350, )
         sd_pipe.set_progress_bar_config(disable=None)
         prompt = "A painting of a squirrel eating a burger"
         output = sd_pipe(
@@ -177,8 +183,7 @@ class StableDiffusionUpscalePipelineFastTests(unittest.TestCase):
             guidance_scale=6.0,
             noise_level=20,
             num_inference_steps=2,
-            output_type="np",
-        )
+            output_type="np", )
         image = output.images
         assert image.shape[0] == 2
         generator = paddle.Generator().manual_seed(0)
@@ -190,8 +195,7 @@ class StableDiffusionUpscalePipelineFastTests(unittest.TestCase):
             guidance_scale=6.0,
             noise_level=20,
             num_inference_steps=2,
-            output_type="np",
-        )
+            output_type="np", )
         image = output.images
         assert image.shape[0] == 2
 
@@ -202,9 +206,11 @@ class StableDiffusionUpscalePipelineFastTests(unittest.TestCase):
         scheduler = DDIMScheduler(prediction_type="v_prediction")
         vae = self.dummy_vae
         text_encoder = self.dummy_text_encoder
-        tokenizer = CLIPTokenizer.from_pretrained("hf-internal-testing/tiny-random-clip")
+        tokenizer = CLIPTokenizer.from_pretrained(
+            "hf-internal-testing/tiny-random-clip")
         image = self.dummy_image.cpu().transpose(perm=[0, 2, 3, 1])[0]
-        low_res_image = Image.fromarray(np.uint8(image)).convert("RGB").resize((64, 64))
+        low_res_image = Image.fromarray(np.uint8(image)).convert("RGB").resize(
+            (64, 64))
         unet = unet.to(dtype=paddle.float16)
         text_encoder = text_encoder.to(dtype=paddle.float16)
         sd_pipe = StableDiffusionUpscalePipeline(
@@ -214,16 +220,19 @@ class StableDiffusionUpscalePipelineFastTests(unittest.TestCase):
             vae=vae,
             text_encoder=text_encoder,
             tokenizer=tokenizer,
-            max_noise_level=350,
-        )
+            max_noise_level=350, )
         sd_pipe.set_progress_bar_config(disable=None)
         prompt = "A painting of a squirrel eating a burger"
         generator = paddle.Generator().manual_seed(0)
         image = sd_pipe(
-            [prompt], image=low_res_image, generator=generator, num_inference_steps=2, output_type="np"
-        ).images
+            [prompt],
+            image=low_res_image,
+            generator=generator,
+            num_inference_steps=2,
+            output_type="np").images
         expected_height_width = low_res_image.size[0] * 4
-        assert image.shape == (1, expected_height_width, expected_height_width, 3)
+        assert image.shape == (1, expected_height_width, expected_height_width,
+                               3)
 
 
 @slow
@@ -248,7 +257,8 @@ class StableDiffusionUpscalePipelineIntegrationTests(unittest.TestCase):
         pipe.enable_attention_slicing()
         prompt = "a cat sitting on a park bench"
         generator = paddle.Generator().manual_seed(0)
-        output = pipe(prompt=prompt, image=image, generator=generator, output_type="np")
+        output = pipe(
+            prompt=prompt, image=image, generator=generator, output_type="np")
         image = output.images[0]
         assert image.shape == (512, 512, 3)
         image = image[-3:, -3:, -1]
