@@ -48,18 +48,16 @@ class PipelineTesterMixin:
     # Canonical parameters that are passed to `__call__` regardless
     # of the type of pipeline. They are always optional and have common
     # sense default values.
-    required_optional_params = frozenset(
-        [
-            "num_inference_steps",
-            "num_images_per_prompt",
-            "generator",
-            "latents",
-            "output_type",
-            "return_dict",
-            "callback",
-            "callback_steps",
-        ]
-    )
+    required_optional_params = frozenset([
+        "num_inference_steps",
+        "num_images_per_prompt",
+        "generator",
+        "latents",
+        "output_type",
+        "return_dict",
+        "callback",
+        "callback_steps",
+    ])
     num_inference_steps_args = ["num_inference_steps"]
     test_attention_slicing = True
     test_cpu_offload = False
@@ -97,8 +95,7 @@ class PipelineTesterMixin:
             "do not make modifications to the existing common sets of arguments. I.e. a text to image pipeline "
             "with non-configurable height and width arguments should set the attribute as "
             "`params = TEXT_TO_IMAGE_PARAMS - {'height', 'width'}`. "
-            "See existing pipeline tests for reference."
-        )
+            "See existing pipeline tests for reference.")
 
     @property
     def batch_params(self) -> frozenset:
@@ -111,8 +108,7 @@ class PipelineTesterMixin:
             "do not make modifications to the existing common sets of batch arguments. I.e. a text to "
             "image pipeline `negative_prompt` is not batched should set the attribute as "
             "`batch_params = TEXT_TO_IMAGE_BATCH_PARAMS - {'negative_prompt'}`. "
-            "See existing pipeline tests for reference."
-        )
+            "See existing pipeline tests for reference.")
 
     def tearDown(self):
         super().tearDown()
@@ -127,7 +123,8 @@ class PipelineTesterMixin:
         output = pipe(**inputs)[0]
         with tempfile.TemporaryDirectory() as tmpdir:
             pipe.save_pretrained(tmpdir, to_diffusers=False)
-            pipe_loaded = self.pipeline_class.from_pretrained(tmpdir, from_diffusers=False)
+            pipe_loaded = self.pipeline_class.from_pretrained(
+                tmpdir, from_diffusers=False)
             pipe_loaded.set_progress_bar_config(disable=None)
         inputs = self.get_dummy_inputs()
         output_loaded = pipe_loaded(**inputs)[0]
@@ -136,8 +133,8 @@ class PipelineTesterMixin:
 
     def test_pipeline_call_signature(self):
         self.assertTrue(
-            hasattr(self.pipeline_class, "__call__"), f"{self.pipeline_class} should have a `__call__` method"
-        )
+            hasattr(self.pipeline_class, "__call__"),
+            f"{self.pipeline_class} should have a `__call__` method")
 
         parameters = inspect.signature(self.pipeline_class.__call__).parameters
 
@@ -149,7 +146,9 @@ class PipelineTesterMixin:
 
         parameters = set(parameters.keys())
         parameters.remove("self")
-        parameters.discard("kwargs")  # kwargs can be added if arguments of pipeline call function are deprecated
+        parameters.discard(
+            "kwargs"
+        )  # kwargs can be added if arguments of pipeline call function are deprecated
 
         remaining_required_parameters = set()
 
@@ -177,8 +176,9 @@ class PipelineTesterMixin:
         self._test_inference_batch_consistent(batch_sizes=batch_sizes)
 
     def _test_inference_batch_consistent(
-        self, batch_sizes=[2, 4, 13], additional_params_copy_to_batched_inputs=["num_inference_steps"]
-    ):
+            self,
+            batch_sizes=[2, 4, 13],
+            additional_params_copy_to_batched_inputs=["num_inference_steps"]):
         components = self.get_dummy_components()
         pipe = self.pipeline_class(**components)
         pipe.set_progress_bar_config(disable=None)
@@ -191,7 +191,10 @@ class PipelineTesterMixin:
                 if name in self.batch_params:
                     if name == "prompt":
                         len_prompt = len(value)
-                        batched_inputs[name] = [value[: len_prompt // i] for i in range(1, batch_size + 1)]
+                        batched_inputs[name] = [
+                            value[:len_prompt // i]
+                            for i in range(1, batch_size + 1)
+                        ]
                         batched_inputs[name][-1] = 2000 * "very long"
                     else:
                         batched_inputs[name] = batch_size * [value]
@@ -217,14 +220,13 @@ class PipelineTesterMixin:
         self._test_inference_batch_single_identical(batch_size=batch_size)
 
     def _test_inference_batch_single_identical(
-        self,
-        batch_size=3,
-        test_max_difference=None,
-        test_mean_pixel_difference=None,
-        relax_max_difference=False,
-        expected_max_diff=1e-4,
-        additional_params_copy_to_batched_inputs=["num_inference_steps"],
-    ):
+            self,
+            batch_size=3,
+            test_max_difference=None,
+            test_mean_pixel_difference=None,
+            relax_max_difference=False,
+            expected_max_diff=1e-4,
+            additional_params_copy_to_batched_inputs=["num_inference_steps"], ):
 
         components = self.get_dummy_components()
         pipe = self.pipeline_class(**components)
@@ -238,14 +240,18 @@ class PipelineTesterMixin:
             if name in self.batch_params:
                 if name == "prompt":
                     len_prompt = len(value)
-                    batched_inputs[name] = [value[: len_prompt // i] for i in range(1, batch_size + 1)]
+                    batched_inputs[name] = [
+                        value[:len_prompt // i]
+                        for i in range(1, batch_size + 1)
+                    ]
                     batched_inputs[name][-1] = 2000 * "very long"
                 else:
                     batched_inputs[name] = batch_size * [value]
             elif name == "batch_size":
                 batched_inputs[name] = batch_size
             elif name == "generator":
-                batched_inputs[name] = [self.get_generator(i) for i in range(batch_size)]
+                batched_inputs[
+                    name] = [self.get_generator(i) for i in range(batch_size)]
             else:
                 batched_inputs[name] = value
 
@@ -286,7 +292,8 @@ class PipelineTesterMixin:
         init_components = self.get_dummy_components()
         pipe = self.pipeline_class(**init_components)
         self.assertTrue(hasattr(pipe, "components"))
-        self.assertTrue(set(pipe.components.keys()) == set(init_components.keys()))
+        self.assertTrue(
+            set(pipe.components.keys()) == set(init_components.keys()))
 
     def test_float16_inference(self, expected_max_diff=1e-2):
         self._test_float16_inference(expected_max_diff)
@@ -301,7 +308,9 @@ class PipelineTesterMixin:
         output = pipe(**self.get_dummy_inputs())[0]
         output_fp16 = pipe_fp16(**self.get_dummy_inputs())[0]
         max_diff = np.abs(to_np(output) - to_np(output_fp16)).max()
-        self.assertLess(max_diff, expected_max_diff, "The outputs of the fp16 and fp32 pipelines are too different.")
+        self.assertLess(
+            max_diff, expected_max_diff,
+            "The outputs of the fp16 and fp32 pipelines are too different.")
 
     def test_save_load_float16(self, expected_max_diff=1e-2):
         self._test_save_load_float16(expected_max_diff)
@@ -349,7 +358,8 @@ class PipelineTesterMixin:
         with tempfile.TemporaryDirectory() as tmpdir:
             # TODO check this
             pipe.save_pretrained(tmpdir, to_diffusers=False)
-            pipe_loaded = self.pipeline_class.from_pretrained(tmpdir, from_diffusers=False)
+            pipe_loaded = self.pipeline_class.from_pretrained(
+                tmpdir, from_diffusers=False)
             pipe_loaded.set_progress_bar_config(disable=None)
         for optional_component in pipe._optional_components:
             self.assertTrue(
@@ -382,19 +392,26 @@ class PipelineTesterMixin:
         pipe = self.pipeline_class(**components)
         pipe.set_progress_bar_config(disable=None)
 
-        model_dtypes = [component.dtype for component in components.values() if hasattr(component, "dtype")]
+        model_dtypes = [
+            component.dtype for component in components.values()
+            if hasattr(component, "dtype")
+        ]
         self.assertTrue(all(dtype == paddle.float32 for dtype in model_dtypes))
 
         pipe.to(paddle_dtype=paddle.float16)
-        model_dtypes = [component.dtype for component in components.values() if hasattr(component, "dtype")]
+        model_dtypes = [
+            component.dtype for component in components.values()
+            if hasattr(component, "dtype")
+        ]
         self.assertTrue(all(dtype == paddle.float16 for dtype in model_dtypes))
 
     def test_attention_slicing_forward_pass(self):
         self._test_attention_slicing_forward_pass()
 
-    def _test_attention_slicing_forward_pass(
-        self, test_max_difference=True, test_mean_pixel_difference=True, expected_max_diff=5e-3
-    ):
+    def _test_attention_slicing_forward_pass(self,
+                                             test_max_difference=True,
+                                             test_mean_pixel_difference=True,
+                                             expected_max_diff=5e-3):
         if not self.test_attention_slicing:
             return
 
@@ -407,17 +424,24 @@ class PipelineTesterMixin:
         inputs = self.get_dummy_inputs()
         output_with_slicing = pipe(**inputs)[0]
         if test_max_difference:
-            max_diff = np.abs(to_np(output_with_slicing) - to_np(output_without_slicing)).max()
-            self.assertLess(max_diff, expected_max_diff, "Attention slicing should not affect the inference results")
+            max_diff = np.abs(
+                to_np(output_with_slicing) - to_np(output_without_slicing)).max(
+                )
+            self.assertLess(
+                max_diff, expected_max_diff,
+                "Attention slicing should not affect the inference results")
         if test_mean_pixel_difference:
-            assert_mean_pixel_difference(output_with_slicing[0], output_without_slicing[0])
+            assert_mean_pixel_difference(output_with_slicing[0],
+                                         output_without_slicing[0])
 
     def test_xformers_attention_forwardGenerator_pass(self):
         self._test_xformers_attention_forwardGenerator_pass()
 
     def _test_xformers_attention_forwardGenerator_pass(
-        self, test_max_difference=True, test_mean_pixel_difference=True, expected_max_diff=1e-2
-    ):
+            self,
+            test_max_difference=True,
+            test_mean_pixel_difference=True,
+            expected_max_diff=1e-2):
         if not self.test_xformers_attention:
             return
         components = self.get_dummy_components()
@@ -433,10 +457,14 @@ class PipelineTesterMixin:
                 output_with_xformers = output_with_xformers.numpy()
             if hasattr(output_without_xformers, "numpy"):
                 output_without_xformers = output_without_xformers.numpy()
-            max_diff = np.abs(output_with_xformers - output_without_xformers).max()
-            self.assertLess(max_diff, expected_max_diff, "XFormers attention should not affect the inference results")
+            max_diff = np.abs(output_with_xformers -
+                              output_without_xformers).max()
+            self.assertLess(
+                max_diff, expected_max_diff,
+                "XFormers attention should not affect the inference results")
         if test_mean_pixel_difference:
-            assert_mean_pixel_difference(output_with_xformers[0], output_without_xformers[0])
+            assert_mean_pixel_difference(output_with_xformers[0],
+                                         output_without_xformers[0])
 
     def test_progress_bar(self):
         components = self.get_dummy_components()
@@ -448,12 +476,13 @@ class PipelineTesterMixin:
             max_steps = re.search("/(.*?) ", stderr).group(1)
             self.assertTrue(max_steps is not None and len(max_steps) > 0)
             self.assertTrue(
-                f"{max_steps}/{max_steps}" in stderr, "Progress bar should be enabled and stopped at the max step"
-            )
+                f"{max_steps}/{max_steps}" in stderr,
+                "Progress bar should be enabled and stopped at the max step")
         pipe.set_progress_bar_config(disable=True)
         with io.StringIO() as stderr, contextlib.redirect_stderr(stderr):
             _ = pipe(**inputs)
-            self.assertTrue(stderr.getvalue() == "", "Progress bar should be disabled")
+            self.assertTrue(stderr.getvalue() == "",
+                            "Progress bar should be disabled")
 
     def test_num_images_per_prompt(self):
         sig = inspect.signature(self.pipeline_class.__call__)
@@ -476,13 +505,17 @@ class PipelineTesterMixin:
                     if key in self.batch_params:
                         inputs[key] = batch_size * [inputs[key]]
 
-                images = pipe(**inputs, num_images_per_prompt=num_images_per_prompt).images
+                images = pipe(
+                    **inputs,
+                    num_images_per_prompt=num_images_per_prompt).images
 
                 assert images.shape[0] == batch_size * num_images_per_prompt
 
 
 def assert_mean_pixel_difference(image, expected_image):
-    image = np.asarray(DiffusionPipeline.numpy_to_pil(image)[0], dtype=np.float32)
-    expected_image = np.asarray(DiffusionPipeline.numpy_to_pil(expected_image)[0], dtype=np.float32)
+    image = np.asarray(
+        DiffusionPipeline.numpy_to_pil(image)[0], dtype=np.float32)
+    expected_image = np.asarray(
+        DiffusionPipeline.numpy_to_pil(expected_image)[0], dtype=np.float32)
     avg_diff = np.abs(image - expected_image).mean()
     assert avg_diff < 10, f"Error image deviates {avg_diff} pixels on average"
