@@ -24,8 +24,7 @@ from ppdiffusers import (
     DDIMScheduler,
     DPMSolverMultistepScheduler,
     TextToVideoSDPipeline,
-    UNet3DConditionModel,
-)
+    UNet3DConditionModel, )
 from ppdiffusers.utils import load_numpy, slow
 
 from ..pipeline_params import TEXT_TO_IMAGE_BATCH_PARAMS, TEXT_TO_IMAGE_PARAMS
@@ -36,9 +35,10 @@ class TextToVideoSDPipelineFastTests(PipelineTesterMixin, unittest.TestCase):
     pipeline_class = TextToVideoSDPipeline
     params = TEXT_TO_IMAGE_PARAMS
     batch_params = TEXT_TO_IMAGE_BATCH_PARAMS
-    required_optional_params = frozenset(
-        ["num_inference_steps", "generator", "latents", "return_dict", "callback", "callback_steps"]
-    )
+    required_optional_params = frozenset([
+        "num_inference_steps", "generator", "latents", "return_dict",
+        "callback", "callback_steps"
+    ])
 
     def get_dummy_components(self):
         paddle.seed(0)
@@ -48,18 +48,18 @@ class TextToVideoSDPipelineFastTests(PipelineTesterMixin, unittest.TestCase):
             sample_size=32,
             in_channels=4,
             out_channels=4,
-            down_block_types=("CrossAttnDownBlock3D", "CrossAttnDownBlock3D", "CrossAttnDownBlock3D", "DownBlock3D"),
-            up_block_types=("UpBlock3D", "CrossAttnUpBlock3D", "CrossAttnUpBlock3D", "CrossAttnUpBlock3D"),
+            down_block_types=("CrossAttnDownBlock3D", "CrossAttnDownBlock3D",
+                              "CrossAttnDownBlock3D", "DownBlock3D"),
+            up_block_types=("UpBlock3D", "CrossAttnUpBlock3D",
+                            "CrossAttnUpBlock3D", "CrossAttnUpBlock3D"),
             cross_attention_dim=32,
-            attention_head_dim=4,
-        )
+            attention_head_dim=4, )
         scheduler = DDIMScheduler(
             beta_start=0.00085,
             beta_end=0.012,
             beta_schedule="scaled_linear",
             clip_sample=False,
-            set_alpha_to_one=False,
-        )
+            set_alpha_to_one=False, )
         paddle.seed(0)
         vae = AutoencoderKL(
             block_out_channels=[32, 64],
@@ -68,8 +68,7 @@ class TextToVideoSDPipelineFastTests(PipelineTesterMixin, unittest.TestCase):
             down_block_types=["DownEncoderBlock2D", "DownEncoderBlock2D"],
             up_block_types=["UpDecoderBlock2D", "UpDecoderBlock2D"],
             latent_channels=4,
-            sample_size=128,
-        )
+            sample_size=128, )
         paddle.seed(0)
         text_encoder_config = CLIPTextConfig(
             bos_token_id=0,
@@ -82,10 +81,10 @@ class TextToVideoSDPipelineFastTests(PipelineTesterMixin, unittest.TestCase):
             pad_token_id=1,
             vocab_size=1000,
             hidden_act="gelu",
-            projection_dim=512,
-        )
+            projection_dim=512, )
         text_encoder = CLIPTextModel(text_encoder_config)
-        tokenizer = CLIPTokenizer.from_pretrained("hf-internal-testing/tiny-random-clip")
+        tokenizer = CLIPTokenizer.from_pretrained(
+            "hf-internal-testing/tiny-random-clip")
         components = {
             "unet": unet,
             "scheduler": scheduler,
@@ -122,20 +121,28 @@ class TextToVideoSDPipelineFastTests(PipelineTesterMixin, unittest.TestCase):
         assert np.abs(image_slice.flatten() - expected_slice).max() < 0.01
 
     def test_xformers_attention_forwardGenerator_pass(self):
-        self._test_xformers_attention_forwardGenerator_pass(test_mean_pixel_difference=False)
+        self._test_xformers_attention_forwardGenerator_pass(
+            test_mean_pixel_difference=False)
 
     def test_attention_slicing_forward_pass(self):
-        self._test_attention_slicing_forward_pass(test_mean_pixel_difference=False)
+        self._test_attention_slicing_forward_pass(
+            test_mean_pixel_difference=False)
 
-    @unittest.skip(reason="Batching needs to be properly figured out first for this pipeline.")
+    @unittest.skip(
+        reason="Batching needs to be properly figured out first for this pipeline."
+    )
     def test_inference_batch_consistent(self):
         pass
 
-    @unittest.skip(reason="Batching needs to be properly figured out first for this pipeline.")
+    @unittest.skip(
+        reason="Batching needs to be properly figured out first for this pipeline."
+    )
     def test_inference_batch_single_identical(self):
         pass
 
-    @unittest.skip(reason="`num_images_per_prompt` argument is not supported for this pipeline.")
+    @unittest.skip(
+        reason="`num_images_per_prompt` argument is not supported for this pipeline."
+    )
     def test_num_images_per_prompt(self):
         pass
 
@@ -147,13 +154,19 @@ class TextToVideoSDPipelineSlowTests(unittest.TestCase):
             "https://huggingface.co/datasets/hf-internal-testing/diffusers-images/resolve/main/text_to_video/video.npy"
         )
         pipe = TextToVideoSDPipeline.from_pretrained(
-            "damo-vilab/text-to-video-ms-1.7b", from_hf_hub=True, from_diffusers=True
-        )
-        pipe.scheduler = DPMSolverMultistepScheduler.from_config(pipe.scheduler.config)
+            "damo-vilab/text-to-video-ms-1.7b",
+            from_hf_hub=True,
+            from_diffusers=True)
+        pipe.scheduler = DPMSolverMultistepScheduler.from_config(
+            pipe.scheduler.config)
         pipe = pipe
         prompt = "Spiderman is surfing"
         generator = paddle.Generator().manual_seed(0)
-        video_frames = pipe(prompt, generator=generator, num_inference_steps=25, output_type="pd").frames
+        video_frames = pipe(
+            prompt,
+            generator=generator,
+            num_inference_steps=25,
+            output_type="pd").frames
         video = video_frames.cpu().numpy()
         assert np.abs(expected_video - video).mean() < 0.8
 
@@ -161,10 +174,15 @@ class TextToVideoSDPipelineSlowTests(unittest.TestCase):
         expected_video = load_numpy(
             "https://huggingface.co/datasets/hf-internal-testing/diffusers-images/resolve/main/text_to_video/video_2step.npy"
         )
-        pipe = TextToVideoSDPipeline.from_pretrained("damo-vilab/text-to-video-ms-1.7b")
+        pipe = TextToVideoSDPipeline.from_pretrained(
+            "damo-vilab/text-to-video-ms-1.7b")
         pipe = pipe
         prompt = "Spiderman is surfing"
         generator = paddle.Generator().manual_seed(0)
-        video_frames = pipe(prompt, generator=generator, num_inference_steps=2, output_type="pd").frames
+        video_frames = pipe(
+            prompt,
+            generator=generator,
+            num_inference_steps=2,
+            output_type="pd").frames
         video = video_frames.cpu().numpy()
         assert np.abs(expected_video - video).mean() < 0.8
