@@ -33,7 +33,8 @@ class VersatileDiffusionDualGuidedPipelineIntegrationTests(unittest.TestCase):
         paddle.device.cuda.empty_cache()
 
     def test_remove_unused_weights_save_load(self):
-        pipe = VersatileDiffusionDualGuidedPipeline.from_pretrained("shi-labs/versatile-diffusion")
+        pipe = VersatileDiffusionDualGuidedPipeline.from_pretrained(
+            "shi-labs/versatile-diffusion")
         pipe.remove_unused_weights()
         pipe.set_progress_bar_config(disable=None)
         second_prompt = load_image(
@@ -47,11 +48,11 @@ class VersatileDiffusionDualGuidedPipelineIntegrationTests(unittest.TestCase):
             generator=generator,
             guidance_scale=7.5,
             num_inference_steps=2,
-            output_type="numpy",
-        ).images
+            output_type="numpy", ).images
         with tempfile.TemporaryDirectory() as tmpdirname:
             pipe.save_pretrained(tmpdirname)
-            pipe = VersatileDiffusionDualGuidedPipeline.from_pretrained(tmpdirname, from_diffusers=False)
+            pipe = VersatileDiffusionDualGuidedPipeline.from_pretrained(
+                tmpdirname, from_diffusers=False)
         pipe.set_progress_bar_config(disable=None)
         generator = paddle.Generator().manual_seed(0)
         new_image = pipe(
@@ -61,12 +62,13 @@ class VersatileDiffusionDualGuidedPipelineIntegrationTests(unittest.TestCase):
             generator=generator,
             guidance_scale=7.5,
             num_inference_steps=2,
-            output_type="numpy",
-        ).images
-        assert np.abs(image - new_image).sum() < 1e-05, "Models don't have the same forward pass"
+            output_type="numpy", ).images
+        assert np.abs(image - new_image).sum(
+        ) < 1e-05, "Models don't have the same forward pass"
 
     def test_inference_dual_guided(self):
-        pipe = VersatileDiffusionDualGuidedPipeline.from_pretrained("shi-labs/versatile-diffusion")
+        pipe = VersatileDiffusionDualGuidedPipeline.from_pretrained(
+            "shi-labs/versatile-diffusion")
         pipe.remove_unused_weights()
         pipe.set_progress_bar_config(disable=None)
         first_prompt = "cyberpunk 2077"
@@ -81,21 +83,18 @@ class VersatileDiffusionDualGuidedPipelineIntegrationTests(unittest.TestCase):
             generator=generator,
             guidance_scale=7.5,
             num_inference_steps=50,
-            output_type="numpy",
-        ).images
+            output_type="numpy", ).images
         image_slice = image[0, 253:256, 253:256, -1]
         assert image.shape == (1, 512, 512, 3)
-        expected_slice = np.array(
-            [
-                0.01500076,
-                0.01142624,
-                0.01418972,
-                0.01518875,
-                0.01114869,
-                0.01190853,
-                0.02978998,
-                0.02376354,
-                0.02396089,
-            ]
-        )
+        expected_slice = np.array([
+            0.01500076,
+            0.01142624,
+            0.01418972,
+            0.01518875,
+            0.01114869,
+            0.01190853,
+            0.02978998,
+            0.02376354,
+            0.02396089,
+        ])
         assert np.abs(image_slice.flatten() - expected_slice).max() < 0.01
